MODULE SFIT_MACROS

  !+
  !  Define variables and subroutines required to treat macros in SFIT
  !
  !  
  !
  !-

  ! Macro definition
  INTEGER, PARAMETER  :: MAC__MAX = 32
  CHARACTER(LEN=1024) :: MAC__COM = ' ' ! holder for macro command line
  CHARACTER(LEN=256)  :: MAC__KEY     ! holder for macro command or keyword
  CHARACTER(LEN=1024) :: MAC__STO(MAC__MAX) ! holder for macros
  CHARACTER(LEN=16)   :: MAC__NAM(MAC__MAX) ! holder for macro names
  INTEGER  :: MAC__LOCS = 0  ! macro string locator
  INTEGER  :: MAC__LENS = 0  ! macro string length
  INTEGER  :: MAC__LEN  = 0  ! macro total length
  INTEGER  :: MAC__NMAC = 0  ! number of stored macros
  INTEGER  :: IMAC, NMAC    ! macro counters + pointers

  !  Explicit Subroutine interfaces
  INTERFACE

    SUBROUTINE KEY_COM (PARSTR, KPROMPT, KSEP, KUNIT, KECHO, KSTAT)
      CHARACTER, INTENT(INOUT)        :: PARSTR*(*)  ! (Given and Returned)
      CHARACTER, INTENT(IN), OPTIONAL :: KPROMPT*(*) ! (Given).
      CHARACTER, INTENT(IN), OPTIONAL :: KSEP*(*)    ! (Given).
      INTEGER, INTENT(IN), OPTIONAL   :: KUNIT       ! (Given).
      INTEGER, INTENT(IN), OPTIONAL   :: KECHO       ! (Given).
      INTEGER, INTENT(OUT), OPTIONAL  :: KSTAT       ! (Returned).
    END SUBROUTINE KEY_COM

  END INTERFACE



CONTAINS


  SUBROUTINE SFIT_DEF_MACRO ( MAC__NAME, COMMAND, NREAD, NECHO )

    !+
    !  Define a macro called MAC__NAME
    !-

    ! Subroutine arguments
    CHARACTER(LEN=*)   :: MAC__NAME    ! name for macro
    CHARACTER(LEN=*)   :: COMMAND      ! command line
    INTEGER            :: NREAD        ! logical unit for read
    INTEGER            :: NECHO        ! flag to echo input

    !.

    CALL STR_LEN ( MAC__NAME, MAC__LENS )

    ! give it a number; replace old macro if duplicate
    NMAC = 0
    IF ( MAC__NMAC > 0 ) THEN 
    FIND_MACRO: DO IMAC = 1,MAC__NMAC
      IF ( MAC__NAME(1:MAC__LENS) == MAC__NAM(IMAC)(1:MAC__LENS)  ) THEN 
        CALL STR_ERR ( 'sfit : macro ', ' overwriting '//MAC__NAME(1:MAC__LENS) )
        NMAC = IMAC
        EXIT FIND_MACRO
      ! too many macros
      ELSEIF ( IMAC == MAC__MAX ) THEN
        CALL STR_ERR ( 'sfit : macro ', ' too many macros ' )
        CALL STR_NULL ( COMMAND )
        RETURN
      END IF
    END DO FIND_MACRO
    ENDIF

    ! macro did not exist, assign it to next entry in macro table
    IF ( NMAC == 0 ) THEN
      MAC__NMAC = MAC__NMAC + 1
      NMAC = MAC__NMAC
    ENDIF

    ! now give it a name
    MAC__NAM(NMAC) = MAC__NAME

    ! transfer remainder of command to macro holder
    MAC__COM = COMMAND

    ! reset the macro length to 0  
    MAC__LEN = 0
    BUILD_MACRO: DO 

      !  Get macro command line
      CALL KEY_COM ( MAC__COM, 'macro>', ';', NREAD, NECHO )
      CALL STR_LCASE ( MAC__COM )

      ! Find length of line
      CALL STR_LEN ( MAC__COM, MAC__LENS )

      !  Scan for end
      CALL STR_LOC ( MAC__COM, 'end', MAC__LOCS )

      IF ( MAC__LOCS == 0 ) THEN
        MAC__STO(NMAC)(MAC__LEN+1:MAC__LEN+MAC__LENS) = MAC__COM(1:MAC__LENS)
        MAC__STO(NMAC)(MAC__LEN+1+MAC__LENS:MAC__LEN+MAC__LENS+3) = ' ; '
        MAC__LEN = MAC__LEN+MAC__LENS+3
        CALL STR_NULL ( MAC__COM )
      ELSE
        MAC__STO(NMAC)(MAC__LEN+1:MAC__LEN+MAC__LOCS-1) = MAC__COM(1:MAC__LOCS-1)
        MAC__LEN = MAC__LEN+MAC__LOCS-1
        CALL STR_NULL ( MAC__COM )
        EXIT BUILD_MACRO
      END IF
    END DO BUILD_MACRO

  END SUBROUTINE SFIT_DEF_MACRO


  SUBROUTINE SFIT_RUN_MACRO  ( MAC__NAME, COMMAND, NECHO )

    CHARACTER(LEN=*)   :: MAC__NAME     ! name for macro
    CHARACTER(LEN=*)   :: COMMAND      ! command line
    INTEGER            :: NECHO        ! flag to echo macro at runtime

    INTEGER            :: LS

    CALL STR_LEN ( MAC__NAME, MAC__LENS )

    ! locate the macro in the dicionary
    NMAC = 0
    FIND_MACRO: DO IMAC = 1,MAC__NMAC
      IF ( MAC__NAME(1:MAC__LENS) == MAC__NAM(IMAC)(1:MAC__LENS) ) THEN 
        NMAC = IMAC
        EXIT FIND_MACRO
      END IF
    END DO FIND_MACRO

    ! substitute macro back into command 
    IF ( NMAC /= 0 ) THEN
      COMMAND = MAC__STO(NMAC)

      CALL STR_LEN ( COMMAND, LS )
      IF ( NECHO > 1 ) CALL STR_TEXT ( 'macro> '// &
           MAC__NAM(IMAC)(1:MAC__LENS)//' :'//COMMAND(1:LS) )

      ! cannot find the macro, give up
    ELSE
      CALL STR_ERR ( 'SFIT_RUN_MACRO', ' macro not found ' )
      CALL STR_NULL ( COMMAND )
      RETURN 
    END IF

  END SUBROUTINE SFIT_RUN_MACRO


END MODULE SFIT_MACROS
