
LTE codes transfer to SUN UNIX machine - August 1992
----------------------------------------------------

The transfer was undertaken by Gediminas Reimeris, who was also
reponsible for setting up the directory structure and writing 
command scripts etc. He also made a number of changes to the codes
to remove non-standard FORTRAN and make them compatible with
the SUN operating system. All these changes are described
in /home/model/LTE/INFO/lte_tran.t.

During the implementation, it was decided to undertake a
thorough review of the codes and this is described below.

The description is as follows
   1. Changes to COMMON blocks and CONSTANTS
   2. Changes to existing SUBROUTINES/FUNCTIONS.
   3. New SUBROUTINES/FUNCTIONS
   4. Changes to PROGRAMS
   5. Archived PROGRAMS/SUBROUTINES/FUNCTIONS
   6. Remaining problem areas
   7. Tests against existing codes
   

1. Changes to COMMON blocks and CONSTANTS
-----------------------------------------

    1. Four new parameters were defined and the others increased as follows
    
       KD  - 50             Maximum number of depth points
       KI  - 30             Maximum number of elements in lines
       KL  - 2000           Maximum number of lines
       KW  - 10000          Maximum number of wavelength points
       KA  - 100            Maximum number of abundances in SYNT
       KV  - 5              Maximum number of microturbulences in SYNT
       KHE - 50             Maximum number of helium diffuse lines

    2. COMMON/WORKS/ was expanded to include an integer array IWORK(KW)
    
    3. Stream NTEMP removed from COMMON as no longer required


2. Changes to SUBROUTINES/FUNCTIONS
-----------------------------------

  ATABUND -    Sets abundances in SYNT to cosmic; reads in microturbulences
 
               Significant rewrite but no fundimental changes.
              


  ATDATA -     Reads atomic and line data from lines_def.d or user file
     
               Changed to include pointers to minor elements
               INA, IP, ICL, IAR - note last (not IA) to avoid 
               confusion with integer counters.
               Change required to improve output from ATSCAN.
                


  ATHEI -      Reads in atomic data for neutral helium diffuse lines.
 
               No changes.


  ATHEII -     Reads in atomic data for ionized helium
 
               No changes


  ATSCAN -     Sets up linelist, atomic data, wavelengths etc. in SYNT

               Complete rewrite to improve readibility.
               Significant changes include
                a. Improved wavelength grids
                b. Automatic search for hydrogen line
                   Only ONE line included
                c. Automatic search for diffuse helium lines
                d. Output to disc improved
               Current parameters should allow about 100A
               to be synthesised.


     
  ATSYNT -     Either reads in previous SYNT data or calls ATSCAN

               Small changes - code no longer checks for first entry



  AVLOL -      Avrett-Loeser solution of transfer equation

               Subroutines PARABEL, EXPI, RELERR split out.
               No other changes.



  COMPOS -     Calculates ANORM, AMU and fractional populations

               Significant rewrite - routine now calculates ANORM.
               
               NOTE: on entry AHE is He/H ratio - on exit it is
               fractional number of helium atoms.



  ELPE -       Calculates electron pressure for hot hydrogen rich star

               Some changes - now checks for zero or negative first
               estimate of the electron pressure - rweritten to remove
               arithmetic IFs.



  EQUIV -      Calculates equivalent widths and normalised fluxes

               Normalisation of continuum flux changed for
               asymmetric profile.



  EXPI -       Called by AVLOL

               No changes



  EXPINT -     Exponential integral

               No changes



  F_INTEGRAL - Integrand for flux integration

               No changes



  FEAUTRIER -  Feautrier solution of transfer equation

               Constants removed in CALL statements



  GEN -        Integrates pressure structure

               Comment card changes



  HE_II -      Calculates He II line profiles

               No changes



  HEIDIF -     Calculates HeI diffuse line profiles

               In doppler width calculation NSP cahnged to IHE
               to remove problems error during synthesis calculation



  HESEARCH -   Finds HeI diffuse lines and sets up wavelength scale in SYNT
  
               Significant rewrite - entered automatically by ATSCAN 
               and does not stop if no lines found.
               Improved wavelength grid.
                              


  HETYPE -     Checks for type of helium line

               Minor changes



  HGRID -      Sets up wavelength grid for hydrogen line in SYNT
  
               Significant rewrite - entered automatically by ATSCAN.
               Improved wavelength grid.



  HSEARCH -    Finds hydrogen line for SYNT
  
               Some changes - does not stop if no line found.
               Searches in order Halpha, beta...epsilon with
               only the first line found.



  HSTARK -     Normalised hydrogen line profiles

               No changes




  I_INTEGRAL - Integrand for specific intensity integral

               No changes



  INGRAT -     Simpsons rule integration called by INTEG_AVLO

               No changes



  INTEG -      Calls appropriate integration routine

               Call to INTEG_FEAUTRIER (NSOURCE.EQ.3)
               not available - minor changes



  INTEG_AVLO - Avrett-Loeser solution of transfer equation

               Subroutine calls changed from numeric to
               variable arguments




  INTEG_FEA..- Feautrier solution of transfer equation

               No changes



  INTEG_PLANCK Solution of transfer equation for Planckian Source function

               No changes



  LHEI -       Neutral diffuse helium line opacity

               Some changes - now uses partition functions rather
               than ground state degeneracies.




  LHEII -      Ionized helium line opacity

               Minor changes - uses ground state degeneracies for 
               partition functions - should not cause serious errors.




  LHI -        Hydrogen line opacity

               Call to NAG routine changed so as not to contain
               constants - Debug statements added.
               Uses ground state degeneracies for partition functions - 
               should not cause serious errors.



  LIN_OP -     Identify NMODE and species for line opacity calculation

               Shortened but no significant changes.



  LMETAL -     Metal/non-diffuse helium line opacities

               Minor changes - NMODE=1 case included



  LSYNT -      Line opacity for SYNT calculations

               Minor changes - partition functions included



  MODEL_ATM -  Reads in model atmosphere

               Some changes
                 1. Remove calculation of ANORM for hydrogen rich
                    models - now in COMPOS
                 2. Writes out He/H for hydrogen rich models.



  OPAC   -     Calls appropriate opacity package

               Comment card changes


  OPHEI etc. - Explicit COMMON blocks replaced by COMMON_OPAC
               where required.


  OUTDIP -     Output of results to DIPSO file

               Small changes to header data - HEADER is
               now written as an internal stream



  OUTDIS -     Output of results to disc file

               Small changes for hydrogen, diffuse and ionized
               helium output



  OUTTER -     Output of results to terminal

               Small changes for hydrogen, diffuse and ionized
               helium output



  PARABEL -    Called by AVLOL

               No changes



  PLANCK -     Calculates Planck function

               No changes



  POLY   -     Quadratic interpolation/extrapolation

               Some changes - arithmetic IFs removed
               Checked with test data



  QAS -        Called by partition function routines

               Changed to REAL*8 function to be compatible
               with UH, UHE, UC, UN - also moved to Kiel
               opacity directory to overcome linking problem



  RELERR -     Called by AVLOL

               No changes



  SFLUX  -     Calculates surface fluxes

               Debug output removed
               New version from CSJ using COMMON_ALL


  TRANSFER -   Called by FEAUTRIER

               Constants removed from CALL statements



  U -          Calculates partition functions

               Change to all for QAS being REAL*8 function



  VCS -        Calculates Vidal et al hydrogen line profiles

               New version from CSJ to prevent extrapolation
               and using COMMON_ALL



  VOIGT -      Calculates Voigt function

               Comment Card changes




  WAVEG -      Sets up wavelength grid for isolated lines/blends

               Minor changes - NMODE=1 case included



  WHOLE -      Main subroutine

               For NMODE=1 output suppressed




  OPAQUB -     Calcualates continuous opacity using QUB routines

               Calculation of fractional populations of silicon
               and magnesium corrected


3. New SUBROUTINES/FUNCTIONS
----------------------------

  DIPS_EXT -   Produces extention for DIPSOS files

  OUTSPC   -   Formatted output for subsequent DIPSO input




4. Changes to PROGRAMS
----------------------

  ATHEII_TEST - Tests routine ATHEII

                Minor changes moved to TEST



  ATLAS -       Reformat ATLAS6/9 output

                Significant rewrite



  GENERATE -    Generates new model atmospheres

                Minor changes



  HEI_FORMAT -  Reformat He I and H I data

                Moved to ARCHIVE



  HEII_TEST -   Tests routine HE_II

                Minor changes moved to TEST



  MAIN -        Main program for SPECTRUM

                Stream NTEMP removed and output of HEADER improved

                Iteration to calculate abundance from equivalent
                width included

  MOD_CHECK -   Tests OPAC and ELPE routines

                Minor changes moved to TEST



  OPAC_CHECK -  Tests opacity FUNCTIONs

                Minor changes moved to TEST



  TAU_SCALE -   Changes optical depth scale

                Moved to ARCHIVE



  VOIGT_TEST -  Tests routine VOIGT

                Minor changes moved to TEST






5. Archived PROGRAMS/SUBROUTINES/FUNCTIONS
------------------------------------------

  INTEGRATE -  Simpsons rule integration

               Is not used by other codes



  ATLAS6 -     Reformats ATLAS6 files

               Not installed at present



  OUTSPC -     Unformatted output for subsequent DIPSO input

               Replaced by OUTSPB



  SYNT -       Calculates line opacity for SYNT

               Old and used version of LSYNT




6. Remaining problem areas
--------------------------

  1. He II not included in SYNT

  2. HEIDIF - code is complicated, also atomic data
     is old/unreliable

  3. Following routines have obscure code

          VCS
          VOIGT
          WAVEG

  4. U written with mainly REAL*4 variables - also calls
     QAS which produced linking problems - candiadte for
     rewrite (especially as PLD would like to understand it)

  5. A number of routines in DP (frozen) and KIEL still have 
     numeric input - non-standard FORTAN giving wrong answers
     on the SUN.



7. Test against existing codes
------------------------------

  1. ATHEII_TEST, HEII_TEST, MOD_CHECK, OPAC_CHECK run on
     both VAX and SUN with similar outputs.

  2. SUN and VAX versions tested with different values for
     NMODE and NSOURCE - good agreement see below)


  Element  Line        [X/H]  Comp.    SUN    VAX    SUN    SUN    VAX
                              NMODE      0      0     10      0      0
                              NSOURCE    0      0      0      2      2


  N II   3995.00+-2     8.56         309.7  309.9  309.4  307.7  307.9

  C II   4267.02+-2     8.05         79.59  79.59  79.88  79.18  79.19

  He I   4143.76+-10   10.99         569.0  569.0  568.8  565.3  565.4

  He I   4471.58+-10   10.99         1453.  1453.  1449.  1447.  1447.

  H I    4340.47+-16   12.00         4585.  4589.  4576.  4548.  4551.



  3. Hydrogen lines have been tested against Kurucz (1979) - note 
     that Kurucz's calculations should agree with Avrett-Loeser
     (AL) and Feautrier (F) calculations - agreement is good apart from H alpha
     Teff=20000, log g=4 - in this case line centre optical
     depth is very near 10**-4 and this may explain the
     discrepancy



Teff = 20 000; log g = 3.0
--------------------------

Wave        Alpha                     Beta                    Gamma                    Delta
       K79    AL     F    Pl    K79    AL     F    Pl    K79    AL     F    Pl    K79    AL      F    Pl

 Ew   2.68  2.50  2.47  2.62   3.10  3.01  2.98  3.14   3.07  3.00  2.98  3.10   3.12  3.04   3.03  3.16

 0.0   542   493   488   529    451   449   444   436    421   423   419    408    413   414   412   400
 0.4   578   576   571   561    530   530   531   514    517   517   518    501    511   510   509   494
 1.0   716   719   719   702    671   671   673   656    652   649   651    636    638   635   635   622
 2.0   820   829   830   818    777   778   780   768    769   767   769    758    760   758   759   749
 4.0   905   914   915   909    886   889   891   884    892   892   893    880    890   891   891   886
 8.0   967   972   973   970    964   966   966   964    968   969   970    968    969   970   970   969
16.0   992   994   994   993    992   993   993   992    993   994   994    994    993   994   994   994
40.0   999   999   999   999    999   999   999   999    999   999   999    999    999   999   999   999




Teff = 20 000; log g = 4.0
--------------------------

Wave        Alpha               Beta              Gamma              Delta
       K79    AL    Pl    K79    AL    Pl    K79    AL    Pl    K79    AL    Pl

 Ew   4.53  4.58  4.43         5.93  5.96   6.19  6.11  6.14   6.43  6.33  6.35

 0.0   542   237   563          390   447    406   395   407    394   394   396
 0.4   580   516   581          512   507    477   477   476    461   463   460
 1.0   688   690   687          606   602    562   564   561    538   540   537
 2.0   763   769   765          675   673    639   640   638    617   618   616
 4.0   833   838   836          770   769    752   753   751    738   739   738
 8.0   914   917   917          886   885    884   885   884    880   881   880
16.0   973   974   974          965   965    967   968   968    967   968   967
40.0   997   997   997          996   996    996   997   997    996   997   997





Teff = 30 000; log g = 3.5
--------------------------

Wave        Alpha               Beta              Gamma              Delta
       K79    AL    Pl    K79    AL    Pl    K79    AL    Pl    K79    AL    Pl

 Ew         1.67  1.91         1.77  2.06   1.83  1.69  1.98   1.84  1.69  1.94

 0.0         627   604          597   562    589   591   553    593   594   558
 0.4         664   633          652   616    654   656   618    659   661   622
 1.0         774   744          775   742    771   774   740    768   771   737
 2.0         882   861          870   847    865   871   848    862   868   844
 4.0         950   941          944   934    944   949   937    943   949   937
 8.0         986   982          985   981    985   987   984    985   987   984
16.0         997   996          997   996    997   997   997    997   997   997
40.0         000   000          000   000    000   000   000    000   000   000




Teff = 30 000; log g = 4.5
--------------------------

Wave        Alpha               Beta              Gamma              Delta
       K79    AL    Pl    K79    AL    Pl    K79    AL    Pl    K79    AL    Pl

 Ew         3.54  3.53         4.41  4.51   4.50  4.53  4.61   4.68  4.70  4.79

 0.0         468   605          526   537    526   522   518    527   526   519
 0.4         604   628          590   582    575   569   565    570   567   561
 1.0         718   715          675   668    654   652   645    641   639   632
 2.0         804   799          750   744    731   730   723    717   716   710
 4.0         874   871          834   830    825   823   819    814   813   809
 8.0         941   939          920   918    920   919   917    916   914   912
16.0         982   982          976   975    977   977   977    977   976   976
40.0         998   998          998   997    997   997   997    997   998   998



  4. He I equivalent width for log g=4 models have been compared
     with LTE results of Auer and Mihalas - comparison is complicated
     by use of different model atmospheres and line broadening.


Teff      4026      4121      4387      4437      4471      4713      4921
        SUN  AM   SUN  AM   SUN  AM   SUN  AM   SUN  AM   SUN  AM   SUN  AM

14000   908        97       359        39       711       110       318

15000       829       112       353        38       659       112       287

16000  1392       172       634        77      1143       191       571

17500      1301       195       652        79      1098       205       554

18000  1742       238       869       115      1499       266       803

20000      1595       257       877       118      1409       283       774

20000  1841       270       962       136      1638       305       909

22500      1605       271       914       131      1455       305       827

22000  1717       262       915       133      1553       303       878

24000  1505       236       807       164      1373       280       783

25000      1451       250       829       120      1330       291       764

26000  1306       208       701       100      1196       253       686

27500      1268       221       723       102      1171       269       678

28000  1149       185       617        86      1058       232       611
 



  5. Metal line strengths tested against analyses of iota Her and gamma Peg


ELEMENT  LINE     [X/H]  EQUIVALENT WIDTHS    [X/H]  EQUIVALENT WIDTHS
                              Iota Her                   Gamma Peg
                         Peters S_sp S_te            Peters S_sp S_te
 He I   4437.55                               10.99   121   125   121  

 C  II  3918.98                                8.16    79    87    90

 C  II  3920.69   8.66     82    86    87      8.15    97   107

 C  II  4267.02   8.53     85   105            8.00   108   126   130

 C  II  4267.27   8.70    111   138   141      7.85   108   126

 N  II  3995.00   8.24     42    43    45      7.74    77    80    83

 N  II  4643.09   8.02     10    12            7.76    37    39

 O  II  4072.16   9.17     21    20            8.94    71    73

 O  II  4414.90   9.06     23    25    28      8.69    75    78    86

 Ne I   6143.06   8.94     56    54    54   

 Ne I   6506.53   8.69     45    44

 Mg II  4390.60   7.22     16    18       

 Mg II  4481.13   7.32     96    97            7.47    80    87

 Mg II  4481.33   7.27    103   104   104      7.33    80    88    88

 Al III 4512.54   6.45     17    13            6.14    33    35

 Al III 4528.91   6.44      5     4              

 Al III 4529.20   6.31     20    15    16      6.51    61    66    66

 Si II  3862.20   7.19     68    63    64      6.85    34    46    49

 Si II  4128.07   6.51     56    56            7.04    36    48 

 Si III 4567.82   7.68     41    34    35      7.61    95   105   109

 Si III 4574.76   7.69     25    20    21      7.43    59    63

 Si IV  4088.85                                7.59    19    20    21

 Si IV  4116.10                                7.52    13    14

 P  II  4475.26   6.37      2     2    

 P  II  5425.93   5.46      6     7     7

 S  II  3923.40                                7.07    19    17    20

 S  II  4162.70                                6.93    29    27    31

 S  II  4294.43   7.28     26    23    28   

 S  II  4716.23   7.39     28    26    31

 S  III 3983.77                                6.76    15    14    15

 S  III 4253.59   7.22     14    10    12

 S  III 4284.99   7.69     18    12    14      6.83    30    28    30

 S  III 4332.71   6.98      3     0.5   1

 Ar II  4401.02   6.97      4     5

 Ar II  4735.93   7.37     11    13    13 

 Ca II  3736.90   5.06      6     5     5

 Ca II  3933.66                                6.33    77    85    85

 Fe II  4233.17   5.95     11     5     7

 Fe II  4416.82   6.60      9     4     5

 Fe III 4164.79   7.64     11     7    10

 Fe III 4395.78   5.07      9     6     8


Notes:
      S_sp - equivalent widths calculated using the Sun version of Spectrum.

      S_te - equivalent widths calculated using Spec_test on the Sun.

  ADOPTED MODEL ATMOSPHERES:

    Iota Herulis      Teff = 17,000 K
                      log g= 4.0
                      vt   = 0 km/s

    Gamma Pegasi      Teff = 21,500 K
                      log g= 3.7
                      vt   = 3 km/s

  Equivalent widths were calculated using the gf values adopted by Peters:
                   Iota Her  - Peters et al. 1970, ApJ, 159, 525.
                   Gamma Peg - Peters 1976, ApJ Supp Ser, 30, 551.



  6. O II lines tested against results calculated by Uli Heber with
     the same model atmosphere and atomic data



COMPARISON OF HEBER'S, PETERS' & DUFTONS OII RESULTS FOR GAMMA PEG:

Gamma Peg: ATLAS6 model, Teff=21500, logg=3.7, Vt=3km/s, H=0.909, He=0.091
-------------------------------------------------------------------------------
 lambda   nr. loggf  wlam    logN    logN   logN   logN    logN   logN
                (peters)     Heber  Peters Dufton Jeffery  S_sp   S_te
 4072.16  10  0.530  0.071   8.926   8.94   8.94   8.84    8.92   8.79
 4078.84  10 -0.259  0.026   8.673   8.61   8.67   8.61    8.66   8.53
 4085.11  10 -0.144  0.031   8.740   8.66   8.74   8.67    8.73   8.60
 4087.15  48  0.530  0.017   8.342   8.25   8.35   8.30    8.34   8.21
 4303.84  54  0.640  0.029   8.672   8.72   8.69   8.62    8.67   8.54
 4366.89   2 -0.239  0.048   8.622   8.58   8.73   8.66    8.73   8.60
 4414.90   5  0.305  0.075   8.643   8.69   8.69   8.58    8.65   8.53
 4416.97   5  0.044  0.063   8.697   8.72   8.63   8.63    8.70   8.58
 4452.37   5 -0.740  0.024   8.610   8.59   8.61   8.56    8.61   8.48
 4590.97  15  0.447  0.043   8.598   8.57   8.59   8.53    8.58   8.46
 4596.18  15  0.290  0.042   8.723   8.70   8.73   8.66    8.72   8.59
 4661.63   1  0.169  0.053   8.403   8.37   8.39   8.32    8.38   8.26
 4676.24   1 -0.296  0.045   8.693   8.66   8.69   8.62    8.68   8.56
 4703.16  40  0.215  0.018   8.824   8.82   8.83   8.79    8.83   8.70
 4705.35  25  0.560  0.039   8.550   8.54   8.55   8.49    8.54   8.41
                                                         
 `COMMON' MODEL ATMOSPHERE:

 2.15000E+04 5.01187E+03 9.10000E-02
 1.00000E-04 1.30264E+04 1.46899E+00 7.31245E-01 3.31483E-01
 3.10000E-04 1.33872E+04 4.36535E+00 2.16954E+00 3.57751E-01
 1.00000E-03 1.37900E+04 1.26703E+01 6.28047E+00 4.25748E-01
 1.58489E-03 1.39916E+04 1.87794E+01 9.30698E+00 4.72010E-01
 2.51189E-03 1.42186E+04 2.74100E+01 1.35801E+01 5.32704E-01
 3.98107E-03 1.44620E+04 3.93653E+01 1.95061E+01 6.11498E-01
 6.30957E-03 1.47204E+04 5.56640E+01 2.75879E+01 7.11428E-01
 1.00000E-02 1.49883E+04 7.75728E+01 3.84533E+01 8.36540E-01
 1.58489E-02 1.52647E+04 1.06751E+02 5.29192E+01 9.91674E-01
 2.51189E-02 1.55573E+04 1.45256E+02 7.20854E+01 1.18350E+00
 3.98107E-02 1.58783E+04 1.96170E+02 9.74126E+01 1.41694E+00
 6.30957E-02 1.62423E+04 2.63005E+02 1.30683E+02 1.69268E+00
 1.00000E-01 1.66813E+04 3.50778E+02 1.74452E+02 2.01109E+00
 1.58489E-01 1.72321E+04 4.66690E+02 2.32333E+02 2.36431E+00
 2.51189E-01 1.79258E+04 6.21550E+02 3.09746E+02 2.72971E+00
 3.98107E-01 1.87728E+04 8.31876E+02 4.15122E+02 3.11759E+00
 6.30957E-01 1.97966E+04 1.12242E+03 5.60452E+02 3.53154E+00
 1.00000E+00 2.10126E+04 1.53106E+03 7.64619E+02 3.99779E+00
 1.58489E+00 2.23841E+04 2.10279E+03 1.04996E+03 4.50902E+00
 2.51189E+00 2.39084E+04 2.90421E+03 1.44989E+03 5.07488E+00
 3.98107E+00 2.56352E+04 4.02914E+03 2.01212E+03 5.69295E+00
 6.30957E+00 2.74925E+04 5.60255E+03 2.79788E+03 6.46520E+00
 1.00000E+01 2.97439E+04 7.82630E+03 3.90993E+03 7.25960E+00
 1.58489E+01 3.23098E+04 1.09295E+04 5.46848E+03 8.08378E+00
 2.51189E+01 3.53240E+04 1.52222E+04 7.65567E+03 9.07811E+00

 ATOMIC DATA:

HYDROGEN 12.00  1.00 13.598 999.99 999.99 999.99  2.00  1.00  1.00  1.00  1.00
  HELIUM 10.99  4.00 24.587 54.416 999.99 999.99  1.00  2.00  1.00  1.00  1.00
 LITHIUM  1.16  6.94  5.392 75.638 122.45 999.99  2.00  1.00  2.00  1.00  1.00
BRYLLIUM  1.15  9.01  9.322 18.211 153.89 217.71  1.00  2.00  1.00  2.00  1.00
   BORON  2.6  10.81  8.298 25.154 37.930 259.37  6.00  1.00  2.00  1.00  2.00
  CARBON  8.56 12.01 11.260 24.376 47.887 64.492  9.00  6.00  1.00  2.00  1.00
NITROGEN  8.05 14.01 14.534 29.601 47.448 77.472  4.00  9.00  6.00  1.00  2.00
  OXYGEN  8.93 16.00 13.618 35.117 54.934 77.413  9.00  4.00  9.00  6.00  1.00
FLUORINE  4.56 19.00 17.442 34.970 62.707 87.138  6.00  9.00  4.00  9.00  6.00
    NEON  8.09 20.18 21.564 40.962 63.450 97.110  1.00  6.00  9.00  4.00  9.00
  SODIUM  6.33 22.99  5.139 47.286 71.640 98.910  2.00  1.00  4.00  5.00  4.00
MAGNSIUM  7.58 24.31  7.646 15.035 80.143 109.31  1.00  2.00  1.00  6.00  9.00
ALMINIUM  6.47 26.98  5.986 18.826 28.448 119.99  6.00  1.00  2.00  1.00  6.00
 SILICON  7.55 28.09  8.151 16.345 33.492 45.141  9.00  6.00  1.00  2.00  1.00
PHOSPRUS  5.45 30.97 10.486 19.725 30.180 51.420  4.00  9.00  6.00  1.00  2.00
 SULPHUR  7.21 32.06 10.360 23.330 34.830 47.300  9.00  4.00  9.00  6.00  1.00
CHLORINE  5.5  35.45 12.967 23.810 39.610 53.460  6.00  9.00  4.00  9.00  6.00
   ARGON  6.56 39.95 15.759 27.629 40.740 59.810  1.00  6.00  9.00  4.00  9.00
POTSSIUM  5.12 39.10   0.00   0.00   0.00   0.00  0.0   0.0   0.0   0.0   0.0
 CALCIUM  6.36 40.08  6.113 11.871 50.910 67.150  1.00  2.00  1.00  6.00  9.00
SCANDIUM  3.10 44.96   0.00   0.00   0.00   0.00  0.0   0.0   0.0   0.0   0.0
TITANIUM  4.99 47.90   0.00   0.00   0.00   0.00  0.0   0.0   0.0   0.0   0.0
VANADIUM  4.00 50.94   0.00   0.00   0.00   0.00  0.0   0.0   0.0   0.0   0.0
CHROMIUM  5.67 52.00   0.00   0.00   0.00   0.00  0.0   0.0   0.0   0.0   0.0
MANGNESE  5.39 54.94   0.00   0.00   0.00   0.00  0.0   0.0   0.0   0.0   0.0
    IRON  7.67 55.85  7.870 16.160 30.651 54.800 25.00 30.00 25.00  6.00 25.00
      27  0.0   0.00   0.00   0.00   0.00   0.00  0.0   0.0   0.0   0.0   0.0
      28  0.0   0.00   0.00   0.00   0.00   0.00  0.0   0.0   0.0   0.0   0.0
      29  0.0   0.00   0.00   0.00   0.00   0.00  0.0   0.0   0.0   0.0   0.0
ENDATOMS  0.0   0.00   0.00   0.00   0.00   0.00  0.0   0.0   0.0   0.0   0.0
  0  0  0000.00 .000E+00 .000E-00 .000E-00 00.000  00.00  OSC/EDAMP/RDAMP
  8  2  4072.16 3.39E+00 4.92E-03 1.27E-04 25.643  10.00  
  8  2  4078.86 5.51E-01 4.92E-03 1.27E-04 25.643  10.00  
  8  2  4085.11 7.18E-01 4.95E-03 1.28E-04 25.643  10.00  
  8  2  4087.16 3.39E+00 1.51E-02 2.13E-04 28.670  48.00  
  8  2  4303.84 4.37E+00 1.72E-02 2.41E-03 28.814  54.00  
  8  2  4366.89 4.48E-01 2.93E-03 5.15E-04 22.993   2.00  
  8  2  4414.90 2.02E+00 3.25E-03 2.08E-03 23.435   5.00  
  8  2  4416.97 1.11E+00 3.25E-03 2.08E-03 23.413   5.00  
  8  2  4452.37 1.82E-01 3.30E-03 2.12E-03 23.435   5.00  
  8  2  4590.97 2.80E+00 3.30E-03 8.45E-04 25.655  15.00  
  8  2  4596.18 1.95E+00 3.31E-03 8.47E-04 25.655  15.00  
  8  2  4661.63 1.48E+00 3.26E-03 5.87E-04 22.973   1.00  
  8  2  4676.24 5.06E-01 3.28E-03 5.91E-04 22.993   1.00  
  8  2  4703.18 1.64E+00 6.46E-03 6.46E-04 28.505  40.00  
  8  2  4705.35 3.63E+00 7.05E-03 1.53E-03 26.242  25.00  
 -1  0  0000.00 .000     .000     .000       0.00  00.00    0.0
**************************************************


  7. Test by CSJ using a hydrogen deficient model b10t20g20.qub


     Avrett-Loeser approximation
     ---------------------------

 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP=  1     ELEM= HYDROGEN     RLAMB=  4861.0     NW= 35     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    8.84     EW= 1.206E-01     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  8.214E-01    0.025  8.222E-01    0.050  8.244E-01    0.075  8.283E-01
    0.100  8.335E-01    0.125  8.401E-01    0.150  8.481E-01    0.200  8.673E-01
    0.250  8.893E-01    0.300  9.116E-01    0.400  9.493E-01    0.500  9.728E-01
    0.600  9.854E-01    0.800  9.950E-01    1.000  9.979E-01    1.250  9.991E-01
    1.500  9.995E-01    2.000  9.998E-01    2.500  9.999E-01    3.000  9.999E-01
    4.000  1.000E+00    5.000  1.000E+00    6.000  1.000E+00    8.000  1.000E+00
   10.000  1.000E+00   13.000  1.000E+00   16.000  1.000E+00   20.000  1.000E+00
   25.000  1.000E+00   30.000  1.000E+00   40.000  1.000E+00   50.000  1.000E+00
   60.000  1.000E+00   80.000  1.000E+00  100.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  2.004E-01    0.025  2.016E-01    0.050  2.053E-01    0.075  2.115E-01
    0.100  2.204E-01    0.125  2.324E-01    0.150  2.470E-01    0.200  2.901E-01
    0.250  3.451E-01    0.300  4.092E-01    0.400  5.545E-01    0.500  6.821E-01
    0.600  7.677E-01    0.800  8.401E-01    1.000  8.624E-01    1.250  8.718E-01
    1.500  8.752E-01    2.000  8.776E-01    2.500  8.784E-01    3.000  8.789E-01
    4.000  8.792E-01    5.000  8.794E-01    6.000  8.795E-01    8.000  8.795E-01
   10.000  8.796E-01   13.000  8.796E-01   16.000  8.796E-01   20.000  8.796E-01
   25.000  8.796E-01   30.000  8.796E-01   40.000  8.796E-01   50.000  8.796E-01
   60.000  8.796E-01   80.000  8.796E-01  100.000  8.796E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP=  1     ELEM= HYDROGEN     RLAMB=  4340.0     NW= 35     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    8.84     EW= 6.710E-02     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  8.848E-01    0.025  8.856E-01    0.050  8.881E-01    0.075  8.922E-01
    0.100  8.976E-01    0.125  9.041E-01    0.150  9.116E-01    0.200  9.279E-01
    0.250  9.441E-01    0.300  9.582E-01    0.400  9.776E-01    0.500  9.878E-01
    0.600  9.930E-01    0.800  9.973E-01    1.000  9.987E-01    1.250  9.993E-01
    1.500  9.996E-01    2.000  9.998E-01    2.500  9.999E-01    3.000  9.999E-01
    4.000  1.000E+00    5.000  1.000E+00    6.000  1.000E+00    8.000  1.000E+00
   10.000  1.000E+00   13.000  1.000E+00   16.000  1.000E+00   20.000  1.000E+00
   25.000  1.000E+00   30.000  1.000E+00   40.000  1.000E+00   50.000  1.000E+00
   60.000  1.000E+00   80.000  1.000E+00  100.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  3.948E-01    0.025  3.969E-01    0.050  4.038E-01    0.075  4.155E-01
    0.100  4.319E-01    0.125  4.518E-01    0.150  4.766E-01    0.200  5.339E-01
    0.250  5.974E-01    0.300  6.666E-01    0.400  7.829E-01    0.500  8.618E-01
    0.600  9.094E-01    0.800  9.482E-01    1.000  9.603E-01    1.250  9.659E-01
    1.500  9.681E-01    2.000  9.699E-01    2.500  9.705E-01    3.000  9.708E-01
    4.000  9.711E-01    5.000  9.713E-01    6.000  9.713E-01    8.000  9.714E-01
   10.000  9.714E-01   13.000  9.714E-01   16.000  9.714E-01   20.000  9.714E-01
   25.000  9.714E-01   30.000  9.714E-01   40.000  9.714E-01   50.000  9.714E-01
   60.000  9.714E-01   80.000  9.714E-01  100.000  9.714E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP=  1     ELEM= HYDROGEN     RLAMB=  4101.0     NW= 35     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    8.84     EW= 3.636E-02     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  9.391E-01    0.025  9.396E-01    0.050  9.411E-01    0.075  9.436E-01
    0.100  9.468E-01    0.125  9.506E-01    0.150  9.548E-01    0.200  9.635E-01
    0.250  9.716E-01    0.300  9.783E-01    0.400  9.875E-01    0.500  9.925E-01
    0.600  9.953E-01    0.800  9.980E-01    1.000  9.989E-01    1.250  9.994E-01
    1.500  9.997E-01    2.000  9.999E-01    2.500  9.999E-01    3.000  9.999E-01
    4.000  1.000E+00    5.000  1.000E+00    6.000  1.000E+00    8.000  1.000E+00
   10.000  1.000E+00   13.000  1.000E+00   16.000  1.000E+00   20.000  1.000E+00
   25.000  1.000E+00   30.000  1.000E+00   40.000  1.000E+00   50.000  1.000E+00
   60.000  1.000E+00   80.000  1.000E+00  100.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  6.047E-01    0.025  6.066E-01    0.050  6.128E-01    0.075  6.227E-01
    0.100  6.360E-01    0.125  6.532E-01    0.150  6.723E-01    0.200  7.164E-01
    0.250  7.618E-01    0.300  8.065E-01    0.400  8.789E-01    0.500  9.264E-01
    0.600  9.561E-01    0.800  9.821E-01    1.000  9.912E-01    1.250  9.957E-01
    1.500  9.976E-01    2.000  9.991E-01    2.500  9.997E-01    3.000  1.000E+00
    4.000  1.000E+00    5.000  1.000E+00    6.000  1.000E+00    8.000  1.001E+00
   10.000  1.001E+00   13.000  1.001E+00   16.000  1.001E+00   20.000  1.001E+00
   25.000  1.001E+00   30.000  1.001E+00   40.000  1.001E+00   50.000  1.001E+00
   60.000  1.001E+00   80.000  1.001E+00  100.000  1.001E+00
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP=  2     ELEM=   HELIUM     RLAMB=  4471.0     NW= 80     SYMM= F
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=   11.53     EW= 6.692E-01     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
 -100.000  1.000E+00  -80.000  1.000E+00  -60.000  1.000E+00  -50.000  1.000E+00
  -40.000  1.000E+00  -30.000  9.999E-01  -25.000  9.999E-01  -20.000  9.998E-01
  -16.000  9.997E-01  -13.000  9.995E-01  -10.000  9.990E-01   -8.000  9.982E-01
   -6.000  9.964E-01   -5.000  9.943E-01   -4.000  9.901E-01   -3.000  9.794E-01
   -2.500  9.677E-01   -2.300  9.593E-01   -2.100  9.473E-01   -2.000  9.410E-01
   -1.900  9.350E-01   -1.800  9.269E-01   -1.700  9.154E-01   -1.600  9.032E-01
   -1.500  8.909E-01   -1.400  8.883E-01   -1.300  8.972E-01   -1.200  9.060E-01
   -1.100  9.139E-01   -1.000  9.179E-01   -0.900  9.178E-01   -0.800  9.137E-01
   -0.700  9.189E-01   -0.600  9.000E-01   -0.500  8.780E-01   -0.400  8.393E-01
   -0.300  7.362E-01   -0.250  6.728E-01   -0.200  6.462E-01   -0.150  6.364E-01
   -0.125  6.336E-01   -0.100  6.316E-01   -0.075  6.310E-01   -0.050  6.302E-01
   -0.025  6.297E-01    0.000  6.296E-01    0.025  6.297E-01    0.050  6.301E-01
    0.075  6.308E-01    0.100  6.318E-01    0.125  6.324E-01    0.150  6.340E-01
    0.200  6.371E-01    0.250  6.401E-01    0.300  6.461E-01    0.400  6.916E-01
    0.500  8.198E-01    0.600  8.715E-01    0.800  9.038E-01    1.000  9.243E-01
    1.250  9.424E-01    1.500  9.559E-01    2.000  9.722E-01    2.500  9.824E-01
    3.000  9.879E-01    4.000  9.935E-01    5.000  9.962E-01    6.000  9.975E-01
    8.000  9.988E-01   10.000  9.993E-01   13.000  9.996E-01   16.000  9.998E-01
   20.000  9.999E-01   25.000  9.999E-01   30.000  1.000E+00   40.000  1.000E+00
   50.000  1.000E+00   60.000  1.000E+00   80.000  1.000E+00  100.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
 -100.000  9.475E-01  -80.000  9.475E-01  -60.000  9.474E-01  -50.000  9.474E-01
  -40.000  9.472E-01  -30.000  9.469E-01  -25.000  9.466E-01  -20.000  9.458E-01
  -16.000  9.446E-01  -13.000  9.426E-01  -10.000  9.382E-01   -8.000  9.315E-01
   -6.000  9.158E-01   -5.000  8.991E-01   -4.000  8.668E-01   -3.000  7.963E-01
   -2.500  7.263E-01   -2.300  6.805E-01   -2.100  6.223E-01   -2.000  5.916E-01
   -1.900  5.638E-01   -1.800  5.287E-01   -1.700  4.827E-01   -1.600  4.352E-01
   -1.500  3.931E-01   -1.400  3.843E-01   -1.300  4.132E-01   -1.200  4.446E-01
   -1.100  4.746E-01   -1.000  4.907E-01   -0.900  4.909E-01   -0.800  4.753E-01
   -0.700  4.919E-01   -0.600  4.257E-01   -0.500  3.675E-01   -0.400  2.648E-01
   -0.300  1.113E-01   -0.250  4.334E-02   -0.200  1.959E-02   -0.150  1.070E-02
   -0.125  8.361E-03   -0.100  6.916E-03   -0.075  6.012E-03   -0.050  5.324E-03
   -0.025  4.975E-03    0.000  4.860E-03    0.025  4.946E-03    0.050  5.245E-03
    0.075  5.809E-03    0.100  6.580E-03    0.125  7.469E-03    0.150  8.690E-03
    0.200  1.127E-02    0.250  1.434E-02    0.300  1.948E-02    0.400  5.963E-02
    0.500  2.264E-01    0.600  3.411E-01    0.800  4.396E-01    1.000  5.168E-01
    1.250  5.940E-01    1.500  6.600E-01    2.000  7.518E-01    2.500  8.146E-01
    3.000  8.509E-01    4.000  8.923E-01    5.000  9.126E-01    6.000  9.248E-01
    8.000  9.362E-01   10.000  9.409E-01   13.000  9.441E-01   16.000  9.454E-01
   20.000  9.463E-01   25.000  9.468E-01   30.000  9.471E-01   40.000  9.473E-01
   50.000  9.474E-01   60.000  9.474E-01   80.000  9.475E-01  100.000  9.475E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP=  2     ELEM=   HELIUM     RLAMB=  4026.0     NW= 69     SYMM= F
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=   11.53     EW= 6.917E-01     C/L RATIO= 1.00001

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
 -100.000  1.000E+00  -80.000  1.000E+00  -60.000  1.000E+00  -50.000  1.000E+00
  -40.000  9.999E-01  -30.000  9.999E-01  -25.000  9.998E-01  -20.000  9.997E-01
  -16.000  9.995E-01  -13.000  9.993E-01  -10.000  9.987E-01   -8.000  9.979E-01
   -6.000  9.961E-01   -5.000  9.943E-01   -4.000  9.907E-01   -3.000  9.832E-01
   -2.500  9.766E-01   -2.000  9.654E-01   -1.500  9.467E-01   -1.250  9.321E-01
   -1.000  9.119E-01   -0.800  8.894E-01   -0.600  8.579E-01   -0.500  8.368E-01
   -0.400  8.092E-01   -0.300  7.589E-01   -0.250  7.008E-01   -0.200  6.399E-01
   -0.150  6.121E-01   -0.125  6.056E-01   -0.100  6.014E-01   -0.075  5.994E-01
   -0.050  5.977E-01   -0.025  5.968E-01    0.000  5.965E-01    0.025  5.967E-01
    0.050  5.974E-01    0.075  5.987E-01    0.100  6.006E-01    0.125  6.024E-01
    0.150  6.054E-01    0.200  6.127E-01    0.250  6.250E-01    0.300  6.535E-01
    0.400  7.694E-01    0.500  8.248E-01    0.600  8.499E-01    0.800  8.842E-01
    1.000  9.082E-01    1.250  9.297E-01    1.500  9.450E-01    2.000  9.646E-01
    2.500  9.762E-01    3.000  9.830E-01    4.000  9.908E-01    5.000  9.943E-01
    6.000  9.962E-01    8.000  9.979E-01   10.000  9.987E-01   13.000  9.993E-01
   16.000  9.995E-01   20.000  9.997E-01   25.000  9.998E-01   30.000  9.999E-01
   40.000  9.999E-01   50.000  1.000E+00   60.000  1.000E+00   80.000  1.000E+00
  100.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
 -100.000  1.015E+00  -80.000  1.015E+00  -60.000  1.015E+00  -50.000  1.015E+00
  -40.000  1.014E+00  -30.000  1.014E+00  -25.000  1.013E+00  -20.000  1.012E+00
  -16.000  1.010E+00  -13.000  1.007E+00  -10.000  1.001E+00   -8.000  9.930E-01
   -6.000  9.770E-01   -5.000  9.618E-01   -4.000  9.357E-01   -3.000  8.867E-01
   -2.500  8.455E-01   -2.000  7.843E-01   -1.500  6.875E-01   -1.250  6.225E-01
   -1.000  5.400E-01   -0.800  4.605E-01   -0.600  3.672E-01   -0.500  3.165E-01
   -0.400  2.561E-01   -0.300  1.739E-01   -0.250  1.082E-01   -0.200  4.527E-02
   -0.150  2.167E-02   -0.125  1.629E-02   -0.100  1.255E-02   -0.075  1.052E-02
   -0.050  9.168E-03   -0.025  8.372E-03    0.000  8.110E-03    0.025  8.282E-03
    0.050  8.911E-03    0.075  1.008E-02    0.100  1.140E-02    0.125  1.341E-02
    0.150  1.612E-02    0.200  2.227E-02    0.250  3.289E-02    0.300  5.659E-02
    0.400  1.913E-01    0.500  2.879E-01    0.600  3.465E-01    0.800  4.436E-01
    1.000  5.267E-01    1.250  6.113E-01    1.500  6.789E-01    2.000  7.786E-01
    2.500  8.419E-01    3.000  8.842E-01    4.000  9.345E-01    5.000  9.611E-01
    6.000  9.766E-01    8.000  9.929E-01   10.000  1.001E+00   13.000  1.007E+00
   16.000  1.010E+00   20.000  1.012E+00   25.000  1.013E+00   30.000  1.014E+00
   40.000  1.014E+00   50.000  1.015E+00   60.000  1.015E+00   80.000  1.015E+00
  100.000  1.015E+00
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP=  2     ELEM=   HELIUM     RLAMB=  4922.0     NW= 80     SYMM= F
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=   11.53     EW= 4.239E-01     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
 -100.000  1.000E+00  -80.000  1.000E+00  -60.000  1.000E+00  -50.000  1.000E+00
  -40.000  1.000E+00  -30.000  1.000E+00  -25.000  1.000E+00  -20.000  9.999E-01
  -16.000  9.999E-01  -13.000  9.998E-01  -10.000  9.997E-01   -8.000  9.997E-01
   -6.000  9.994E-01   -5.000  9.989E-01   -4.000  9.975E-01   -3.000  9.934E-01
   -2.500  9.880E-01   -2.300  9.839E-01   -2.100  9.779E-01   -2.000  9.743E-01
   -1.900  9.703E-01   -1.800  9.654E-01   -1.700  9.594E-01   -1.600  9.514E-01
   -1.500  9.410E-01   -1.400  9.320E-01   -1.300  9.304E-01   -1.200  9.366E-01
   -1.100  9.443E-01   -1.000  9.491E-01   -0.900  9.501E-01   -0.800  9.478E-01
   -0.700  9.538E-01   -0.600  9.392E-01   -0.500  9.177E-01   -0.400  8.778E-01
   -0.300  7.736E-01   -0.250  7.149E-01   -0.200  6.859E-01   -0.150  6.737E-01
   -0.125  6.703E-01   -0.100  6.686E-01   -0.075  6.670E-01   -0.050  6.660E-01
   -0.025  6.654E-01    0.000  6.652E-01    0.025  6.654E-01    0.050  6.660E-01
    0.075  6.670E-01    0.100  6.686E-01    0.125  6.703E-01    0.150  6.737E-01
    0.200  6.859E-01    0.250  7.149E-01    0.300  7.736E-01    0.400  8.745E-01
    0.500  9.042E-01    0.600  9.221E-01    0.800  9.450E-01    1.000  9.600E-01
    1.250  9.710E-01    1.500  9.787E-01    2.000  9.875E-01    2.500  9.919E-01
    3.000  9.944E-01    4.000  9.969E-01    5.000  9.981E-01    6.000  9.987E-01
    8.000  9.994E-01   10.000  9.996E-01   13.000  9.998E-01   16.000  9.999E-01
   20.000  9.999E-01   25.000  1.000E+00   30.000  1.000E+00   40.000  1.000E+00
   50.000  1.000E+00   60.000  1.000E+00   80.000  1.000E+00  100.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
 -100.000  8.694E-01  -80.000  8.694E-01  -60.000  8.694E-01  -50.000  8.694E-01
  -40.000  8.694E-01  -30.000  8.693E-01  -25.000  8.692E-01  -20.000  8.690E-01
  -16.000  8.688E-01  -13.000  8.683E-01  -10.000  8.672E-01   -8.000  8.652E-01
   -6.000  8.611E-01   -5.000  8.560E-01   -4.000  8.429E-01   -3.000  8.128E-01
   -2.500  7.788E-01   -2.300  7.532E-01   -2.100  7.166E-01   -2.000  6.954E-01
   -1.900  6.725E-01   -1.800  6.455E-01   -1.700  6.143E-01   -1.600  5.736E-01
   -1.500  5.252E-01   -1.400  4.855E-01   -1.300  4.782E-01   -1.200  5.057E-01
   -1.100  5.388E-01   -1.000  5.598E-01   -0.900  5.634E-01   -0.800  5.516E-01
   -0.700  5.756E-01   -0.600  5.110E-01   -0.500  4.312E-01   -0.400  3.053E-01
   -0.300  1.244E-01   -0.250  5.377E-02   -0.200  2.779E-02   -0.150  1.669E-02
   -0.125  1.353E-02   -0.100  1.147E-02   -0.075  1.026E-02   -0.050  9.336E-03
   -0.025  8.783E-03    0.000  8.611E-03    0.025  8.783E-03    0.050  9.336E-03
    0.075  1.026E-02    0.100  1.147E-02    0.125  1.353E-02    0.150  1.669E-02
    0.200  2.779E-02    0.250  5.377E-02    0.300  1.244E-01    0.400  2.941E-01
    0.500  3.809E-01    0.600  4.434E-01    0.800  5.400E-01    1.000  6.136E-01
    1.250  6.729E-01    1.500  7.191E-01    2.000  7.776E-01    2.500  8.083E-01
    3.000  8.262E-01    4.000  8.451E-01    5.000  8.542E-01    6.000  8.592E-01
    8.000  8.644E-01   10.000  8.665E-01   13.000  8.679E-01   16.000  8.685E-01
   20.000  8.689E-01   25.000  8.691E-01   30.000  8.692E-01   40.000  8.693E-01
   50.000  8.694E-01   60.000  8.694E-01   80.000  8.694E-01  100.000  8.694E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP=  2     ELEM=   HELIUM     RLAMB=  4386.0     NW= 69     SYMM= F
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=   11.53     EW= 4.307E-01     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
 -100.000  1.000E+00  -80.000  1.000E+00  -60.000  1.000E+00  -50.000  1.000E+00
  -40.000  1.000E+00  -30.000  1.000E+00  -25.000  9.999E-01  -20.000  9.999E-01
  -16.000  9.998E-01  -13.000  9.997E-01  -10.000  9.995E-01   -8.000  9.992E-01
   -6.000  9.985E-01   -5.000  9.977E-01   -4.000  9.964E-01   -3.000  9.930E-01
   -2.500  9.902E-01   -2.000  9.851E-01   -1.500  9.753E-01   -1.250  9.659E-01
   -1.000  9.519E-01   -0.800  9.353E-01   -0.600  9.095E-01   -0.500  8.907E-01
   -0.400  8.643E-01   -0.300  8.109E-01   -0.250  7.550E-01   -0.200  6.936E-01
   -0.150  6.575E-01   -0.125  6.485E-01   -0.100  6.426E-01   -0.075  6.388E-01
   -0.050  6.365E-01   -0.025  6.352E-01    0.000  6.347E-01    0.025  6.352E-01
    0.050  6.365E-01    0.075  6.388E-01    0.100  6.426E-01    0.125  6.485E-01
    0.150  6.575E-01    0.200  6.936E-01    0.250  7.550E-01    0.300  8.109E-01
    0.400  8.643E-01    0.500  8.907E-01    0.600  9.095E-01    0.800  9.354E-01
    1.000  9.523E-01    1.250  9.663E-01    1.500  9.751E-01    2.000  9.855E-01
    2.500  9.907E-01    3.000  9.935E-01    4.000  9.964E-01    5.000  9.978E-01
    6.000  9.985E-01    8.000  9.992E-01   10.000  9.995E-01   13.000  9.997E-01
   16.000  9.998E-01   20.000  9.999E-01   25.000  9.999E-01   30.000  1.000E+00
   40.000  1.000E+00   50.000  1.000E+00   60.000  1.000E+00   80.000  1.000E+00
  100.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
 -100.000  9.629E-01  -80.000  9.629E-01  -60.000  9.628E-01  -50.000  9.627E-01
  -40.000  9.626E-01  -30.000  9.623E-01  -25.000  9.620E-01  -20.000  9.615E-01
  -16.000  9.607E-01  -13.000  9.595E-01  -10.000  9.572E-01   -8.000  9.539E-01
   -6.000  9.471E-01   -5.000  9.404E-01   -4.000  9.284E-01   -3.000  9.041E-01
   -2.500  8.818E-01   -2.000  8.452E-01   -1.500  7.807E-01   -1.250  7.280E-01
   -1.000  6.559E-01   -0.800  5.770E-01   -0.600  4.735E-01   -0.500  4.091E-01
   -0.400  3.331E-01   -0.300  2.180E-01   -0.250  1.397E-01   -0.200  6.803E-02
   -0.150  3.556E-02   -0.125  2.754E-02   -0.100  2.230E-02   -0.075  1.885E-02
   -0.050  1.692E-02   -0.025  1.595E-02    0.000  1.556E-02    0.025  1.595E-02
    0.050  1.692E-02    0.075  1.885E-02    0.100  2.230E-02    0.125  2.754E-02
    0.150  3.556E-02    0.200  6.803E-02    0.250  1.397E-01    0.300  2.180E-01
    0.400  3.331E-01    0.500  4.091E-01    0.600  4.735E-01    0.800  5.770E-01
    1.000  6.559E-01    1.250  7.280E-01    1.500  7.807E-01    2.000  8.452E-01
    2.500  8.818E-01    3.000  9.041E-01    4.000  9.284E-01    5.000  9.404E-01
    6.000  9.471E-01    8.000  9.539E-01   10.000  9.572E-01   13.000  9.595E-01
   16.000  9.607E-01   20.000  9.615E-01   25.000  9.620E-01   30.000  9.623E-01
   40.000  9.626E-01   50.000  9.627E-01   60.000  9.628E-01   80.000  9.629E-01
  100.000  9.629E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP=  6     ELEM=   CARBON     RLAMB=  4267.0     NW= 69     SYMM= F
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    9.14     EW= 2.807E-01     C/L RATIO= 1.00017

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
   -5.000  1.000E+00   -4.000  9.999E-01   -3.000  9.997E-01   -2.500  9.995E-01
   -2.000  9.991E-01   -1.500  9.982E-01   -1.250  9.972E-01   -1.000  9.953E-01
   -0.800  9.923E-01   -0.600  9.850E-01   -0.500  9.774E-01   -0.400  9.635E-01
   -0.300  9.355E-01   -0.250  9.098E-01   -0.200  8.567E-01   -0.175  8.028E-01
   -0.150  7.311E-01   -0.125  6.704E-01   -0.100  6.399E-01   -0.080  6.289E-01
   -0.060  6.229E-01   -0.050  6.216E-01   -0.040  6.202E-01   -0.030  6.192E-01
   -0.025  6.188E-01   -0.020  6.185E-01   -0.015  6.183E-01   -0.010  6.181E-01
   -0.005  6.180E-01    0.000  6.180E-01    0.025  6.188E-01    0.050  6.216E-01
    0.075  6.269E-01    0.100  6.378E-01    0.125  6.443E-01    0.150  6.328E-01
    0.175  6.232E-01    0.200  6.189E-01    0.225  6.166E-01    0.250  6.158E-01
    0.255  6.159E-01    0.260  6.160E-01    0.265  6.161E-01    0.270  6.163E-01
    0.275  6.166E-01    0.280  6.169E-01    0.290  6.178E-01    0.300  6.189E-01
    0.310  6.205E-01    0.330  6.248E-01    0.350  6.335E-01    0.375  6.571E-01
    0.400  7.087E-01    0.425  7.769E-01    0.450  8.316E-01    0.500  8.896E-01
    0.550  9.202E-01    0.650  9.551E-01    0.750  9.727E-01    0.850  9.821E-01
    1.050  9.911E-01    1.250  9.948E-01    1.500  9.969E-01    1.750  9.980E-01
    2.250  9.990E-01    2.750  9.995E-01    3.250  9.997E-01    4.250  9.999E-01
    5.250  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
   -5.000  9.811E-01   -4.000  9.791E-01   -3.000  9.747E-01   -2.500  9.705E-01
   -2.000  9.631E-01   -1.500  9.481E-01   -1.250  9.341E-01   -1.000  9.103E-01
   -0.800  8.770E-01   -0.600  8.160E-01   -0.500  7.647E-01   -0.400  6.874E-01
   -0.300  5.672E-01   -0.250  4.799E-01   -0.200  3.396E-01   -0.175  2.267E-01
   -0.150  1.250E-01   -0.125  5.415E-02   -0.100  2.819E-02   -0.080  1.845E-02
   -0.060  1.333E-02   -0.050  1.173E-02   -0.040  1.066E-02   -0.030  9.956E-03
   -0.025  9.593E-03   -0.020  9.311E-03   -0.015  9.102E-03   -0.010  8.957E-03
   -0.005  8.872E-03    0.000  8.843E-03    0.025  9.588E-03    0.050  1.171E-02
    0.075  1.686E-02    0.100  2.651E-02    0.125  3.216E-02    0.150  2.192E-02
    0.175  1.359E-02    0.200  9.665E-03    0.225  7.680E-03    0.250  7.178E-03
    0.255  7.197E-03    0.260  7.254E-03    0.265  7.352E-03    0.270  7.493E-03
    0.275  7.682E-03    0.280  7.926E-03    0.290  8.616E-03    0.300  9.673E-03
    0.310  1.086E-02    0.330  1.507E-02    0.350  2.266E-02    0.375  4.311E-02
    0.400  9.771E-02    0.425  1.851E-01    0.450  2.837E-01    0.500  4.188E-01
    0.550  5.133E-01    0.650  6.470E-01    0.750  7.363E-01    0.850  7.959E-01
    1.050  8.662E-01    1.250  9.040E-01    1.500  9.305E-01    1.750  9.459E-01
    2.250  9.621E-01    2.750  9.700E-01    3.250  9.744E-01    4.250  9.789E-01
    5.250  9.811E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP=  6     ELEM=   CARBON     RLAMB=  4313.0     NW= 30     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    9.14     EW= 2.788E-02     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  8.300E-01    0.005  8.304E-01    0.010  8.315E-01    0.015  8.334E-01
    0.020  8.360E-01    0.025  8.393E-01    0.030  8.434E-01    0.040  8.536E-01
    0.050  8.663E-01    0.060  8.813E-01    0.080  9.154E-01    0.100  9.491E-01
    0.125  9.793E-01    0.150  9.932E-01    0.175  9.980E-01    0.200  9.994E-01
    0.250  9.999E-01    0.300  1.000E+00    0.400  1.000E+00    0.500  1.000E+00
    0.600  1.000E+00    0.800  1.000E+00    1.000  1.000E+00    1.250  1.000E+00
    1.500  1.000E+00    2.000  1.000E+00    2.500  1.000E+00    3.000  1.000E+00
    4.000  1.000E+00    5.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  2.712E-01    0.005  2.720E-01    0.010  2.744E-01    0.015  2.783E-01
    0.020  2.839E-01    0.025  2.911E-01    0.030  3.002E-01    0.040  3.234E-01
    0.050  3.526E-01    0.060  3.903E-01    0.080  4.964E-01    0.100  6.283E-01
    0.125  7.951E-01    0.150  9.059E-01    0.175  9.550E-01    0.200  9.703E-01
    0.250  9.751E-01    0.300  9.757E-01    0.400  9.760E-01    0.500  9.762E-01
    0.600  9.762E-01    0.800  9.763E-01    1.000  9.764E-01    1.250  9.764E-01
    1.500  9.764E-01    2.000  9.764E-01    2.500  9.764E-01    3.000  9.764E-01
    4.000  9.764E-01    5.000  9.764E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP= 14     ELEM=  SILICON     RLAMB=  4128.1     NW= 30     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    7.54     EW= 3.280E-02     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  6.903E-01    0.005  6.913E-01    0.010  6.942E-01    0.015  6.992E-01
    0.020  7.067E-01    0.025  7.172E-01    0.030  7.313E-01    0.040  7.718E-01
    0.050  8.290E-01    0.060  8.933E-01    0.080  9.780E-01    0.100  9.970E-01
    0.125  9.995E-01    0.150  9.997E-01    0.175  9.998E-01    0.200  9.998E-01
    0.250  9.999E-01    0.300  9.999E-01    0.400  1.000E+00    0.500  1.000E+00
    0.600  1.000E+00    0.800  1.000E+00    1.000  1.000E+00    1.250  1.000E+00
    1.500  1.000E+00    2.000  1.000E+00    2.500  1.000E+00    3.000  1.000E+00
    4.000  1.000E+00    5.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  8.112E-02    0.005  8.210E-02    0.010  8.510E-02    0.015  9.032E-02
    0.020  9.811E-02    0.025  1.099E-01    0.030  1.258E-01    0.040  1.704E-01
    0.050  2.581E-01    0.060  4.169E-01    0.080  7.911E-01    0.100  9.435E-01
    0.125  9.829E-01    0.150  9.891E-01    0.175  9.911E-01    0.200  9.922E-01
    0.250  9.934E-01    0.300  9.940E-01    0.400  9.946E-01    0.500  9.949E-01
    0.600  9.950E-01    0.800  9.952E-01    1.000  9.953E-01    1.250  9.953E-01
    1.500  9.953E-01    2.000  9.953E-01    2.500  9.954E-01    3.000  9.954E-01
    4.000  9.954E-01    5.000  9.954E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP= 14     ELEM=  SILICON     RLAMB=  4130.9     NW= 30     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    7.54     EW= 3.900E-02     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  6.669E-01    0.005  6.676E-01    0.010  6.696E-01    0.015  6.729E-01
    0.020  6.780E-01    0.025  6.851E-01    0.030  6.951E-01    0.040  7.262E-01
    0.050  7.770E-01    0.060  8.453E-01    0.080  9.622E-01    0.100  9.948E-01
    0.125  9.992E-01    0.150  9.995E-01    0.175  9.997E-01    0.200  9.998E-01
    0.250  9.999E-01    0.300  9.999E-01    0.400  9.999E-01    0.500  1.000E+00
    0.600  1.000E+00    0.800  1.000E+00    1.000  1.000E+00    1.250  1.000E+00
    1.500  1.000E+00    2.000  1.000E+00    2.500  1.000E+00    3.000  1.000E+00
    4.000  1.000E+00    5.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  5.783E-02    0.005  5.836E-02    0.010  5.997E-02    0.015  6.280E-02
    0.020  6.822E-02    0.025  7.596E-02    0.030  8.649E-02    0.040  1.209E-01
    0.050  1.781E-01    0.060  2.952E-01    0.080  6.981E-01    0.100  9.175E-01
    0.125  9.761E-01    0.150  9.854E-01    0.175  9.884E-01    0.200  9.901E-01
    0.250  9.919E-01    0.300  9.928E-01    0.400  9.937E-01    0.500  9.941E-01
    0.600  9.943E-01    0.800  9.946E-01    1.000  9.947E-01    1.250  9.947E-01
    1.500  9.948E-01    2.000  9.948E-01    2.500  9.948E-01    3.000  9.948E-01
    4.000  9.948E-01    5.000  9.948E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP= 14     ELEM=  SILICON     RLAMB=  4088.9     NW= 30     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    7.54     EW= 6.406E-02     C/L RATIO= 1.00010

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  7.667E-01    0.005  7.672E-01    0.010  7.687E-01    0.015  7.712E-01
    0.020  7.745E-01    0.025  7.788E-01    0.030  7.839E-01    0.040  7.964E-01
    0.050  8.117E-01    0.060  8.291E-01    0.080  8.675E-01    0.100  9.045E-01
    0.125  9.371E-01    0.150  9.533E-01    0.175  9.619E-01    0.200  9.678E-01
    0.250  9.759E-01    0.300  9.813E-01    0.400  9.880E-01    0.500  9.918E-01
    0.600  9.941E-01    0.800  9.966E-01    1.000  9.979E-01    1.250  9.986E-01
    1.500  9.991E-01    2.000  9.995E-01    2.500  9.997E-01    3.000  9.998E-01
    4.000  9.999E-01    5.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  1.711E-01    0.005  1.717E-01    0.010  1.735E-01    0.015  1.766E-01
    0.020  1.812E-01    0.025  1.876E-01    0.030  1.962E-01    0.040  2.142E-01
    0.050  2.428E-01    0.060  2.789E-01    0.080  3.883E-01    0.100  5.295E-01
    0.125  6.883E-01    0.150  7.766E-01    0.175  8.218E-01    0.200  8.530E-01
    0.250  8.965E-01    0.300  9.243E-01    0.400  9.556E-01    0.500  9.717E-01
    0.600  9.808E-01    0.800  9.902E-01    1.000  9.947E-01    1.250  9.976E-01
    1.500  9.992E-01    2.000  1.001E+00    2.500  1.002E+00    3.000  1.002E+00
    4.000  1.002E+00    5.000  1.003E+00
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP= 14     ELEM=  SILICON     RLAMB=  4116.1     NW= 30     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    7.54     EW= 4.857E-02     C/L RATIO= 1.00005

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  7.953E-01    0.005  7.958E-01    0.010  7.972E-01    0.015  7.992E-01
    0.020  8.024E-01    0.025  8.063E-01    0.030  8.111E-01    0.040  8.228E-01
    0.050  8.371E-01    0.060  8.533E-01    0.080  8.891E-01    0.100  9.229E-01
    0.125  9.525E-01    0.150  9.671E-01    0.175  9.743E-01    0.200  9.789E-01
    0.250  9.851E-01    0.300  9.889E-01    0.400  9.933E-01    0.500  9.956E-01
    0.600  9.970E-01    0.800  9.983E-01    1.000  9.989E-01    1.250  9.993E-01
    1.500  9.995E-01    2.000  9.998E-01    2.500  9.999E-01    3.000  9.999E-01
    4.000  1.000E+00    5.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  2.103E-01    0.005  2.110E-01    0.010  2.130E-01    0.015  2.165E-01
    0.020  2.217E-01    0.025  2.288E-01    0.030  2.383E-01    0.040  2.621E-01
    0.050  2.954E-01    0.060  3.383E-01    0.080  4.583E-01    0.100  6.151E-01
    0.125  7.740E-01    0.150  8.479E-01    0.175  8.841E-01    0.200  9.078E-01
    0.250  9.376E-01    0.300  9.548E-01    0.400  9.729E-01    0.500  9.816E-01
    0.600  9.864E-01    0.800  9.913E-01    1.000  9.936E-01    1.250  9.950E-01
    1.500  9.958E-01    2.000  9.966E-01    2.500  9.970E-01    3.000  9.972E-01
    4.000  9.974E-01    5.000  9.975E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT= 10.0
 NSP=  1     ELEM= HYDROGEN     RLAMB=  4101.0     NW= 35     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    8.84     EW= 3.607E-02     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  9.455E-01    0.025  9.458E-01    0.050  9.468E-01    0.075  9.485E-01
    0.100  9.507E-01    0.125  9.535E-01    0.150  9.565E-01    0.200  9.634E-01
    0.250  9.703E-01    0.300  9.765E-01    0.400  9.860E-01    0.500  9.916E-01
    0.600  9.948E-01    0.800  9.978E-01    1.000  9.988E-01    1.250  9.994E-01
    1.500  9.996E-01    2.000  9.998E-01    2.500  9.999E-01    3.000  9.999E-01
    4.000  1.000E+00    5.000  1.000E+00    6.000  1.000E+00    8.000  1.000E+00
   10.000  1.000E+00   13.000  1.000E+00   16.000  1.000E+00   20.000  1.000E+00
   25.000  1.000E+00   30.000  1.000E+00   40.000  1.000E+00   50.000  1.000E+00
   60.000  1.000E+00   80.000  1.000E+00  100.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  6.305E-01    0.025  6.320E-01    0.050  6.364E-01    0.075  6.439E-01
    0.100  6.540E-01    0.125  6.663E-01    0.150  6.810E-01    0.200  7.153E-01
    0.250  7.539E-01    0.300  7.933E-01    0.400  8.637E-01    0.500  9.157E-01
    0.600  9.492E-01    0.800  9.802E-01    1.000  9.906E-01    1.250  9.955E-01
    1.500  9.975E-01    2.000  9.991E-01    2.500  9.997E-01    3.000  1.000E+00
    4.000  1.000E+00    5.000  1.000E+00    6.000  1.000E+00    8.000  1.001E+00
   10.000  1.001E+00   13.000  1.001E+00   16.000  1.001E+00   20.000  1.001E+00
   25.000  1.001E+00   30.000  1.001E+00   40.000  1.001E+00   50.000  1.001E+00
   60.000  1.001E+00   80.000  1.001E+00  100.000  1.001E+00
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT= 10.0
 NSP=  2     ELEM=   HELIUM     RLAMB=  4471.0     NW= 80     SYMM= F
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=   11.53     EW= 7.242E-01     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
 -100.000  1.000E+00  -80.000  1.000E+00  -60.000  1.000E+00  -50.000  1.000E+00
  -40.000  1.000E+00  -30.000  9.999E-01  -25.000  9.999E-01  -20.000  9.998E-01
  -16.000  9.997E-01  -13.000  9.995E-01  -10.000  9.990E-01   -8.000  9.982E-01
   -6.000  9.964E-01   -5.000  9.943E-01   -4.000  9.901E-01   -3.000  9.794E-01
   -2.500  9.677E-01   -2.300  9.593E-01   -2.100  9.473E-01   -2.000  9.410E-01
   -1.900  9.350E-01   -1.800  9.269E-01   -1.700  9.154E-01   -1.600  9.032E-01
   -1.500  8.909E-01   -1.400  8.883E-01   -1.300  8.972E-01   -1.200  9.060E-01
   -1.100  9.138E-01   -1.000  9.177E-01   -0.900  9.175E-01   -0.800  9.132E-01
   -0.700  9.178E-01   -0.600  8.948E-01   -0.500  8.265E-01   -0.400  6.971E-01
   -0.300  6.482E-01   -0.250  6.404E-01   -0.200  6.363E-01   -0.150  6.336E-01
   -0.125  6.326E-01   -0.100  6.318E-01   -0.075  6.312E-01   -0.050  6.315E-01
   -0.025  6.313E-01    0.000  6.312E-01    0.025  6.312E-01    0.050  6.313E-01
    0.075  6.316E-01    0.100  6.313E-01    0.125  6.318E-01    0.150  6.326E-01
    0.200  6.345E-01    0.250  6.371E-01    0.300  6.404E-01    0.400  6.548E-01
    0.500  6.973E-01    0.600  8.098E-01    0.800  9.028E-01    1.000  9.241E-01
    1.250  9.423E-01    1.500  9.559E-01    2.000  9.722E-01    2.500  9.824E-01
    3.000  9.879E-01    4.000  9.935E-01    5.000  9.962E-01    6.000  9.975E-01
    8.000  9.988E-01   10.000  9.993E-01   13.000  9.996E-01   16.000  9.998E-01
   20.000  9.999E-01   25.000  9.999E-01   30.000  1.000E+00   40.000  1.000E+00
   50.000  1.000E+00   60.000  1.000E+00   80.000  1.000E+00  100.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
 -100.000  9.475E-01  -80.000  9.475E-01  -60.000  9.474E-01  -50.000  9.474E-01
  -40.000  9.472E-01  -30.000  9.469E-01  -25.000  9.466E-01  -20.000  9.458E-01
  -16.000  9.446E-01  -13.000  9.426E-01  -10.000  9.382E-01   -8.000  9.315E-01
   -6.000  9.158E-01   -5.000  8.991E-01   -4.000  8.668E-01   -3.000  7.963E-01
   -2.500  7.263E-01   -2.300  6.804E-01   -2.100  6.222E-01   -2.000  5.916E-01
   -1.900  5.638E-01   -1.800  5.287E-01   -1.700  4.826E-01   -1.600  4.351E-01
   -1.500  3.930E-01   -1.400  3.843E-01   -1.300  4.131E-01   -1.200  4.443E-01
   -1.100  4.743E-01   -1.000  4.901E-01   -0.900  4.899E-01   -0.800  4.737E-01
   -0.700  4.883E-01   -0.600  4.133E-01   -0.500  2.524E-01   -0.400  6.007E-02
   -0.300  2.140E-02   -0.250  1.461E-02   -0.200  1.067E-02   -0.150  8.309E-03
   -0.125  7.545E-03   -0.100  7.013E-03   -0.075  6.649E-03   -0.050  6.408E-03
   -0.025  6.238E-03    0.000  6.140E-03    0.025  6.156E-03    0.050  6.286E-03
    0.075  6.455E-03    0.100  6.705E-03    0.125  7.062E-03    0.150  7.555E-03
    0.200  9.122E-03    0.250  1.128E-02    0.300  1.468E-02    0.400  2.740E-02
    0.500  6.447E-02    0.600  1.996E-01    0.800  4.370E-01    1.000  5.161E-01
    1.250  5.936E-01    1.500  6.599E-01    2.000  7.518E-01    2.500  8.146E-01
    3.000  8.509E-01    4.000  8.923E-01    5.000  9.126E-01    6.000  9.248E-01
    8.000  9.362E-01   10.000  9.409E-01   13.000  9.441E-01   16.000  9.454E-01
   20.000  9.463E-01   25.000  9.468E-01   30.000  9.471E-01   40.000  9.473E-01
   50.000  9.474E-01   60.000  9.474E-01   80.000  9.475E-01  100.000  9.475E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT= 10.0
 NSP=  6     ELEM=   CARBON     RLAMB=  4267.0     NW= 69     SYMM= F
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    9.14     EW= 3.810E-01     C/L RATIO= 1.00017

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
   -5.000  1.000E+00   -4.000  9.999E-01   -3.000  9.997E-01   -2.500  9.995E-01
   -2.000  9.991E-01   -1.500  9.981E-01   -1.250  9.972E-01   -1.000  9.952E-01
   -0.800  9.918E-01   -0.600  9.834E-01   -0.500  9.719E-01   -0.400  9.079E-01
   -0.300  7.306E-01   -0.250  6.731E-01   -0.200  6.456E-01   -0.175  6.382E-01
   -0.150  6.331E-01   -0.125  6.296E-01   -0.100  6.270E-01   -0.080  6.255E-01
   -0.060  6.243E-01   -0.050  6.238E-01   -0.040  6.234E-01   -0.030  6.231E-01
   -0.025  6.229E-01   -0.020  6.228E-01   -0.015  6.227E-01   -0.010  6.226E-01
   -0.005  6.225E-01    0.000  6.224E-01    0.025  6.220E-01    0.050  6.218E-01
    0.075  6.222E-01    0.100  6.219E-01    0.125  6.216E-01    0.150  6.212E-01
    0.175  6.209E-01    0.200  6.206E-01    0.225  6.204E-01    0.250  6.205E-01
    0.255  6.205E-01    0.260  6.205E-01    0.265  6.206E-01    0.270  6.207E-01
    0.275  6.208E-01    0.280  6.209E-01    0.290  6.211E-01    0.300  6.214E-01
    0.310  6.217E-01    0.330  6.220E-01    0.350  6.233E-01    0.375  6.253E-01
    0.400  6.282E-01    0.425  6.321E-01    0.450  6.378E-01    0.500  6.585E-01
    0.550  7.058E-01    0.650  8.828E-01    0.750  9.650E-01    0.850  9.800E-01
    1.050  9.906E-01    1.250  9.946E-01    1.500  9.969E-01    1.750  9.980E-01
    2.250  9.990E-01    2.750  9.995E-01    3.250  9.997E-01    4.250  9.999E-01
    5.250  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
   -5.000  9.811E-01   -4.000  9.791E-01   -3.000  9.747E-01   -2.500  9.705E-01
   -2.000  9.630E-01   -1.500  9.477E-01   -1.250  9.333E-01   -1.000  9.085E-01
   -0.800  8.729E-01   -0.600  8.045E-01   -0.500  7.324E-01   -0.400  4.732E-01
   -0.300  1.246E-01   -0.250  5.629E-02   -0.200  3.294E-02   -0.175  2.679E-02
   -0.150  2.226E-02   -0.125  1.902E-02   -0.100  1.693E-02   -0.080  1.576E-02
   -0.060  1.462E-02   -0.050  1.418E-02   -0.040  1.381E-02   -0.030  1.350E-02
   -0.025  1.337E-02   -0.020  1.325E-02   -0.015  1.314E-02   -0.010  1.304E-02
   -0.005  1.295E-02    0.000  1.287E-02    0.025  1.258E-02    0.050  1.239E-02
    0.075  1.223E-02    0.100  1.203E-02    0.125  1.177E-02    0.150  1.146E-02
    0.175  1.116E-02    0.200  1.093E-02    0.225  1.081E-02    0.250  1.085E-02
    0.255  1.088E-02    0.260  1.092E-02    0.265  1.096E-02    0.270  1.102E-02
    0.275  1.108E-02    0.280  1.116E-02    0.290  1.134E-02    0.300  1.156E-02
    0.310  1.184E-02    0.330  1.258E-02    0.350  1.365E-02    0.375  1.564E-02
    0.400  1.788E-02    0.425  2.132E-02    0.450  2.643E-02    0.500  4.408E-02
    0.550  9.323E-02    0.650  3.992E-01    0.750  6.952E-01    0.850  7.816E-01
    1.050  8.613E-01    1.250  9.018E-01    1.500  9.295E-01    1.750  9.454E-01
    2.250  9.619E-01    2.750  9.699E-01    3.250  9.744E-01    4.250  9.789E-01
    5.250  9.810E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP= 14     ELEM=  SILICON     RLAMB=  4128.1     NW= 30     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    6.54     EW= 4.103E-03     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  9.423E-01    0.005  9.432E-01    0.010  9.457E-01    0.015  9.498E-01
    0.020  9.550E-01    0.025  9.609E-01    0.030  9.672E-01    0.040  9.793E-01
    0.050  9.886E-01    0.060  9.945E-01    0.080  9.990E-01    0.100  9.998E-01
    0.125  9.999E-01    0.150  1.000E+00    0.175  1.000E+00    0.200  1.000E+00
    0.250  1.000E+00    0.300  1.000E+00    0.400  1.000E+00    0.500  1.000E+00
    0.600  1.000E+00    0.800  1.000E+00    1.000  1.000E+00    1.250  1.000E+00
    1.500  1.000E+00    2.000  1.000E+00    2.500  1.000E+00    3.000  1.000E+00
    4.000  1.000E+00    5.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  6.268E-01    0.005  6.304E-01    0.010  6.422E-01    0.015  6.611E-01
    0.020  6.860E-01    0.025  7.154E-01    0.030  7.477E-01    0.040  8.147E-01
    0.050  8.752E-01    0.060  9.222E-01    0.080  9.739E-01    0.100  9.901E-01
    0.125  9.941E-01    0.150  9.947E-01    0.175  9.949E-01    0.200  9.951E-01
    0.250  9.952E-01    0.300  9.952E-01    0.400  9.953E-01    0.500  9.953E-01
    0.600  9.953E-01    0.800  9.954E-01    1.000  9.954E-01    1.250  9.954E-01
    1.500  9.954E-01    2.000  9.954E-01    2.500  9.954E-01    3.000  9.954E-01
    4.000  9.954E-01    5.000  9.954E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP= 14     ELEM=  SILICON     RLAMB=  4128.1     NW= 30     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    7.02     EW= 1.414E-02     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  8.247E-01    0.005  8.264E-01    0.010  8.314E-01    0.015  8.396E-01
    0.020  8.509E-01    0.025  8.649E-01    0.030  8.811E-01    0.040  9.171E-01
    0.050  9.507E-01    0.060  9.753E-01    0.080  9.958E-01    0.100  9.994E-01
    0.125  9.998E-01    0.150  9.999E-01    0.175  9.999E-01    0.200  1.000E+00
    0.250  1.000E+00    0.300  1.000E+00    0.400  1.000E+00    0.500  1.000E+00
    0.600  1.000E+00    0.800  1.000E+00    1.000  1.000E+00    1.250  1.000E+00
    1.500  1.000E+00    2.000  1.000E+00    2.500  1.000E+00    3.000  1.000E+00
    4.000  1.000E+00    5.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  2.478E-01    0.005  2.506E-01    0.010  2.624E-01    0.015  2.824E-01
    0.020  3.104E-01    0.025  3.442E-01    0.030  3.846E-01    0.040  5.136E-01
    0.050  6.549E-01    0.060  7.828E-01    0.080  9.317E-01    0.100  9.796E-01
    0.125  9.916E-01    0.150  9.935E-01    0.175  9.941E-01    0.200  9.944E-01
    0.250  9.948E-01    0.300  9.950E-01    0.400  9.951E-01    0.500  9.952E-01
    0.600  9.953E-01    0.800  9.953E-01    1.000  9.953E-01    1.250  9.953E-01
    1.500  9.954E-01    2.000  9.954E-01    2.500  9.954E-01    3.000  9.954E-01
    4.000  9.954E-01    5.000  9.954E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP= 14     ELEM=  SILICON     RLAMB=  4128.1     NW= 30     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    7.54     EW= 3.280E-02     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  6.903E-01    0.005  6.913E-01    0.010  6.942E-01    0.015  6.992E-01
    0.020  7.067E-01    0.025  7.172E-01    0.030  7.313E-01    0.040  7.718E-01
    0.050  8.290E-01    0.060  8.933E-01    0.080  9.780E-01    0.100  9.970E-01
    0.125  9.995E-01    0.150  9.997E-01    0.175  9.998E-01    0.200  9.998E-01
    0.250  9.999E-01    0.300  9.999E-01    0.400  1.000E+00    0.500  1.000E+00
    0.600  1.000E+00    0.800  1.000E+00    1.000  1.000E+00    1.250  1.000E+00
    1.500  1.000E+00    2.000  1.000E+00    2.500  1.000E+00    3.000  1.000E+00
    4.000  1.000E+00    5.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  8.112E-02    0.005  8.210E-02    0.010  8.510E-02    0.015  9.032E-02
    0.020  9.811E-02    0.025  1.099E-01    0.030  1.258E-01    0.040  1.704E-01
    0.050  2.581E-01    0.060  4.169E-01    0.080  7.911E-01    0.100  9.435E-01
    0.125  9.829E-01    0.150  9.891E-01    0.175  9.911E-01    0.200  9.922E-01
    0.250  9.934E-01    0.300  9.940E-01    0.400  9.946E-01    0.500  9.949E-01
    0.600  9.950E-01    0.800  9.952E-01    1.000  9.953E-01    1.250  9.953E-01
    1.500  9.953E-01    2.000  9.953E-01    2.500  9.954E-01    3.000  9.954E-01
    4.000  9.954E-01    5.000  9.954E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP= 14     ELEM=  SILICON     RLAMB=  4128.1     NW= 30     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    8.02     EW= 4.878E-02     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  6.405E-01    0.005  6.409E-01    0.010  6.421E-01    0.015  6.441E-01
    0.020  6.471E-01    0.025  6.513E-01    0.030  6.570E-01    0.040  6.744E-01
    0.050  7.049E-01    0.060  7.587E-01    0.080  9.131E-01    0.100  9.866E-01
    0.125  9.979E-01    0.150  9.991E-01    0.175  9.994E-01    0.200  9.995E-01
    0.250  9.997E-01    0.300  9.998E-01    0.400  9.999E-01    0.500  9.999E-01
    0.600  1.000E+00    0.800  1.000E+00    1.000  1.000E+00    1.250  1.000E+00
    1.500  1.000E+00    2.000  1.000E+00    2.500  1.000E+00    3.000  1.000E+00
    4.000  1.000E+00    5.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  3.761E-02    0.005  3.794E-02    0.010  3.893E-02    0.015  4.055E-02
    0.020  4.281E-02    0.025  4.600E-02    0.030  5.041E-02    0.040  6.497E-02
    0.050  9.819E-02    0.060  1.566E-01    0.080  4.824E-01    0.100  8.446E-01
    0.125  9.582E-01    0.150  9.765E-01    0.175  9.825E-01    0.200  9.858E-01
    0.250  9.895E-01    0.300  9.913E-01    0.400  9.931E-01    0.500  9.940E-01
    0.600  9.944E-01    0.800  9.948E-01    1.000  9.950E-01    1.250  9.951E-01
    1.500  9.952E-01    2.000  9.953E-01    2.500  9.953E-01    3.000  9.953E-01
    4.000  9.953E-01    5.000  9.954E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP= 14     ELEM=  SILICON     RLAMB=  4128.1     NW= 30     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    8.54     EW= 6.447E-02     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  6.191E-01    0.005  6.193E-01    0.010  6.198E-01    0.015  6.206E-01
    0.020  6.218E-01    0.025  6.235E-01    0.030  6.257E-01    0.040  6.325E-01
    0.050  6.445E-01    0.060  6.663E-01    0.080  7.729E-01    0.100  9.344E-01
    0.125  9.896E-01    0.150  9.956E-01    0.175  9.973E-01    0.200  9.982E-01
    0.250  9.990E-01    0.300  9.994E-01    0.400  9.996E-01    0.500  9.998E-01
    0.600  9.998E-01    0.800  9.999E-01    1.000  9.999E-01    1.250  1.000E+00
    1.500  1.000E+00    2.000  1.000E+00    2.500  1.000E+00    3.000  1.000E+00
    4.000  1.000E+00    5.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  1.946E-02    0.005  1.959E-02    0.010  2.001E-02    0.015  2.075E-02
    0.020  2.186E-02    0.025  2.346E-02    0.030  2.553E-02    0.040  3.094E-02
    0.050  4.109E-02    0.060  5.830E-02    0.080  1.774E-01    0.100  5.617E-01
    0.125  8.745E-01    0.150  9.333E-01    0.175  9.528E-01    0.200  9.638E-01
    0.250  9.758E-01    0.300  9.820E-01    0.400  9.879E-01    0.500  9.906E-01
    0.600  9.921E-01    0.800  9.935E-01    1.000  9.942E-01    1.250  9.946E-01
    1.500  9.949E-01    2.000  9.951E-01    2.500  9.952E-01    3.000  9.952E-01
    4.000  9.953E-01    5.000  9.953E-01



    Planck approximation
    --------------------

 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP=  1     ELEM= HYDROGEN     RLAMB=  4861.0     NW= 35     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    8.84     EW= 1.882E-01     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  7.491E-01    0.025  7.500E-01    0.050  7.525E-01    0.075  7.566E-01
    0.100  7.622E-01    0.125  7.695E-01    0.150  7.786E-01    0.200  8.006E-01
    0.250  8.275E-01    0.300  8.561E-01    0.400  9.099E-01    0.500  9.482E-01
    0.600  9.711E-01    0.800  9.903E-01    1.000  9.959E-01    1.250  9.981E-01
    1.500  9.990E-01    2.000  9.995E-01    2.500  9.997E-01    3.000  9.998E-01
    4.000  9.999E-01    5.000  9.999E-01    6.000  1.000E+00    8.000  1.000E+00
   10.000  1.000E+00   13.000  1.000E+00   16.000  1.000E+00   20.000  1.000E+00
   25.000  1.000E+00   30.000  1.000E+00   40.000  1.000E+00   50.000  1.000E+00
   60.000  1.000E+00   80.000  1.000E+00  100.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  1.914E-01    0.025  1.928E-01    0.050  1.967E-01    0.075  2.033E-01
    0.100  2.126E-01    0.125  2.250E-01    0.150  2.403E-01    0.200  2.820E-01
    0.250  3.373E-01    0.300  4.036E-01    0.400  5.478E-01    0.500  6.749E-01
    0.600  7.594E-01    0.800  8.316E-01    1.000  8.537E-01    1.250  8.632E-01
    1.500  8.665E-01    2.000  8.689E-01    2.500  8.698E-01    3.000  8.702E-01
    4.000  8.705E-01    5.000  8.707E-01    6.000  8.708E-01    8.000  8.708E-01
   10.000  8.709E-01   13.000  8.709E-01   16.000  8.709E-01   20.000  8.709E-01
   25.000  8.709E-01   30.000  8.709E-01   40.000  8.709E-01   50.000  8.709E-01
   60.000  8.709E-01   80.000  8.709E-01  100.000  8.709E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP=  1     ELEM= HYDROGEN     RLAMB=  4340.0     NW= 35     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    8.84     EW= 1.186E-01     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  8.175E-01    0.025  8.185E-01    0.050  8.215E-01    0.075  8.264E-01
    0.100  8.329E-01    0.125  8.411E-01    0.150  8.509E-01    0.200  8.732E-01
    0.250  8.969E-01    0.300  9.187E-01    0.400  9.532E-01    0.500  9.740E-01
    0.600  9.851E-01    0.800  9.946E-01    1.000  9.974E-01    1.250  9.987E-01
    1.500  9.992E-01    2.000  9.996E-01    2.500  9.998E-01    3.000  9.999E-01
    4.000  9.999E-01    5.000  1.000E+00    6.000  1.000E+00    8.000  1.000E+00
   10.000  1.000E+00   13.000  1.000E+00   16.000  1.000E+00   20.000  1.000E+00
   25.000  1.000E+00   30.000  1.000E+00   40.000  1.000E+00   50.000  1.000E+00
   60.000  1.000E+00   80.000  1.000E+00  100.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  3.877E-01    0.025  3.900E-01    0.050  3.968E-01    0.075  4.082E-01
    0.100  4.242E-01    0.125  4.439E-01    0.150  4.682E-01    0.200  5.255E-01
    0.250  5.901E-01    0.300  6.591E-01    0.400  7.746E-01    0.500  8.536E-01
    0.600  9.009E-01    0.800  9.396E-01    1.000  9.518E-01    1.250  9.573E-01
    1.500  9.596E-01    2.000  9.613E-01    2.500  9.620E-01    3.000  9.623E-01
    4.000  9.626E-01    5.000  9.627E-01    6.000  9.628E-01    8.000  9.628E-01
   10.000  9.628E-01   13.000  9.628E-01   16.000  9.629E-01   20.000  9.629E-01
   25.000  9.629E-01   30.000  9.629E-01   40.000  9.629E-01   50.000  9.629E-01
   60.000  9.629E-01   80.000  9.629E-01  100.000  9.629E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP=  1     ELEM= HYDROGEN     RLAMB=  4101.0     NW= 35     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    8.84     EW= 7.487E-02     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  8.842E-01    0.025  8.849E-01    0.050  8.872E-01    0.075  8.910E-01
    0.100  8.960E-01    0.125  9.020E-01    0.150  9.087E-01    0.200  9.232E-01
    0.250  9.380E-01    0.300  9.516E-01    0.400  9.712E-01    0.500  9.830E-01
    0.600  9.899E-01    0.800  9.957E-01    1.000  9.978E-01    1.250  9.989E-01
    1.500  9.993E-01    2.000  9.997E-01    2.500  9.998E-01    3.000  9.999E-01
    4.000  9.999E-01    5.000  1.000E+00    6.000  1.000E+00    8.000  1.000E+00
   10.000  1.000E+00   13.000  1.000E+00   16.000  1.000E+00   20.000  1.000E+00
   25.000  1.000E+00   30.000  1.000E+00   40.000  1.000E+00   50.000  1.000E+00
   60.000  1.000E+00   80.000  1.000E+00  100.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  5.949E-01    0.025  5.969E-01    0.050  6.031E-01    0.075  6.133E-01
    0.100  6.268E-01    0.125  6.440E-01    0.150  6.632E-01    0.200  7.075E-01
    0.250  7.530E-01    0.300  7.979E-01    0.400  8.705E-01    0.500  9.181E-01
    0.600  9.476E-01    0.800  9.736E-01    1.000  9.828E-01    1.250  9.872E-01
    1.500  9.891E-01    2.000  9.907E-01    2.500  9.913E-01    3.000  9.916E-01
    4.000  9.918E-01    5.000  9.919E-01    6.000  9.920E-01    8.000  9.920E-01
   10.000  9.920E-01   13.000  9.921E-01   16.000  9.921E-01   20.000  9.921E-01
   25.000  9.921E-01   30.000  9.921E-01   40.000  9.921E-01   50.000  9.921E-01
   60.000  9.921E-01   80.000  9.921E-01  100.000  9.921E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP=  2     ELEM=   HELIUM     RLAMB=  4471.0     NW= 80     SYMM= F
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=   11.53     EW= 9.625E-01     C/L RATIO= 1.00001

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
 -100.000  1.000E+00  -80.000  1.000E+00  -60.000  1.000E+00  -50.000  1.000E+00
  -40.000  9.999E-01  -30.000  9.999E-01  -25.000  9.998E-01  -20.000  9.996E-01
  -16.000  9.993E-01  -13.000  9.989E-01  -10.000  9.978E-01   -8.000  9.962E-01
   -6.000  9.925E-01   -5.000  9.886E-01   -4.000  9.811E-01   -3.000  9.641E-01
   -2.500  9.467E-01   -2.300  9.352E-01   -2.100  9.201E-01   -2.000  9.119E-01
   -1.900  9.041E-01   -1.800  8.936E-01   -1.700  8.799E-01   -1.600  8.657E-01
   -1.500  8.518E-01   -1.400  8.486E-01   -1.300  8.573E-01   -1.200  8.664E-01
   -1.100  8.741E-01   -1.000  8.771E-01   -0.900  8.754E-01   -0.800  8.690E-01
   -0.700  8.703E-01   -0.600  8.464E-01   -0.500  8.204E-01   -0.400  7.756E-01
   -0.300  6.633E-01   -0.250  6.019E-01   -0.200  5.749E-01   -0.150  5.646E-01
   -0.125  5.619E-01   -0.100  5.602E-01   -0.075  5.590E-01   -0.050  5.583E-01
   -0.025  5.579E-01    0.000  5.578E-01    0.025  5.579E-01    0.050  5.582E-01
    0.075  5.588E-01    0.100  5.597E-01    0.125  5.609E-01    0.150  5.623E-01
    0.200  5.653E-01    0.250  5.687E-01    0.300  5.748E-01    0.400  6.199E-01
    0.500  7.531E-01    0.600  8.160E-01    0.800  8.570E-01    1.000  8.836E-01
    1.250  9.085E-01    1.500  9.273E-01    2.000  9.516E-01    2.500  9.679E-01
    3.000  9.769E-01    4.000  9.868E-01    5.000  9.917E-01    6.000  9.946E-01
    8.000  9.973E-01   10.000  9.984E-01   13.000  9.992E-01   16.000  9.995E-01
   20.000  9.997E-01   25.000  9.998E-01   30.000  9.999E-01   40.000  1.000E+00
   50.000  1.000E+00   60.000  1.000E+00   80.000  1.000E+00  100.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
 -100.000  9.389E-01  -80.000  9.389E-01  -60.000  9.388E-01  -50.000  9.387E-01
  -40.000  9.386E-01  -30.000  9.383E-01  -25.000  9.379E-01  -20.000  9.372E-01
  -16.000  9.360E-01  -13.000  9.340E-01  -10.000  9.297E-01   -8.000  9.230E-01
   -6.000  9.073E-01   -5.000  8.908E-01   -4.000  8.587E-01   -3.000  7.887E-01
   -2.500  7.201E-01   -2.300  6.753E-01   -2.100  6.181E-01   -2.000  5.876E-01
   -1.900  5.598E-01   -1.800  5.247E-01   -1.700  4.787E-01   -1.600  4.328E-01
   -1.500  3.918E-01   -1.400  3.829E-01   -1.300  4.114E-01   -1.200  4.416E-01
   -1.100  4.706E-01   -1.000  4.860E-01   -0.900  4.860E-01   -0.800  4.706E-01
   -0.700  4.858E-01   -0.600  4.211E-01   -0.500  3.623E-01   -0.400  2.605E-01
   -0.300  1.035E-01   -0.250  4.351E-02   -0.200  1.966E-02   -0.150  1.073E-02
   -0.125  8.391E-03   -0.100  6.936E-03   -0.075  6.034E-03   -0.050  5.342E-03
   -0.025  4.990E-03    0.000  4.875E-03    0.025  4.961E-03    0.050  5.262E-03
    0.075  5.830E-03    0.100  6.598E-03    0.125  7.492E-03    0.150  8.722E-03
    0.200  1.131E-02    0.250  1.440E-02    0.300  1.956E-02    0.400  5.998E-02
    0.500  2.219E-01    0.600  3.371E-01    0.800  4.359E-01    1.000  5.120E-01
    1.250  5.888E-01    1.500  6.546E-01    2.000  7.448E-01    2.500  8.069E-01
    3.000  8.429E-01    4.000  8.840E-01    5.000  9.042E-01    6.000  9.163E-01
    8.000  9.276E-01   10.000  9.324E-01   13.000  9.355E-01   16.000  9.368E-01
   20.000  9.377E-01   25.000  9.382E-01   30.000  9.385E-01   40.000  9.387E-01
   50.000  9.388E-01   60.000  9.388E-01   80.000  9.389E-01  100.000  9.389E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP=  2     ELEM=   HELIUM     RLAMB=  4026.0     NW= 69     SYMM= F
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=   11.53     EW= 1.016E+00     C/L RATIO= 1.00003

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
 -100.000  1.000E+00  -80.000  1.000E+00  -60.000  9.999E-01  -50.000  9.999E-01
  -40.000  9.998E-01  -30.000  9.997E-01  -25.000  9.995E-01  -20.000  9.992E-01
  -16.000  9.988E-01  -13.000  9.982E-01  -10.000  9.969E-01   -8.000  9.952E-01
   -6.000  9.916E-01   -5.000  9.881E-01   -4.000  9.817E-01   -3.000  9.692E-01
   -2.500  9.590E-01   -2.000  9.424E-01   -1.500  9.156E-01   -1.250  8.962E-01
   -1.000  8.693E-01   -0.800  8.415E-01   -0.600  8.026E-01   -0.500  7.774E-01
   -0.400  7.458E-01   -0.300  6.903E-01   -0.250  6.309E-01   -0.200  5.726E-01
   -0.150  5.447E-01   -0.125  5.382E-01   -0.100  5.342E-01   -0.075  5.317E-01
   -0.050  5.301E-01   -0.025  5.292E-01    0.000  5.289E-01    0.025  5.291E-01
    0.050  5.298E-01    0.075  5.310E-01    0.100  5.328E-01    0.125  5.352E-01
    0.150  5.380E-01    0.200  5.454E-01    0.250  5.580E-01    0.300  5.853E-01
    0.400  7.006E-01    0.500  7.636E-01    0.600  7.931E-01    0.800  8.349E-01
    1.000  8.647E-01    1.250  8.930E-01    1.500  9.132E-01    2.000  9.410E-01
    2.500  9.582E-01    3.000  9.687E-01    4.000  9.815E-01    5.000  9.880E-01
    6.000  9.915E-01    8.000  9.952E-01   10.000  9.969E-01   13.000  9.982E-01
   16.000  9.988E-01   20.000  9.992E-01   25.000  9.995E-01   30.000  9.997E-01
   40.000  9.998E-01   50.000  9.999E-01   60.000  9.999E-01   80.000  1.000E+00
  100.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
 -100.000  1.006E+00  -80.000  1.006E+00  -60.000  1.006E+00  -50.000  1.006E+00
  -40.000  1.006E+00  -30.000  1.005E+00  -25.000  1.004E+00  -20.000  1.003E+00
  -16.000  1.001E+00  -13.000  9.980E-01  -10.000  9.923E-01   -8.000  9.846E-01
   -6.000  9.687E-01   -5.000  9.535E-01   -4.000  9.275E-01   -3.000  8.788E-01
   -2.500  8.379E-01   -2.000  7.770E-01   -1.500  6.817E-01   -1.250  6.172E-01
   -1.000  5.351E-01   -0.800  4.563E-01   -0.600  3.633E-01   -0.500  3.113E-01
   -0.400  2.526E-01   -0.300  1.685E-01   -0.250  1.007E-01   -0.200  4.546E-02
   -0.150  2.176E-02   -0.125  1.634E-02   -0.100  1.260E-02   -0.075  1.055E-02
   -0.050  9.204E-03   -0.025  8.403E-03    0.000  8.139E-03    0.025  8.312E-03
    0.050  8.945E-03    0.075  1.011E-02    0.100  1.144E-02    0.125  1.346E-02
    0.150  1.617E-02    0.200  2.238E-02    0.250  3.306E-02    0.300  5.692E-02
    0.400  1.854E-01    0.500  2.835E-01    0.600  3.423E-01    0.800  4.397E-01
    1.000  5.219E-01    1.250  6.061E-01    1.500  6.732E-01    2.000  7.714E-01
    2.500  8.344E-01    3.000  8.764E-01    4.000  9.263E-01    5.000  9.528E-01
    6.000  9.683E-01    8.000  9.844E-01   10.000  9.922E-01   13.000  9.980E-01
   16.000  1.001E+00   20.000  1.003E+00   25.000  1.004E+00   30.000  1.005E+00
   40.000  1.006E+00   50.000  1.006E+00   60.000  1.006E+00   80.000  1.006E+00
  100.000  1.006E+00
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP=  2     ELEM=   HELIUM     RLAMB=  4922.0     NW= 80     SYMM= F
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=   11.53     EW= 6.065E-01     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
 -100.000  1.000E+00  -80.000  1.000E+00  -60.000  1.000E+00  -50.000  1.000E+00
  -40.000  1.000E+00  -30.000  1.000E+00  -25.000  9.999E-01  -20.000  9.999E-01
  -16.000  9.998E-01  -13.000  9.997E-01  -10.000  9.994E-01   -8.000  9.991E-01
   -6.000  9.982E-01   -5.000  9.972E-01   -4.000  9.943E-01   -3.000  9.873E-01
   -2.500  9.787E-01   -2.300  9.724E-01   -2.100  9.636E-01   -2.000  9.586E-01
   -1.900  9.530E-01   -1.800  9.464E-01   -1.700  9.386E-01   -1.600  9.278E-01
   -1.500  9.142E-01   -1.400  9.029E-01   -1.300  9.007E-01   -1.200  9.075E-01
   -1.100  9.164E-01   -1.000  9.214E-01   -0.900  9.213E-01   -0.800  9.167E-01
   -0.700  9.206E-01   -0.600  9.007E-01   -0.500  8.731E-01   -0.400  8.224E-01
   -0.300  7.020E-01   -0.250  6.440E-01   -0.200  6.147E-01   -0.150  6.021E-01
   -0.125  5.987E-01   -0.100  5.964E-01   -0.075  5.948E-01   -0.050  5.938E-01
   -0.025  5.932E-01    0.000  5.930E-01    0.025  5.932E-01    0.050  5.938E-01
    0.075  5.948E-01    0.100  5.964E-01    0.125  5.987E-01    0.150  6.021E-01
    0.200  6.147E-01    0.250  6.440E-01    0.300  7.020E-01    0.400  8.193E-01
    0.500  8.583E-01    0.600  8.822E-01    0.800  9.133E-01    1.000  9.352E-01
    1.250  9.512E-01    1.500  9.630E-01    2.000  9.776E-01    2.500  9.854E-01
    3.000  9.898E-01    4.000  9.943E-01    5.000  9.964E-01    6.000  9.976E-01
    8.000  9.988E-01   10.000  9.993E-01   13.000  9.996E-01   16.000  9.998E-01
   20.000  9.999E-01   25.000  9.999E-01   30.000  1.000E+00   40.000  1.000E+00
   50.000  1.000E+00   60.000  1.000E+00   80.000  1.000E+00  100.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
 -100.000  8.607E-01  -80.000  8.607E-01  -60.000  8.607E-01  -50.000  8.607E-01
  -40.000  8.607E-01  -30.000  8.606E-01  -25.000  8.605E-01  -20.000  8.603E-01
  -16.000  8.601E-01  -13.000  8.596E-01  -10.000  8.585E-01   -8.000  8.565E-01
   -6.000  8.524E-01   -5.000  8.474E-01   -4.000  8.344E-01   -3.000  8.046E-01
   -2.500  7.709E-01   -2.300  7.458E-01   -2.100  7.102E-01   -2.000  6.894E-01
   -1.900  6.671E-01   -1.800  6.409E-01   -1.700  6.099E-01   -1.600  5.693E-01
   -1.500  5.210E-01   -1.400  4.814E-01   -1.300  4.743E-01   -1.200  5.014E-01
   -1.100  5.344E-01   -1.000  5.550E-01   -0.900  5.584E-01   -0.800  5.464E-01
   -0.700  5.692E-01   -0.600  5.054E-01   -0.500  4.271E-01   -0.400  3.003E-01
   -0.300  1.154E-01   -0.250  5.405E-02   -0.200  2.790E-02   -0.150  1.674E-02
   -0.125  1.358E-02   -0.100  1.151E-02   -0.075  1.029E-02   -0.050  9.374E-03
   -0.025  8.816E-03    0.000  8.643E-03    0.025  8.816E-03    0.050  9.374E-03
    0.075  1.029E-02    0.100  1.151E-02    0.125  1.358E-02    0.150  1.674E-02
    0.200  2.790E-02    0.250  5.405E-02    0.300  1.154E-01    0.400  2.899E-01
    0.500  3.774E-01    0.600  4.396E-01    0.800  5.350E-01    1.000  6.081E-01
    1.250  6.670E-01    1.500  7.122E-01    2.000  7.696E-01    2.500  8.001E-01
    3.000  8.178E-01    4.000  8.366E-01    5.000  8.456E-01    6.000  8.506E-01
    8.000  8.557E-01   10.000  8.578E-01   13.000  8.592E-01   16.000  8.598E-01
   20.000  8.602E-01   25.000  8.604E-01   30.000  8.605E-01   40.000  8.606E-01
   50.000  8.607E-01   60.000  8.607E-01   80.000  8.607E-01  100.000  8.607E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP=  2     ELEM=   HELIUM     RLAMB=  4386.0     NW= 69     SYMM= F
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=   11.53     EW= 6.405E-01     C/L RATIO= 1.00001

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
 -100.000  1.000E+00  -80.000  1.000E+00  -60.000  1.000E+00  -50.000  1.000E+00
  -40.000  9.999E-01  -30.000  9.999E-01  -25.000  9.998E-01  -20.000  9.997E-01
  -16.000  9.995E-01  -13.000  9.993E-01  -10.000  9.988E-01   -8.000  9.981E-01
   -6.000  9.966E-01   -5.000  9.950E-01   -4.000  9.922E-01   -3.000  9.861E-01
   -2.500  9.808E-01   -2.000  9.721E-01   -1.500  9.558E-01   -1.250  9.416E-01
   -1.000  9.216E-01   -0.800  8.983E-01   -0.600  8.643E-01   -0.500  8.395E-01
   -0.400  8.070E-01   -0.300  7.433E-01   -0.250  6.823E-01   -0.200  6.218E-01
   -0.150  5.870E-01   -0.125  5.777E-01   -0.100  5.717E-01   -0.075  5.679E-01
   -0.050  5.655E-01   -0.025  5.642E-01    0.000  5.638E-01    0.025  5.642E-01
    0.050  5.655E-01    0.075  5.679E-01    0.100  5.717E-01    0.125  5.777E-01
    0.150  5.870E-01    0.200  6.218E-01    0.250  6.823E-01    0.300  7.433E-01
    0.400  8.070E-01    0.500  8.395E-01    0.600  8.643E-01    0.800  8.983E-01
    1.000  9.219E-01    1.250  9.418E-01    1.500  9.556E-01    2.000  9.724E-01
    2.500  9.811E-01    3.000  9.864E-01    4.000  9.922E-01    5.000  9.951E-01
    6.000  9.966E-01    8.000  9.981E-01   10.000  9.988E-01   13.000  9.993E-01
   16.000  9.995E-01   20.000  9.997E-01   25.000  9.998E-01   30.000  9.999E-01
   40.000  9.999E-01   50.000  1.000E+00   60.000  1.000E+00   80.000  1.000E+00
  100.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
 -100.000  9.543E-01  -80.000  9.543E-01  -60.000  9.542E-01  -50.000  9.542E-01
  -40.000  9.540E-01  -30.000  9.537E-01  -25.000  9.535E-01  -20.000  9.529E-01
  -16.000  9.521E-01  -13.000  9.510E-01  -10.000  9.486E-01   -8.000  9.454E-01
   -6.000  9.386E-01   -5.000  9.319E-01   -4.000  9.200E-01   -3.000  8.959E-01
   -2.500  8.737E-01   -2.000  8.373E-01   -1.500  7.733E-01   -1.250  7.215E-01
   -1.000  6.505E-01   -0.800  5.718E-01   -0.600  4.690E-01   -0.500  4.059E-01
   -0.400  3.289E-01   -0.300  2.133E-01   -0.250  1.323E-01   -0.200  6.719E-02
   -0.150  3.575E-02   -0.125  2.765E-02   -0.100  2.241E-02   -0.075  1.892E-02
   -0.050  1.698E-02   -0.025  1.600E-02    0.000  1.563E-02    0.025  1.600E-02
    0.050  1.698E-02    0.075  1.892E-02    0.100  2.241E-02    0.125  2.765E-02
    0.150  3.575E-02    0.200  6.719E-02    0.250  1.323E-01    0.300  2.133E-01
    0.400  3.289E-01    0.500  4.059E-01    0.600  4.690E-01    0.800  5.718E-01
    1.000  6.505E-01    1.250  7.215E-01    1.500  7.733E-01    2.000  8.373E-01
    2.500  8.737E-01    3.000  8.959E-01    4.000  9.200E-01    5.000  9.319E-01
    6.000  9.386E-01    8.000  9.454E-01   10.000  9.486E-01   13.000  9.510E-01
   16.000  9.521E-01   20.000  9.529E-01   25.000  9.535E-01   30.000  9.537E-01
   40.000  9.540E-01   50.000  9.542E-01   60.000  9.542E-01   80.000  9.543E-01
  100.000  9.543E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP=  6     ELEM=   CARBON     RLAMB=  4267.0     NW= 69     SYMM= F
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    9.14     EW= 4.037E-01     C/L RATIO= 1.00094

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
   -5.000  1.000E+00   -4.000  9.995E-01   -3.000  9.984E-01   -2.500  9.974E-01
   -2.000  9.956E-01   -1.500  9.919E-01   -1.250  9.884E-01   -1.000  9.821E-01
   -0.800  9.730E-01   -0.600  9.561E-01   -0.500  9.415E-01   -0.400  9.182E-01
   -0.300  8.788E-01   -0.250  8.469E-01   -0.200  7.878E-01   -0.175  7.297E-01
   -0.150  6.573E-01   -0.125  5.998E-01   -0.100  5.701E-01   -0.080  5.589E-01
   -0.060  5.530E-01   -0.050  5.512E-01   -0.040  5.498E-01   -0.030  5.489E-01
   -0.025  5.485E-01   -0.020  5.482E-01   -0.015  5.480E-01   -0.010  5.479E-01
   -0.005  5.478E-01    0.000  5.478E-01    0.025  5.485E-01    0.050  5.512E-01
    0.075  5.569E-01    0.100  5.679E-01    0.125  5.748E-01    0.150  5.628E-01
    0.175  5.533E-01    0.200  5.486E-01    0.225  5.464E-01    0.250  5.458E-01
    0.255  5.458E-01    0.260  5.459E-01    0.265  5.460E-01    0.270  5.462E-01
    0.275  5.464E-01    0.280  5.467E-01    0.290  5.475E-01    0.300  5.486E-01
    0.310  5.501E-01    0.330  5.548E-01    0.350  5.636E-01    0.375  5.871E-01
    0.400  6.359E-01    0.425  7.029E-01    0.450  7.598E-01    0.500  8.231E-01
    0.550  8.594E-01    0.650  9.056E-01    0.750  9.330E-01    0.850  9.506E-01
    1.050  9.700E-01    1.250  9.804E-01    1.500  9.874E-01    1.750  9.914E-01
    2.250  9.953E-01    2.750  9.973E-01    3.250  9.984E-01    4.250  9.995E-01
    5.250  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
   -5.000  9.726E-01   -4.000  9.705E-01   -3.000  9.661E-01   -2.500  9.619E-01
   -2.000  9.544E-01   -1.500  9.392E-01   -1.250  9.250E-01   -1.000  9.010E-01
   -0.800  8.674E-01   -0.600  8.059E-01   -0.500  7.546E-01   -0.400  6.777E-01
   -0.300  5.574E-01   -0.250  4.705E-01   -0.200  3.307E-01   -0.175  2.195E-01
   -0.150  1.153E-01   -0.125  5.448E-02   -0.100  2.833E-02   -0.080  1.853E-02
   -0.060  1.339E-02   -0.050  1.177E-02   -0.040  1.070E-02   -0.030  1.000E-02
   -0.025  9.635E-03   -0.020  9.352E-03   -0.015  9.141E-03   -0.010  8.995E-03
   -0.005  8.909E-03    0.000  8.880E-03    0.025  9.630E-03    0.050  1.175E-02
    0.075  1.692E-02    0.100  2.662E-02    0.125  3.233E-02    0.150  2.203E-02
    0.175  1.365E-02    0.200  9.707E-03    0.225  7.708E-03    0.250  7.202E-03
    0.255  7.221E-03    0.260  7.279E-03    0.265  7.377E-03    0.270  7.519E-03
    0.275  7.709E-03    0.280  7.955E-03    0.290  8.651E-03    0.300  9.716E-03
    0.310  1.090E-02    0.330  1.514E-02    0.350  2.278E-02    0.375  4.333E-02
    0.400  9.034E-02    0.425  1.770E-01    0.450  2.753E-01    0.500  4.112E-01
    0.550  5.031E-01    0.650  6.374E-01    0.750  7.263E-01    0.850  7.857E-01
    1.050  8.565E-01    1.250  8.946E-01    1.500  9.214E-01    1.750  9.370E-01
    2.250  9.533E-01    2.750  9.613E-01    3.250  9.658E-01    4.250  9.703E-01
    5.250  9.725E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP=  6     ELEM=   CARBON     RLAMB=  4313.0     NW= 30     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    9.14     EW= 4.347E-02     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  7.586E-01    0.005  7.590E-01    0.010  7.603E-01    0.015  7.623E-01
    0.020  7.652E-01    0.025  7.690E-01    0.030  7.736E-01    0.040  7.856E-01
    0.050  8.001E-01    0.060  8.180E-01    0.080  8.603E-01    0.100  9.068E-01
    0.125  9.556E-01    0.150  9.837E-01    0.175  9.953E-01    0.200  9.986E-01
    0.250  9.997E-01    0.300  9.998E-01    0.400  9.999E-01    0.500  9.999E-01
    0.600  1.000E+00    0.800  1.000E+00    1.000  1.000E+00    1.250  1.000E+00
    1.500  1.000E+00    2.000  1.000E+00    2.500  1.000E+00    3.000  1.000E+00
    4.000  1.000E+00    5.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  2.642E-01    0.005  2.650E-01    0.010  2.672E-01    0.015  2.710E-01
    0.020  2.763E-01    0.025  2.833E-01    0.030  2.920E-01    0.040  3.151E-01
    0.050  3.453E-01    0.060  3.845E-01    0.080  4.889E-01    0.100  6.213E-01
    0.125  7.867E-01    0.150  8.975E-01    0.175  9.465E-01    0.200  9.618E-01
    0.250  9.666E-01    0.300  9.671E-01    0.400  9.675E-01    0.500  9.676E-01
    0.600  9.677E-01    0.800  9.678E-01    1.000  9.678E-01    1.250  9.678E-01
    1.500  9.678E-01    2.000  9.678E-01    2.500  9.679E-01    3.000  9.679E-01
    4.000  9.679E-01    5.000  9.679E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP= 14     ELEM=  SILICON     RLAMB=  4128.1     NW= 30     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    7.54     EW= 4.655E-02     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  6.195E-01    0.005  6.204E-01    0.010  6.231E-01    0.015  6.276E-01
    0.020  6.345E-01    0.025  6.439E-01    0.030  6.567E-01    0.040  6.934E-01
    0.050  7.479E-01    0.060  8.148E-01    0.080  9.333E-01    0.100  9.831E-01
    0.125  9.958E-01    0.150  9.978E-01    0.175  9.985E-01    0.200  9.989E-01
    0.250  9.993E-01    0.300  9.995E-01    0.400  9.997E-01    0.500  9.998E-01
    0.600  9.999E-01    0.800  9.999E-01    1.000  1.000E+00    1.250  1.000E+00
    1.500  1.000E+00    2.000  1.000E+00    2.500  1.000E+00    3.000  1.000E+00
    4.000  1.000E+00    5.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  7.829E-02    0.005  7.908E-02    0.010  8.150E-02    0.015  8.571E-02
    0.020  9.198E-02    0.025  1.008E-01    0.030  1.142E-01    0.040  1.575E-01
    0.050  2.444E-01    0.060  4.001E-01    0.080  7.754E-01    0.100  9.333E-01
    0.125  9.740E-01    0.150  9.804E-01    0.175  9.824E-01    0.200  9.836E-01
    0.250  9.848E-01    0.300  9.855E-01    0.400  9.861E-01    0.500  9.864E-01
    0.600  9.866E-01    0.800  9.867E-01    1.000  9.868E-01    1.250  9.868E-01
    1.500  9.868E-01    2.000  9.869E-01    2.500  9.869E-01    3.000  9.869E-01
    4.000  9.869E-01    5.000  9.869E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP= 14     ELEM=  SILICON     RLAMB=  4130.9     NW= 30     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    7.54     EW= 5.369E-02     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  5.973E-01    0.005  5.979E-01    0.010  5.998E-01    0.015  6.032E-01
    0.020  6.080E-01    0.025  6.149E-01    0.030  6.241E-01    0.040  6.524E-01
    0.050  6.985E-01    0.060  7.641E-01    0.080  9.043E-01    0.100  9.748E-01
    0.125  9.937E-01    0.150  9.967E-01    0.175  9.977E-01    0.200  9.983E-01
    0.250  9.990E-01    0.300  9.993E-01    0.400  9.996E-01    0.500  9.998E-01
    0.600  9.998E-01    0.800  9.999E-01    1.000  9.999E-01    1.250  1.000E+00
    1.500  1.000E+00    2.000  1.000E+00    2.500  1.000E+00    3.000  1.000E+00
    4.000  1.000E+00    5.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  5.838E-02    0.005  5.891E-02    0.010  6.055E-02    0.015  6.343E-02
    0.020  6.788E-02    0.025  7.411E-02    0.030  8.259E-02    0.040  1.101E-01
    0.050  1.653E-01    0.060  2.773E-01    0.080  6.808E-01    0.100  9.064E-01
    0.125  9.670E-01    0.150  9.766E-01    0.175  9.797E-01    0.200  9.814E-01
    0.250  9.833E-01    0.300  9.843E-01    0.400  9.852E-01    0.500  9.856E-01
    0.600  9.858E-01    0.800  9.861E-01    1.000  9.862E-01    1.250  9.862E-01
    1.500  9.863E-01    2.000  9.863E-01    2.500  9.863E-01    3.000  9.863E-01
    4.000  9.863E-01    5.000  9.864E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP= 14     ELEM=  SILICON     RLAMB=  4088.9     NW= 30     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    7.54     EW= 8.115E-02     C/L RATIO= 1.00011

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  7.002E-01    0.005  7.008E-01    0.010  7.025E-01    0.015  7.052E-01
    0.020  7.090E-01    0.025  7.138E-01    0.030  7.202E-01    0.040  7.354E-01
    0.050  7.541E-01    0.060  7.763E-01    0.080  8.255E-01    0.100  8.757E-01
    0.125  9.191E-01    0.150  9.408E-01    0.175  9.517E-01    0.200  9.596E-01
    0.250  9.702E-01    0.300  9.774E-01    0.400  9.859E-01    0.500  9.905E-01
    0.600  9.932E-01    0.800  9.961E-01    1.000  9.975E-01    1.250  9.984E-01
    1.500  9.989E-01    2.000  9.994E-01    2.500  9.997E-01    3.000  9.998E-01
    4.000  9.999E-01    5.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  1.678E-01    0.005  1.684E-01    0.010  1.701E-01    0.015  1.732E-01
    0.020  1.777E-01    0.025  1.840E-01    0.030  1.923E-01    0.040  2.116E-01
    0.050  2.404E-01    0.060  2.765E-01    0.080  3.853E-01    0.100  5.259E-01
    0.125  6.831E-01    0.150  7.695E-01    0.175  8.152E-01    0.200  8.460E-01
    0.250  8.891E-01    0.300  9.166E-01    0.400  9.476E-01    0.500  9.635E-01
    0.600  9.725E-01    0.800  9.819E-01    1.000  9.863E-01    1.250  9.892E-01
    1.500  9.908E-01    2.000  9.923E-01    2.500  9.931E-01    3.000  9.935E-01
    4.000  9.939E-01    5.000  9.941E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP= 14     ELEM=  SILICON     RLAMB=  4116.1     NW= 30     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    7.54     EW= 6.184E-02     C/L RATIO= 1.00005

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  7.333E-01    0.005  7.339E-01    0.010  7.355E-01    0.015  7.383E-01
    0.020  7.420E-01    0.025  7.466E-01    0.030  7.524E-01    0.040  7.675E-01
    0.050  7.852E-01    0.060  8.063E-01    0.080  8.537E-01    0.100  9.004E-01
    0.125  9.407E-01    0.150  9.591E-01    0.175  9.683E-01    0.200  9.743E-01
    0.250  9.822E-01    0.300  9.871E-01    0.400  9.924E-01    0.500  9.950E-01
    0.600  9.965E-01    0.800  9.980E-01    1.000  9.987E-01    1.250  9.992E-01
    1.500  9.995E-01    2.000  9.997E-01    2.500  9.998E-01    3.000  9.999E-01
    4.000  1.000E+00    5.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  2.077E-01    0.005  2.084E-01    0.010  2.104E-01    0.015  2.139E-01
    0.020  2.191E-01    0.025  2.263E-01    0.030  2.359E-01    0.040  2.602E-01
    0.050  2.925E-01    0.060  3.356E-01    0.080  4.550E-01    0.100  6.099E-01
    0.125  7.669E-01    0.150  8.410E-01    0.175  8.768E-01    0.200  9.002E-01
    0.250  9.297E-01    0.300  9.468E-01    0.400  9.647E-01    0.500  9.733E-01
    0.600  9.781E-01    0.800  9.829E-01    1.000  9.851E-01    1.250  9.866E-01
    1.500  9.874E-01    2.000  9.882E-01    2.500  9.885E-01    3.000  9.887E-01
    4.000  9.889E-01    5.000  9.890E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT= 10.0
 NSP=  1     ELEM= HYDROGEN     RLAMB=  4101.0     NW= 35     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    8.84     EW= 7.593E-02     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  8.938E-01    0.025  8.944E-01    0.050  8.959E-01    0.075  8.985E-01
    0.100  9.019E-01    0.125  9.062E-01    0.150  9.112E-01    0.200  9.223E-01
    0.250  9.345E-01    0.300  9.470E-01    0.400  9.669E-01    0.500  9.802E-01
    0.600  9.884E-01    0.800  9.953E-01    1.000  9.977E-01    1.250  9.988E-01
    1.500  9.993E-01    2.000  9.997E-01    2.500  9.998E-01    3.000  9.999E-01
    4.000  9.999E-01    5.000  1.000E+00    6.000  1.000E+00    8.000  1.000E+00
   10.000  1.000E+00   13.000  1.000E+00   16.000  1.000E+00   20.000  1.000E+00
   25.000  1.000E+00   30.000  1.000E+00   40.000  1.000E+00   50.000  1.000E+00
   60.000  1.000E+00   80.000  1.000E+00  100.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  6.212E-01    0.025  6.227E-01    0.050  6.271E-01    0.075  6.345E-01
    0.100  6.447E-01    0.125  6.571E-01    0.150  6.719E-01    0.200  7.062E-01
    0.250  7.448E-01    0.300  7.841E-01    0.400  8.552E-01    0.500  9.073E-01
    0.600  9.407E-01    0.800  9.717E-01    1.000  9.821E-01    1.250  9.871E-01
    1.500  9.891E-01    2.000  9.907E-01    2.500  9.913E-01    3.000  9.916E-01
    4.000  9.918E-01    5.000  9.919E-01    6.000  9.920E-01    8.000  9.920E-01
   10.000  9.920E-01   13.000  9.921E-01   16.000  9.921E-01   20.000  9.921E-01
   25.000  9.921E-01   30.000  9.921E-01   40.000  9.921E-01   50.000  9.921E-01
   60.000  9.921E-01   80.000  9.921E-01  100.000  9.921E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT= 10.0
 NSP=  2     ELEM=   HELIUM     RLAMB=  4471.0     NW= 80     SYMM= F
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=   11.53     EW= 1.025E+00     C/L RATIO= 1.00001

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
 -100.000  1.000E+00  -80.000  1.000E+00  -60.000  1.000E+00  -50.000  1.000E+00
  -40.000  9.999E-01  -30.000  9.999E-01  -25.000  9.998E-01  -20.000  9.996E-01
  -16.000  9.993E-01  -13.000  9.989E-01  -10.000  9.978E-01   -8.000  9.962E-01
   -6.000  9.925E-01   -5.000  9.886E-01   -4.000  9.811E-01   -3.000  9.641E-01
   -2.500  9.466E-01   -2.300  9.352E-01   -2.100  9.201E-01   -2.000  9.118E-01
   -1.900  9.041E-01   -1.800  8.935E-01   -1.700  8.799E-01   -1.600  8.656E-01
   -1.500  8.517E-01   -1.400  8.485E-01   -1.300  8.572E-01   -1.200  8.662E-01
   -1.100  8.738E-01   -1.000  8.767E-01   -0.900  8.748E-01   -0.800  8.679E-01
   -0.700  8.679E-01   -0.600  8.374E-01   -0.500  7.515E-01   -0.400  6.205E-01
   -0.300  5.769E-01   -0.250  5.690E-01   -0.200  5.645E-01   -0.150  5.619E-01
   -0.125  5.610E-01   -0.100  5.603E-01   -0.075  5.598E-01   -0.050  5.595E-01
   -0.025  5.593E-01    0.000  5.592E-01    0.025  5.592E-01    0.050  5.593E-01
    0.075  5.595E-01    0.100  5.599E-01    0.125  5.604E-01    0.150  5.610E-01
    0.200  5.627E-01    0.250  5.653E-01    0.300  5.691E-01    0.400  5.836E-01
    0.500  6.247E-01    0.600  7.343E-01    0.800  8.546E-01    1.000  8.831E-01
    1.250  9.083E-01    1.500  9.272E-01    2.000  9.516E-01    2.500  9.679E-01
    3.000  9.769E-01    4.000  9.867E-01    5.000  9.917E-01    6.000  9.946E-01
    8.000  9.973E-01   10.000  9.984E-01   13.000  9.992E-01   16.000  9.995E-01
   20.000  9.997E-01   25.000  9.998E-01   30.000  9.999E-01   40.000  1.000E+00
   50.000  1.000E+00   60.000  1.000E+00   80.000  1.000E+00  100.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
 -100.000  9.389E-01  -80.000  9.389E-01  -60.000  9.388E-01  -50.000  9.387E-01
  -40.000  9.386E-01  -30.000  9.383E-01  -25.000  9.379E-01  -20.000  9.372E-01
  -16.000  9.360E-01  -13.000  9.340E-01  -10.000  9.297E-01   -8.000  9.230E-01
   -6.000  9.073E-01   -5.000  8.908E-01   -4.000  8.587E-01   -3.000  7.887E-01
   -2.500  7.200E-01   -2.300  6.753E-01   -2.100  6.181E-01   -2.000  5.875E-01
   -1.900  5.598E-01   -1.800  5.247E-01   -1.700  4.787E-01   -1.600  4.327E-01
   -1.500  3.917E-01   -1.400  3.828E-01   -1.300  4.113E-01   -1.200  4.414E-01
   -1.100  4.702E-01   -1.000  4.854E-01   -0.900  4.850E-01   -0.800  4.690E-01
   -0.700  4.821E-01   -0.600  4.080E-01   -0.500  2.300E-01   -0.400  6.044E-02
   -0.300  2.150E-02   -0.250  1.468E-02   -0.200  1.071E-02   -0.150  8.339E-03
   -0.125  7.569E-03   -0.100  7.034E-03   -0.075  6.667E-03   -0.050  6.424E-03
   -0.025  6.262E-03    0.000  6.163E-03    0.025  6.179E-03    0.050  6.310E-03
    0.075  6.472E-03    0.100  6.723E-03    0.125  7.083E-03    0.150  7.580E-03
    0.200  9.157E-03    0.250  1.132E-02    0.300  1.474E-02    0.400  2.751E-02
    0.500  6.451E-02    0.600  1.929E-01    0.800  4.331E-01    1.000  5.113E-01
    1.250  5.885E-01    1.500  6.544E-01    2.000  7.447E-01    2.500  8.069E-01
    3.000  8.429E-01    4.000  8.840E-01    5.000  9.042E-01    6.000  9.163E-01
    8.000  9.276E-01   10.000  9.324E-01   13.000  9.355E-01   16.000  9.368E-01
   20.000  9.377E-01   25.000  9.382E-01   30.000  9.385E-01   40.000  9.387E-01
   50.000  9.388E-01   60.000  9.388E-01   80.000  9.389E-01  100.000  9.389E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT= 10.0
 NSP=  6     ELEM=   CARBON     RLAMB=  4267.0     NW= 69     SYMM= F
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    9.14     EW= 5.121E-01     C/L RATIO= 1.00094

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
   -5.000  1.000E+00   -4.000  9.995E-01   -3.000  9.984E-01   -2.500  9.974E-01
   -2.000  9.955E-01   -1.500  9.918E-01   -1.250  9.882E-01   -1.000  9.816E-01
   -0.800  9.719E-01   -0.600  9.529E-01   -0.500  9.319E-01   -0.400  8.448E-01
   -0.300  6.563E-01   -0.250  6.021E-01   -0.200  5.757E-01   -0.175  5.683E-01
   -0.150  5.632E-01   -0.125  5.596E-01   -0.100  5.570E-01   -0.080  5.555E-01
   -0.060  5.544E-01   -0.050  5.539E-01   -0.040  5.535E-01   -0.030  5.532E-01
   -0.025  5.531E-01   -0.020  5.529E-01   -0.015  5.528E-01   -0.010  5.527E-01
   -0.005  5.526E-01    0.000  5.525E-01    0.025  5.522E-01    0.050  5.520E-01
    0.075  5.518E-01    0.100  5.516E-01    0.125  5.512E-01    0.150  5.509E-01
    0.175  5.505E-01    0.200  5.502E-01    0.225  5.500E-01    0.250  5.501E-01
    0.255  5.501E-01    0.260  5.502E-01    0.265  5.502E-01    0.270  5.503E-01
    0.275  5.504E-01    0.280  5.505E-01    0.290  5.507E-01    0.300  5.510E-01
    0.310  5.513E-01    0.330  5.522E-01    0.350  5.534E-01    0.375  5.554E-01
    0.400  5.582E-01    0.425  5.622E-01    0.450  5.678E-01    0.500  5.884E-01
    0.550  6.327E-01    0.650  8.158E-01    0.750  9.208E-01    0.850  9.464E-01
    1.050  9.687E-01    1.250  9.798E-01    1.500  9.872E-01    1.750  9.912E-01
    2.250  9.953E-01    2.750  9.973E-01    3.250  9.984E-01    4.250  9.995E-01
    5.250  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
   -5.000  9.725E-01   -4.000  9.705E-01   -3.000  9.661E-01   -2.500  9.618E-01
   -2.000  9.542E-01   -1.500  9.388E-01   -1.250  9.242E-01   -1.000  8.992E-01
   -0.800  8.633E-01   -0.600  7.943E-01   -0.500  7.225E-01   -0.400  4.641E-01
   -0.300  1.144E-01   -0.250  5.669E-02   -0.200  3.313E-02   -0.175  2.692E-02
   -0.150  2.237E-02   -0.125  1.911E-02   -0.100  1.699E-02   -0.080  1.584E-02
   -0.060  1.469E-02   -0.050  1.424E-02   -0.040  1.387E-02   -0.030  1.356E-02
   -0.025  1.343E-02   -0.020  1.331E-02   -0.015  1.320E-02   -0.010  1.310E-02
   -0.005  1.301E-02    0.000  1.293E-02    0.025  1.263E-02    0.050  1.244E-02
    0.075  1.228E-02    0.100  1.208E-02    0.125  1.181E-02    0.150  1.150E-02
    0.175  1.120E-02    0.200  1.096E-02    0.225  1.085E-02    0.250  1.089E-02
    0.255  1.092E-02    0.260  1.095E-02    0.265  1.100E-02    0.270  1.106E-02
    0.275  1.112E-02    0.280  1.120E-02    0.290  1.138E-02    0.300  1.161E-02
    0.310  1.189E-02    0.330  1.264E-02    0.350  1.371E-02    0.375  1.571E-02
    0.400  1.795E-02    0.425  2.142E-02    0.450  2.656E-02    0.500  4.435E-02
    0.550  8.717E-02    0.650  3.923E-01    0.750  6.855E-01    0.850  7.714E-01
    1.050  8.516E-01    1.250  8.924E-01    1.500  9.204E-01    1.750  9.365E-01
    2.250  9.532E-01    2.750  9.612E-01    3.250  9.657E-01    4.250  9.703E-01
    5.250  9.725E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP= 14     ELEM=  SILICON     RLAMB=  4128.1     NW= 30     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    6.54     EW= 1.099E-02     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  8.742E-01    0.005  8.754E-01    0.010  8.790E-01    0.015  8.847E-01
    0.020  8.924E-01    0.025  9.017E-01    0.030  9.125E-01    0.040  9.358E-01
    0.050  9.568E-01    0.060  9.739E-01    0.080  9.927E-01    0.100  9.983E-01
    0.125  9.996E-01    0.150  9.998E-01    0.175  9.998E-01    0.200  9.999E-01
    0.250  9.999E-01    0.300  1.000E+00    0.400  1.000E+00    0.500  1.000E+00
    0.600  1.000E+00    0.800  1.000E+00    1.000  1.000E+00    1.250  1.000E+00
    1.500  1.000E+00    2.000  1.000E+00    2.500  1.000E+00    3.000  1.000E+00
    4.000  1.000E+00    5.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  6.058E-01    0.005  6.096E-01    0.010  6.210E-01    0.015  6.399E-01
    0.020  6.655E-01    0.025  6.958E-01    0.030  7.291E-01    0.040  7.981E-01
    0.050  8.616E-01    0.060  9.107E-01    0.080  9.646E-01    0.100  9.815E-01
    0.125  9.856E-01    0.150  9.862E-01    0.175  9.864E-01    0.200  9.866E-01
    0.250  9.867E-01    0.300  9.868E-01    0.400  9.868E-01    0.500  9.868E-01
    0.600  9.869E-01    0.800  9.869E-01    1.000  9.869E-01    1.250  9.869E-01
    1.500  9.869E-01    2.000  9.869E-01    2.500  9.869E-01    3.000  9.869E-01
    4.000  9.869E-01    5.000  9.869E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP= 14     ELEM=  SILICON     RLAMB=  4128.1     NW= 30     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    7.02     EW= 2.523E-02     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  7.425E-01    0.005  7.441E-01    0.010  7.489E-01    0.015  7.570E-01
    0.020  7.683E-01    0.025  7.829E-01    0.030  8.004E-01    0.040  8.415E-01
    0.050  8.863E-01    0.060  9.275E-01    0.080  9.784E-01    0.100  9.948E-01
    0.125  9.987E-01    0.150  9.993E-01    0.175  9.995E-01    0.200  9.997E-01
    0.250  9.998E-01    0.300  9.999E-01    0.400  9.999E-01    0.500  1.000E+00
    0.600  1.000E+00    0.800  1.000E+00    1.000  1.000E+00    1.250  1.000E+00
    1.500  1.000E+00    2.000  1.000E+00    2.500  1.000E+00    3.000  1.000E+00
    4.000  1.000E+00    5.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  2.344E-01    0.005  2.374E-01    0.010  2.465E-01    0.015  2.635E-01
    0.020  2.885E-01    0.025  3.217E-01    0.030  3.680E-01    0.040  4.898E-01
    0.050  6.347E-01    0.060  7.661E-01    0.080  9.209E-01    0.100  9.706E-01
    0.125  9.830E-01    0.150  9.849E-01    0.175  9.856E-01    0.200  9.859E-01
    0.250  9.863E-01    0.300  9.865E-01    0.400  9.867E-01    0.500  9.867E-01
    0.600  9.868E-01    0.800  9.868E-01    1.000  9.869E-01    1.250  9.869E-01
    1.500  9.869E-01    2.000  9.869E-01    2.500  9.869E-01    3.000  9.869E-01
    4.000  9.869E-01    5.000  9.869E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP= 14     ELEM=  SILICON     RLAMB=  4128.1     NW= 30     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    7.54     EW= 4.655E-02     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  6.195E-01    0.005  6.204E-01    0.010  6.231E-01    0.015  6.276E-01
    0.020  6.345E-01    0.025  6.439E-01    0.030  6.567E-01    0.040  6.934E-01
    0.050  7.479E-01    0.060  8.148E-01    0.080  9.333E-01    0.100  9.831E-01
    0.125  9.958E-01    0.150  9.978E-01    0.175  9.985E-01    0.200  9.989E-01
    0.250  9.993E-01    0.300  9.995E-01    0.400  9.997E-01    0.500  9.998E-01
    0.600  9.999E-01    0.800  9.999E-01    1.000  1.000E+00    1.250  1.000E+00
    1.500  1.000E+00    2.000  1.000E+00    2.500  1.000E+00    3.000  1.000E+00
    4.000  1.000E+00    5.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  7.829E-02    0.005  7.908E-02    0.010  8.150E-02    0.015  8.571E-02
    0.020  9.198E-02    0.025  1.008E-01    0.030  1.142E-01    0.040  1.575E-01
    0.050  2.444E-01    0.060  4.001E-01    0.080  7.754E-01    0.100  9.333E-01
    0.125  9.740E-01    0.150  9.804E-01    0.175  9.824E-01    0.200  9.836E-01
    0.250  9.848E-01    0.300  9.855E-01    0.400  9.861E-01    0.500  9.864E-01
    0.600  9.866E-01    0.800  9.867E-01    1.000  9.868E-01    1.250  9.868E-01
    1.500  9.868E-01    2.000  9.869E-01    2.500  9.869E-01    3.000  9.869E-01
    4.000  9.869E-01    5.000  9.869E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP= 14     ELEM=  SILICON     RLAMB=  4128.1     NW= 30     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    8.02     EW= 6.540E-02     C/L RATIO= 1.00000

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  5.726E-01    0.005  5.729E-01    0.010  5.740E-01    0.015  5.759E-01
    0.020  5.788E-01    0.025  5.828E-01    0.030  5.882E-01    0.040  6.046E-01
    0.050  6.333E-01    0.060  6.821E-01    0.080  8.382E-01    0.100  9.515E-01
    0.125  9.875E-01    0.150  9.933E-01    0.175  9.954E-01    0.200  9.966E-01
    0.250  9.979E-01    0.300  9.986E-01    0.400  9.992E-01    0.500  9.995E-01
    0.600  9.997E-01    0.800  9.998E-01    1.000  9.999E-01    1.250  9.999E-01
    1.500  9.999E-01    2.000  1.000E+00    2.500  1.000E+00    3.000  1.000E+00
    4.000  1.000E+00    5.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  3.791E-02    0.005  3.824E-02    0.010  3.924E-02    0.015  4.084E-02
    0.020  4.313E-02    0.025  4.637E-02    0.030  5.084E-02    0.040  6.522E-02
    0.050  9.192E-02    0.060  1.458E-01    0.080  4.640E-01    0.100  8.310E-01
    0.125  9.484E-01    0.150  9.673E-01    0.175  9.735E-01    0.200  9.770E-01
    0.250  9.808E-01    0.300  9.827E-01    0.400  9.846E-01    0.500  9.854E-01
    0.600  9.859E-01    0.800  9.863E-01    1.000  9.865E-01    1.250  9.867E-01
    1.500  9.867E-01    2.000  9.868E-01    2.500  9.868E-01    3.000  9.869E-01
    4.000  9.869E-01    5.000  9.869E-01
 


 TEFF= 20000.     GRAV= 1.00E+02     FRACT(HE)= 9.87E-01     VT=  0.0
 NSP= 14     ELEM=  SILICON     RLAMB=  4128.1     NW= 30     SYMM= T
 ION=  0     WAVE=      0.00     GF=     0.000     MULT=     0.000
 ABUNDANCE=    8.54     EW= 8.694E-02     C/L RATIO= 1.00002

    WAVE      FLUX      WAVE      FLUX      WAVE      FLUX      WAVE      FLUX
    0.000  5.511E-01    0.005  5.512E-01    0.010  5.517E-01    0.015  5.526E-01
    0.020  5.538E-01    0.025  5.555E-01    0.030  5.578E-01    0.040  5.647E-01
    0.050  5.765E-01    0.060  5.970E-01    0.080  6.960E-01    0.100  8.656E-01
    0.125  9.596E-01    0.150  9.781E-01    0.175  9.848E-01    0.200  9.887E-01
    0.250  9.930E-01    0.300  9.952E-01    0.400  9.973E-01    0.500  9.983E-01
    0.600  9.989E-01    0.800  9.994E-01    1.000  9.996E-01    1.250  9.998E-01
    1.500  9.998E-01    2.000  9.999E-01    2.500  1.000E+00    3.000  1.000E+00
    4.000  1.000E+00    5.000  1.000E+00


       WAVE     TAUC      WAVE     TAUC      WAVE     TAUC      WAVE     TAUC
    0.000  1.955E-02    0.005  1.969E-02    0.010  2.011E-02    0.015  2.085E-02
    0.020  2.198E-02    0.025  2.359E-02    0.030  2.565E-02    0.040  3.113E-02
    0.050  4.137E-02    0.060  5.882E-02    0.080  1.657E-01    0.100  5.437E-01
    0.125  8.617E-01    0.150  9.224E-01    0.175  9.427E-01    0.200  9.540E-01
    0.250  9.665E-01    0.300  9.730E-01    0.400  9.792E-01    0.500  9.820E-01
    0.600  9.835E-01    0.800  9.850E-01    1.000  9.857E-01    1.250  9.861E-01
    1.500  9.864E-01    2.000  9.866E-01    2.500  9.867E-01    3.000  9.868E-01
    4.000  9.868E-01    5.000  9.868E-01
