!
!       Generates LTE models by interpolating temperature structure
!       and then re-calculate pressure structure
!
      PROGRAM GENERATE

!
!       Double precision version
!
      IMPLICIT REAL*8 (A-H,O-Z)

!
!       Common blocks
!
      INCLUDE 'common_all.f'

!
!       Grid variables - 
!                        upto 29 effective temperatures
!                        upto 9 gravities
!
      DIMENSION TEFFT(29),GRAVT(9),IT(29,9),
     1TAT(30,29,9),TET(30,29,9),PGT(30,29,9),PET(30,29,9),OPT(30,29,9)

!
!       Initialize some variables
!
      DATA IT,ITEFF,IGRAV/263*0/,TEFFT,GRAVT/38*0.0/,NDEPTH/25/
      RLAMB=5000.

!
!       Input/output streams
!
!      NREAD=5
!      NWRITE=6
!      NDISC=7
!      NDEBUG=90
!      NATOM=11
!      NMODEL=20

!
!       QUB Opacities
!
      NOPTYP=0

!
!       Debug
!
!     BUGMN=.FALSE.

      IF(BUGMN) THEN
        OPEN(UNIT=NDEBUG,FILE='LT_TEMP:MOD_BUG.DBG',STATUS='NEW')
      ENDIF

!
!       Read in atomic data for opacity calculation
!
      CALL ATDATA

!
!       Read in models
!
      OPEN(UNIT=NMODEL,FILE='LT_MODEL:LTEMOD.DAT',STATUS='OLD',READONLY)

   10 READ(NMODEL,100,END=11)TEFF,GRAV,AHE

!
!       Check for end of models
!
      IF(TEFF.LT.0.0) GOTO 11

!
!       Check for logarithmic gravity
!
      IF(GRAV.GT.10.0) THEN
        GRAV=LOG10(GRAV)
      ENDIF

      READ(NMODEL,100)(TAU(I),TEMP(I),PG(I),PE(I),OP(I),I=1,NDEPTH)

!
!       Check for first model
!
      IF(ITEFF.EQ.0) THEN

        I=1
        J=1
        ITEFF=1
        IGRAV=1
        TEFFT(1)=TEFF
        GRAVT(1)=GRAV
      ELSE

!
!       Search for position in grid
!
        DO I=1,ITEFF
          IF(ABS((TEFF-TEFFT(I))/TEFF).LT.1.0E-3) GOTO 12
        ENDDO

!
!       New temperature
!
        ITEFF=ITEFF+1
        I=ITEFF
        TEFFT(I)=TEFF

      ENDIF

!
!       Check for gravity
!
   12 DO J=1,IGRAV
        IF((ABS(GRAV-GRAVT(J))/GRAV).LT.1.0E-3) GOTO 13
      ENDDO

!
!       New gravity
!
      IGRAV=IGRAV+1
      J=IGRAV
      GRAVT(J)=GRAV

!
!        Insert model in grid and set IT to 1
!
   13 DO K=1,NDEPTH
        TAT(K,I,J)=TAU(K)
        TET(K,I,J)=TEMP(K)
        PGT(K,I,J)=PG(K)
        PET(K,I,J)=PE(K)
        OPT(K,I,J)=OP(K)
        IT(I,J)=1
      ENDDO

      GOTO 10

!
!      Debug output
!
   11 IF(BUGMN) THEN
        DO I=1,9
          DO J=1,29
          IF(IT(J,I).NE.0) THEN
            WRITE(NDEBUG,901)TEFFT(J),GRAVT(I),
     *                       (TAT(K,J,I),TET(K,J,I),PGT(K,J,I),
     *                        PET(K,J,I),OPT(K,J,I),K=1,NDEPTH)
          ENDIF
          ENDDO
        ENDDO
      ENDIF

!
!       Read in effective temperature, gravity and helium/hydrogen ratio
!
      WRITE(NWRITE,200)
      READ(NREAD,*)TEFF,GRAV,HETOH

      IF(TEFF.LE.0.0)STOP
!
!      Check for logarithmic gravity
!
      IF(GRAV.GT.10.0) THEN
        GRAV=LOG10(GRAV)
      ENDIF

!
!      Check for loarithmic helium abundance
!
      IF(HETOH.GT.1.0) THEN
        HETOH=1.0E-12*(10.0**HETOH)
      ENDIF

!
!       Calculate composition - on exit from subroutine COMPOS,
!       AHE will be the fractional number of helium atoms
!
      AHE=HETOH
      CALL COMPOS

!
!       Find position in the grid
!
      DO I=2,ITEFF
        IF(TEFF.LT.TEFFT(I)) GOTO 15
      ENDDO

      I=ITEFF

   15 DO J=2,IGRAV
        IF(GRAV.LT.GRAVT(J)) GOTO 16
      ENDDO

      J=IGRAV
!
!       Check that all models are available for temperature interpolation
!       Assumes that only low temperature models will be missing
!
   16 IF(IT(I,J-1).EQ.0.OR.IT(I-1,J-1).EQ.0)J=J+1

!
!       Linearly interpolates temperature structure
!
      DELT=TEFFT(I)-TEFFT(I-1)
      DELG=GRAVT(J)-GRAVT(J-1)
      CONST=1.0/(DELT*DELG)

      A1=CONST*(TEFF-TEFFT(I-1))*(GRAV-GRAVT(J-1))
      A2=CONST*(TEFFT(I)-TEFF)*  (GRAV-GRAVT(J-1))
      A3=CONST*(TEFF-TEFFT(I-1))*(GRAVT(J)-GRAV)
      A4=CONST*(TEFFT(I)-TEFF)*  (GRAVT(J)-GRAV)

      DO K=1,NDEPTH

        TAU(K)=TAT(K,1,1)

        TEMP(K)=A4*TET(K,I-1,J-1)+
     *          A2*TET(K,I-1,J)+
     *          A3*TET(K,I,J-1)+
     *          A1*TET(K,I,J)

      ENDDO

!
!      Debug
!
      IF(BUGMN) THEN
        WRITE(NDEBUG,900)NDEPTH,(TAU(I),TEMP(I),I=1,NDEPTH)
      ENDIF

!
!       Generate pressure structure
!
      CALL GEN

!
!       Write to screen
!
      WRITE(NWRITE,201)TEFF,GRAV,HETOH,
     *                 AH,AHE,AC,AN,AO,ANE,AMG,ASI,AS,ACA,AFE
      WRITE(NWRITE,202)(TAU(I),TEMP(I),PG(I),PE(I),OP(I),I=1,NDEPTH)

!
!       Write to disc
!
      OPEN(UNIT=NDISC,FILE='LT_TEMP:MODELS.TMP',STATUS='NEW')

      WRITE(NDISC,300)TEFF,GRAV,HETOH
      WRITE(NDISC,300)(TAU(I),TEMP(I),PG(I),PE(I),OP(I),I=1,NDEPTH)

      GOTO 11

!
!      Format statements
!
  100 FORMAT(5E12.5)
  200 FORMAT(' ***** INPUT TEFF,GRAV,(He/H) - 0 0 0 TO STOP *****')
  201 FORMAT(//' TEFF=',F8.0,5X,'GRAV=',1PE10.3,5X,'HE/H=',0PF8.2//
     *       ' AH =',1PE10.3,2X,'AHE=',1PE10.3,2X,'AC =',1PE10.3,
     *       2X,'AN =',1PE10.3,2X,'AO =',1PE10.3/
     *       ' ANE=',1PE10.3,2X,'AMG=',1PE10.3,2X,'ASI=',1PE10.3,
     *       2X,'AS =',1PE10.3,2X,'ACA=',1PE10.3/' AFE=',1PE10.3/)
  202 FORMAT(9X,'TAU',8X,'TEMP',10X,'PG',10X,'PE',8X,'OPAC'/
     130(1P5E12.4/))
  300 FORMAT(1P5E12.5)

!
!      Debug statements
!
  900 FORMAT(' NDEPTH=',I5//9X,'TAU',8X,'TEMP'/30(1P2E12.5/))
  901 FORMAT(//' TEFF=',F10.0,5X,'GRAV=',1PE10.2//
     *9X,'TAU',8X,'TEMP',10X,'PG',10X,'PE',10X,'OP'/
     *30(1PE13.3,0PF12.0,1P3E12.3/))
      END
