  module bb_global

!+
!
!  Purpose:
!     Module for opacity sampling line data
!
!  Authors:
!     CSJ: C. S. Jeffery (Armagh Observatory)
!
!  History:
!     03-MAR-1999 (CSJ): Created
!     17-MAY-2004 (NTB): modified
!-

    implicit none

!  Array index parameters.

      integer, parameter :: BB_MAXNL=1000000      ! Lines in linelist 
      integer, parameter :: BB_MAXBA=109          ! Number of atomic species in linelist
      integer, parameter :: BB_MAXNI=10           ! Number of ions per atom in linelist

!  Parameters defining the grid of tabulated H functions

      integer, parameter :: BB_MAXNP  = 40        ! Maximum value of damping constant
      integer, parameter :: BB_PRANGE =  8        ! Range of tabulated log damping constant
      integer, parameter :: BB_PZERO  = -7

      real, parameter :: BB_PDELTA = BB_MAXNP/BB_PRANGE  
      integer, parameter :: BB_MAXNQ  = 40        ! Maximum value of reduced frequency
      integer, parameter :: BB_QRANGE =  5        ! Range of tabulated log reduced frequency
      integer, parameter :: BB_QZERO  = -2
      real, parameter :: BB_QDELTA = BB_MAXNQ/BB_QRANGE  

!  Array holders for absorption line data
      integer ::       BB_KK(BB_MAXNL)   ! Atom identifiers
      integer ::       BB_JJ(BB_MAXNL)   ! Ion  identifiers
      real ::          BB_LN(BB_MAXNL)   ! Line frequency as log (vu_ref-vu_l)
      real ::          BB_NU(BB_MAXNL)   ! Line frequency as (vu_ref-vu_l)**2
      real ::          BB_EX(BB_MAXNL)   ! Line lower level excitation energy (erg)
      real ::          BB_GF(BB_MAXNL)   ! Line gf-value (ln)
      real ::          BB_GAM(BB_MAXNL)  ! Damping constant (log gamma/4pi)

      real ::          BB_AM(BB_MAXBA)   ! Atomic masses for atoms

!  Array pointers for frequency blocks
      integer, allocatable :: BB_NUS(:)  ! index for start line in frequency block 
      integer, allocatable :: BB_NUF(:)  ! index for final line in frequency block 

!  Tabulated Voigt function
      real ::          BB_HH (0:BB_MAXNP,0:BB_MAXNQ)  ! ln H(a,v)

  end module bb_global


