*+ CHR_APPND - Copy one string into another (ignoring trailing blanks).
      SUBROUTINE CHR_APPND (STR1,STR2,LEN2)
*    Description :
*     The string STR1 (or as much of it as there is room for) is 
*     copied into the part of STR2 beginning at position LEN2+1. 
*     LEN2 is updated to indicate the final length of STR2 after 
*     this operation. Trailing blanks in STR1 are ignored. 
*    Invocation :
*     CALL CHR_APPND (STR1, STR2, LEN2)
*    Arguments :
*     STR1  =  CHARACTER*(*) (Given)
*           Input string to be copied into the string that is to be
*           modified.
*     STR2  =  CHARACTER*(*) (Modified)
*           String to be updated by adding the contents of STR1.
*     LEN2  =  INTEGER (Modified)
*           The current position of the last non-blank character in
*           STR2.
*    Method :
*     Compute the maximum size of the output string.
*     Compute the length of the input string that can be copied;
*     either all of it or as much as there is space for in the
*     output string.
*     Copy the input string into the output string.
*     Update the length (last non-blank character) of the output
*     string.
*    Authors :
*     Sid Wright.                (UCL::SLW)
*     A C Davenhall.             (ROE::ACD)
*    History :
*     07-Mar-1983:  Original.                                (UCL::SLW)
*     06-Nov-1984:  Documentation improved.                  (ROE::ACD)
*     13-Sep-1988:  Use LEN instead of CHR_SIZE
*                   Improve documentation                    (RAL::AJC)
*    Type definitions :
      IMPLICIT NONE        ! Force Total Declarations.
*    Import :
      CHARACTER
     :  STR1*(*)           ! Input string.
*    Import-Export :
      CHARACTER
     :  STR2*(*)           ! Output string.
      INTEGER
     :  LEN2               ! Length of STR2.
*    External references :
      INTEGER
     :  CHR_LEN            ! string length (ignoring trailing blanks)
*    Local variables :
      INTEGER
     :  SIZE2,             ! Size of STR2.
     :  SIZE1              ! Size of STR1.
*-

      SIZE2 = LEN (STR2)
      SIZE1 = MIN( CHR_LEN(STR1), SIZE2-LEN2)
      STR2(LEN2+1:LEN2+SIZE1) = STR1(1:SIZE1)
      LEN2 = LEN2 + SIZE1

      END
