*+  CHR_COPY - Copy one string to another, checking for truncation.
      SUBROUTINE CHR_COPY (INSTR,FLAG,OUTSTR,LSTAT)
*    Description :
*     This routine copies one character string to another, checking
*     for truncation caused by the output being too short to
*     accommodate all the input string.
*     Trailing blanks in the input string are ignored. If truncation
*     is found it is indicated by a local status being set.
*     As much as possible of a truncated string is copied and
*     optionally the last character of the output string may be set 
*     to # if truncation has occurred.
*    Invocation :
*     CALL CHR_COPY (INSTR, FLAG, OUTSTR, LSTAT)
*    Arguments :
*     INSTR  =  CHARACTER*(*) (Given)
*           Input string.
*     FLAG  =  LOGICAL (Given)
*           A logical flag indicating the action to be taken on the
*           event of truncation being detected. If FLAG is .TRUE.
*           then a # will be written into the last element of the
*           output string on detecting truncation. If FLAG 
*           is .FALSE. then no # is written to the output string.
*     OUTSTR  =  CHARACTER*(*) (Returned)
*           Output string. This will contain the input string, 
*           possibly truncated.
*     LSTAT  =  INTEGER (Returned)
*           Local status, return only. = 0 for success, = 1 if
*           truncation is detected.
*    Method :
*     Find the length of the input string (without trailing blanks)
*     Find the total length of the output string
*     set the output string = blank
*     if the input string is (effectively) shorter than the output
*     string then
*       output string = input string
*     else
*       copy as much as possible of the input to the output.
*       if FLAG is set then
*         set the last element of the output to '#'
*       end if
*       set the local status
*     end if
*    Deficiencies :
*     The routine may be rather slow, and probably should not be
*     used where it is going to be called many times inside a 
*     loop. It is really intended for cases where it will not
*     be called very often, but it is imperative to check
*     that truncation is not occurring.
*    Bugs :
*     None known.
*    Authors :
*     A C Davenhall.      (ROE::ACD)
*    History :
*     29/6/84:  Original version.                        (ROE::ACD)
*     27/2/89:  Modified prologue                        (RAL::AJC)
*    Type Definitions :
      IMPLICIT NONE
*    Import :
      CHARACTER
     :  INSTR*(*)    ! Input string.
      LOGICAL
     :  FLAG         ! Flag; truncation to be flagged in output string?
*    Export :
      CHARACTER
     :  OUTSTR*(*)   ! Output string.
*    Status :
      INTEGER
     :  LSTAT        ! Local status. Return only. = 0 for success.
*    External references :
      EXTERNAL
     :  CHR_LEN
      INTEGER
     :  CHR_LEN
*    Local variables :
      INTEGER
     :  INLEN,   ! Length of input string, ignoring trailing blanks.
     :  OUTLEN   ! Total length of output string.
*-

      LSTAT=0

      INLEN=CHR_LEN(INSTR)
      OUTLEN=LEN(OUTSTR)

      OUTSTR=' '

      IF (INLEN.LE.OUTLEN) THEN
         OUTSTR(1:INLEN)=INSTR(1:INLEN)
      ELSE
         OUTSTR(1:OUTLEN)=INSTR(1:OUTLEN)
         IF (FLAG) OUTSTR(OUTLEN:OUTLEN)='#'
         LSTAT=1
      END IF

      END
