*+   CHR_CTOR - Read a real number from a character string.
      SUBROUTINE CHR_CTOR (STRING,RVALUE,STATUS)
*    Description :
*     Read a real number from a character string.
*    Invocation :
*     CALL CHR_CTOR (STRING, RVALUE, STATUS)
*    Arguments :
*     STRING  =  CHARACTER*(*) (Given)
*           String from which an attempt will be made to read
*           a real number.
*     RVALUE  =  REAL (Returned)
*           Value decoded from the input string.
*     STATUS = INTEGER (Modified)
*           Variable holding the status value.
*           If this variable is not SAI__OK on input, then the routine
*           will return without action.
*           If the routine fails to complete, STATUS will be set
*           to SAI__ERROR.
*    Method :
*     Construct G-format and decode using Fortran 77 READ.
*    Authors :
*     Jack Giddings.               (UCL::JRG)
*     A C Davenhall.               (ROE::ACD)
*    History :
*     19-MAR-1982:  Original.                             (UCL::JRG)
*     02-OCT-1984:  Documentation improved.               (ROE::ACD)
*     03-OCT-1988:  Documentation improved.               (RAL::AJC)
*     16-AUG-1989:  Use SAE_PAR                           (RAL::AJC)
*     22-Jan-1990:  Eliminate overlapping substring       (RAL::DLT)
*                   assignment
*    Type definitions :
      IMPLICIT NONE
*    Global constants :
      INCLUDE 'sae_par.f'
*    Import :
      CHARACTER
     :  STRING*(*)      ! string to be decoded.
*    Export :
      REAL
     :  RVALUE          ! Value decoded.
*    Status :
      INTEGER
     :  STATUS          ! Status flag.
*    External references :
      INTEGER
     :  CHR_LEN         ! string length.
*    Local variables :
      CHARACTER
     :  FORMAT*8,       ! Fortran 77 format string.
     :  COUNT*3         ! Character count
      INTEGER
     :  NCHAR,          ! Character count.
     :  CODE            ! Code from READ/WRITE.
*-

      IF (STATUS .EQ. SAI__OK) THEN

         NCHAR = CHR_LEN(STRING)
         WRITE (COUNT, '(I3)', IOSTAT=CODE) NCHAR
         IF (CODE .NE. 0) THEN
            STATUS = SAI__ERROR
         ELSE
            FORMAT = '(G'//COUNT//'.0)'
            READ (STRING(1:NCHAR),FORMAT, IOSTAT=CODE) RVALUE
            IF (CODE .NE. 0) THEN
               STATUS = SAI__ERROR
            END IF
         END IF

      END IF

      END
