*+ CHR_ITOC - Encode an integer value as a string.
      SUBROUTINE CHR_ITOC (IVALUE, CVALUE, NCHAR)
*    Description :
*     Encode an integer value as a character string, using as concise a
*     format as possible, and return the number of characters used.
*     In the event of an error, `*'s will be written to the string.
*    Invocation :
*     CALL CHR_ITOC (IVALUE, CVALUE, NCHAR)
*    Arguments :
*     IVALUE  =  INTEGER (Given)
*           Value to be encoded.
*     CVALUE  =  CHARACTER*(*) (Returned)
*           String into which the integer value is to be encoded.
*     NCHAR  =  INTEGER (Returned)
*           Field width used in encoding the value.
*    Method :
*     <method>
*    Authors :
*     Jack Giddings.      (UCL::JRG)
*     A C Davenhall.      (ROE::ACD)
*     A J Chipperfield.   (RAL::AJC)
*    History :
*     3-JAN-1983:    Original.                      (UCL::JRG)
*     16-NOV-1984:   Documentation improved.        (ROE::ACD)
*      1-Sep-1988:   Use LEN instead of CHR_SIZE    (RAL::AJC)
*      3-Oct-1988:   Remove termination to declared length
*                    of CVALUE.
*                    Improve documentation.         (RAL::AJC)
*     14-Jun-1989:   Use field min of size/precision
*                    and CHR_LDBLK not RMBLK.       (RAL::AJC)
*    Type definitions :
      IMPLICIT NONE           ! Force Total Declarations.
*    Import :
      INTEGER
     :  IVALUE                ! Value to be coded into the string.
*    Export :
      CHARACTER
     :  CVALUE*(*)            ! String to be filled.
      INTEGER
     :  NCHAR                 ! Field width.
*    External references :
      INTEGER
     :  CHR_LEN               ! String length.
*    Local variables :
      CHARACTER
     :  FORMAT*10             ! Fortran 77 format string.
      INTEGER
     :  SIZE,                 ! Buffer size
     :  PREC,                 ! Max number of digits in integer
     :  FIELD,                ! Character count.
     :  CODE                  ! Local status.
*-

      SIZE = LEN(CVALUE)
*    Max integer 10 digits plus sign
      PREC = 11
*    Calculate field size for write
      FIELD = MIN( SIZE, PREC )

      WRITE (FORMAT, '(''(I'',I3,'')'')', IOSTAT=CODE) FIELD
      IF (CODE .EQ. 0) THEN

         WRITE (CVALUE, FORMAT, IOSTAT=CODE) IVALUE

         IF (CODE .EQ. 0) THEN
*          Remove leading spaces - the remainder was cleared by WRITE
            CALL CHR_LDBLK(CVALUE(1:FIELD))
            NCHAR = CHR_LEN(CVALUE(1:FIELD))
         ELSE
            CALL CHR_FILL('*', CVALUE)
            NCHAR = SIZE
         END IF

      ELSE

         CALL CHR_FILL('*', CVALUE)
         NCHAR = SIZE

      END IF

      END
