*+ CHR_LEN - Find used length of string.
      INTEGER FUNCTION CHR_LEN(STR)
*    Description :
*     Find length of string ignoring trailing blanks.
*    Invocation :
*     INTEGER = CHR_LEN(STR)
*    Arguments :
*     STR  =  CHARACTER*(*) (Given)
*            String whose length is to be determined.
*    Result :
*     CHR_LEN = INTEGER
*           Returns the used length of the string.
*    Method :
*     Fortran standard version;
*     Start from string's declared size and work back to start
*     until first non-blank character is found.
*     !VAX VMS version;
*     !This has been found to be slower unless there are around 150
*     !trailing spaces.
*     !The utility copies the given string to a local string, removing
*     !trailing blank and tab characters in the process, and returns
*     !the number of characters copied into the local string. 
*     !The local string, of course, has to be able to hold anything up
*     !to the largest string possible on the Vax. This may be rather
*     !expensive in its use of space. If it is, a shorter local string
*     !could be used and the status returned from the VAX utility 
*     !could be used to check for truncation and if truncation has 
*     !occured then the standard Fortran method used.
*    Authors :
*     Jack Giddings.      (UCL::JRG)
*     A C Davenhall.      (ROE::ACD)
*    History :
*     03-JAN-1983:  Original.                               (UCL::JRG)
*     02-OCT-1984:  Documentation improved.                 (ROE::ACD)
*     13-SEP-1988:  Add VAX VMS version in comments
*                   (Slower unless the tail is very long)   (RAL::AJC)
*     03-OCT-1988:  Improve documentation                   (RAL::AJC)
*     26-JAN-1990:  Improve Method comments                 (RAL::AJC)
*    Type definitions :
      IMPLICIT NONE        ! Force Total Declarations.
*    Import :
      CHARACTER*(*)
     :  STR                ! string to be measured.
*    Local constants :
!      INTEGER MAXLEN ! maximum string length that can be handled
!      PARAMETER ( MAXLEN = 65535 )
*    Local variables :
!      CHARACTER*( MAXLEN )
!     :  LOCAL ! to contain STRING with trailing blanks and tabs removed
      INTEGER
     :  TOTLEN,            ! Declared length of the string.
     :  CURPOS             ! Current position in the string.
*-
      
      TOTLEN=LEN (STR)
      CURPOS=TOTLEN

      DO WHILE (CURPOS .GT.0 .AND. STR(CURPOS:CURPOS) .EQ. ' ')
         CURPOS=CURPOS-1
      END DO

      CHR_LEN=CURPOS

!*    VAX VMS method
!*    Get the declared length of the string to be truncated
!      TOTLEN = LEN( STRING )
!*
!*    copies STRING to LOCAL removing trailing blanks and tabs and returns
!*    the number of characters copied in CHR_LEN. If truncation occurs
!*    CHR_LEN will correspond to the maximum number of characters that
!*    can be held in LOCAL.
!*      CALL STR$TRIM ( LOCAL( 1:TOTLEN ), STRING, CHR_LEN )

      END
