*+  CHR_LOWER - Give lower case equivalent of a character.
      CHARACTER*1 FUNCTION CHR_LOWER( ACHAR )
*    Description :
*     If the given character is an upper case character, this
*     function returns the lower case equivalent. Otherwise the given
*     character will be returned as the function value.
*    Invocation :
*     CHARACTER = CHR_LOWER( ACHAR )
*    Arguments :
*     ACHAR = CHARACTER (Given)
*           Character for which the lower case equivalent is required.
*    Result :
*     CHR_LOWER = CHARACTER
*           Lower case equivalent of input character if input character
*           is an upper case letter; otherwise set to the input character.
*    Method :
*     Get ascii value of given character.
*     If given character is not an upper case letter then
*        Set returned value to given character.
*     Else
*        Returned value is set to lower case equivalent.
*     Endif
*    Authors :
*     Dave Baines. (ROE::ASOC5)
*    History :
*     29/06/1984 : Original version (ROE::ASOC5)
*     03/10/1988 : Improved documentation  (RAL::AJC)
*     25/01/1990 : Use ICHAR instead of integer parameters because of
*                  DECstation compiler bugs.  (RAL::DLT)
*    Type Definitions :
      IMPLICIT NONE  ! switch off default typing
*    Import :
      CHARACTER
     :  ACHAR         ! character for which a lower case equivalent is required
*    External references :
      INTEGER ICHAR  ! ascii value of given character
      CHARACTER CHAR ! character corresponding to given ascii value
*    Local variables :
      INTEGER
     :  ASCII        ! value of given input character
*-

*    get ascii value of given character
      ASCII = ICHAR( ACHAR )

*    check for given character not an upper case letter
      IF( ASCII .LT. ICHAR('A')) THEN

*       returned value is set to given character
         CHR_LOWER = ACHAR

      ELSEIF( ASCII .GT. ICHAR('Z') ) THEN

*       returned value is set to given character
         CHR_LOWER = ACHAR

      ELSE

*       returned value is set to lower case equivalent of given character
*       add on the offset between lower and upper case characters
         CHR_LOWER = CHAR( ASCII + ICHAR('a') - ICHAR('A') )
      ENDIF

      END
