*+ CHR_OTOI - Read an integer from an octal string.
      SUBROUTINE CHR_OTOI (STRING, IVALUE, STATUS)
*    Description :
*     Read an integer from an octal string.
*    Invocation :
*     CALL CHR_OTOI (STRING, IVALUE, STATUS)
*    Arguments :
*     STRING  =  CHARACTER*(*) (Given)
*           String to be decoded.
*     IVALUE  =  INTEGER (Returned)
*           Value decoded from the given string.
*     STATUS = INTEGER (Modified)
*           Variable holding the status value.
*           If this variable is not SAI__OK on input, then the routine
*           will return without action.
*           If the routine fails to complete, STATUS will be set
*           to SAI__ERROR.
*    Method :
*     Construct an O-format and decode using a Fortran 77 internal READ
*     into the integer argument.
*    Authors :
*     Jack Giddings.        (UCL::JRG)
*     A C Davenhall.        (ROE::ACD)
*    History :
*     19-MAR-1982:   Original.                   (UCL::JRG)
*     19-NOV-1984:   Documentation improved.     (ROE::ACD)
*     26-OCT-1988:   Documentation improved.     (RAL::AJC)       
*     16-AUG-1989:   Use SAE_PAR                 (RAL::AJC)
*    Type definitions :
      IMPLICIT NONE
*    Global constants :
      INCLUDE 'sae_par.f'
*    Import :
      CHARACTER
     :  STRING*(*)            ! String to be decoded.
*    Export :
      INTEGER
     :  IVALUE                ! Decoded value.
*    Status :
      INTEGER
     :  STATUS                ! Status flag.
*    External references :
      INTEGER
     :  CHR_LEN               ! String length.
*    Local variables :
      CHARACTER
     :  FORMAT*6              ! Fortran 77 format string.
      INTEGER
     :  NCHAR,                ! Character count.
     :  CODE                  ! Return status from internal READ/WRITE.
*-

      IF (STATUS .EQ. SAI__OK) THEN

         NCHAR = CHR_LEN(STRING)
         WRITE (FORMAT, '(I3)', IOSTAT=CODE) NCHAR
         IF (CODE .NE. 0) THEN
            STATUS = SAI__ERROR
         ELSE
            FORMAT = '(O'//FORMAT(1:3)//')'
            READ (STRING(1:NCHAR),FORMAT, IOSTAT=CODE) IVALUE
            IF (CODE .NE. 0) THEN
               STATUS = SAI__ERROR
            END IF
         END IF

      END IF

      END
