*+ CHR_SIMLR - Determine whether two strings are equal apart from case.
      LOGICAL FUNCTION CHR_SIMLR( STR1, STR2 )
*    Description :
*     Determine whether the two given strings are the same ignoring
*     distinctions between upper and lower case letters.
*     Their lengths must be identical after removing trailing blanks.
*    Invocation :
*     LOGICAL = CHR_SIMLR( STR1, STR2 )
*    Arguments :
*     STR1 = CHARACTER*(*) (Given)
*           First string.
*     STR2 = CHARACTER*(*) (Given)
*           Second string.
*    Result :
*     CHR_SIMLR = LOGICAL
*           Returned as .TRUE. if the two given strings are the same
*           ignoring case distinctions; otherwise .FALSE.
*    Method :
*     Jack's original method :
*     Get their lengths using CHR_LEN.   Compare the strings until
*     they differ.   Each character is converted to lower case for
*     the comparison.
*     !This was found to be rather slow so a Vax specific method
*     !has been used. 
*    Deficiencies :
*     !This routine is implemented using the VAX VMS Run Time 
*     !Library routine STR$CASE_BLIND_COMPARE
*    Authors :
*     Jack Giddings. (UCL::JRG)
*     Dave Baines.   (ROE::ASOC5)
*    History :
*     03/01/1983 : Original version   (UCL::JRG)
*     20/06/1984 : Optimised version (ROE::ASOC5)
*      2/09/1988 : Remove INCLUDE 'SAE_PAR'  (RAL::AJC)
*      7/10/1988 : Improve documentation (RAL::AJC)
*     26/05/1989 : Use STR$CASE_BLIND_COMPARE (RAL::AJC)
*     25/01/1990 : Use local variables in portable version
*                  because of DECstation compiler bugs
*    Type Definitions :
      IMPLICIT NONE ! switch off default typing
*    Import :
      CHARACTER*(*)
     :  STR1, ! first string
     :  STR2  ! second string
*    External references :
      integer chr_len ! returns string length ignoring trailing blanks
      character chr_lower ! convert alphabetic to lower case
c      INTEGER STR$CASE_BLIND_COMPARE
*    Local variables :
      integer i ! length of str1
      logical test
      character*1 c1, c2
*
      i = chr_len(str1)
      test = chr_len(str2) .eq. i
      if (test) then
         dowhile (i .gt. 0)
            c1 = chr_lower(str1(i:i))
            c2 = chr_lower(str2(i:i))
            test = c1 .eq. c2
            if (.not. test) then
               goto 1
            endif
            i = i - 1
         enddo
 1       continue
      endif
      chr_simlr = test

C      IF ( STR$CASE_BLIND_COMPARE( STR1, STR2 ) .EQ. 0 ) THEN
c         CHR_SIMLR = .TRUE.
C      ELSE
C         CHR_SIMLR = .FALSE.
C      ENDIF

      END
