       SUBROUTINE BOXCAR (X,YIN,YOUT,NPOINT,BOXWID)

!+
!
!  Program:
!      BOXCAR
!
!  Purpose:
!=    Applies a box car smoothing function to NPOINT data in a function YIN(X)
!     where the full width of the box is BOXWID. Output is YOUT.
!
!  Accuracy:
!      Preserves integrated equivalent widths of lines in smoothed spectra 
!      to 0.003 % 
!
!  Language:
!     Fortran 77
! 
!  Authors:
!     C.S.Jeffery (CSJ) (Armagh Observatory)
!
!  History:
!     03-FEB-2000: CSJ
!        original version
!
!-

! Subroutine arguments.
       REAL X(*), YIN(*), YOUT(*)
       REAL BOXWID
       INTEGER NPOINT

! Local variables.
       REAL HALFWID, SUMWT, SUM, DX, X0 
       INTEGER I, J

!.

!  Check this is really necessary
       IF ( BOXWID .LT. ABS(X(2)-X(1))*1.E-2 ) THEN
          DO I = 1,NPOINT
             YOUT(I) = YIN(I)
          ENDDO
          RETURN
       ENDIF 


!  Compute the halfwidth
       HALFWID = BOXWID / 2.


!  For each datum
       DO I = 1, NPOINT

          X0 = X(I)
          SUM = 0.
          SUMWT = 0.

!       Integrate the data below
          J = I - 1
   50     CONTINUE
          IF (J.NE.0) THEN
             DX = ABS(X(J)-X0)
             Y1 = YIN(J+1)
             Y2 = YIN(J)
             IF (DX.GE.HALFWID) THEN
                H  = HALFWID - (X0-X(J+1))
                A  = H/2.
                J  = 0
             ELSE
                H = X(J+1)-X(J)
                A = 0.5
                J  = J - 1
             ENDIF 
             SUM   = SUM   + H * ((1-A)*Y1 + A*Y2)
             SUMWT = SUMWT + H
             GOTO 50
          ENDIF


!       Integrate the data above
          J = I + 1
  100     CONTINUE
          IF (J.LE.NPOINT) THEN
             DX = ABS(X(J)-X0)
             Y1 = YIN(J-1)
             Y2 = YIN(J)
             IF (DX.GE.HALFWID) THEN
                H  = HALFWID - (X(J-1)-X0)
                A  = H/2.
                J  = NPOINT + 1
             ELSE
                H = X(J)-X(J-1)
                A = 0.5
                J  = J + 1
             ENDIF 
             SUM   = SUM   + H * ((1-A)*Y1 + A*Y2)
             SUMWT = SUMWT + H
             GOTO 100

          ENDIF

!       Normalize the integral
          YOUT(I) = SUM/SUMWT

       ENDDO

       END
