      SUBROUTINE CBEVAL (NORDER,CBCOFF, CBXMIN,CBXMAX, X, CBVAL)
!+
!     PROGRAM:      CBEVAL
!     PURPOSE:      
!=                  EVALUATES A POLYNOMIAL FROM CHEBYSHEV-SERIES REPRESENTATION.
!     REFERENCES:   
!                   NUMERICAL RECIPES: CHAPTER 5   (METHOD 2)
!
!     HISTORY:
!     VERSION       MACHINE       DATE      AUTHOR/INSTITUTE
!     1.0           microVAX      22.02.88  C.S.JEFFERY / ST.ANDREWS
!
!
!  NORDER - Order of Chebyshev series
!  CBCOFF - Array of Chebyshev polynomial coefficients (dimension > NORDER+1)
!  CBXMIN - Minimum of interval for normalisation
!  CBXMAX - Maximum of interval for normalisation
!  X      - Value of independent variable at which polynomial to be evaluated
!  CBVAL  - Value of poynomial corresponding to the argument X
!-
      IMPLICIT REAL    (A-H,O-Z)
      IMPLICIT INTEGER (I-N)

      INTEGER NORDER
      REAL    CBCOFF(*), CBXMIN,CBXMAX, X,CBVAL

      INTEGER IERCNT
      DATA    IERCNT / 0 /
      SAVE    IERCNT
!.


!.....LOCAL X
      XL = X

!.....DO SOME ERROR TRAPPING
      IF (CBXMIN.GT.XL .OR. XL.GT.CBXMAX) THEN
         IF (IERCNT.LE.10) THEN
            WRITE (*,*) 'CBEVAL: X out of range'
            IERCNT = IERCNT + 1
         ENDIF
         XL = MAX (XL,CBXMIN)
         XL = MIN (XL,CBXMAX)
      ENDIF

!  ...CHANGE TO NORMALISED VARIABLE
      Y1 = ((XL-CBXMIN)+(XL-CBXMAX)) / (CBXMAX-CBXMIN)
      Y2 = 2. * Y1
      OO = 0.
      OP = 0.

!  ...CLENSHAW'S RECURRENCE
      DO 20 I = NORDER+1,2,-1
         SV = OO
         OO = Y2 * OO - OP + CBCOFF(I)
         OP = SV
20       CONTINUE
      CBVAL = Y1 * OO - OP + 0.5*CBCOFF(1)

!.....QUIT
      END
