      SUBROUTINE CBROOT (NORDER,CBCOFF,CBXMIN,CBXMAX, VALUE, GUESS,ROOT)

!+
!     PROGRAM:      PNROOT
!     PURPOSE:      
!=                  FIND THE ROOT OF THE EQUATION F(X) = Y NEAREST TO X=GUESS.
!                   F(X) IS A POLYNOMIAL IN CHEBYSHEV-SERIES REPRESENTATION
!                   F(X) = 0.5*A0 + A1*T1(X) + A2*T2(X) + ...
!     METHOD:       NEWTON-RAPHSON ITERATION
!
!     HISTORY:
!     VERSION       MACHINE       DATE      AUTHOR/INSTITUTE
!     1.0           microVAX      05.02.88  C.S.JEFFERY / ST.ANDREWS
!
!     INPUT:        NORDER       ORDER OF POLYNOMIAL (EQ QUADRATIC = 2)
!                   CBCOFF       COEFFICIENTS OF POLYNOMIAL
!                   CBXMIN       MINIMUM OF RANGE OVER WHICH F(X) WAS FITTED
!                   CBXMAX       MAXIMUM OF RANGE
!                   VALUE        VALUE OF FUNCTION AT WHICH X IS REQUIRED (Y)
!                   GUESS        INITIAL GUESS FOR ROOT OF F(X) = Y
!
!     OUTPUT:       ROOT         SOLUTION : F(ROOT) = Y
!
!     NOTE:         DIMENSION OF PNCOFF MUST BE .GE. NORDER+1
!-

      INTEGER       NORDER
      REAL          CBCOFF(*), VALUE, GUESS, ROOT
!  ...WORK AREA FOR DERIVATIVE OF F(X)
      REAL          DCBDX(20)
!.


!  ...GET FIRST DERIVATIVE OF THE POLYNOMIAL
      CALL CBDIFF (NORDER, CBCOFF, DCBDX, CBXMIN, CBXMAX)

!  ...PERFORM NEWTON-RAPHSON ITERATION
      XN = GUESS
      DO 1 I = 1,20
         CALL CBEVAL (NORDER, CBCOFF,CBXMIN,CBXMAX, XN, FX)
         FX = FX - VALUE
         CALL CBEVAL (NORDER-1, DCBDX,CBXMIN,CBXMAX, XN, DF)
         DX = FX / DF
         IF (ABS(DX).LE.XN*1.E-3) GO TO 2
         XN = XN - DX
1        CONTINUE

!  ...FINAL CORRECTION
2     ROOT = XN - DX

!  ...QUIT
      END
