      SUBROUTINE CBTOPN (NORDER, CBCOFF, PNCOFF, CBXMIN, CBXMAX)

!+
!     PROGRAM:      CBTOPN
!     PURPOSE:      
!=                  OBTAIN POLYNOMIAL APPROXIMATION FROM CHEBYSHEV COEFFICIENTS
!                   ON INTERVAL XMIN TO XMAX.
!                   IF POLYNOMIAL COEFFICIENTS ON NORMAILSED VARIABLE ARE
!                   REQUIRED, THEN SET CBXMIN = CBXMAX = 1.0 ON INPUT.
!     REFERENCES:   NUMERICAL RECIPES: CHAPTER 5
!
!     HISTORY:
!     VERSION       MACHINE       DATE      AUTHOR/INSTITUTE
!     1.0           microVAX      22.02.88  C.S.JEFFERY / ST.ANDREWS
!
!
!  NORDER - Order of Chebyshev series
!  CBCOFF - Array of Chebyshev polynomial coefficients (dimension > NORDER+1)
!  PNCOFF - Array of actual polynomial coefficients
!  CBXMIN - Minimum of interval for polynomial coefficients
!  CBXMAX - Maximum of interval for    "       coefficients
!-
      IMPLICIT REAL    (A-H,O-Z)
      IMPLICIT INTEGER (I-N)

      INTEGER NORDER
      REAL    CBCOFF(*), PNCOFF(*)

      PARAMETER (KMAX=50)
      DIMENSION DDCOFF(KMAX)
!.

!.....ZERO COEFFICIENT ARRAYS
      KP1 = NORDER + 1
      DO 11 J = 1,KP1
         PNCOFF(J) = 0.
11       DDCOFF(J) = 0.

!.....APPLY CLENSHAW'S RECURRENCE ALGEBRAICALLY
      PNCOFF(1) = CBCOFF(KP1)
      DO 15 J = NORDER,2,-1
         DO 14 K = KP1-J+1,2,-1
            SV = PNCOFF(K)
            PNCOFF(K) = 2.*PNCOFF(K-1) - DDCOFF(K)
            DDCOFF(K) = SV
14          CONTINUE
         SV = PNCOFF(1)
         PNCOFF(1) = -DDCOFF(1) + CBCOFF(J)
         DDCOFF(1) = SV
15       CONTINUE
      DO 18 J = KP1,2,-1
         PNCOFF(J) = PNCOFF(J-1) - DDCOFF(J)
18       CONTINUE
      PNCOFF(1) = -DDCOFF(1) + 0.5*CBCOFF(1)

!.....TRANSFORM POLYNOMIAL TO RENORMALISED X-INTERVAL
      CC = 2.0 / (CBXMAX-CBXMIN)
      FF = CC
!  ...SCALE BY FACTOR CC
      DO 21 J = 2,KP1
         PNCOFF(J) = PNCOFF(J) * FF
         FF = FF * CC
21       CONTINUE
      CC = 0.5 * (CBXMIN + CBXMAX)
!  ...AND SHIFT USING SYNTHETIC DIVISION
      DO 23 J = 1,NORDER
         DO 22 K = NORDER,J,-1
            PNCOFF(K) = PNCOFF(K) - CC * PNCOFF(K+1)
22          CONTINUE
23       CONTINUE

!.....QUIT
      END
