      SUBROUTINE INTEP (XP,P,X,F,N,IER)

!+
!
!= INTEP is an interpolation scheme based on hermite polynomials.
!  Source is U.S. Airforce Surveys in Geophysics No 272. X and FX
!  are arrays of N input point pairs. XP is the interpolation point
!  and P is the interpolated value. IER=0 for normal completion
!  and IER=1 if XP lies outside the range of X.
!  For random values of XP, use CALL INTEP or after the first call
!  to INTEP with monotonically increasing or decreasing values of XP
!  consistent with the X array use CALL EINTEP(XP,P,X,F,N,IER).
!-

      IMPLICIT  REAL      (A-H,O-Z)
      IMPLICIT  INTEGER   (I-N)
      REAL*4    LP1,LP2,L1,L2
      DIMENSION F(*),X(*)
!.
      IER = 0
      IO  = 1
      IUP = 0
      IF (X(2).LT.X(1)) IUP = 1
      N1  = N - 1
      IF ((XP.GE.X(N) .AND. IUP.EQ.0) .OR.
     :    (XP.LE.X(N) .AND. IUP.EQ.1)) THEN
5        P = F(N)
         IF ((XP.GT.X(N) .AND. IUP.EQ.0) .OR.
     :       (XP.LT.X(N) .AND. IUP.EQ.1)) IER = 1
         RETURN
      ELSEIF ((XP.LE.X(1) .AND. IUP.EQ.0) .OR.
     :        (XP.GE.X(1) .AND. IUP.EQ.1)) THEN
         P = F(1)
         IF ((XP.LT.X(1) .AND. IUP.EQ.0) .OR.
     :       (XP.GT.X(1) .AND. IUP.EQ.1)) IER = 1
         RETURN
      ENDIF


      ENTRY EINTEP (XP,P,X,F,N,IER)
8     DO I = IO,N
        IF (XP.LT.X(I) .AND. IUP.EQ.0) GOTO 2
        IF (XP.GT.X(I) .AND. IUP.EQ.1) GOTO 2
      ENDDO
      P = F(N)
      IF ((XP.GT.X(N) .AND. IUP.EQ.0) .OR.
     :    (XP.LT.X(N) .AND. IUP.EQ.1)) IER = 1
      RETURN

2     I   = I - 1
      IF (I.EQ.IO-1) GOTO 4
      IO  = I + 1
      LP1 = 1.0 / (X(I) - X(I+1))
      LP2 = 1.0 / (X(I+1) - X(I))
      IF (I.EQ.1) THEN
         FP1 = (F(2) - F(1))/(X(2) - X(1))
         GOTO 3
      ENDIF
      FP1 = (F(I+1) - F(I-1)) / (X(I+1) - X(I-1))
3     IF (I.GE.N1) THEN
         FP2 = (F(N) - F(N-1)) / (X(N) - X(N-1))
         GOTO 4
      ENDIF
      FP2 = (F(I+2) - F(I)) / (X(I+2) - X(I))
4     XPI1 = XP - X(I+1)
      XPI = XP - X(I)
      L1  = XPI1 * LP1
      L2  = XPI * LP2
      P   = F(I) * (1.D0 - 2.0D0 * LP1 * XPI) * L1 * L1 + F(I+1) * 
     :      (1.0D0 - 2.0D0 * LP2 * XPI1) * L2 * L2 + FP2 * XPI1 *
     :      L2 * L2 + FP1 * XPI * L1 * L1

      RETURN
      END
