      SUBROUTINE L2FRES (IER,MAX,N,XN,FN,GN,DN,THETA,DEFIND,M,XD,YD,
     >                   RD,WEIGHT,WD,DEFINE,NINT,XINT,YINT,W)

!+
!     PROGRAM:      L2FRES
!     PURPOSE:      
!=                  LEAST SQUARES FIT WITH FREE KNOTS CUBIC SPLINE
!
!     REFERENCES:   POWELL 1967, REPORT HL67/5309, AERE, HARWELL
!
!     HISTORY:
!     VERSION       MACHINE       DATE      AUTHOR/INSTITUTE
!     0.0                           .  .67  M. POWELL / AERE, HARWELL
!     ***  A LONG AND APOCRYPHAL SERIES OF INCARNATIONS ***
!     1.0                           .  .77  R.W.HILDITCH / DAO  
!     1.1           microVAX      28.10.87  C.S.JEFFERY / ST.ANDREWS
!
!     INPUT:        
!
!     OUTPUT:       
!

!
! Least squares fit with free knots cubic spline.
!
! IER is an error flag with the following meanings :-
!
! 0 ==> Successful fit made.
! 1 ==> Error in data definition.
! 2 ==> Error in interpolation point definition.
! 3 ==> Error in model definition.
! 7 ==> Requires more knots to do a good fit.
!
! MAX    : Maximum number of knots allowed (2/3 of M)
!
! XN to  : Work spaces of dimension no less than max containing
! THETA    information about the fitting spline.
!
! DEFIND : .TRUE.  If data points are provided for fitting.
!          .FALSE. If the data has already been fitted. Work spaces XN
!                  to THETA must have been previously set up.
!
! M      : Number of data points, dummy if DEFIND .FALSE.
!
! XD,YD  : Data point arrays of dimension no less than M, they can be
!          dummy if DEFIND = .FALSE.
!
! RD     : Array of dimension no less than M containing upon return
!          residues of curve fitting.
!
! WEIGHT : .TRUE. If data points are not equally weighted, .FALSE. otherwise.
!
! WD     : Array of weights, can be dummy if WEIGHT = .FALSE.
!
! DEFINE : .TRUE. If an interpolation is to be attempted at given XINT points.
!
! NINT   : Number of interpolation points, dummy if DEFINE .FALSE.
!
! XINT   : Array of abscissae of interpolation points, dummy if DEFINE .FALSE.
!
! YINT   : Array of interpolated y values, dummy if DEFINE .FALSE.
!
! W      : Work space of dimension 7*M+9*MAX+6. => 13*M+6
!-

      IMPLICIT  REAL*4     (A-H,O-Z)
      IMPLICIT  INTEGER*4  (I-N)
      LOGICAL   DEFIND,DEFINE,WEIGHT
      DIMENSION XN(*),FN(*),GN(*),DN(*),THETA(*),XD(*),YD(*),
     1          WD(*),RD(*),XINT(*),YINT(*),W(*)
!.
      IER=3
      IF(MAX.LT.1) GOTO 30

! Least squares fit required.

1     IF(.NOT.DEFIND) GOTO 10
       IF(MAX.GT.M) GOTO 30
      IER=1
       IF(M.LT.5) GOTO 30
2     CALL VC03A(M,MAX,XD,YD,RD,WEIGHT,WD,XN,FN,GN,N,DN,THETA,W)
      IF(N.GT.0) GOTO 10

! Number of knots required exceeds estimated maximum.

      IER=7
      N=-N
       GOTO 30
10     IER=0
      IF(.NOT.DEFINE) GOTO 30

! Evaluate interpolation points.

      IF(NINT.GT.0) GOTO 15
      IER=2
      GOTO 30
15    DO 20 I=1,NINT
      X=XINT(I)
20    YINT(I)=TG01B(-1,N,XN,FN,GN,X)
30    RETURN
      END
