      SUBROUTINE LSQ (X,Y,NPT,A,B,SA,SB,S2)

!+
!     PROGRAM:     LINEQT
!     TYPE:        SUBROUTINE
!     LANGUAGE:    FORTRAN 77
!     PURPOSE:     
!=                 FIND A STRAIGHT-LINE FIT TO A DATA OF FORM: Y = A + B.X
!     METHOD:      LEAST-SQUARES
!     AUTHOR:      C.S.JEFFERY
!     VERSION:     I
!     PLACE:       UNIVERSITY OF ST ANDREWS
!     DATE:        1984
!     HISTORY:     VERSION I - VAX 11/785
!
!     ARGUMENTS:
!        X         VECTOR CONTAINING X VALUES
!        Y         VECTOR CONTAINING Y VALUES
!        NPT       NUMBER OF VALID DATA IN THE INPUT VECTORS
!        A         ORDINATE OF FIT
!        B         GRADIENT OF FIT
!        SA        VARIANCE IN A (I.E. SIGMA**2)
!        SB        VARIANCE IN B
!        S2        VARIANCE OF DATA ABOUT THE FIT
!-

      DIMENSION X(*),Y(*)
!.

!.....SET SUMS TO ZERO
      SX  = 0
      SY  = 0
      SXX = 0
      SYY = 0
      SXY = 0

!.....COMPUTE SUMMATIONS
      DO 10 I = 1,NPT
        SX  = SX  + X(I)
        SY  = SY  + Y(I)
        SXY = SXY + X(I)*Y(I)
        SXX = SXX + X(I)*X(I)
        SYY = SYY + Y(I)*Y(I)
 10   CONTINUE

!.....COMPUTE FIT
      D  = NPT*SXX-SX*SX
      A  = (SY*SXX-SX*SXY)/D
      B  = (NPT*SXY-SX*SY)/D
      SA = SXX/D
      SB = NPT/D
      S2 = (SYY-A*SY-B*SXY)/NPT

!.....QUIT
      END
