      SUBROUTINE MTH_D_NTINTP (N,X,F,XX,PN)

!+
!     PROGRAM:      NTINTP
!     PURPOSE:      
!=    Constructs and evaluates Newton's interpolating polynomial (order N).
!                   GIVEN N+1 VALUES FOR X AND F(X).    
!     REFERENCES:   CONTE & DE BOOR; P197
!     
!     HISTORY:
!     VERSION       MACHINE       DATE      AUTHOR/INSTITUTE
!     1.0           HONEYWELL       .  .81  C.S.JEFFERY / ST.ANDREWS
!     1.1           VAX 11/780      .  .83  C.S.JEFFERY / ST.ANDREWS
!     2.0           microVAX      03.11.87  C.S.JEFFERY / ST.ANDREWS
!     >>> THIS VERSION CHANGED FROM USING N+1 TO N AS AN ARGUMENT.
!     3.0           linux         20.05.03  C.S.JEFFERY / ARMAGH
!     >>> Double precision f95 version
!     
!     INPUT:    
!     N       ORDER OF INTERPOLATING POLYNOMIAL
!     X       N+1 VALUES OF INDEPENDENT VARIABLE
!     F       N+1 VALUES OF DEPENDENT VARIABLE
!     XX      VALUE OF INDEPENDENT VARIABLE AT WHICH INTERPOLATION IS TO BE EVALUATED
!     
!     OUTPUT:       PN      VALUE OF INTERPOLATED DATA
!-     

     
!     Double Precision version
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)

!     Subroutine Arguments
      INTEGER,                        INTENT(IN) :: N             
      DOUBLE PRECISION, DIMENSION(*), INTENT(IN) :: X
      DOUBLE PRECISION, DIMENSION(*), INTENT(IN) :: F
      DOUBLE PRECISION,               INTENT(IN) :: XX

      DOUBLE PRECISION,              INTENT(OUT) :: PN
!.

     
      NP   = N + 1
      SUMI = 0.
      DO I = 1,NP
        SUMJ = 0.
        DO J = 1,I
          DIVJ = 1.
          DO K = 1,I
            IF (J /= K) DIVJ = DIVJ * (X(J)-X(K))
          ENDDO
          TERMJ = F(J) / DIVJ
          SUMJ = SUMJ + TERMJ
        ENDDO
        PIJ = 1.
        IF (I /= 1) THEN
          DO  J = 1,I-1
            PIJ = PIJ * (XX - X(J))
          ENDDO
        ENDIF
        SUMI = SUMI + SUMJ * PIJ
      ENDDO
      PN = SUMI

      END
