      SUBROUTINE NTINTP (N,X,F,XX,PN)

!+
!     PROGRAM:      NTINTP
!     PURPOSE:      
!=                  CONSTRUCTS AND EVALUATES NEWTON'S INTERPOLATING POLYNOMIAL (ORDER N), !                   GIVEN N+1 VALUES FOR X AND F(X).    
!     REFERENCES:   CONTE & DE BOOR; P197
!
!     HISTORY:
!     VERSION       MACHINE       DATE      AUTHOR/INSTITUTE
!     1.0           HONEYWELL       .  .81  C.S.JEFFERY / ST.ANDREWS
!     1.1           VAX 11/780      .  .83  C.S.JEFFERY / ST.ANDREWS
!     2.0           microVAX      03.11.87  C.S.JEFFERY / ST.ANDREWS
!     >>> THIS VERSION CHANGED FROM USING N+1 TO N AS AN ARGUMENT.
!
!     INPUT:        N       ORDER OF INTERPOLATING POLYNOMIAL
!                   X       N+1 VALUES OF INDEPENDENT VARIABLE
!                   F       N+1 VALUES OF DEPENDENT VARIABLE
!                   XX      VALUE OF INDEPENDENT VARIABLE AT WHICH 
!                           INTERPOLATION IS TO BE EVALUATED
!
!     OUTPUT:       PN      VALUE OF INTERPOLATED DATA
!-


      IMPLICIT REAL (A-H,O-Z)
      DIMENSION X(*),F(*)
!.

      NP   = N + 1
      SUMI = 0.
      DO 400 I = 1,NP
         SUMJ = 0.
         DO 200 J = 1,I
            DIVJ = 1.
            DO 100 K = 1,I
               IF (J.NE.K) DIVJ = DIVJ * (X(J)-X(K))
  100       CONTINUE
            TERMJ = F(J) / DIVJ
            SUMJ = SUMJ + TERMJ
  200    CONTINUE
         PIJ = 1.
         IF (I.NE.1) THEN
            DO 300 J = 1,I-1
  300       PIJ = PIJ * (XX - X(J))
         ENDIF
         SUMI = SUMI + SUMJ * PIJ
  400 CONTINUE
      PN = SUMI
      END
