      SUBROUTINE TABINP (NV,XA,YA,NP,X,Y)


!+
!     PROGRAM:      TABINP
!     PURPOSE:      
!=                  POLYNOMIAL INTERPOLATION WITH DERIVATIVES
!     NOTE:         X-VALUES MUST BE SUPPLIED IN INCREASING ORDER
!
!     HISTORY:
!     VERSION       MACHINE       DATE      AUTHOR/INSTITUTE
!     1.0           SunOS4.1.2    22.12.94  C.S.JEFFERY / ST ANDREWS
!
!     INPUT:        NV     NUMBER OF POINTS IN INTERPOLATION TABLE
!                   XA     ARRAY OF X-VALUES
!                   YA     ARRAY OF Y-VALUES
!                   NP     DEGREE OF POLYNOMIAL INTERPOLATION
!                   X      X-VALUE FOR INTERPOLATION
!
!     OUTPUT:       Y      ARRAY OF Y AND DERIVATIVES 
!
!-

      PARAMETER (MMAX=10)
      IMPLICIT REAL (A-H,O-Z)
      REAL     XA(*), YA(*)
      REAL     Y(*)
      REAL     XSEG(MMAX), YSEG(MMAX), COF(MMAX)

!.....ERROR HANDLING
      INTEGER  IERCNT
      SAVE     IERCNT
      DATA     IERCNT / 0 /

!.

!.....VERIFY APPLICATION

!  ...TEST X IS IN RANGE
      IF (IERCNT.LE.MMAX) THEN
         IF (X.LT.XA(1) .OR. X.GT.XA(NV)) THEN
            CALL STR_ERR ('TABINP','X out of range, extrapolating')
            IERCNT = IERCNT + 1
         ENDIF
         IF (NP.GT.MMAX-1) THEN
            CALL STR_ERR ('TABINP','NP too large')
            IERCNT = IERCNT + 1
         ENDIF
      ENDIF

      NPOL = MIN (NP,MMAX-1)


!.....INITIALIZE HIGHER DERIVATIVES

      DO I = 1,NPOL
         Y(I) = 0.
      ENDDO

!.....LINEAR INTERPOLATION

      IF (NPOL.EQ.1) THEN

!     ...LOCATE GRID NEIGHBOURS
         IF (X.LT.XA(1)) THEN
            IL = 1
            IH = 2
         ELSE
            DO I = 2,NV-1
               IF (X.LT.XA(I)) THEN
                  IL = I - 1
                  GOTO 3
               ENDIF
            ENDDO
            IL = NV - 1
3           IH = IL + 1
         ENDIF

!     ...INTERPOLATION INTERVAL
         SINT = XA(IH) - XA(IL)

!     ...TRAP INFINITE GRADIENT
         IF (SINT.LT.1.E-10) THEN
            IF (IERCNT.LE.10) THEN
               CALL STR_ERR ('TABINT','Infinite gradient')
               IERCNT = IERCNT + 1
            ENDIF
            Y(1) = (YA(IL) + YA(IH)) / 2.
            Y(2) = SIGN(1.0E+38,YA(IH)-YA(IL)) 

!     ...EVALUATE INTERPOLATION
         ELSE
            Y(2) = (YA(IH)-YA(IL)) / SINT
            Y(1) = YA(IL) + (X - XA(IL)) * Y(2)
         ENDIF

!.....POLYNOMIAL INTERPOLATION (N>1)

      ELSE

!     ...IDENTIFY ARRAY POINTER XA(I) .LT. X
         I = 1
         DO II = 1,NV-1
            IF (XA(II).LE.X .AND. X.LT.XA(II+1)) I = II
         ENDDO
         IF (X.GT.XA(NV)) I = NV

!     ...GET RANGE OF ARRAY VALUES TO PASS TO INTRPOLATING ENGINE
         NBACK = INT((NPOL+1)/2) - 1
         NMIN  = MAX (1, MIN (I-NBACK, NV-NPOL) )

!     ...COPY SEGMENTS OF XA,YA TO XSEG
   20    DO J = 1,NPOL+1
            JJ = NMIN + (J-1)
            XSEG(J) = XA(JJ)
            YSEG(J) = YA(JJ)
         ENDDO

!     ...GET INTERPOLATING POLYNOMIAL COFFICIENTS
         CALL NR_POLCOF (XSEG,YSEG,NPOL+1,COF)

!     ...EVALUATE THE FUNCTION AND DERIVATIVES
         DO J = 1,NPOL
            Y(J) = COF(J)
            DO I = J+1,NPOL+1
               Y(J) = Y(J) + COF(I) * X**(I-J)
               COF(I) = COF(I) * (I-J)
            ENDDO
         ENDDO
!        Y(NPOL+1) = COF(NPOL+1)


      ENDIF

      END
