      SUBROUTINE TABINT (NV,XA,YA,NP,X,Y)

!+
!     PROGRAM:      TABINT
!     PURPOSE:      
!=                  PROVIDE POLYNOMIAL INTERPOLATION OF DEGREE N IN 1D TABLE
!     NOTE:         X-VALUES MUST BE SUPPLIED IN INCREASING ORDER
!
!     HISTORY:
!     VERSION       MACHINE       DATE      AUTHOR/INSTITUTE
!     1.0           HONEYWELL       .  .81  C.S.JEFFERY / ST.ANDREWS
!     2.0           VAX 11/780      .  .83  C.S.JEFFERY / ST.ANDREWS
!     3.0           microVAX      09.03.88  C.S.JEFFERY / ST.ANDREWS
!
!     INPUT:        NV     NUMBER OF POINTS IN INTERPOLATION TABLE
!                   XA     ARRAY OF X-VALUES
!                   YA     ARRAY OF Y-VALUES
!                   NP     DEGREE OF POLYNOMIAL INTERPOLATION
!                   X      X-VALUE FOR INTERPOLATION
!
!     OUTPUT:       Y      INTERPOLATED VALUE FOR Y(X)
!-


      IMPLICIT REAL (A-H,O-Z)
      REAL     XA(*), YA(*)
      REAL     XSEG(10), YSEG(10)

!.....ERROR HANDLING
      INTEGER  IERCNT
      SAVE     IERCNT
      DATA     IERCNT / 0 /
!.


!.....VERIFY APPLICATION

!  ...TEST X IS IN RANGE
      XMIN = XA(1) - (XA(2)-XA(1)/2.)
      XMAX = XA(NV) + (XA(NV)-XA(NV-1)/2.)
      IF (IERCNT.LE.10) THEN
         IF (X.LT.XMIN .OR. X.GT.XMAX) THEN
            WRITE (*,'(''TABINT: X'',1P,E10.3,'' out of range:'',
     :                 2E10.3,'', extrapolating'')') X,XA(1),XA(NV)
            IERCNT = IERCNT + 1
         ENDIF
         IF (NP.GT.9) THEN
            WRITE (*,*) 'TABINT: NP too large, set = 9'
            IERCNT = IERCNT + 1
         ENDIF
      ENDIF

      NPOL = MIN (NP,9)

!.....LINEAR INTERPOLATION

      IF (NPOL.EQ.1) THEN

!     ...LOCATE GRID NEIGHBOURS
         IF (X.LT.XA(1)) THEN
            IL = 1
            IH = 2
         ELSE
            DO 2 I = 2,NV-1
               IF (X.LT.XA(I)) THEN
                  IL = I - 1
                  GOTO 3
               ENDIF
2              CONTINUE
            IL = NV - 1
3           IH = IL + 1
         ENDIF

!     ...INTERPOLATION INTERVAL
         SINT = XA(IH) - XA(IL)

!     ...TRAP INFINITE GRADIENT
         IF (SINT.LT.1.E-10) THEN
            IF (IERCNT.LE.10) THEN
               WRITE (*,*) 'TABINT: * Error * Infinite gradient'
               IERCNT = IERCNT + 1
            ENDIF
            Y = (YA(IL) + YA(IH)) / 2.

!     ...EVALUATE INTERPOLATION
         ELSE
            Y = YA(IL) + (X - XA(IL)) * (YA(IH)-YA(IL)) / SINT
         ENDIF

!.....POLYNOMIAL INTERPOLATION (N>1)

      ELSE

!     ...IDENTIFY ARRAY POINTER XA(I) .LT. X
         I = 1
         DO 10 II = 1,NV-1
10        IF (XA(II).LE.X .AND. X.LT.XA(II+1)) I = II
         IF (X.GT.XA(NV)) I = NV

!     ...GET RANGE OF ARRAY VALUES TO PASS TO NTINTP
         NBACK = INT((NPOL+1)/2) - 1
         NMIN  = MAX (1, MIN (I-NBACK, NV-NPOL) )

!     ...COPY SEGMENTS OF XA,YA TO XSEG
   20    DO 30 J = 1,NPOL+1
            JJ = NMIN + (J-1)
            XSEG(J) = XA(JJ)
            YSEG(J) = YA(JJ)
   30       CONTINUE

!     ...INTERPOLATE IN XSEG USING NEWTONIAN FORM
         CALL NTINTP (NPOL,XSEG,YSEG,X,Y)

!.....THAT'S ALL THE CHOICES
      ENDIF

!.....FINISH
      END
