      DOUBLE PRECISION FUNCTION TG01B(IX,N,U,S,D,X)

!+
!     04/08/70 : LAST LIBRARY UPDATE
!
!
!
!      TG01BD - 
!=              Function routine to evaluate a cubic spline
!               given spline values and first derivative values at
!               the given knots.
!
!      The spline value is defined as zero outside the knot range, which
!      is extended by a rounding error for the purpose.
!
!               F = TG01BD(IX,N,U,S,D,X)
!
!       IX    Allows caller to take advantage of spline parameters set
!             on a previous call in cases when X point follows previous
!             X point. If IX < 0 the whole range is searched for knot
!             interval; If IX > 0 it is assumed that x is greater than
!             the X of the previous call and search started from there.
!
!       N     Number of knots.
!       U     The knots.
!       S     The spline values.
!       D     The first derivative values of the spline at the knots.
!       X     The point at which the spline value is required.
!       F     The value of the spline at the point X.
!
!                                      MODIFIED JULY 1970
!
!
! Allowable rounding error on points at extremes of knot range is
! 2**IEPS*MAX(!U(1)!,!U(N)!).
!-

      IMPLICIT  REAL*4     (A-H,O-Z)
      IMPLICIT  INTEGER*4  (I-N)
      DIMENSION U(*),S(*),D(*)
      DATA      IFLG/0/,IEPS/-50/
!.
! Test whether point in range.

      IF(X.LT.U(1)) GOTO 990
      IF(X.GT.U(N)) GOTO 991

! Jump if knot interval requires random search.

      IF(IX.LT.0.OR.IFLG.EQ.0) GOTO 12

! Jump if knot interval same as last time.

      IF(X.LE.U(J+1)) GOTO 8

! Loop till interval found.

1     J=J+1
11    IF(X.GT.U(J+1)) GOTO 1
      GOTO 7

! Estimate knot interval by assuming equally spaced knots.

12    J=ABS(X-U(1))/(U(N)-U(1))*(N-1)+1

! Ensure case x=u(n) gives j=n-1.

      J=MIN(J,N-1)

! Indicate that knot interval inside range has been used.

      IFLG=1

! Search for knot interval containing X.

      IF(X.GE.U(J)) GOTO 11
2     J=J-1
      IF(X.LT.U(J)) GOTO 2

! Calculate spline parameters for jth interval.

7     H=U(J+1)-U(J)
      Q1=H*D(J)
      Q2=H*D(J+1)
      SS=S(J+1)-S(J)
      B=3.0*SS-2.0*Q1-Q2
      A=Q1+Q2-2.0*SS

! Calculate spline value.

8     Z=(X-U(J))/H
      TG01B =((A*Z+B)*Z+Q1)*Z+S(J)
      RETURN

! Test if X within rounding error of U(1).

990   IF(X.LE.U(1)-2.0**IEPS*MAX(ABS(U(1)),ABS(U(N))))GOTO99
      J=1
      GOTO 7

! Test if x within rounding error of U(N).

991   IF(X.GE.U(N)+2.0**IEPS*MAX(ABS(U(1)),ABS(U(N))))GOTO99
      J=N-1
      GOTO 7
99    IFLG=0

! Function value set to zero for points outside the range.

      TG01B =0.0
      RETURN
      END
