SUBROUTINE NR_COVSRT (COVAR,NCVM,MA,LISTA,MFIT)

  !+
  !  Program:
  !     NR_COVSRT

  !  Purpose:
  !=    Sort covariance matrix to true order of fitting coefficients

  !  Type:
  !     SUBROUINE subprogram

  !  Description:
  !     Given the covariance matrix COVAR of a fit for MFIT of MA total
  !     parameters, and their ordering LISTA(I), repack the covariance
  !     matrix to the true order of the parameters. Elements are associated
  !     with fixed parameters will be zero. NCVM is the physical dimension
  !     of COVAR.

  !  Arguments given:
  !     COVAR (real)           matrix of covariance coefficients
  !     NCVM (integer)         physical dimension of COVAR
  !     MA (integer)           total number of parameters in fit
  !     LISTA (integer)        ordering of coefficients
  !     MFIT (integer)         number of parameters used

  !  Reference:
  !     Press et al. 1989, Numerical Recipes, p. 515

  !  Authors:
  !     Press et al. 
  !     C.S.Jeffery (CSJ) (St Andrews)

  !  History:
  !     1-DEC-1994: CSJ
  !        original version, adapted from Numerical Recipes

  !-

  !  Constant and variable declarations:

  !  Subroutine arguments:
  INTEGER NCVM
  REAL COVAR(NCVM,NCVM)



  INTEGER MFIT
  INTEGER LISTA(*)
  INTEGER MA

  !.

  !  Zero all elements below diagonal
  DO J = 1,MA-1
     DO I = J+1,MA
        COVAR(I,J) = 0.
     ENDDO
  ENDDO

  !  Repack off-diagonal elements into correct locations below diagonal
  DO I = 1,MFIT-1
     DO J = I+1,MFIT
        IF(LISTA(J).GT.LISTA(I)) THEN
           COVAR(LISTA(J),LISTA(I))=COVAR(I,J)
        ELSE
           COVAR(LISTA(I),LISTA(J))=COVAR(I,J)
        ENDIF
     ENDDO
  ENDDO

  !  Temporarily store original diagonal elements in top row,
  !  and zero the diagonal
  SWAP = COVAR(1,1)
  DO J = 1,MA
     COVAR(1,J) = COVAR(J,J)
     COVAR(J,J) = 0.
  ENDDO

  !  Now sort elements into proper order on diagonal
  COVAR(LISTA(1),LISTA(1)) = SWAP
  DO J = 2,MFIT
     COVAR(LISTA(J),LISTA(J))=COVAR(1,J)
  ENDDO

  !  Finally, fill in above diagonal by symmetry
  DO J = 1,MA
     DO I = 1,J-1
        COVAR(I,J) = COVAR(J,I)
     ENDDO
  ENDDO

END SUBROUTINE NR_COVSRT
