      SUBROUTINE NR_INVERT (A, NP, N, AX, INDX)

!+
!  Program:
!     NR_INVERT

!  Purpose:
!=    Obtains the inverse, AX, of matrix A
!     by first obtaining the LU decomposition of A and then
!     by backsubstitution.

!  Description:
!     Finds the inverse matrix 

!  Arguments given:
!     A (real array)      LU decomposition of matrix A provided by LUDCMP
!     N (integer)         order of matrix
!     NP (integer)        physical dimension of array A

!  Arguments returned:
!     AX (real array)     inverse of A
!     INDX (integer vector) permutation vector

!  Reference:
!     Press et al. 1989, Numerical Recipes, p. 38

!  Authors:
!     Press et al. 
!     Y.C.Unruh (YCU) (Sussex)
!     C.S.Jeffery (CSJ) (St Andrews)

!  History:
!     1-DEC-1994: YCU
!        original version, adapted from Numerical Recipes
!     17-OCT-1997: CSJ
!        adapted for package NR

!  See also:
!     pack/math/matinv.f      Matrix inversion routine due to Bevington
!     pack/mx/mxinv.f         Matrix inversion using up.tri. factorization
!-

!  Global declarations:
      IMPLICIT NONE

!  Subroutine arguments (given and returned):
      INTEGER          N
      INTEGER          NP
      DOUBLE PRECISION A(NP,NP)
      DOUBLE PRECISION AX(NP,NP)
      INTEGER          INDX(N)

!  Local variables:
      DOUBLE PRECISION D
      INTEGER          I, J

!.

      DO I = 1, N
        DO J = 1, N
          AX(I,J) = 0.
        ENDDO
        AX(I,I) = 1.
      ENDDO

!  LU  decomposition of A executed just once
      CALL NR_LUDCMP(A, N, NP, INDX, D)

!  back substitution
      DO J = 1, N
        CALL NR_LUBKSB(A, N, NP, INDX, AX(1,J) )
      ENDDO

      END
