SUBROUTINE NR_MRQCOF (X,Y,SIG,NDATA, A,MA,LISTA,MFIT, &
     ALPHA,BETA,NALP,CHISQ,FUNCS)

  !+
  !  Program:
  !     NR_MRQCOF

  !  Purpose:
  !=    Evaluate linearized fitting matrix ALPHA and vector BETA for NR_MRQMIN

  !  Type:
  !     SUBROUINE subprogram

  !  Description:
  !     see NR_MRQMIN

  !  Arguments given:
  !     X	(real)           array of x-values
  !     Y (real)           array of y-values
  !     SIG (real)         array of standard deviations on y-values
  !     NDATA (integer)    number of data in X,Y,SIG


  !  Reference:
  !     Press et al. 1989, Numerical Recipes, p. 527

  !  Authors:
  !     Press et al. 
  !     C.S.Jeffery (CSJ) (St Andrews)

  !  History:
  !     21-DEC-1994: CSJ
  !        original version, adapted from Numerical Recipes

  !-

  !  Constant and variable declarations:

  !  Subroutine arguments (given):
  INTEGER,INTENT(IN) :: NDATA
  REAL,INTENT(IN)    :: X(NDATA)
  REAL,INTENT(IN)    :: Y(NDATA)
  REAL,INTENT(IN)    :: SIG(NDATA)
  INTEGER,INTENT(IN) :: MA
  INTEGER,INTENT(IN) :: LISTA(MA)
  INTEGER,INTENT(IN) :: MFIT
  INTEGER,INTENT(IN) :: NALP

  !  Subroutine arguments (returned):
  REAL A(MA)
  REAL ALPHA(NALP,NALP)
!  REAL BETA(MA,1)
!  array converted to true vector in attempt to resolve memory leak in mrqmin
!  code conversion is fine, but bug not fixed
  REAL BETA(MA)
  REAL CHISQ

  !  Local constants:
  PARAMETER (MMAX=50)        ! maximum number of coefficients MA

  !  Local arrays:
  REAL :: DYDA(MMAX) = [ (-99,I=1,MMAX) ]

  !.


  !  Initialize (symmetric) ALPHA, BETA.
  ALPHA(1:MFIT,1:MFIT) = 0.
  BETA(1:MFIT) = 0.
  CHISQ = 0.


  !  Summation loop over all data
  DO I = 1,NDATA
     XX = X(I)
     CALL FUNCS (XX,A,YMOD,DYDA,MA)
     SIG2I = 1./(SIG(I)*SIG(I))
     DY = Y(I) - YMOD
     DO J = 1,MFIT
        WT = DYDA(LISTA(J)) * SIG2I
        ALPHA(J,1:J) = ALPHA(J,1:J) + WT*DYDA(LISTA(1:J))
!        BETA(J,1) = BETA(J,1) + DY*WT
        BETA(J) = BETA(J) + DY*WT
     ENDDO

     !     and find chi-squared.
     CHISQ = CHISQ + DY*DY*SIG2I
  ENDDO


  !  Fill in the symmetric side.
  DO J = 2,MFIT
     ALPHA(1:J-1,J) = ALPHA(J,1:J-1)
  ENDDO


END SUBROUTINE NR_MRQCOF
