      SUBROUTINE NR_POLIN2 (X1A, X2A, YA, M, N, X1, X2, Y, DY)

!+
!  Program:
!     NR_POLIN2
!  Purpose:
!=    Returns an interpolated function and a corresponding accuracy based on a direction.
!  Description:
!     Given arrays X1A (length M) and X2A (length N) of independent variables,
!     and an M by N array of function values YA, tabulated at the grid points
!     defined by bX1A and X2A; and given values X1 and X2 of the independent 
!     variables; this routine returns an interpolated function Y, and an 
!     accuracy DY (based only on the interpolation in the X1 direction, 
!     however).

!  Arguments given:
!     X1A (real)             input array containing M x-values
!     X2A (real)             input array containing N x-values
!     YA  (real)             input array containing MxN y-values
!     N (integer)            number of elements in input arrays
!     M (integer)            number of elements in input arrays
!     X1 (real)              value at which Y=P(x1,x2) is to be evaluated
!     X2 (real)              value at which Y=P(x1,x2) is to be evaluated

!  Arguments returned:
!     Y (real)               Y = P(x)
!     DY (real)              error estimate in Y

!  Reference:
!     Press et al. 1989, Numerical Recipes, p. 97
!-

!  Subroutine arguments (given):
      DOUBLE PRECISION X1A(*)
      DOUBLE PRECISION X2A(*)
      DOUBLE PRECISION YA(M,N)
      INTEGER N, M
      DOUBLE PRECISION X1, X2

!  Subroutine arguments (returned):
      DOUBLE PRECISION Y
      DOUBLE PRECISION DY

!  Local constants:
!     NMAX should be the largest anticipated value of N.
      PARAMETER (NMAX=20,MMAX=20)

!  Local arrays:
      DOUBLE PRECISION YNTMP(NMAX),YMTMP(MMAX)

!.

!   Loop over rows
      DO J=1,M

!     Copy the row into temporary storage
        DO K=1,N
          YNTMP(K)=YA(J,K)
        END DO

!     Interpolate answer into temporoary storage
        CALL NR_POLINT (X2A,YNTMP,X2,YMTMP(J),DY)
      END DO

!   Do the final interpolation
      CALL NR_POLINT (X1A,YMTMP,X1,Y,DY)
      END
