      SUBROUTINE BARK01

!+
!     PROGRAM:      BARK01
!     PURPOSE:      
!=                  AUTOMATIC BLAZE FUNCTION DEFINITION
!
!     REFERENCES:   BARKER,P.K., 1984. A.J., 89, 899.
!
!     HISTORY:
!     VERSION       MACHINE       DATE      AUTHOR/INSTITUTE
!     1.0           microVAX      12.01.88  C.S.JEFFERY / ST.ANDREWS
!-

      INCLUDE 'implct.f'
      INCLUDE 'ecdeck.f'


      REAL      MM, XM, YM
      REAL      RR, RX, RY, RMX, RMY, DRMXDK, DRMYDK
      REAL      WL, WX, WY
      REAL      FRATIO, FX, FY
      REAL      DELTAK, DKP, DKM
      REAL      XY, YY
      REAL      PI
      INTEGER   MX,  MY,  NCX, NCY, ITER

      DATA      PI / 3.1415927 /
!.


!     LOOP THROUGH ORDERS

      DO 200 M = 2,NECORD-1

!        SAVE K FROM ADJACENT ORDERS

         KMM1 = BLWCEN(M-1)
         KMP1 = BLWCEN(M+1)

!        ITERATE CORRECTIONS TO K

         DO 190 ITER = 1,10

!           EQUALISE K IN ADJACENT ORDERS (BLAZE USES BLWCEN)

            BLWCEN(M-1) = BLK(M) / MECORD(M-1)
            BLWCEN(M+1) = BLK(M) / MECORD(M+1)

!           DETERMINE MEAN FLUX RATIO 
!           IN OVERLAP REGION BETWEEN ORDERS M-1 AND M

            MX     = M - 1
            MY     = M

            FX     = 0.
            DO 110 I = NXLOOV(MX),NXUPOV(MX)
               CALL BLAZE (I, MX, WL, XM, RX)
 110           FX = FX + ECSTAK (I,MX) / RX
            FY     = 0.
            DO 120 I = NYLOOV(MY),NYUPOV(MY)
               CALL BLAZE (I, MY, WL, YM, RY)
 120           FY = FY + ECSTAK (I,MY) / RY
            FRATIO = FX / FY

!           DETERMINE DERIVATIVES OF THE BLAZE FUNCTIONS

            NCX    = NXLOOV(MX) + NWAVOV/2
            CALL BLAZE (NCX, MX, WX, XM, RMX)
            CALL DBLDX (NCX, MX, DRMXDK)
            NCY    = NYLOOV(MY) + NWAVOV/2
            CALL BLAZE (NCY, MY, WY, YM, RMY)
            CALL DBLDX (NCX, MX, DRMYDK)

!           DETERMINE CORRECTION  DELTA K(M)

            DKM    = ( FRATIO - 1.0 ) /
     1                 ( DRMXDK / RMX - DRMYDK * FRATIO / RMY )

!           DETERMINE MEAN FLUX IN OVERLAP REGION BETWEEN ORDERS M AND M+1

            MX     = M
            MY     = M + 1

            FX     = 0.
            DO 130 I = NXLOOV(MX),NXUPOV(MX)
               CALL BLAZE (I, MX, WL, XM, RX)
 130           FX = FX + ECSTAK (I,MX) / RX
            FY     = 0.
            DO 140 I = NYLOOV(MY),NYUPOV(MY)
               CALL BLAZE (I, MY, WL, YM, RY)
 140           FY = FY + ECSTAK (I,MY) / RY
            FRATIO = FX / FY

!           DETERMINE DERIVATIVES OF THE BLAZE FUNCTIONS

            NCX    = NXLOOV(MX) + NWAVOV/2
            CALL BLAZE (NCX, MX, WX, XM, RMX)
            CALL DBLDX (NCX, MX, DRMXDK)
            NCY    = NYLOOV(MY) + NWAVOV/2
            CALL BLAZE (NCY, MY, WY, YM, RMY)
            CALL DBLDX (NCX, MX, DRMYDK)

!           DETERMINE CORRECTION  DELTA K(M)

            DKP    = ( FRATIO - 1.0 ) /
     1                 ( DRMXDK / RMX - DRMYDK * FRATIO / RMY )

!           DETERMINE MEAN CORRECTION, TEST VALUE AND APPLY IT

            DELTAK = (DKP + DKM) / 2.
            BLK(M)  = BLK(M) + DELTAK
            BLWCEN(M) = BLK(M) / MECORD(M)
!           write out some diagnostics
!           write (6,*) m, xm, wx, wy, dkm, dkp, BLK(m), BLWCEN(m)
            IF (ABS(DELTAK).LE.1.0) GO TO 191

!           CONCLUDE ITERATION LOOP

 190        CONTINUE

 191     CONTINUE

!        RESTORE VALUES FOR LAMDAC

         BLWCEN(M-1) = KMM1
         BLWCEN(M+1) = KMP1

!        CONCLUDE LOOP OVER ORDERS

 200     CONTINUE

!     REPLACE K FOR FIRST AND LAST ORDERS 
!     (BETTER TO USE SMOOTHING AND EXTRAPOLATION)

      BLK(1)      = BLK(2)
      BLWCEN(1)    = BLK(1) / MECORD(1)
      BLK(NECORD)   = BLK(NECORD-1)
      BLWCEN(NECORD) = BLK(NECORD) / MECORD(NECORD)
!
 999  END
