      SUBROUTINE BLCHEK

!+
!     PROGRAM:      BLCHEK
!     PURPOSE:
!=    CHECK THE BLAZE FUNCTION FOR THE CURRENT ECHELLE SPECTROGRAM
! 
!     REFERENCES:   
!
!     HISTORY:
!     VERSION       MACHINE       DATE      AUTHOR/INSTITUTE
!     1.0           microVAX      09.03.88  C.S.JEFFERY / ST.ANDREWS
!-

      INCLUDE 'implct.f'
      INCLUDE 'ecdeck.f'
      INCLUDE 'cadeck.f'
      INCLUDE 'spdeck.f'

!     CONTROL CODES
      CHARACTER*1   CCODE

!     ORDER TRACKING
      INTEGER       NORDER
      INTEGER       NORDLO
      INTEGER       NORDHI

!     PLOT CONTROL FLAGS
      LOGICAL       LNORM
      LOGICAL       LTRIM
      LOGICAL       LSOLO

!     ORDER MARKERS
      REAL          SL
      REAL          DL
      INTEGER       NL

!     PLOT PARAMETERS (DO NOT USE IF DECK 'DISPGX' IS ACTIVATED)
      CHARACTER*3   CHC,CHP,CHM
      CHARACTER*79  HEADER, XLABEL, YLABEL
      REAL          DXMIN, DXMAX, DYMIN, DYMAX

!     EXTERNAL FUNCTIONS USED
      CHARACTER*20  CHFRMI
!.

!     STATEMENT FUNCTION TO GET ORDER POINTER FROM ORDER
      IDXORD (NORDER) = (NORDER-MECORD(1)) * (MECORD(2)-MECORD(1)) + 1



!     VERIFY GRAPHICS DEVICE IS SET UP

      CALL GX_OK (IOK)
      IF (IOK.EQ.0) THEN
         CALL MESSGE ('BLCHEK: * Error * No graphics device')
         RETURN
      ENDIF

!     SET UP START VALUES REQUIRED BY THIS ROUTINE ONLY

!     SET UP THE ORDER MAPPING
      NORDLO = MIN(MECORD(1),MECORD(NECORD))
      NORDHI = MAX(MECORD(1),MECORD(NECORD))
      NORDER = NORDLO

!     INITIALISE PLOT FLAGS
      LSOLO = LT
      LNORM = LF
      LTRIM = LT

!     WARN USER ABOUT LIVE KEY-BOARD
      CALL IOHEAD ('Blaze function polynomial verification')
      CALL KEYWRN
      CALL IOFOOT


!     SELECT ORDER FOR FIT

100   CALL MESSGE (' <')
      CALL KEYCHK (CCODE,'=.+-EFGHNQOST')

!     HELP
      IF (CCODE.EQ.'H') THEN
         CALL MESSGE (' Select echelle order / plotting mode')
         CALL MESSGE ('   =      Specify order by number')
         CALL MESSGE ('   +      Next order')
         CALL MESSGE ('   -      Back to previous order')
         CALL MESSGE ('   .      Repeat current order')
         CALL MESSGE ('   F      Plot complete orders')
         CALL MESSGE ('   G      Plot gross spectrum and fit')
         CALL MESSGE ('   N      Plot normalised spectrum')
         CALL MESSGE ('   O      Plot overlapping orders')
         CALL MESSGE ('   S      Plot single orders')
         CALL MESSGE ('   T      Plot trimmed orders')
         CALL MESSGE ('   E      Exit')
         CALL MESSGE ('   Q      Quit')
         CALL MESSGE ('   H      Help')

!     EXIT
      ELSEIF (CCODE.EQ.'E') THEN
         GOTO 900

!     ABORT
      ELSEIF (CCODE.EQ.'Q') THEN
         GOTO 999

!     SPECIFY ORDER BY NUMBER
      ELSEIF (CCODE.EQ.'=') THEN
         CALL GETINT ('Specify order number', NORDER)
         GOTO 150

!     PROCEED TO NEXT ORDER
      ELSEIF (CCODE.EQ.'+') THEN
         NORDER = NORDER + 1
         NORDER = MAX (NORDLO,NORDER)
         GOTO 150

!     REPEAT CURRENT ORDER
      ELSEIF (CCODE.EQ.'.') THEN
         GOTO 150

!     GO BACK TO PREVIOUS ORDER
      ELSEIF (CCODE.EQ.'-') THEN
         NORDER = NORDER - 1
         NORDER = MIN (NORDER,NORDHI)
         GOTO 150

!     SET FLAG FOR PLOTTING NORMALISED SPECTRA
      ELSEIF (CCODE.EQ.'N') THEN
         LNORM = LT

!     SET FLAG FOR PLOTTING GROSS SPECTRA + FITS
      ELSEIF (CCODE.EQ.'G') THEN
         LNORM = LF

!     SET FLAG FOR PLOTTING SINGLE ORDERS
      ELSEIF (CCODE.EQ.'S') THEN
         LSOLO = LT

!     SET FLAG FOR PLOTTING OVERLAPPING ORDERS
      ELSEIF (CCODE.EQ.'O') THEN
         LSOLO = LF

!     SET FLAG FOR PLOTTING TRIMMED ORDERS
      ELSEIF (CCODE.EQ.'T') THEN
         LTRIM = LT

!     SET FLAG FOR PLOTTING COMPLETE
      ELSEIF (CCODE.EQ.'F') THEN
         LTRIM = LF

!     NO MORE OPTIONS
      ENDIF
      GOTO 100

!     CHECK ORDER EXISTS BEFORE DOING ANYTHING SILLY

150   CONTINUE
      CALL OUTINT ('Processing order',NORDER)
      IF (NORDER.LT.NORDLO .OR. NORDER.GT.NORDHI) THEN
         CALL MESSGE ('* WARNING * nonexistent order')
         CALL OUTINT ('Limits for order number are', NORDLO)
         CALL OUTINT ('and',                         NORDHI)
         GOTO 100
      ENDIF

!     GET ORDER POINTER FROM ORDER NUMBER
      J = IDXORD (NORDER) 
      IF (.NOT.LSOLO) THEN
         J  = MAX (2,J)
         J  = MIN (J,NECORD-1)
         JP = J + 1
         JM = J - 1
         NORDER = MECORD(J)
      ENDIF

!     GET THE CURRENT ORDER

!     COPY THE ORDER INTO THE SPECTRUM ARRAYS
      SL = ECSLAM(J)
      DL = ECDLAM(J)
      NL = NECWAV(J)
      DO 155 I = 1,NL
         SPW(I) = SL + I * DL
         SPF(I) = ECSTAK(I,J)
155      CONTINUE
      NSPW = NL
      SPHEAD(1) = ECHEAD(1:10) // ' : Order ' // CHFRMI (NORDER, 3)

!     DETERMINE LIMITS IF TRIMMING REQUIRED
      ILO = 1
      IHI = NL
      IF (LTRIM) THEN
         ILO = (BLXMIN(J) + BLWCEN(J) - SL) / DL
         IHI = (BLXMAX(J) + BLWCEN(J) - SL) / DL
      ENDIF

!     GET ARRAY LIMITS
      SPWMIN = SPW(1)
      SPWMAX = SPW(NSPW)
!        FLUX LIMITS DERIVED AVOIDING END OF ORDER EFFECTS
      CALL MINMAX (SPF, 10,NSPW-10, SPFMIN,SPFMAX)

!     NOW CALCULATE SOME DISPLAY PARAMETERS

!     THE X-RANGE
      XLABEL = 'Wavelength (A)'
      IF (LSOLO) THEN
         DXMIN = SL +      DL
         DXMAX = SL + NL * DL
      ELSE
         DXMIN = ECSLAM(JM)
         DXMAX = ECSLAM(JP) + NECWAV(JP)*ECDLAM(JP)
      ENDIF

!     THE Y-RANGE
      IF (LNORM) THEN
         YLABEL = 'Normalised flux'
         I = NL / 2
         CALL BLAZE (I,J, W,O,R)
         DYMIN = 0.0
         DYMAX = 1.5 * ECSTAK(I,J) / R
      ELSE
         YLABEL = 'Flux (counts)'
         DYMIN = SPFMIN - (SPFMAX-SPFMIN) / 10.
         DYMAX = SPFMAX + (SPFMAX-SPFMIN) / 10.
      ENDIF

!     THE HEADER
      IF (LSOLO) THEN
         CHC = CHFRMI (NORDER,3)
         HEADER = ECHEAD (1:10) // ' : Order ' // CHC
      ELSE
         CHM = CHFRMI (NORDER-1,3)
         CHP = CHFRMI (NORDER+1,3)
         HEADER = ECHEAD (1:10) // ' : Orders ' // CHP // ' - ' // CHM
      ENDIF

!     PLOT THE FRAME
160   CALL GX_CLR
      IF (LSOLO) THEN
         CALL GX_RSPC ( 0.2,   0.1,   0.8,   0.9 )
      ELSE
         CALL GX_RSPC ( 0.1,   0.2,   0.9,   0.8 )
      ENDIF
      CALL GX_QSPC (DXMIN, DYMIN, DXMAX, DYMAX)
      CALL GX_AXES (HEADER, XLABEL, YLABEL)

!     PLOT THE CURRENT ORDER

!     NORMALISED DATA
      IF (LNORM) THEN
         DO 161 I = ILO,IHI
            CALL BLAZE (I,J, W,O,R)
            IS = 1 + I - ILO
            SPW(IS) = W
            SPF(IS) = ECSTAK(I,J) / R
161         CONTINUE
         NSPW = 1 + IHI - ILO
         CALL GX_QPLT (NSPW, SPW, SPF)

!     GROSS SPECTRUM + BLAZE FUNCTION
      ELSE
!        GROSS ALREADY IN SPECTRUM ARRAY
         CALL GX_QPLT (NSPW, SPW, SPF)
!        NOW COPY BLAZE FUNCTION, SKIPPING BY 10
         IS = 0
         DO 162 I = ILO,IHI,10
            CALL BLAZE (I,J, W,O,R)
            IS = IS + 1
            SPW(IS) = W
            SPF(IS) = R * BLFMAX(J)
162         CONTINUE
         NSPW = IS
         CALL GSPLI  (4)
         CALL GX_QPLT (NSPW, SPW, SPF)
         CALL GSPLI  (1)
      ENDIF

!     PLOT THE ADJACENT ORDERS IF REQUIRED

      IF (.NOT.LSOLO) THEN

         DO 180 JJ = JM,JP,2

!           COPY THE ORDER
            SL = ECSLAM(JJ)
            DL = ECDLAM(JJ)
            NL = NECWAV(JJ)
            DO 170 I = 1,NL
               SPW(I) = SL + I * DL
               SPF(I) = ECSTAK(I,JJ)
170         CONTINUE
            NSPW = NECWAV(JJ)

!           ACTIVATE TRIMMING
            ILO = 1
            IHI = NL
            IF (LTRIM) THEN
               ILO = (BLXMIN(JJ) + BLWCEN(JJ) - SL) / DL
               IHI = (BLXMAX(JJ) + BLWCEN(JJ) - SL) / DL
            ENDIF

!           NORMALISED DATA
            IF (LNORM) THEN
               DO 171 I = ILO,IHI
                  CALL BLAZE (I,JJ, W,O,R)
                  IS = 1 + I - ILO
                  SPW(IS) = W
                  SPF(IS) = ECSTAK(I,JJ) / R
171               CONTINUE
               NSPW = IS
               CALL GSPLI  (2)
               CALL GX_QPLT (NSPW, SPW, SPF)
               CALL GSPLI  (1)

!           GROSS SPECTRUM + BLAZE FUNCTION
            ELSE
!              GROSS ALREADY IN SPECTRUM ARRAY
               CALL GSPLI  (2)
               CALL GX_QPLT (NSPW, SPW, SPF)
               CALL GSPLI  (1)
!              NOW COPY BLAZE FUNCTION, SKIPPING BY 10
               IS = 0
               DO 172 I = ILO,IHI,10
                  CALL BLAZE (I,JJ, W,O,R)
                  IS = IS + 1
                  SPW(IS) = W
                  SPF(IS) = R * BLFMAX(JJ)
172               CONTINUE
               NSPW = IS
               CALL GSPLI  (4)
               CALL GX_QPLT (NSPW, SPW, SPF)
               CALL GSPLI  (1)
            ENDIF

180      CONTINUE

      ENDIF

!     I THINK WE'VE PLOTTED EVERYTHING
      CALL GX_FLSH
      GOTO 100


!     NORMAL EXIT

900   CONTINUE
      CALL GX_CLR

!     AND QUIT THIS SUBROUTINE
      CALL LINEFD (1)
      CALL MESSGE ('End of Echelle Blaze function verification')
      CALL IOFOOT
      RETURN


!     ABORT EXIT

999   CALL MESSGE ('BLCHEK: Abnormal termination')
      END
