      SUBROUTINE BLINTP

!+
!     PROGRAM:      BLINTP
!     PURPOSE:      
!=                  DEFINE APPROXIMATION POLYNOMIALS FOR BLAZE FUNCTION
!                   FOR ECHELLE ORDERS UNSUITABLE FOR CONTINUUM FITTING
!
!     METHOD:       USES LINEAR INTERPOLATION
!                   TO DEFINE THE BLAZE FUNCTION BETWEEN KNOWN ORDERS
!                   AND FITS A NEW APPROXIMATION POLYNOMIAL TO THE RESULT
!     REFERENCES:   
!
!     HISTORY:
!     VERSION       MACHINE       DATE      AUTHOR/INSTITUTE
!     1.0           microVAX      16.03.88  C.S.JEFFERY / ST.ANDREWS
!
!-
      INCLUDE 'implct.f'
      INCLUDE 'ecdeck.f'


!     CONTROL CODES
      CHARACTER*1  CCODE

!     ORDER CONTROLLERS
      INTEGER       NORDER
      INTEGER       NORDLO
      INTEGER       NORDHI

!     LOCAL BLAZE FUNCTION ARRAYS
      REAL          CBCOFF(10)
      REAL          CBDCFF(10)
      REAL          CBCLO(10)
      REAL          CBCHI(10)

      REAL          EBLCF(10,32)
      REAL          EBLWC(32)
      REAL          EBLFM(32)
      REAL          EBLXM(32)
      REAL          EBLXP(32)
      LOGICAL       LEBLF(32)

!     CHECK FOR MISSING ORDERS
      INTEGER       NN
      INTEGER       IORD(32)

!     ARRAYS FOR ACCUMULATING INTERPOLATED BLAZE FUNCTIONS
      REAL          FX(1000), FY(1000)
      INTEGER       NX

!     EXTERNAL FUNCTIONS USED
      CHARACTER     CHFRMI
      INTEGER       INDEXR
!.

!     STATEMENT FUNCTION RELATING ORDER NUMBER (NORDER) AND ARRAY INDEX (IDXORD)
      IDXORD (NORDER) = (NORDER-MECORD(1)) * (MECORD(2)-MECORD(1)) + 1



!     VERIFY BLAZE FUNCTION APPROPRIATE

      IF (IBLTYP.NE.2) THEN
         CALL MESSGE ('BLINTP: * Error * Inappropriate blaze function')
         RETURN
      ENDIF

!     SET UP START VALUES REQUIRED BY THIS ROUTINE ONLY

!     SET UP THE ORDER MAPPING
      NORDLO = MIN (MECORD(1),MECORD(NECORD))
      NORDHI = MAX (MECORD(1),MECORD(NECORD))

!     ZERO LOCAL FITTING ARRAYS
      CALL MXZERO (EBLCF, 10,32)
      DO 10 N = 1,NECORD
         EBLWC(N) = 0.
         EBLFM(N) = 0.
         EBLXM(N) = 0.
         EBLXP(N) = 0.
10       LEBLF(N) = LF

!     COPY EXISTING FIT INTO LOCAL WORK AREA
      DO 20 N = 1,NECORD
         IF (LBLF(N)) THEN
            DO 11 K = 1,10
11             EBLCF(K,N) = BLCHEB(K,N)
            EBLWC(N) = BLWCEN(N)
            EBLFM(N) = BLFMAX(N)
            EBLXM(N) = BLXMIN(N)
            EBLXP(N) = BLXMAX(N)
            LEBLF(N) = LT
         ENDIF
20       CONTINUE

!     WRITE ROUTINE HEADER
      CALL IOHEAD ('Blaze function interpolation')
!     WARN USER ABOUT LIVE KEY-BOARD
      CALL LINEFD (1)
      CALL KEYWRN
      CALL IOFOOT

!     SELECT OPTION

100   CALL MESSGE (' <')
      CALL KEYCHK (CCODE,'DEHILQ')



!     HELP
      IF (CCODE.EQ.'H') THEN
         CALL MESSGE (' BLINTP   Smooth blaze function parameters')
         CALL MESSGE ('   D      Delete fit for specified order')
         CALL MESSGE ('   E      Exit')
         CALL MESSGE ('   H      Help')
         CALL MESSGE ('   I      Interpolate fits for missing orders')
         CALL MESSGE ('   L      List missing orders')
         CALL MESSGE ('   Q      Quit = Abort')
         GOTO 100

!     EXIT
      ELSEIF (CCODE.EQ.'E') THEN
         GOTO 900

!     ABORT
      ELSEIF (CCODE.EQ.'Q') THEN
         GOTO 999


!     DELETE SPECIFIED ORDER 
      ELSEIF (CCODE.EQ.'D') THEN
         CALL GETINT ('Specify order number', NORDER)
!        VERIFY NORDER
         IF (NORDER.LT.NORDLO .OR. NORDER.GT.NORDHI) THEN
            CALL MESSGE ('Attempt to process non-existent order')
            CALL OUTINT ('Limits for order number are', NORDLO)
            CALL OUTINT ('and',                         NORDHI)
            GOTO 100
         ENDIF
!        AND DELETE IT
         JORDER = IDXORD (NORDER) 
         LEBLF(JORDER) = LF
         GOTO 100

!        END OF OPTION



!     LIST MISSING ORDERS TO BE INTERPOLATED
      ELSEIF (CCODE.EQ.'L') THEN

!        IDENTIFY MISSING ORDERS
         NN = 0
         DO 120 N = 1,NECORD
            IF (.NOT.LEBLF(N)) THEN
               NN = NN + 1
               IORD(NN) = MECORD(N)
            ENDIF
120         CONTINUE
         IF (NN.EQ.0) GOTO 100
!
!        PRINT OUT LIST
         CALL MESSGE 
     1      ('BLINTP will interpolate for the following missing orders')
         CALL PRINAR (NN, IORD)



!     INTERPOLATE (LINEAR) FOR MISSING ORDERS
      ELSEIF (CCODE.EQ.'I') THEN

!        IDENTIFY END ORDERS WITH DEFINED BLAZE FUNCTIONS
         JLO = 10000
         JHI = 0
         DO 201 N = 1,NECORD
            IF (LEBLF(N)) THEN
               JLO = MIN (N,JLO)
               JHI = MAX (N,JHI)
            ENDIF
201         CONTINUE

!        LOOK FOR MISSING ORDERS
         DO 220 N = 1,NECORD
            IF (.NOT.LEBLF(N)) THEN

!              LOOK FOR ADJACENT OK ORDERS

!                 BELOW
               DO 202 II = N,1,-1
                  IF (LEBLF(II)) THEN
                     ILO = II
                     GOTO 204
                  ENDIF
202               CONTINUE
!                 NOT FOUND - EXTRAPOLATE
               ILO = JLO
               IHI = JLO + 1
               GOTO 210

!                 ABOVE
204            CONTINUE
               DO 206 II = N,NECORD,1
                  IF (LEBLF(II)) THEN
                     IHI = II
                     GOTO 210
                  ENDIF
206               CONTINUE
!                 NOT FOUND - EXTRAPOLATE
               ILO = JHI - 1
               IHI = JHI

!              JUMP OUT POINT AND REPORT
210            CONTINUE
               CALL OUTINT ('Interpolating blaze function for ' //
     1                      'order', MECORD(N))

!              GET THE INTERPOLATION WEIGHTS 
               FINT     = FLOAT (IHI-ILO)
               FLO      = FLOAT (IHI-N) / FINT
               FHI      = FLOAT (N-ILO) / FINT

!              INTERPOLATE THE CENTRAL WAVELENGTH, FLUX MAMXIMUM
               WCEN     = FLO * EBLWC(ILO) + FHI * EBLWC(IHI)
               FMAX     = 1.0
!             <RELIC FROM WHEN BLAZE FUNCTION NORMALISATION WAS USED>
!              FMAX     = FLO * EBLFM(ILO) + FHI * EBLFM(IHI)

!              COLLECT THE INTERPOLATING POLYNOMIALS
               DO 212 K = 1,10
                  CBCLO(K) = EBLCF(K,ILO)
                  CBCHI(K) = EBLCF(K,IHI)
212               CONTINUE

!              INTERPOLATE THE MISSING BLAZE FUNCTION
               IMIN     = 10.0 * MAX (EBLXM(ILO), EBLXM(IHI))
               IMAX     = 10.0 * MIN (EBLXP(ILO), EBLXP(IHI))
               DO 214 I = IMIN,IMAX
!                 SET UP THE GRID FOR EVALUATING THE INTERPOLATION FUNCTIONS
                  X      = FLOAT (I) / 10.0
!                 EVALUATE AND INTERPOLATE THE MISSING FUNCTION
                  CALL CBEVAL (9,CBCLO,EBLXM(ILO),EBLXP(ILO), X,YLO)
                  CALL CBEVAL (9,CBCHI,EBLXM(IHI),EBLXP(IHI), X,YHI)
                  Y      = FLO * YLO + FHI * YHI
!                 STORE INTERPOLATED FUNCTION
                  IX     = 1 + I - IMIN
                  FX(IX) = X
                  FY(IX) = Y
214               CONTINUE
               NX = 1 + IMAX - IMIN

!              FIT A POLYNOMIAL TO THE INTERPOLATED FUNCTION
               CALL CBLSQF (FX,FY,NX, 9, CBCOFF, XMIN,XMAX)

!              FIND THE MAXIMUM
               CALL CBDIFF (9, CBCOFF,CBDCFF, XMIN,XMAX)
               CALL CBROOT (8, CBDCFF,XMIN,XMAX, 0.0,0.0, XC)
               CALL CBEVAL (9, CBCOFF,XMIN,XMAX, XC,FC)

!              SHIFT POLYNOMIAL TO ENSURE F(WCEN) = FMAX AND CBFMAX = 1.0
               WCEN = WCEN + XC
               FMAX = 1.0
               FC   = 1.0
!             <RELIC FROM WHEN BLAZE FUNCTION NORMALISATION WAS USED>             
!              FMAX = FMAX * FC
               DO 216 IX = 1,NX
                  FX(IX) = FX(IX) - XC
                  FY(IX) = FY(IX) / FC
216               CONTINUE
               CALL CBLSQF (FX,FY,NX, 9, CBCOFF, XMIN,XMAX)

!              STORE RESULT
               EBLWC(N) = WCEN
               EBLFM(N) = FMAX
               EBLXM(N) = XMIN
               EBLXP(N) = XMAX
               DO 218 K = 1,10
218               EBLCF(K,N) = CBCOFF(K)

!           END OF LOOP
            ENDIF
220         CONTINUE

!        NOW SET ALL THE FLAGS
         DO 225 N = 1,NECORD
225         LEBLF(N) = LT

!        AND THAT'S ALL



!     NO MORE OPTIONS
      ENDIF
      GOTO 100



!     NORMAL EXIT

900   CONTINUE

!     COPY POLYNOMIAL FIT TO PERMANENT ARRAYS
      DO 910 N = 1,NECORD
         BLWCEN(N) = EBLWC(N)
         BLFMAX(N) = EBLFM(N)
         BLXMIN(N) = EBLXM(N)
         BLXMAX(N) = EBLXP(N)
         DO 905 K = 1,10
905         BLCHEB(K,N) = EBLCF(K,N)
         LBLF(N)   = LEBLF(N)
910   CONTINUE

!     AND QUIT THIS SUBROUTINE
      CALL LINEFD (1)
      CALL MESSGE ('End of Echelle Blaze function interpolation')
      CALL IOFOOT
      RETURN


!     ABORT EXIT

999   CALL MESSGE ('BLINTP: Abnormal termination')
      CALL MESSGE ('        Polynomial fit definition is not altered')
      END
