      SUBROUTINE BLPDEF

!+
!     PROGRAM:  BLPDEF
!     PURPOSE:      
!=              DEFINE THE BLAZE FUNCTION FOR THE CURRENT ECHELLE SPECTROGRAM
!               AS A SET OF 9TH ORDER POLYNOMIALS.
!               POLYNOMIALS ARE REPRESENTED AS CHEBYSHEV SERIES
!
!     REFERENCES:   
!
!     HISTORY:
!     VERSION       MACHINE       DATE      AUTHOR/INSTITUTE
!     1.0           microVAX      03.02.88  C.S.JEFFERY / ST.ANDREWS
!-

      INCLUDE 'implct.f'
      INCLUDE 'ecdeck.f'
      INCLUDE 'cadeck.f'
      INCLUDE 'spdeck.f'
!     INCLUDE 'dispgx.f'


!     CONTROL CODES
      CHARACTER*1  CCODE

!     CURRENT ORDER BLAZE FUNCTION ARRAYS
      REAL          PNCOFF(10), CBCOFF(10), CBXMIN, CBXMAX, WCEN, FMAX
      LOGICAL       LFIT
!        WORKING ARRAYS AND INTERMEDIATE VARIABLES
      REAL          CBDCFF(10)
      REAL          CXC, XMAX

!     LOCAL BLAZE FUNCTION ARRAYS
      REAL          EBLCB(10,32), EBLXLO(32), EBLXHI(32), 
     1                            EBLWC(32),  EBLFM(32)
      LOGICAL       LEBLF(32)

!     SOME ARRAYS FOR KEEPING SUMMARIES
      INTEGER       IORD(8), IFLG(8)
      REAL          RKK(8)

!     PLOT PARAMETERS (DO NOT USE IF DECK 'DISPGX' IS ACTIVATED)
      CHARACTER*79  HEADER, XLABEL, YLABEL
      REAL          DXMIN, DXMAX, DYMIN, DYMAX

!     EXTERNAL FUNCTIONS USED
      CHARACTER*20  CHFRMI
!     INTEGER       INDEXR

!.

!     NO ASSUMPTIONS ARE MADE ABOUT WHETHER A FIT EXISTS OR NOT FOR A 
!     GIVEN ORDER

!     VERIFY WORKSATION OPEN

      CALL GX_OK (IOK)
      IF (IOK.EQ.0) THEN
         CALL MESSGE ('BLPDEF: * Error * No graphics device')
         RETURN
      ENDIF

!     SET UP START VALUES REQUIRED BY THIS ROUTINE ONLY

!     SET UP THE ORDER MAPPING
      IORDLO = MIN(MECORD(1),MECORD(NECORD))
      IORDHI = MAX(MECORD(1),MECORD(NECORD))
      IORDER = IORDLO - 1

!     ZERO LOCAL FITTING ARRAYS
      CALL MXZERO (EBLCB, 10,32)
      DO 10 I = 1,NECORD
         EBLXLO(I) = 0.
         EBLXHI(I) = 0.
         EBLWC(I)  = 0.
         EBLFM(I)  = 0.
         LEBLF(I)  = LF
10       CONTINUE

!     COPY EXISTING FIT INTO LOCAL WORK AREA
      DO 12 I = 1,NECORD
         IF (LBLF(I)) THEN
            DO 11 J = 1,10
11             EBLCB(J,I) = BLCHEB(J,I)
            EBLXLO(I) = BLXMIN(I)
            EBLXHI(I) = BLXMAX(I)
            EBLWC(I)  = BLWCEN(I)
            EBLFM(I)  = BLFMAX(I)
            LEBLF(I)  = LT
         ENDIF
12       CONTINUE

!     WARN USER ABOUT LIVE KEY-BOARD
      CALL IOHEAD ('Blaze function polynomial definition')
      CALL KEYWRN
      CALL IOFOOT


!     SELECT ORDER FOR FIT

100   CALL MESSGE (' <')
      CALL KEYCHK (CCODE,'=.+-DEHLQS')

!     HELP
      IF (CCODE.EQ.'H') THEN
         CALL MESSGE (' Select echelle order ')
         CALL MESSGE ('   =      Specify order by number')
         CALL MESSGE ('   .      Repeat current order')
         CALL MESSGE ('   +      Next order')
         CALL MESSGE ('   -      Back one order')
         CALL MESSGE ('   D      Delete fit for specified order')
         CALL MESSGE ('   E      Exit')
         CALL MESSGE ('   H      Help')
!        CALL MESSGE ('   L      List current fits')
         CALL MESSGE ('   Q      Quit = Abort')
         CALL MESSGE ('   S      Summarise current fits')
         GOTO 100

!     EXIT
      ELSEIF (CCODE.EQ.'E') THEN
         GOTO 900

!     ABORT
      ELSEIF (CCODE.EQ.'Q') THEN
         GOTO 999

!     SPECIFY ORDER BY NUMBER
      ELSEIF (CCODE.EQ.'=') THEN
         CALL GETINT ('Specify order number', IORDER)
         GOTO 150

!     PROCEED TO NEXT ORDER
      ELSEIF (CCODE.EQ.'+') THEN
         IORDER = IORDER + 1
         IORDER = MAX (IORDLO,IORDER)
         GOTO 150

!     REPEAT CURRENT ORDER
      ELSEIF (CCODE.EQ.'.') THEN
         GOTO 150

!     GO BACK TO PREVIOUS ORDER
      ELSEIF (CCODE.EQ.'-') THEN
         IORDER = IORDER - 1
         IORDER = MIN (IORDER,IORDHI)
         GOTO 150

!     DELETE SPECIFIED ORDER 
      ELSEIF (CCODE.EQ.'D') THEN
         CALL GETINT ('Specify order number', IORDER)
!        VERIFY IORDER
         IF (IORDER.LT.IORDLO .OR. IORDER.GT.IORDHI) THEN
            CALL MESSGE ('Attempt to process non-existent order')
            CALL OUTINT ('Limits for order number are', IORDLO)
            CALL OUTINT ('and',                         IORDHI)
            GOTO 100
         ENDIF
!        AND DELETE IT
         JORDER = (IORDER-MECORD(1)) * (MECORD(2)-MECORD(1)) + 1
         LEBLF(JORDER) = LF
         GOTO 100

!     LIST THE CURRENT FITS
      ELSEIF (CCODE.EQ.'L') THEN
!       -- ABANDONED --

!     SUMMARISE THE CURRENT FITS
      ELSEIF (CCODE.EQ.'S') THEN
         CALL IOFOOT
         CALL MESSGE ('Echelle Blaze function polynomial summary')
         CALL LINEFD (1)
         DO 120 I = 1,NECORD-1,8

            WRITE (6,9999) (MECORD(J),J=I,I+7)
            WRITE (6,9999)  (LEBLF(J),J=I,I+7)
            WRITE (6,9998)  (EBLWC(J),J=I,I+7)
            WRITE (6,9998)  (EBLFM(J),J=I,I+7)
            WRITE (6,9998) ((EBLCB(K,J),J=I,I+7),K=1,10)


9999  FORMAT (1X,10I10)
9998  FORMAT (1X,10F10.2)


120         CONTINUE
         CALL IOFOOT
         GOTO 100

!     NO MORE OPTIONS
      ENDIF
      GOTO 100


!     CHECK ORDER EXISTS BEFORE DOING ANYTHING SILLY

150   CONTINUE
      CALL OUTINT ('Processing order',IORDER)
      IF (IORDER.LT.IORDLO .OR. IORDER.GT.IORDHI) THEN
         CALL MESSGE ('* WARNING * nonexistent order')
         CALL OUTINT ('Limits for order number are', IORDLO)
         CALL OUTINT ('and',                         IORDHI)
         GOTO 100
      ENDIF

!     PLOT THE ORDER

!     GET ORDER POINTER FROM ORDER NUMBER
      JORDER = (IORDER-MECORD(1)) * (MECORD(2)-MECORD(1)) + 1

!     COPY THE ORDER INTO THE SPECTRUM ARRAYS
      SL = ECSLAM(JORDER)
      DL = ECDLAM(JORDER)
      NSPW = NECWAV(JORDER)
      DO 155 I = 1,NSPW
         SPW(I) = SL + I*DL
         SPF(I) = ECSTAK(I,JORDER)
155      CONTINUE
      SPHEAD(1) = ECHEAD(1:10) // ' : Order ' // CHFRMI (IORDER, 3)

!     GET ARRAY LIMITS
      SPWMIN = SPW(1)
      SPWMAX = SPW(NSPW)
!        FLUX LIMITS DERIVED AVOIDING END OF ORDER EFFECTS
      CALL MINMAX (SPF, 10,NSPW-10, SPFMIN,SPFMAX)

!     COMPUTE PLOT PARAMETERS
      XLABEL = 'Wavelength (A)'
      YLABEL = 'Flux (counts)'
      HEADER = SPHEAD(1)
!        we want a routine for getting a useful y range !
      DXMIN = SPWMIN
      DXMAX = SPWMAX
      DYMIN = SPFMIN - (SPFMAX-SPFMIN) / 10.
      DYMAX = SPFMAX + (SPFMAX-SPFMIN) / 10.
!
!     DO THE PLOT
!
!        how about a GX_ routine for selecting the pen/line-type/symbol ?
!        can we do something about GX_ZONE and GXAREA ?
!
160   CALL GX_CLR
      CALL GX_RSPC ( 0.2,   0.1,   0.8,   0.9 )
      CALL GX_QSPC (DXMIN, DYMIN, DXMAX, DYMAX)
      CALL GX_AXES (HEADER, XLABEL, YLABEL)
      CALL GX_QPLT (NSPW, SPW, SPF)
      CALL GX_FLSH

!     IF A CURRENT FIT EXISTS, COPY IT INTO THE CURRENT AREA
      IF (LEBLF(JORDER)) THEN
         LFIT   = LT
         WCEN   = EBLWC(JORDER)
         FMAX   = EBLFM(JORDER)
         CBXMIN = EBLXLO(JORDER)
         CBXMAX = EBLXHI(JORDER)
         CALL MXRGET (EBLCB, CBCOFF, 10,32, JORDER)
      ENDIF


!     VERIFY THE PLOT AND SELECT STEP

200   CALL MESSGE (' <-')
      CALL KEYCHK (CCODE,'CHQS')

!     HELP
      IF (CCODE.EQ.'H') THEN
         CALL MESSGE (' Order verification and continuum definition ')
         CALL MESSGE ('   C      Define continuum zones for fit')
         CALL MESSGE ('   H      Help')
         CALL MESSGE ('   Q      Quit and skip to top menu')
         CALL MESSGE ('   S      Show current fit for this order')
         GOTO 200

!     QUIT
      ELSEIF (CCODE.EQ.'Q') THEN
         CALL GX_CLR
         GOTO 100

!     SHOW CURRENT FIT
      ELSEIF (CCODE.EQ.'S') THEN
         IF (.NOT.LFIT) THEN
            CALL MESSGE ('No current fit for this order')
            GOTO 200
         ENDIF
         GOTO 400

!     DEFINE POINTS FOR FITTING POLYNOMIAL (CONTINUUM / POINTS)
      ELSEIF (CCODE.EQ.'C') THEN
         GOTO 250

!     NO MORE OPTIONS
      ENDIF
      GOTO 200


!     DEFINE POINTS FOR LEAST SQUARES POLYNOMIAL FIT

!     USING CONTINUUM REGIONS PICKED OUT BY CURSOR
250   CONTINUE
      CALL MESSGE (' Delimit continuum regions with cursor:')
      CALL MESSGE ('  Regions must be in increasing wavelength order')
      CALL MESSGE ('  Null or reverse region to end')
!     VOID COLLATING ARRAYS
      NCX = 0

!     LOOP AROUND COLLECTING CONTINUUM WINDOWS
      CYBAR = (SPFMAX-SPFMIN) / 20.
      DO 252 IC = 1,1000

!        GRAB THE WINDOW
         CALL GX_QCUR (CTWX1,CTWY1)
         CALL GX_QCUR (CTWX2,CTWY2)

!        CHECK FOR END OF INPUT
         IF (CTWX1.GE.CTWX2) GOTO 253

!        CHECK FOR ILLEGAL X VALUE 
!        (CONTINUUM REGIONS MUST BE DEFINED IN INCREASING WAVELENGTH ORDER)
         IF (NCX.GT.0) THEN
            IF (CTWX1.LT.CX(NCX)) GOTO 252
         ENDIF

!        MAP THE WINDOW DATA INTO THE 'CURRENT' ARRAYS
         IX1 = INDEXR (CTWX1, SPW, 1,NSPW)
         IX2 = INDEXR (CTWX2, SPW, 1,NSPW)
         DO 251 IX = IX1,IX2
            NCX = NCX + 1
            CX(NCX) = SPW(IX)
            CY(NCX) = SPF(IX)
251         CONTINUE

!        DISPLAY THE WINDOW
         CALL GSPLI  (4)
         CALL GX_QMOV (CTWX1,SPF(IX1)-CYBAR)
         CALL GX_QDRW (CTWX1,SPF(IX1)+CYBAR)
         CALL GX_QMOV (CTWX2,SPF(IX2)-CYBAR)
         CALL GX_QDRW (CTWX2,SPF(IX2)+CYBAR)
         CALL GSPLI  (1)

!        GO TO NEXT REGION
252      CONTINUE

!     END OF DEFINITION
253   CONTINUE
      GOTO 300


!     VERIFY REGIONS WERE SELECTED OK AND SELECT STEP

300   CALL MESSGE (' <=')
      CALL KEYCHK (CCODE,'FHQR')

!     HELP
      IF (CCODE.EQ.'H') THEN
         CALL MESSGE (' Verify continuum and fit blaze function ')
         CALL MESSGE ('   F       Fit polynomial')
         CALL MESSGE ('   H       Help')
         CALL MESSGE ('   Q       Quit and skip to top menu')
         CALL MESSGE ('   R       Repeat plot and continuum defn')
         GOTO 300

!     QUIT
      ELSEIF (CCODE.EQ.'Q') THEN
         CALL GX_CLR
         GOTO 100

!     REPEAT STEP
      ELSEIF (CCODE.EQ.'R') THEN
         GOTO 160

!     FIT POLYNOMIAL
      ELSEIF (CCODE.EQ.'F') THEN
         GOTO 350

!     NO MORE OPTIONS
      ENDIF
      GOTO 300


!     FIT POLYNOMIALS

350   CONTINUE

!     TRANSLATE X VALUES TO AN APPROXIMATE MIDDLE OF THE ORDER
      CXC = (SPW(1)+SPW(NSPW)) / 2.
      DO 351 I = 1,NCX
351      CX(I) = CX(I) - CXC

!     FIT A NINTH ORDER CHEBYSHEV SERIES APPROXIMATION TO THE CONTINUUM DATA
      CALL CBLSQF (CX,CY,NCX, 9, CBCOFF,CBXMIN,CBXMAX)

!     DIFFERENTIATE THE POLYNOMIAL (CBCOFF)
      CALL CBDIFF (9, CBCOFF,CBDCFF,CBXMIN,CBXMAX)

!     FIND THE MAXIMUM (AND CALL IT THE CENTRE)
      CALL CBROOT (8, CBDCFF,CBXMIN,CBXMAX, 0.0, 0.0, XMAX)
      CALL CBEVAL (9, CBCOFF,CBXMIN,CBXMAX, XMAX, FMAX)

!     SHIFT THE X VALUES AGAIN (SPECTRA ARE ASSUMED TO BE NORMALISED)
      CXC  = CXC + XMAX
      WCEN = CXC
      FMAX = 1.0
      DO 352 I = 1,NCX
         CX(I) = CX(I) - XMAX
         CY(I) = CY(I) / FMAX
352      CONTINUE

!     FIT ANOTHER CHEBYSHEV SERIES
      CALL CBLSQF (CX,CY,NCX, 9, CBCOFF,CBXMIN,CBXMAX)
      LFIT = LT



!     PLOT POLYNOMIALS

400   CONTINUE

!     IDENTIFY UPPER AND LOWER LIMITS OF VALID FIT
      ILO = INDEXR (CBXMIN+WCEN, SPW, 1,NSPW) + 1
      IHI = INDEXR (CBXMAX+WCEN, SPW, 1,NSPW) - 1
!     USE SKIPPING TO SPEED THIS UP
!        select another pen when we know how to !
      X = SPW(ILO)
      CALL CBEVAL (9, CBCOFF,CBXMIN,CBXMAX, X-WCEN, F)
      CALL GSPLI  (2)
      CALL GX_QMOV (X,F*FMAX)
      DO 410 I = ILO,IHI,10
         X = SPW(I)
         CALL CBEVAL (9, CBCOFF,CBXMIN,CBXMAX, X-WCEN, F)
         CALL GX_QDRW (X,F*FMAX)
410      CONTINUE
      CALL GSPLI  (1)
      CALL GX_FLSH


!     VERIFY FIT AND SELECT STEP

450   CALL MESSGE (' <+')
      CALL KEYCHK (CCODE,'AHQR')

!     HELP
      IF (CCODE.EQ.'H') THEN
         CALL MESSGE (' Verify polynomial fit ')
         CALL MESSGE ('   A       Accept')
         CALL MESSGE ('   H       Help')
         CALL MESSGE ('   Q       Quit and skip to top menu')
         CALL MESSGE ('   R       Repeat fit for this order')
         GOTO 450

!     QUIT
      ELSEIF (CCODE.EQ.'Q') THEN
         CALL GX_CLR
         GOTO 100

!     REPEAT FIT
      ELSEIF (CCODE.EQ.'R') THEN
         GOTO 150

!     ACCEPT FIT
      ELSEIF (CCODE.EQ.'A') THEN
         GOTO 500

!     NO MORE OPTIONS
      ENDIF
      GOTO 450


!     SAVE COEFFICIENTS FOR THIS ORDER AND UPDATE TABLES

500   CONTINUE
      EBLWC(JORDER)  = WCEN
      EBLFM(JORDER)  = FMAX
      EBLXLO(JORDER) = CBXMIN
      EBLXHI(JORDER) = CBXMAX
      CALL MXRPUT (EBLCB, CBCOFF, 10,32, JORDER)
      LEBLF(JORDER)  = LT

!     GO BACK TO TOP MENU
      GOTO 100


!     NORMAL EXIT

900   CONTINUE

!     ZERO PERMANENT ARRAYS SO NO UNDESIRED RESIDUALS ARE CARRIED OVER
      CALL MXZERO (BLCHEB, 10,32)
      CALL MXZERO (BLPOLY, 10,32)
      DO 901 I = 1,NECORD
         BLWCEN(I) = 0.
         BLFMAX(I) = 0.
         BLXMIN(I) = 0.
         BLXMAX(I) = 0.
         LBLF(I)   = LF
         BLK(I)    = 0.
         BLA(I)    = 0.
901      CONTINUE

      DO 910 I = 1,NECORD
!        COPY POLYNOMIAL FIT TO PERMANENT ARRAYS
         IF (LEBLF(I)) THEN
            BLWCEN(I) = EBLWC(I)
            BLFMAX(I) = EBLFM(I)
            BLXMIN(I) = EBLXLO(I)
            BLXMAX(I) = EBLXHI(I)
            CALL MXRGET (EBLCB,  CBCOFF, 10,32, I)
            CALL MXRPUT (BLCHEB, CBCOFF, 10,32, I)
            CALL CBTOPN (NORDER, CBCOFF,PNCOFF, CBXMIN,CBXMAX)
            CALL MXRPUT (BLPOLY, PNCOFF, 10,32, I)
            LBLF(I)   = LT
            BLK(I)    = BLWCEN(I) * MECORD(I)
         ENDIF
910   CONTINUE

!     AND QUIT THIS SUBROUTINE
      CALL GX_CLR
      CALL LINEFD (1)
      CALL MESSGE ('End of Echelle Blaze function definition')
      CALL IOFOOT
      RETURN


!     ABORT EXIT

999   CALL MESSGE ('BLDEFP: Abnormal termination')
      CALL MESSGE ('        Polynomial fit definition is not altered')
      END
