      SUBROUTINE CAFIT (CSTYLE,IORDER)

!+
!     PROGRAM:      CAFIT
!     PURPOSE:      
!=                  INTERPOLATE A FUNCTION ON EXISTING DATA ON A NEW GRID
!
!     NOTES:        
!                   A PREVIOUS CALL TO GRID IS EXPECTED TO SET UP GRID
!
!     HISTORY:
!     VERSION       MACHINE       DATE      AUTHOR/INSTITUTE
!     1.0           microVAX      28.10.87  C.S.JEFFERY / ST.ANDREWS
!
!     INPUT:        CSTYLE        METHOD OF INTERPOLATION
!                   IORDER        ORDER OF FIT/INTERP POLY (-1 TO IGNORE)
!-

      INCLUDE 'ctdeck.f'
      INCLUDE 'cadeck.f'
      INCLUDE 'gddeck.f'


!     LOCAL VARIABLES DEFINING THE INTERPOLATION GRID AND RESULTING FIT
      CHARACTER*(*) CSTYLE
      INTEGER       IORDER

!     LOCAL VARIABLES DEFINING TYPE OF FIT
      CHARACTER*10 STYLE
      INTEGER      IERR, NORDER

!     WORK ARRAYS REQUIRED BY PNLSQF
      REAL         AA(11), ERR(11), RMS, CH2

!     WORK ARRAYS REQUIRED BY L2FRES
      INTEGER      NW, MAX, NK
      PARAMETER   (NW=50, NQ=13*NC+6)
      REAL         WX(NW),WF(NW),WG(NW),WD(NW),WT(NW)
      REAL         WR(NC), WW(NC), WS(NQ)
!.


!     VERIFY THAT A GRID HAS BEEN DEFINED
      IF (NGX.LE.0) THEN
         CALL MESSGE ('CAFIT: grid not defined, task aborted')
         RETURN
      ENDIF

!     GET TYPE OF INTERPOLATION

!     AS SUBROUTINE ARGUMENT
      IF (CSTYLE.NE.'USER') THEN
         STYLE = CSTYLE
         CALL OUTSTR ('CAFIT: interpolation type ',STYLE)
!     AS COMMAND ARGUMENT
      ELSEIF (NARG.GE.1) THEN
         STYLE = ARG(1)
!     REQUEST FROM USER
      ELSE
1        CALL GETCHV ('CAFIT: interpolation type ',STYLE)
         IF (STYLE(1:4).EQ.'HELP') THEN
            CALL MESSGE ('        LIN    : Linear join the dots')
            CALL MESSGE ('        POL    : Polynomial join the dots')
            CALL MESSGE ('        FIT    : Least squares polynomial')
            CALL MESSGE ('        SPLINE : Cubic with knots (L2FRES)')
            CALL MESSGE ('        HERMITE: Hermite polynomials (INTEP)')
            GO TO 1
         ENDIF
      ENDIF

!     IDENTIFY THE ORDER FOR THE INTERPOLATING/FITTING POLYNOMIAL

      NORDER = 0
      IF (STYLE(1:3).EQ.'FIT'.OR.STYLE(1:3).EQ.'POL') THEN
!        FROM THE SUBROUTINE ARGUMENT
         IF (IORDER.GE.0) THEN
            NORDER = IORDER
!        FROM THE COMMAND ARGUMENT
         ELSEIF (NARG.GE.2) THEN
            NORDER = IFRMCH (ARG(2))
!        FROM THE USER
         ELSE
            CALL GETINT ('CAFIT: Order of polynomial',NORDER)
         ENDIF
      ENDIF

!     INTERPOLATE/FIT THE DATA

!     LINEAR INTERPOLATION
      IF (STYLE(1:3).EQ.'LIN') THEN
         DO 301 I = 1,NGX
            CALL TABINT (NCX, CX, CY, 1, GX(I), GY(I))
301         CONTINUE

!     POLYNOMIAL INTERPOLATION (DEGREE N)
      ELSEIF (STYLE(1:3).EQ.'POL') THEN
         DO 401 I = 1,NGX
            CALL TABINT (NCX, CX, CY, NORDER, GX(I), GY(I))
401         CONTINUE

!     LEAST SQUARES POLYNOMIAL (DEGREE N) INTERPOLATION
      ELSEIF (STYLE(1:3).EQ.'FIT') THEN

!        FIND THE ORDER AND DO THE FIT
         CALL PNLSQF (CX, CY, NCX, NORDER, AA, ERR, RMS, CH2)

!        NOW CONSTRUCT THE FITTED FUNCTION USING EXPANDED POLYNOMIAL
         DO 505 I = 1,NGX
            CALL PNEVAL (NORDER, AA, GX(I), GY(I))
505         CONTINUE

!     HERMITE POLYNOMIAL FITTING
      ELSEIF (STYLE(1:3).EQ.'HER') THEN
         CALL INTEP (GX(1), GY(1), CX, CY, NCX, IERR)
         DO 601 I = 2,NGX
            CALL EINTEP (GX(I), GY(I), CX, CY, NCX, IERR)
601         CONTINUE

!     LEAST SQUARES KNOTTED CUBIC SPLINE INTERPOLATION
      ELSEIF (STYLE(1:3).EQ.'SPL') THEN
         MAX = MIN ( NCX*0.66, FLOAT(NW) )
         CALL L2FRES (IERR, MAX, NK,WX,WF,WG,WD,WT,
     1        .TRUE.,NCX,CX,CY, WR, .FALSE.,WW, .TRUE.,NGX,GX,GY, WS)

!     NO MORE METHODS
      ELSE
         CALL MESSGE ('CAFIT: Interpolation style illegal')
         RETURN
      ENDIF

!     OVERWRITE THE WORK ARRAYS BACK INTO THE MAIN DATA ARRAYS
      DO 701 I = 1,NGX
         CX(I) = GX(I)
         CY(I) = GY(I)
701   CONTINUE
      NCX = NGX
      CALL MINMAX (CX,1,NCX,CXMIN,CXMAX)
      CALL MINMAX (CY,1,NCX,CYMIN,CYMAX)      

!     QUIT
      END
