      SUBROUTINE ECNORM

!+
!     PROGRAM:      ECNORM
!     PURPOSE:      
!=                  NORMALISE ECHELLE SPECTRUM
!                   USING CONTINUUM DEFINED BY ECRESP
!
!     HISTORY:
!     VERSION       MACHINE       DATE      AUTHOR/INSTITUTE
!     1.0           microVAX      15.01.88  C.S.JEFFERY / ST.ANDREWS
!-

      INCLUDE 'implct.f'
      INCLUDE 'ecdeck.f'


!     INTERPOLATION DATA
      REAL      WC(NEC)
      REAL      FM(NEC)
!.

!     VERIFY CONTINUUM HAS BEEN SUCCESSFULLY SPECIFIED
      IF (.NOT.LECRES) THEN
         CALL MESSGE ('ECNORM: * Error * Continuum undefined')
         RETURN
      ENDIF

!     NORMALISE THE ECHELLE SPECTRUM

!     LOOP THROUGH ORDERS
      DO 250 N = 1,NECORD

!        SAVE SOME INTERPOLATION CONSTANTS
                          K = N
         IF (N.EQ.1)      K = 2
         IF (N.EQ.NECORD) K = NECORD - 1

         WQ = ECWCEN(K-1)
         W0 = ECWCEN(K)
         WP = ECWCEN(K+1)
         FQ = ECFMAX(K-1)
         F0 = ECFMAX(K)
         FP = ECFMAX(K+1)
         D0 = WQ - WP
         DP = WP - W0
         DQ = W0 - WQ

!        LOOP THROUGH WAVELENGTHS
         DO 240 I = 1,NECWAV(N)

!           GET THE WAVELENGTH
            W = ECSLAM(N) + I * ECDLAM(N) - W0

!           FIND THE NORMALISATION CONSTANT (QUADRATIC INTERPOLATION)
            F = (   W   * (W-DP)) / (-DQ*D0) * FQ
     1        + ((W-DP) * (W+DQ)) / (-DP*DQ) * F0
     2        + ((W+DQ) *   W   ) / (-D0*DP) * FP

!           NORMALISE THE FLUX
            ECSTAK(I,N) = ECSTAK(I,N) / F

!           END WAVELENGTH LOOP
240         CONTINUE

!        END ORDER LOOP
250      CONTINUE

!     QUIT
      END
