      SUBROUTINE ECRESP

!+
!     PROGRAM:      ECRESP
!     PURPOSE:      
!=                  DEFINE THE DETECTOR RESPONSE / OBJECT CONTINUUM SHAPE
!                   FOR THE CURRENT ECHELLE SPECTRUM
!     REFERENCES:   
!
!     HISTORY:
!     VERSION       MACHINE       DATE      AUTHOR/INSTITUTE
!     1.0           microVAX      11.03.88  C.S.JEFFERY / ST.ANDREWS
!-

      INCLUDE 'implct.f'
      INCLUDE 'ecdeck.f'
      INCLUDE 'cadeck.f'
      INCLUDE 'spdeck.f'


!     CONTROL CODES
      CHARACTER*1   CCODE

!     ORDER TRACKING
      INTEGER       NORDER
      INTEGER       NORDLO
      INTEGER       NORDHI

!     ORDER CHARACTERISTICS
      REAL          SL
      REAL          DL
      INTEGER       NL

!     FLAG FOR PROCESSING ALL ORDERS
      LOGICAL       LALL

!     CONTINUUM DEFINITIONS
      REAL          WC
      REAL          FC

!     INTERPOLATION ARRAY
      REAL          WM(32)
      REAL          FM(32)

!     PLOT PARAMETERS (DO NOT USE IF DECK 'DISPGX' IS ACTIVATED)
      CHARACTER*3   CHC
      CHARACTER*79  HEADER, XLABEL, YLABEL
      REAL          DXMIN, DXMAX, DYMIN, DYMAX

!     WORK AREAS REQUIRED BY L2FRES
      INTEGER      NW
      PARAMETER   (NW=50)
      INTEGER      NQ
      PARAMETER   (NQ=13*NEC+6)
      INTEGER      MAXK
      INTEGER      NK
      REAL         WX(NW)
      REAL         WF(NW)
      REAL         WG(NW)
      REAL         WD(NW)
      REAL         WT(NW)
      REAL         WS(NQ)
!     RESIDUALS OF SPLINE
      REAL         WR(NEC)
!     WEIGHTS FOR DATA
      REAL         WW(NEC)

!    VARIABLES FOR PARABOLA FITTING
      REAL         PX(1024)
      REAL         PY(1024)
      REAL         AA
      REAL         EA
      REAL         BB
      REAL         EB
      REAL         CC
      REAL         EC
      REAL         WSTART
      REAL         WEND
      REAL         EW
      REAL         EF
      INTEGER      I1
      INTEGER      I2
      INTEGER      IS

!     EXTERNAL FUNCTIONS USED
      CHARACTER*20  CHFRMI
!.


!     VERIFY GRAPHICS DEVICE IS SET UP

      CALL GX_OK (IOK)
      IF (IOK.EQ.0) THEN
         CALL MESSGE ('ECRESP: * Error * No graphics device')
         RETURN
      ENDIF

!     SET UP START VALUES REQUIRED BY THIS ROUTINE ONLY

!     SET UP THE ORDER MAPPING
      NORDLO = MIN(MECORD(1),MECORD(NECORD))
      NORDHI = MAX(MECORD(1),MECORD(NECORD))
      NORDER = NORDLO
!     SWITCH AUTO PROCESSING OF ALL ORDERS TO .FALSE.
      LALL   = LF
      LECRES = LF

!     WARN USER ABOUT LIVE KEY-BOARD
      CALL IOHEAD ('Echelle spectrum continuum definition')
      CALL KEYWRN
      CALL IOFOOT


!     SELECT ORDER FOR FIT

100   CALL MESSGE (' <')
      CALL KEYCHK (CCODE,'=.+-*ADEHQX')

!     HELP
      IF (CCODE.EQ.'H') THEN
         CALL MESSGE (' Select echelle order for continuum definition')
         CALL MESSGE ('   =      Specify order by number')
         CALL MESSGE ('   +      Next order')
         CALL MESSGE ('   -      Back to previous order')
         CALL MESSGE ('   .      Repeat current order')
         CALL MESSGE ('   *      Process all orders sequentially')
         CALL MESSGE ('   A      Process all orders automatically')
         CALL MESSGE ('   D      Delete data for specified order')
         CALL MESSGE ('   X      Display continuum data')
         CALL MESSGE ('   E      Exit')
         CALL MESSGE ('   Q      Quit')
         CALL MESSGE ('   H      Help')

!     EXIT
      ELSEIF (CCODE.EQ.'E') THEN
         GOTO 900

!     ABORT
      ELSEIF (CCODE.EQ.'Q') THEN
         GOTO 999

!     SPECIFY ORDER BY NUMBER
      ELSEIF (CCODE.EQ.'=') THEN
         CALL GETINT ('Specify order number', NORDER)
         GOTO 200

!     PROCEED TO NEXT ORDER
      ELSEIF (CCODE.EQ.'+') THEN
         NORDER = NORDER + 1
         NORDER = MAX (NORDLO,NORDER)
         GOTO 200

!     REPEAT CURRENT ORDER
      ELSEIF (CCODE.EQ.'.') THEN
         GOTO 200

!     GO BACK TO PREVIOUS ORDER
      ELSEIF (CCODE.EQ.'-') THEN
         NORDER = NORDER - 1
         NORDER = MIN (NORDER,NORDHI)
         GOTO 200

!     PROCESS ALL ORDERS
      ELSEIF (CCODE.EQ.'*') THEN
         NORDER = NORDLO
         LALL   = LT
         GOTO 200

!     PROCESS ALL ORDERS AUTOMATICALLY
      ELSEIF (CCODE.EQ.'A') THEN
         GOTO 600

!     DELETE FIT FOR SPECIFIED ORDER
      ELSEIF (CCODE.EQ.'D') THEN
         GOTO 300

!     DISPLAY THE CURRENT CONTINUUM
      ELSEIF (CCODE.EQ.'X') THEN
         GOTO 400

!     NO MORE OPTIONS
      ENDIF
      GOTO 100



!     CHECK ORDER EXISTS BEFORE DOING ANYTHING SILLY

200   CONTINUE
      IF (NORDER.LT.NORDLO .OR. NORDER.GT.NORDHI) THEN
         CALL MESSGE ('* WARNING * nonexistent order')
         CALL OUTINT ('Limits for order number are', NORDLO)
         CALL OUTINT ('and',                         NORDHI)
         GOTO 100
      ENDIF

!     GET ORDER POINTER FROM ORDER NUMBER
      J = ECXORD (NORDER) 

!     COPY THE ORDER INTO THE SPECTRUM ARRAYS
      SL   = ECSLAM(J)
      DL   = ECDLAM(J)
      NL   = NECWAV(J)
      DO 215 I = 1,NL
         SPW(I) = SL + I * DL
         SPF(I) = ECSTAK(I,J)
215      CONTINUE
      NSPW = NL
      SPHEAD(1) = ECHEAD(1:10) // ' : Order ' // CHFRMI (NORDER, 3)

!     GET ARRAY LIMITS
      SPWMIN = SPW(1)
      SPWMAX = SPW(NSPW)
!        FLUX LIMITS DERIVED AVOIDING END OF ORDER EFFECTS
      I1 = NSPW * 0.4
      I2 = NSPW * 0.6
      SS = 0.
      DO 217 I = I1,I2
217      SS = SS + SPF(I)
      SPFMAX = SS / (I2-I1+1)

!     NOW CALCULATE SOME DISPLAY PARAMETERS

!     THE X-RANGE
      XLABEL = 'Wavelength (A)'
      DXMIN  = SL +      DL
      DXMAX  = SL + NL * DL
      XRANGE = DXMAX - DXMIN

!     THE Y-RANGE
      YLABEL = 'Flux (counts)'
      DYMIN  = 0.0
      DYMAX  = 1.5 * SPFMAX
      YRANGE = DYMAX - DYMIN

!     THE HEADER
      CHC = CHFRMI (NORDER,3)
      HEADER = ECHEAD (1:10) // ' : Order ' // CHC

!     PLOT THE FRAME
      CALL GX_CLR
      CALL GX_RSPC ( 0.2,   0.1,   0.8,   0.9 )
      CALL GX_QSPC (DXMIN, DYMIN, DXMAX, DYMAX)
      CALL GX_AXES (HEADER, XLABEL, YLABEL)

!     PLOT THE CURRENT ORDER
      CALL GX_QPLT (NSPW, SPW, SPF)

!     I THINK WE'VE PLOTTED EVERYTHING
      CALL GX_FLSH

!     NOW DEFINE THE CONTINUUM HEIGHT AT THE ORDER CENTRE
      CALL GX_QCUR (WC,FC)

!     MARK POSITION
      CALL GX_QMOV (WC-20.,FC)
      CALL GX_QDRW (WC+20.,FC)
      CALL GX_QMOV (WC,FC*0.8)
      CALL GX_QDRW (WC,FC)
      CALL GX_FLSH

!     VERIFY
220   CALL KEYCHK (CCODE,' DHR')

!     WHAT WAS THAT?
      IF (CCODE.EQ.'H') THEN
         CALL MESSGE ('         Accept (= space) ')
         CALL MESSGE ('   D     Delete order fit ')
         CALL MESSGE ('   R     Repeat continuum definition')
         CALL MESSGE ('   H     Help')
         GOTO 220

!     REPEAT POSITION
      ELSEIF (CCODE.EQ.'R') THEN
         GOTO 200

!     REJECT ORDER
      ELSEIF (CCODE.EQ.'D') THEN
         ECWCEN(J) = WC
         ECFMAX(J) = -1.

!     ACCEPT MEASUREMENT
      ELSEIF (CCODE.EQ.' ') THEN
         ECWCEN(J) = WC
         ECFMAX(J) = FC
      ENDIF

!     AND GET THE NEXT COMMAND
      IF (LALL .AND. NORDER.NE.NORDHI) THEN
         NORDER = NORDER + 1
         GOTO 200
      ENDIF
      IF (LALL) LECRES = LT
      LALL = LF
      GOTO 100



!     DELETE SPECIFIED ORDER

!     WHICH ORDER ?
300   CALL GETINT ('Specify order to be deleted', NORDER)

!     VERIFY ORDER EXISTS
      IF (NORDER.LT.NORDLO .OR. NORDER.GT.NORDHI) THEN
         CALL MESSGE ('* WARNING * nonexistent order')
         CALL OUTINT ('Limits for order number are', NORDLO)
         CALL OUTINT ('and',                         NORDHI)
         GOTO 100
      ENDIF

!     IDENTIFY AND DELETE
      J = ECXORD (NORDER)
      IF (J.EQ.1) THEN
         ECWCEN(J) =  2 * ECWCEN(2) - ECWCEN(3)
      ELSEIF (J.EQ.NECORD) THEN
         ECWCEN(J) =  2 * ECWCEN(J-1) - ECWCEN(J-2)
      ELSE
         ECWCEN(J) = (ECWCEN(J-1) + ECWCEN(J+1)) / 2.
      ENDIF
      ECFMAX(J) = -1.

!     THAT SHOULD DO
      LECRES = LF
      GOTO 100



!     DISPLAY THE CURRENT CONTINUUM

!     IDENTIFY THE RANGES
400   CONTINUE
      CALL MINMAX (ECWCEN,1,NECORD, DXMIN,DXMAX)
      CALL MINMAX (ECFMAX,1,NECORD, DYMIN,DYMAX)
      DXMIN = DXMIN - 10.
      DXMAX = DXMAX + 10.
      DYMIN = 0.
      DYMAX = 1.1 * DYMAX

!     PLOT THE AXES
      HEADER = ' Echelle continuum shape '
      XLABEL = ' Central wavelengths '
      YLABEL = ' Flux maxima '
      CALL GX_CLR
      CALL GX_RSPC (  0.1,   0.2,   0.9,   0.8  )
      CALL GX_QSPC ( DXMIN, DYMIN, DXMAX, DYMAX )
      CALL GX_AXES ( HEADER, XLABEL, YLABEL )

!     PLOT THE CONTINUUM AS A SERIES OF CROSSES
      CALL GSPMI  ( 2 )
      CALL GX_QMRK ( NECORD, ECWCEN, ECFMAX )

!     THAT'S IT, SELECT OPTION
      CALL GX_FLSH
410   CALL MESSGE (' <-')
      CALL KEYCHK (CCODE,' DHS')

!     EXPLAIN OPTIONS
      IF (CCODE.EQ.'H') THEN
         CALL MESSGE ('         Continue (=space)')
         CALL MESSGE ('   D     Mark order for deletion')
         CALL MESSGE ('   S     Smooth over all orders')
         CALL MESSGE ('   H     Help')

!     DELETE MARKED ORDER
      ELSEIF (CCODE.EQ.'D') THEN

!        DEFINE AND MARK WAVELENGTH
         CALL GX_QCUR (WC,FC)
         CALL GX_QMOV (WC,FC)
         CALL GX_PSYM (4,0.05,0.125)
         CALL GX_FLSH

!        IDENTIFY ORDER TO BE DELETED
         DN = ABS (ECSLAM(1)-ECSLAM(NECORD)) / FLOAT (NECORD-1)
         DO 420 N = 1,NECORD
            IF ( ABS (WC-ECWCEN(N)) .LT. DN/3. ) THEN
               ECFMAX(N) = -1.
               GOTO 421
            ENDIF
420         CONTINUE

!        GOTO NEXT OPTION
421      GOTO 410

!     SMOOTHING
      ELSEIF (CCODE.EQ.'S') THEN
         GOTO 500

!     OTHERWISE RETURN TO TOP LEVEL
      ENDIF
      GOTO 100



!     SMOOTH OVER ALL ORDERS

!     COPY VALID DATA TO INTERPOLATION/SMOOTHING ARRAY
500   CONTINUE
      I = 0
      DO 510 N = 1,NECORD
         IF (ECFMAX(N).GT.0.) THEN
            I = I + 1
            WM(I) = ECWCEN(N)
            FM(I) = ECFMAX(N)
         ENDIF
510      CONTINUE

!     RECONSTRUCT WCEN FOR MISSING ORDERS
      DO 520 N = 1,NECORD
         IF (ECFMAX(N).LE.0.) THEN
            IF (ECFMAX(N-1)*ECFMAX(N+1).GT.0.) THEN
               ECWCEN(N) = (ECWCEN(N-1) + ECWCEN(N+1)) / 2.
            ELSE
               ECWCEN(N) = ECSLAM(N) + NECWAV(N) * ECDLAM(N) / 2.
            ENDIF
         ENDIF
520      CONTINUE

!     USE CUBIC SPLINE INTERPOLATION WITH KNOTS
      MAXK = FLOAT(I) * 0.667
      CALL L2FRES (IERR, MAXK, NK,WX,WF,WG,WD,WT,
     1             LT,I,WM,FM, WR, LF,WW, LT,NECORD,ECWCEN,ECFMAX, WS)

!     DISPLAY THE FIT ON THE CURRENT PLOT
      CALL GX_QPLT ( NECORD, ECWCEN, ECFMAX )
      CALL GX_FLSH

!     THAT'S IT
      LECRES = LT
      GOTO 100



!     DEFINE WCEN, FMAX FOR ALL ORDERS AUTOMATICALLY

600   CONTINUE

!     LOOP THROUGH ORDERS
      DO 650 N = 1,NECORD

!        COPY CENTRAL THIRD OF ORDER TO WORK ARRAYS
         J  = 0
         I1 = NECWAV(N) * 0.4
         I2 = NECWAV(N) * 0.6
         WSTART = ECSLAM(N) + I1 * ECDLAM(N)
         WEND   = ECSLAM(N) + I2 * ECDLAM(N)
         DO 610 I = I1,I2
            J = J + 1
            PX(J) = I * ECDLAM(N)
            PY(J) = ECSTAK(I,N)
610         CONTINUE

!        FIND APPROXIMATE CENTRE BY FITTING PARABOLA
         CALL PRBOLA (PX,PY,J, AA,EA,BB,EB,CC,EC, WC,EW,FC,EF, IS)
         WC = WC + ECSLAM(N)

!        SAVE RESULTS
         ECWCEN(N) = WC
         ECFMAX(N) = FC

!        WARN ABOUT FAILURE TO FIND MAXIMUM
         IF (IS.EQ.1 .OR. WC.LE.WSTART .OR. WC.GE.WEND) THEN
            CALL OUTINT ('Bad fit for order',MECORD(N))
            ECWCEN(N) = ECSLAM(N) + NECWAV(N) * ECDLAM(N) / 2.
            ECFMAX(N) = -1.
         ENDIF

!        END OF LOOP AND END OF SECTION
650      CONTINUE
      GOTO 100


!     NORMAL EXIT
900   CONTINUE

!     AND QUIT THIS SUBROUTINE
      CALL GX_CLR
      CALL LINEFD (1)
      CALL MESSGE ('End of continuum definition')
      CALL IOFOOT
      RETURN


!     ABORT EXIT

999   CALL MESSGE ('ECRESP: Abnormal termination')
      LECRES = LF
      END
