      SUBROUTINE GRID (CGRID, AGXINT, AGXMIN, AGXMAX)

!+
!     PROGRAM:      GRID
!     PURPOSE:      
!=                  DEFINE A GRID FOR CREATING A NEW DATA SET
!     REFERENCES:   
!
!     HISTORY:
!     VERSION       MACHINE       DATE      AUTHOR/INSTITUTE
!     1.0           microVAX      28.10.87  C.S.JEFFERY / ST.ANDREWS
!
!     INPUT:        AGXINT        GRID INTERVAL
!                   AGXMIN        GRID START VALUE
!                   AGXMAX        GRID END VALUE
!                   CGRID         DEFAULT GRID
!-

      INCLUDE 'ctdeck.f'
      INCLUDE 'cadeck.f'
      INCLUDE 'gddeck.f'


!     LOCAL VARIABLES DEFINING THE INTERPOLATION GRID AND RESULTING FIT
      CHARACTER*(*) CGRID
      REAL          AGXINT, AGXMIN, AGXMAX
!.


!     GET THE PARAMETERS FOR THE NEW GRID

!     FROM THE SUBROUTINE ARGUMENTS
      IF (CGRID.EQ.'LIMITS') THEN
         GXINT = AGXINT
         GXMIN = AGXMIN
         GXMAX = AGXMAX
!     FROM THE DATA IN THE CURRENT ARRAYS (EQUAL SPACING REGRID)
      ELSEIF (CGRID.NE.'USER') THEN
         IF (NCX.EQ.0) THEN
            CALL MESSGE ('GRID: * Error * No data in current arrays')
            RETURN
         ELSE
            CALL MINMAX (CX,1,NCX,CXMIN,CXMAX)
            GXMIN = CXMIN
            GXMAX = CXMAX
            GXINT = (GXMAX-GXMIN) / NCX
         ENDIF

!     BY THE COMMAND ARGUMENT / FROM THE TERMINAL
      ELSEIF (NARG.GE.3) THEN
         GXINT = RFRMCH (ARG(1))
         GXMIN = RFRMCH (ARG(2))
         GXMAX = RFRMCH (ARG(3))
      ELSEIF (NARG.EQ.2) THEN
         GXINT = RFRMCH (ARG(1))
         GXMIN = RFRMCH (ARG(2))
         CALL GETFPV ('GRID: Maximum X-value for grid',GXMAX)
      ELSEIF (NARG.EQ.1) THEN
         GXINT = RFRMCH (ARG(1))
         CALL GETFPV ('GRID: Minimum X-value for grid',GXMIN)
         CALL GETFPV ('GRID: Maximum X-value for grid',GXMAX)
      ELSE
         CALL GETFPV ('GRID: Interpolation interval',GXINT)
         CALL GETFPV ('GRID: Minimum X-value',GXMIN)
         CALL GETFPV ('GRID: Maximum X-value',GXMAX)
      ENDIF

!     SNEAKY BIT FOR ADJUSTING GRID TO SENSIBLE SCALE (WE HOPE)

      GGMIN = GXMIN
      GGMAX = GXMAX

      GXMIN = INT (GGMIN)
      NIFRQ = INT (1.0/GXINT)
      DO 201 I=0,NIFRQ,1
         XI = GXMIN + I*GXINT
         IF (XI.GE.GGMIN) THEN
            GXMIN = XI
            GO TO 202
         ENDIF
201      CONTINUE
      GXMIN = GGMIN
202   CONTINUE
      NIMAX = INT ((GGMAX-GGMIN)/GXINT + 1.)
      DO 206 I=1,NIMAX,1
         XI = GXMIN + (I-1)*GXINT
         IF (XI.GE.GGMAX) THEN
            GXMAX = XI
            NGX = I
            GO TO 207
         ENDIF
206      CONTINUE
      NGX = NIMAX
      GXMAX = GXMIN + (NGX-1.0) * GXINT
207   CONTINUE

!          ............................................
!          .     OUTPUT FROM THIS SECTION:            .
!          .     -------------------------            .
!          .     GXINT : INTERPOLATION INTERVAL       .
!          .     GXMIN : MINIMUM VALUE ON GRID        .
!          .     GXMAX : MAXIMUM VALUE ON GRID        .
!          .     NGX   : NUMBER OF POINTS ON GRID     .
!          ............................................

!     COMPLETE THE X-VALUE ENTRIES
      DO 310 I = 1,NGX
310      GX(I) = GXMIN + (I-1.0) * GXINT

!     QUIT
      END
