
      SUBROUTINE LPCONV

!+
!     PROGRAM:       LPCONV
!     PURPOSE:       
!=                   CONVOLVE LINE PROFILE WITH GAUSSIAN (INSTRUMENTAL PROFILE)
!
!     PACKAGE:       PART OF THE FORTRAN VERSION OF "PROFILE"
!     AUTHOR:        C.S.JEFFERY
!     DATE:          15 APR 1987
!     LANGUAGE:      FORTRAN 77
!     VERSION:       I
!     MACHINE:       MICROVAX
!-

      INCLUDE 'ctdeck.f'
      INCLUDE 'lpdeck.f'
!     DUMMY ARRAY FOR STORING CONVOLUTION INTEGRALS
      REAL*4  BLPF(NLP)

!     WEIGHTS FOR GAUSSIAN SMOOTHING FUNCTION
!     SIGMA  = FWHM / 2.3548
!     SIGMA2 = SIGMA ** 2
      WTGAUS (X,SIGMA2) = EXP (-0.5 * X*X / SIGMA2 )


!     GET THE WIDTH (FWHM) OF THE GAUSSIAN
      IF (NARG.EQ.1) THEN
         FWHM = RFRMCH (ARG(1))
      ELSE
         CALL GETFPV ('LPCONV: FWHM of Gaussian :',FWHM)
      ENDIF

!     GET SOME CONSTANTS
      SIGMA  = FWHM / 2.3548
      SIGMA2 = SIGMA * SIGMA

!     LOOP OVER WAVELENGTH POINTS IN THE LINE PROFILE
      DO 500 I = 1,NLPW

!     COMPUTE THE CONVOLUTION INTEGRAL FOR EACH WAVELENGTH POINT
!        (EXECUTED AS A (3-POINT) SUMMATION OVER THE GIVEN LINE PROFILE)
!        (-->> EXTEND INTEGRATION RANGE BY INCLUDING CONTINUUM BEYOND WINGS)
         BLPF(I) = 0.
         BNORM   = 0.
         DO 200 J = 2,NLPW-1
            BW1 = LPW(I) - LPW(J-1)
            BW2 = LPW(I) - LPW( J )
            BW3 = LPW(I) - LPW(J+1)
            WT1 = WTGAUS (BW1,SIGMA2)
            WT2 = WTGAUS (BW2,SIGMA2)
            WT3 = WTGAUS (BW3,SIGMA2)
            BF1 = LPF(J-1) * WT1
            BF2 = LPF( J ) * WT2
            BF3 = LPF(J+1) * WT3
            BQD = 0.25 * ((BF1+BF2) * (BW1-BW2) + (BF2+BF3) * (BW2-BW3))
            BWT = 0.25 * ((WT1+WT2) * (BW1-BW2) + (WT2+WT3) * (BW2-BW3))
            BLPF(I) = BLPF(I) + BQD
            BNORM   = BNORM   + BWT
200      CONTINUE
         BLPF(I) = BLPF(I) / BNORM

500   CONTINUE

!     WRITE THE BROADENED LINE PROFILE BACK OVER THE CURRENT PROFILE
      DO 600 I = 1,NLPW
         LPF(I) = BLPF(I)
600   CONTINUE

!     QUIT
      END
