      SUBROUTINE SP2ECH

!+
!     PROGRAM:      SP2ECH
!     PURPOSE:      
!=                  READ ECHELLE SPECTRUM INTO STACK, ORDER BY ORDER
!                   THE ORDERS ARE ASSUMED TO BE IN INDIVIDUAL FILES
!                   OF SPECTRUM FORMAT 0. THEN WRITE AS ONE UNIT.
!
!     HISTORY:
!     VERSION       MACHINE       DATE      AUTHOR/INSTITUTE
!     1.0           microVAX      12.01.88  C.S.JEFFERY / ST.ANDREWS
!-

      INCLUDE 'implct.f'
      INCLUDE 'ecdeck.f'
      INCLUDE 'spdeck.f'

      CHARACTER*10  SPDIR, SPROOT, SPORD, SPLOW, SPHIGH, SPTYPE
      CHARACTER*40  SPFILE
      INTEGER       NORDLO, NORDHI, NDIFF, DN
      INTEGER       LD, LR, LO, LX

      CHARACTER*10  STTYPE
      CHARACTER*40  STFILE

!     EXTERNAL FUNCTIONS
      INTEGER       IFRMCH, LENSTR
      CHARACTER*20  CHFRMI
!.

!     DETERMINE THE STRUCTURE OF THE ORDER FILE NAMES
      CALL LINEFD (1)
      CALL GETCHV ('Directory containing SPECTRUM files', SPDIR)
      LD = LENSTR (SPDIR)
      CALL GETCHV ('Root of SPECTRUM filename',           SPROOT)
      LR = LENSTR (SPROOT)
      CALL GETCHV ('Number of first order (shortest wl)', SPLOW)
      CALL GETCHV ('Number of last order',                SPHIGH)
      LO = MAX (LENSTR (SPLOW), LENSTR (SPHIGH))
      CALL MESSGE ('File extension assumed to be .SP0')
      SPTYPE = '.SP0'
      LX = 4

!     DETERMINE THE NUMBER OF ORDERS
      NORDLO = IFRMCH (SPLOW)
      NORDHI = IFRMCH (SPHIGH)
      NDIFF  = NORDHI - NORDLO
      NECORD = ABS (NDIFF) + 1
      DN     = SIGN (1, NDIFF)
      DO 10 M = 1,NECORD
10       MECORD(M) = NORDLO + (M-1) * DN 

!     READ THE SPECTRUM FILES
      DO 100 M = 1,NECORD

!        CONSTRUCT THE SPECTRUM FILE NAME
         SPORD  = CHFRMI (MECORD(M), LO)
         SPFILE = SPDIR(1:LD)//SPROOT(1:LR)//SPORD(1:LO)//SPTYPE(1:LX)
         CALL OUTSTR ('SP2ECH: Reading spectrum file', SPFILE)

!        READ THE SPECTRUM FILR
         CALL SPRD (0,SPFILE,SPHEAD,NSPW,SPW,SPF)

!        IF THIS IS THE FIRST ORDER, ASSUME HEADER(1) IS COMMON TO ALL
         IF (M.EQ.1) ECHEAD = SPHEAD(1)

!        CALCULATE THE WAVELENGTH COEFFICIENTS
         DWL = (SPW(NSPW) - SPW(1)) / (FLOAT(NSPW)-1.0)
         WL0 = SPW(1) - DWL

!        STORE THE SPECTRUM IN THE APPROPRIATE STACK SLOT
         ECSLAM(M) = WL0
         ECDLAM(M) = DWL
         NECWAV(M) = NSPW
         DO 20 I = 1,NSPW
 20         ECSTAK(I,M) = SPF(I)

!        GO TO NEXT ORDER
 100     CONTINUE

!     NOW SUGGEST THE STACK FILE NAME

      STTYPE = '.ECH'
      LX = 4
      SPORD = '0000000000'
      STFILE = SPDIR(1:LD)//SPROOT(1:LR)//SPORD(1:LO)//STTYPE(1:LX)
      CALL OUTSTR ('SP2ECH: Suggested filename', STFILE)

!     AND WRITE THE STACK CONTENTS TO IT

      CALL ECWRIT (STFILE)

!     AND THAT'S IT

 99   END
