FUNCTION OPHEL(TEMP,PE,RLAMB)

  !+
  !=      Continuous opacity due to helium line wings
  !       No stimulated emission
  !
  !       Not sure why we would ever use this if we are using tabulated HeI profiles
  !-

  !       Double precision version
  IMPLICIT REAL*8 (A-H,O-Z)

  !  Function Type
  REAL ::  OPHEL

  !  Input Arguments:
  REAL, INTENT(IN) :: TEMP  ! Temperature (K)
  REAL, INTENT(IN) :: PE    ! Electron pressure (cgs)
  REAL, INTENT(IN) :: RLAMB ! Wavelength (A)


  DIMENSION R(10),W(10),C(10),F(10),E(10)

  DATA R /4387.,4143.,4009.,3926.,3871.,4026.,3819.,3705.,3634.,3587./
  DATA W /.456,.99,1.82,3.24,5.32,.326,.665,1.22,2.38,3.9/
  DATA C /.177,.33,.53,.81,1.17,.139,.254,.427,.646,.925/
  DATA F /.129,.063,.036,.022,.012,.432,.216,.126,.081,.058/
  DATA E /5*21.13,5*20.87/

  !.

  CONST=8.84E-21*RLAMB*RLAMB
  ELNUM=7.246*PE/TEMP
  OPHEL=.0

  ! Profile for HeI 4471
  IF(ABS(RLAMB-4471.)>20.) THEN
     DO II=1,10
        I = II
        DLAN=ABS(RLAMB-R(I))
        IF(DLAN<=20.) THEN
           IF(DLAN>4.) &
                OPHEL=OPHEL+CONST*F(I)*(.318*W(I)*ELNUM/(DLAN*DLAN)+ &
                C(I)*ELNUM/(DLAN**2.5))*EXP(-E(I)*11607./TEMP)
        ENDIF
     ENDDO

  ! Other HeI profiles
  ELSE
     DLAN=RLAMB-4471.
     IF(ABS(DLAN)>4.) THEN
        X=.318*.114*ELNUM/(DLAN*DLAN)
        IF(DLAN<=0.) THEN
           X=X+.081*ELNUM/(((-DLAN)**.75)*((-DLAN+1.44)**1.75))
        ELSE
           X=X+.081*ELNUM/((DLAN**1.75)*((DLAN+1.44)**.75))
        ENDIF
        OPHEL=CONST*1.125*X*EXP(-E(6)*11607./TEMP)
     ENDIF
    
  ENDIF
END FUNCTION OPHEL
