FUNCTION OPHI(TEMP,PE,RLAMB)

  !+
  !
  !  Function:
  !    OPHI
  !
  !  Package:
  !    QUB : QUeens Belfast LTE continuous opacity subroutines 
  !
  !  Purpose:
  !=    Continuous opacity for neutral hydrogen
  !     No stimulated emission

  !  Authors:
  !     RLK : Bob Kurucz (Smithsonian) 
  !     PLD : Philip Dufton
  !     CSJ : Simon Jeffery
  !
  !  History
  !     ??-???-???? : RLK/PLD : Original from ATLAS6 and cludged
  !     27-FEB-2003 : CSJ : Identified error in location of Balmer edge
  !
  !-

  !  Double precision version
  IMPLICIT DOUBLE PRECISION (A-H,O-Z)

  !  Function Type
  REAL ::  OPHI

  !  Input Arguments:
  REAL, INTENT(IN) :: TEMP  ! Temperature (K)
  REAL, INTENT(IN) :: PE    ! Electron pressure (cgs)
  REAL, INTENT(IN) :: RLAMB ! Wavelength (A)


  !  Fit coefficients
  DIMENSION G(12),C(9),H(5)

  DATA C /.992,.0907,-25.24,1.105,-.792,.4536,1.1,-.329,.1152/
  DATA G /12*1./
  DATA H /1.25,1.22,1.2,1.18,1.17/

  DOUBLE PRECISION, PARAMETER :: Z1=2.
  !     DOUBLE PRECISION, PARAMETER :: RYDBERG = 10.594E-4 ! (RLK/PLD)
  DOUBLE PRECISION, PARAMETER :: RYDBERG = 10.973731568549E-4 ! (CSJ)

  !       Save variables for subsequent runs at the same wavelength 

  DATA RLAN/.0/
  SAVE RLAN, WAVE, IMIN, G

  !.

  IF (RLAMB /= RLAN) THEN
     WAVE=(1.0E-4)*RLAMB
     IMIN=INT(SQRT(RYDBERG*RLAMB))+1
     DO J=1,3
        J3=3*J-2
        G(J)=C(J3)+WAVE*(C(J3+1)+WAVE*C(J3+2))
     ENDDO
  ENDIF

  A=(1.5778E5)/TEMP
  THM1=TEMP/5040.0
  SUM=0.0
  RI=IMIN-1
  DO I=IMIN,12
     RI=RI+1.
     U=A/(RI*RI)
     SUM=SUM+EXP(U)/(RI*RI*RI)*G(I)
  ENDDO

  IF (RLAMB > 5999.0 .AND. TEMP < 25000.0) THEN 
     GF=1.084+0.0188*THM1+WAVE*(.00161+.02661*THM1-WAVE*(.0192+THM1* &
          (-.03889+THM1*(.02833+THM1*(-.728E-2+(.7304E-3)*THM1)))))
  ELSE
     IGF=INT(10.0/THM1)
     IF (IGF > 5) IGF=5
     IF (IGF == 0) IGF=1
     GF=H(IGF)
  ENDIF

  B=(2.0898E-14)*EXP(-A)*WAVE*WAVE*WAVE/Z1
  OPHI=B*(SUM+.5*(EXP(U)-1.+GF)/A)
  RLAN=RLAMB

END FUNCTION OPHI
