FUNCTION OPHL(TEMP,PE,RLAMB)

!+
!=       Continuous opacity due to hydrogen line wings
!-


!       Double precision version
  IMPLICIT REAL*8 (A-H,O-Z)

!  Function Type
  REAL ::  OPHL

!  Input Arguments:
  REAL, INTENT(IN) :: TEMP  ! Temperature (K)
  REAL, INTENT(IN) :: PE    ! Electron pressure (cgs)
  REAL, INTENT(IN) :: RLAMB ! Wavelength (A)

  DIMENSION W(14),S(14),F(14),R(3)

  DATA S(1:6) /.0075,.0097,.0166,.0217,.0329,.0412/
  DATA S(7:14)/.0577,.073,.094,.111,.143,.167,.208,.237/
  DATA W(1:6) /4340.5,4101.7,3970.1,3889.1,3835.4,3797.9/
  DATA W(7:14)/3770.6,3750.2,3734.4,3721.9,3712.,3703.9,3697.2,3691.6/
  DATA F(1:6) /.038,.022,.0114,.008,.005,.0039/
  DATA F(7:14)/.0027,.0021,.0016,.0013,.001,.00088,.0007,.00061/

  !.

  ELNUM=(7.246E15)*PE/TEMP
  CONST=(8.84E-21)*RLAMB*RLAMB*4.*EXP(-118279./TEMP)
  PERNUM=1.5*ELNUM
  FIELD=(1.25E-9)*(PERNUM**.667)

  ! Default return value 
  OPHL=0.

  ! lambda beyond series "limit"
  IF (W(14)-RLAMB > 2.) RETURN

  ! identify line by wavelength
  DO II=1,14
     I = II
     IF (W(I)-RLAMB <= 2.) EXIT
  ENDDO

  ! is this Hgamma?
  IF (I == 1) THEN
     RL=RLAMB-W(1)
     IF(RL > 2.) OPHL=CONST*F(1)*S(1)/RL*((FIELD/RL)**1.5)
     RETURN
  ENDIF

  ! no line opacity if within 5 Angstroms of the line centre
  R(1)=RLAMB-W(I)
  R(2)=W(I-1)-RLAMB

  IF (R(1) > 5. .AND. R(2) > 5.) THEN
     DO J=1,2
        J1=I+1-J
        OPHL=OPHL+CONST*F(J1)*S(J1)/R(J)*((FIELD/R(J))**1.5)
     ENDDO
     RETURN
  ENDIF

  IF(I <= 2) RETURN

  KT=I
  IF (R(1) <= 5.) KT=I+1
  R(1)=RLAMB-W(KT)
  R(3)=W(KT-2)-RLAMB
  OPHL=.0
  DO K=1,3,2
     K1=KT-K+1
     OPHL=OPHL+CONST*F(K1)*S(K1)/R(K)*((FIELD/R(K))**1.5)
  ENDDO
  RETURN

END FUNCTION OPHL
