      SUBROUTINE rtf_gauleg ( x1, x2, x, w, n )

!+
!  Program:
!     rtf_gauleg
!
!  Purpose:
!=    Arrays of length n containing abscissas and weights of the Gauss-Legendre n-point quadrature formula.
!
!  Purpose:
!     Given the lower and upper limits of integration x1 and x2
!     and given , this routine returns arrays x and w of length
!     n containing the abscissas and weights of the Gauss-Legendre
!     n-point quadrature formula.
!
!-

!  Global constants.
      USE TAPM_PAR

!  Global declarations.
      IMPLICIT NONE
      
!  Subroutine Arguments.
!    Import
      DOUBLE PRECISION x1          ! lower limit of integration
      DOUBLE PRECISION x2          ! upper limit of integration
      INTEGER          n           ! order of quadrature
!    Export      
      DOUBLE PRECISION x(1)        ! abscissae
      DOUBLE PRECISIOn w(1)        ! weights

!  Local constants.
      DOUBLE PRECISION eps         ! precision
      PARAMETER (eps = 3.D-14)

!  Local variables.
!    Scaled integrand
      INTEGER          m               ! number of values to be computed
      DOUBLE PRECISION xn              ! float(n)
      DOUBLE PRECISION xr              ! x range of integral
      DOUBLE PRECISION xm              ! x midpoint of integral 
      INTEGER          i, j            ! loop indices
      DOUBLE PRECISION p1, p2, p3, pp  ! Polynomial coefficients
      DOUBLE PRECISION z, z1           ! Legendre polynomials
!.

!  Initialization
      xn = float(n)
      m = (n+1) / 2
      xm = 0.5D0 * (x1+x2)
      xr = 0.5D0 * (x2-x1)

!  Loop over the desired roots
      DO i = 1,m
         z1 = 0.D0
!     Approximation to i'th root
         z = cos (tapm__pi*(i-0.25D0)/(xn+0.5D0))
         DO WHILE ( z-z1 .GT. eps )
            p1 = 1.D0
            p2 = 0.D0
!        Loop up recurrence relation to find Legendre polynomial p1 at z
            DO j = 1,n
               p3 = p2
               p2 = p1
               p1 = ((2.D0*j-1.D0)*z*p2-(j-1.D0)*p3)/float(j)
            ENDDO
!        Find pp, the derivative of p1.
             pp = xn * (z*p1-p2)/(z*z-1.d0)
             z1 = z
!        Newton's method top find z
             z  = z1 - p1/pp             
         ENDDO
         
!     Scale the roots and weights to the desired interval
!     and store the symmetric components         
         x(i)     = xm - xr * z
         x(n+1-i) = xm + xr * z
         w(i)     = 2.D0*xr/((1.D0-z*z)*pp*pp)
         w(n+1-i) = w(i)
      ENDDO
      
      END
