      SUBROUTINE rtf_xi ( t, f, n, tau, xi )
!+
!
!  Program.
!     rtf-xi
!
!  Purpose.
!=   1-dimensional 'XI' operator for evaluating the second moment integral.
!
!-

!  Global declaration
      IMPLICIT NONE

!  Subroutine Arguments
!    Import
      DOUBLE PRECISION t(*)                   ! t
      DOUBLE PRECISION f(*)                   ! f(t)
      INTEGER n                               ! dimension of f(t)
      DOUBLE PRECISION tau                    ! XI evaluation
!    Export
      DOUBLE PRECISION xi                     ! XI integral

!  Local Constants
      INTEGER    kd                           ! Quadrature dimensions
      PARAMETER (kd=100)

!  Local Variables
!     Depth quadrature
      DOUBLE PRECISION  s(kd)                 ! integrand
      INTEGER  d                              ! quadrature index
      DOUBLE PRECISION  smax                ! maximum value of integrand
      DOUBLE PRECISION  tmax                ! limit of integral

!  Functions Called
      DOUBLE PRECISION rtf_expi

!.

!  Integrand
!  detect largest value and store upper limit to abscissa.
      smax = 0.
      tmax = 0.
      DO d = 1,n
         s(d) = f(d) * rtf_expi(3,abs(t(d)-tau))
         IF ( s(d).GT.smax ) THEN
           smax = s(d)
           tmax = t(d+1)
         ELSEIF ( s(d).GT.smax/100. .AND. t(d).LT.tau*100. ) THEN
           tmax = t(d)
         ENDIF
      ENDDO

!  Integral
      call rtf_qgauss ( t, s, 0.D+0, tmax, 24, xi )

!  Result
      xi = 2 * xi

      END
