      SUBROUTINE ATHEI_BWB

!+
!=      Input subroutine for He I line profiles
!
!       Using data from Beauchamp, Wesemael & Bergeron, APJS, 108, 559-573, 1997 February.
!
!       Data lie on a fixed grid in temperature and density and
!       a fixed grid in wavelength for each line.
!
!       Wavelengths:  
!       3705.00  3733.00  3819.60  3867.50  3888.65  3964.73  4009.27
!       4023.97  4026.20  4120.80  4143.76  4168.97  4387.93  4437.55  
!       4471.50  4713.20  4921.93  5015.68  5047.74  5875.70  6678.15
!       Temperature grid (log/K) :  
!       4.000, 4.301, 4.602
!       Density Grid:  
!       14.000, 14.477, 15.000, 15.477, 16.000, 16.477, 17.000, 17.477, 17.778 
!-       

!  Global variables
      USE SPC_GLOBAL

!  Double precision version
      IMPLICIT REAL*8 (A-H,O-Z)

!  Local variables
      CHARACTER*1 HEADER
      CHARACTER*6 ATOM,LOWER,UPPER,LEVEL1,LEVEL2

!.

!       Open input stream

!       Default is to choose a subset of lines

      OPEN(UNIT=NHEIB,FILE='HEI_BEAUCHAMP',STATUS='OLD')


!  READ TABLES FROM NHEIB
!  **********************
!
!..READ HEADER

      READ(NHEIB,1100)


!..THE FOLLOWING DATA ARE READ
!
!       WAV       WAVELENGTH OF LINE IN ANGSTROMS
!       NW        NUMBER OF DISPLACEMENTS FROM LINE CENTRE
!
!       FOR I=1,NE
!         FOR L=1,NT
!           EDEN(I)   VALUE OF ELECTRON DENSITY IN CM-3
!           TEMP(L)   VALUES OF TEMPERATURE IN KELVIN
!           FOR K=1,NW
!             S(I,L,K)  VALUES OF S IN FREQUENCY UNITS
!
!        ALL VALUES ARE CONVERTED TO LOG UNITS





      DO NHE1=1,21

      NDHE1(NHE1) = 9
      NTHE1(NHE1) = 3

      READ(NHEIB,1101) WAVHE1
      READ(NHEIB,1102) NWW
      READ(NHEIB,1105) (WHE1(K,1,NHE1),K=1,NWW) 
      DO I=1,NDHE1(NHE1)
        NWHE1(I,NHE1) = NWW
        DO L=1,NTHE1(NHE1)
          READ(NHEIB,1103) ELHE1(I,NHE1),TEHE1(L,NHE1)
          READ(NHEIB,1104) (SHE1(K,L,I,NHE1),K=1,NWHE1(I,NHE1))
          ELHE1(I,NHE1) = LOG10(ELHE1(I,NHE1))
          TEHE1(L,NHE1) = LOG10(TEHE1(L,NHE1))
          DO K=1,NWHE1(I,NHE1)
            SHE1(K,L,I,NHE1) = LOG10(SHE1(K,L,I,NHE1))
          ENDDO
        ENDDO
        DO K=1,NWHE1(I,NHE1)
          WHE1(K,I,NHE1)   = WHE1(K,1,NHE1)
        ENDDO
      ENDDO


!       Debug Output


      IF (BUGAT) THEN
       WRITE(NDEBUG,900) 
     *                   WAVHE1
       WRITE(NDEBUG,901) NHE1
       WRITE(NDEBUG,902) NTHE1(NHE1),(TEHE1(K,NHE1),K=1,NTHE1(NHE1))
       WRITE(NDEBUG,903) NDHE1(NHE1),(ELHE1(K,NHE1),K=1,NDHE1(NHE1))

       NELBUG=NDHE1(NHE1)/2
       NTBUG=NTHE1(NHE1)/2
         WRITE(NDEBUG,905) TEHE1(NTBUG,NHE1),ELHE1(NELBUG,NHE1),
     *                 (SHE1(K,NTBUG,NELBUG,NHE1),K=1,NWHE1(1,NHE1))
      ENDIF


!     End of data

      ENDDO

      NHE1 = 21
      CLOSE(UNIT=NHEIB)
      RETURN



!     Formats


 1100 FORMAT(30(/))
 1101 FORMAT(16x,F10.0)
 1102 FORMAT(25x,I8)
 1105 FORMAT(9F8.2)
 1103 FORMAT(30X,E12.0,20X,F8.0)
 1104 FORMAT(6E12.0)


!     Debug
 

  900 FORMAT('*** ATHEI_B ***',1X,F10.2)
  901 FORMAT('*** ATHEI_B ***',2H W,I4,2X,6(1PG12.4)/(8X,6(1PG12.4)))
  902 FORMAT('*** ATHEI_B ***',2H T,I4,2X,6(1PG12.4)/(8X,6(1PG12.4)))
  903 FORMAT('*** ATHEI_B ***',2H E,I4,2X,6(1PG12.4)/(8X,6(1PG12.4)))
  905 FORMAT('*** ATHEI_B ***',4X,'T=',F7.3,10X,'NE=',F7.3/
     *       (10(1X,F7.3)))

      END
