      SUBROUTINE ATHEI_STARK

!+
!
!     ATHEI_STARK
!
!
!=      Input subroutine for He I line Stark broadening coefficients
!       Dimitrijevic M., Sahal Brechot S., 1990. A&AS 82, 519
!
!       Data lie on a variable grid in temperature and density 
!       The following data are read for each line....
!
!           WAVHES(KHES)         Wavelengths
!           GFHES(KHES)          Oscillator strengths
!           EXCHES(KHES)         Excitation potentials
!           NDHES(KHES)          Number of densities for each line
!           ELHES(KEL,KHES)      Electron densities for profiles
!           NTHES(KHES)          Number of temperatures = 6  
!           TEHES(KTE,KHES)      Temperatures for each line
!           EWIDHES(KTE,KEL,KHES) Electron damping width
!           EDELHES(KTE,KEL,KHES) Line shift
!
!       The data (EWDI and EDEL) are normalised to Ne=10^15 cm^-3,
!       while the density and temperature scales are converted to 
!       log_10 units in order to simplify interpolation.
!
!       Data quality for WAVHES, GFHES and EXCHES is not ideal - 
!       see other sources for these. Thereofre they are not stored.
!
!
!     Author: CSJ
!     Date:   April 2001
!
!-

!  Global variables
      USE SPC_GLOBAL

!  Implicit typing (denegrated).
      IMPLICIT REAL*8 (A-H,O-Z)

!.

!     open input stream

      OPEN(UNIT=NHEIS,FILE='HEI_STARK',STATUS='OLD')

!     skip header 
      READ(NHEIS,1100)

!     read data
      DO NHES=1,79
        READ(NHEIS,*)
        READ(NHEIS,1101) 
     :      WAVHES,GFHES,EXCHES,NDHES(NHES)
        NTHES(NHES) = 6
        DO I=1,NDHES(NHES)
          READ(NHEIS,1102) ELHES(I,NHES)
          DO L=1,NTHES(NHES)
            READ(NHEIS,1103) TEHES(L,NHES),
     :                       EWIDHES(L,I,NHES),EDELHES(L,I,KHES)
          ENDDO
        ENDDO
      ENDDO

!     end of data
      NHES = 79
      CLOSE(UNIT=NHEIS)

!     convert 2WE to WE and normalise to Ne=10^15 cm^-3
      DO NHES=1,79
       DO I=1,NDHES(NHES)
         TENX = 10.**(15.-ELHES(I,NHES))
         DO L=1,NTHES(NHES)
          EWIDHES(L,I,NHES) = EWIDHES(L,I,NHES)*TENX ! / 2.
          EDELHES(L,I,NHES) = EDELHES(L,I,NHES)*TENX
         ENDDO
       ENDDO
      ENDDO
      

!     Formats


 1100 FORMAT(15(/))
 1101 FORMAT(F9.0,E11.0,F8.0,I3,  A35,E9.0)
 1102 FORMAT(F9.0)
 1103 FORMAT(F9.0,6E11.0)


      END
