      SUBROUTINE COMPOS

!+
!        Purpose:
!        Calculate fractional abundances and  molecular weights.
!
!        Description:
!        Calculates fractional abundances and mean
!        molecular weight for a normal a helium/to hydrogen
!        ratio (i.e. nHe/nH << 1) and 'solar' abundances
!        for elements heavier than He
!
!        NOTE subroutine assumes that AHE is the
!        helium to hydrogen ratio (by number) on ENTRY
!        while on exit AHE will be the fractional number
!        of helium atoms
!-

!  Global variables
      USE SPC_GLOBAL

!  Double precision version
      IMPLICIT REAL*8 (A-H,O-Z)


!  Check for logarithmic value
      IF(AHE.GT.1.0) THEN
        AHE=1.0E-12*(10.0**AHE)
      ENDIF


!  AHE is assumed to be helium to hydrogen ratio
      FRACT=AHE


!     Calculate number of atoms per hydrogen atom
      DO I=1,KI
        IF (I.NE.IH .AND. I.NE.IHE)
     *                    FRACT=FRACT+1.0E-12*(10.0**COSMIC(I))
      ENDDO

!
!       ANORM  is 
!         Log10(1.E12*(Number of atoms per hydrogen atom)
!
!       Used in Main for all NMODES to normalise abundances 
!       so that they are per ATOM
!       i.e. number of  ELEMENT atoms per unit mass =
!            normalised abundance* Avagdro's number/AMU
!
!       Also used in output routines to transform back to scale [H]=12
!
      ANORM=12.0+LOG10(1.0+FRACT)


!      Calculate fractional abundances - only abundant elements included

      AH =1.0                        /(1.0+FRACT)
      AHE=AHE                        /(1.0+FRACT)
      AC =1.0E-12*(10.0**COSMIC(IC) )/(1.0+FRACT)
      AN =1.0E-12*(10.0**COSMIC(IN) )/(1.0+FRACT)
      AO =1.0E-12*(10.0**COSMIC(IO) )/(1.0+FRACT)
      ANE=1.0E-12*(10.0**COSMIC(INE))/(1.0+FRACT)
      AMG=1.0E-12*(10.0**COSMIC(IMG))/(1.0+FRACT)
      ASI=1.0E-12*(10.0**COSMIC(ISI))/(1.0+FRACT)
      AS =1.0E-12*(10.0**COSMIC(IS ))/(1.0+FRACT)
      ACA=1.0E-12*(10.0**COSMIC(ICA))/(1.0+FRACT)
      AFE=1.0E-12*(10.0**COSMIC(IFE))/(1.0+FRACT)


!       Calculate mean atomic weight

      AMU= AH
     *    +AHE*ATW(IHE)
     *    +AC *ATW(IC)
     *    +AN *ATW(IN)
     *    +AO *ATW(IO)
     *    +ANE*ATW(INE)
     *    +AMG*ATW(IMG)
     *    +ASI*ATW(ISI)
     *    +AS *ATW(IS)
     *    +ACA*ATW(ICA)
     *    +AFE*ATW(IFE)

      END
