      SUBROUTINE DP_ATHEI

!+
!=      Input subroutine for He I 
!
!       Fundamental line data are from NIST, including
!       wavelengths, gf values and lower level excitation potentials
!
!           NHE                  Number of helium lines.... 
!           WAVHE(KHES)          Wavelengths
!           GFHE(KHES)           Oscillator strengths
!           EXCHE(KHES)          Excitation potentials
!           DELHE(2,KHE)         Triplet line splitting 
!           EWIDHE(KHE)          Electron damping width for NE=10**15 cm-3
!           CORRHE(KHE)          Correction for ion broadening
!           RATHE(KHE)           Parameter for ion broadening fit
!           SNHE(KHE)            Parameter for ion broadening fit
!           ITABHE(3,KHE)        Pointers for broadening tables 
!
!       Line broadening data (Stark) are taken from 
!       Dimitrijevic M., Sahal Brechot S., 1990. A&AS 82, 519
!
!       Data lie on a variable grid in temperature and density 
!       The following data are read for each line....
!
!           WAVHES(KHES)         Wavelengths
!           GFHES(KHES)          Oscillator strengths
!           EXCHES(KHES)         Excitation potentials
!           NDHES(KHES)          Number of densities for each line
!           ELHES(KEL,KHES)      Electron densities for profiles
!         ( NTHES(KHES)          Number of temperatures = 6 )
!           TEHES(KTE,KHES)      Temperatures for each line
!           GAMHES(KTE,KEL,KHES) Electron damping width
!           CORHES(KTE,KEL,KHES) Correction for ion broadening
!           DELHES(KTE,KEL,KHES) Triplet line splitting
!
!       Tabulated line profiles are selected as required...
!-

!   Global constants
      USE TAPM_PAR
      USE TAPP_PAR

!   Global variables
      USE SPC_GLOBAL

!   Double precision version
      IMPLICIT REAL*8 (A-H,O-Z)

!  Local constants
      INTEGER, PARAMETER :: HHMM = TAPP__HB2PI / TAPP__ME  !! convert to cgs 

!.

! I.  Read the NIST data and miscellaneous Stark broadening coefficients

!     open input stream
      OPEN(UNIT=NHEIS,FILE='HEI_NIST',STATUS='OLD')
!     skip header 
      READ(NHEIS,'(3(/))')

!     read data
      DO N=1,KHE
 101     READ(NHEIS,*,ERR=101) WAVHE(N),GFHE(N),EXCHE(N),
     :      NQ,DELHE(1:2,N),ITABHE(1:3,N),
     :      EWIDHE(N),CORRHE(N),
     :      RATHE(N),SNHE(N),
     :      DEL_HE1F(N),WNQ
!        convert gf 
         GFHE(N) = 10.**GFHE(N)
!        compute gf for isolated forbidden component
         IF (WNQ.GT.1.E-10) 
     :      ALF_HE1F(N) = TAPM__4PI/3.*
     :                   (NQ*NQ*(NQ*NQ-4)/WNQ/WNQ*(HHMM))**0.75
         IF (WAVHE(N).LT.1.) EXIT
      ENDDO
 100  NHE = N - 1
      CLOSE(UNIT=NHEIS)


! II. Read Dimitrijevic data

      CALL ATHEI_STARK


! III. Tabulated profile data

      IF ( NHEDAT /= 2 ) THEN
        CALL ATHEI_BCS
      ELSE
        CALL ATHEI_BWB
      ENDIF


      END
