      SUBROUTINE DP_ATHEII

!+
!=      Input subroutine for He II line profiles
!
!
!       THIS IS INTENDED TO BE A SAMPLE PROGRAM FOR READING
!       STARK BROADENING TABLES GENERATED BY T.SCHOENING AND K.BUTLER,
!       MUNICH OBSERVATORY (TABLES HAVE THE SAME STRUCTURE AS THOSE
!       GENERATED BY PROGRAM GRIME)
!       TABLES ARE READ FROM TAPE1 AND ARE WRITTEN TO OUTPUT FOR
!       SPECIFIED TRANSITIONS
!-


!  Global variables
      USE SPC_GLOBAL

!  Double precision version
      IMPLICIT REAL*8 (A-H,O-Z)

!  Local variables
      CHARACTER*1 HEADER
      CHARACTER*6 ATOM,LOWER,UPPER,LEVEL1,LEVEL2

!.
!       Open input stream
!
!
!       Default is to choose a subset of lines
!
      OPEN(UNIT=NHEII,FILE='HEII_RED',STATUS='OLD')


!  READ TABLES FROM NHEII
!  **********************
!
!..READ HEADER

   20  READ(NHEII,'(1X,A1)') HEADER
       IF (HEADER.NE.' ') GOTO 20


!..THE FOLLOWING DATA ARE READ
!
!       ATOM      INDEX FOR ATOM
!       LEVEL1    INDEX FOR LOWER LEVEL
!       LEVEL2    INDEX FOR UPPER LEVEL
!       MFULL     = 0 ONLY RED WING IS TABULATED
!                 = 1 FULL PROFILE
!
!       WAVHE2    WAVELENGTH OF LINE IN ANGSTROMS
!       GFHE2     GF-VALUE
!       EXCHE2    Excitation energy
!
!       NW        NUMBER OF DISPLACEMENTS FROM LINE CENTRE
!        FOR K=1,NW -
!       WAVE(K)   DISPLACEMENTS FROM LINE CENTRE IN ANGSTROEM
!       NT        NUMBER OF TEMPERATURES
!        FOR L=1,NT -
!       TEMP(L)   VALUES OF LOG TEMPERATURE IN KELVIN
!       NE        NUMBER OF ELECTRON DENSITIES
!        FOR I=1,NE -
!       EDEN(I)   VALUES OF LOG ELECTRON DENSITY IN CM-3
!       SCALE     SCALING FACTOR
!        FOR I=1,NE, L=1,NT AND K=1,NW
!       S(I,L,K)  VALUES OF LOG S IN FREQUENCY UNITS


      NHE2=0
   30 NHE2=NHE2+1

      READ(NHEII,1000,END=100) ATOM,LEVEL1,LEVEL2,MHE2(NHE2),
     *                         WAVHE2(NHE2),GFHE2(NHE2),EXCHE2(NHE2)
      READ(NHEII,1001) NWHE2(NHE2),(WHE2(K,NHE2),K=1,NWHE2(NHE2))
      READ(NHEII,1001) NTHE2(NHE2),(THE2(L,NHE2),L=1,NTHE2(NHE2))
      READ(NHEII,1001) NDHE2(NHE2),(ELHE2(I,NHE2),I=1,NDHE2(NHE2))
      READ(NHEII,1002) SCHE2(NHE2)

      DO 40 I=1,NDHE2(NHE2)
       DO 35 L=1,NTHE2(NHE2)
        READ(NHEII,1003) (SHE2(K,I,L,NHE2),K=1,NWHE2(NHE2))
   35  CONTINUE
   40 CONTINUE


!       Debug Output

      IF (BUGAT) THEN
       WRITE(NDEBUG,900) ATOM,LEVEL1,LEVEL2,MHE2(NHE2),
     *                   WAVHE2(NHE2),GFHE2(NHE2),EXCHE2(NHE2)
       WRITE(NDEBUG,901) NWHE2(NHE2),(WHE2(K,NHE2),K=1,NWHE2(NHE2))
       WRITE(NDEBUG,902) NTHE2(NHE2),(THE2(K,NHE2),K=1,NTHE2(NHE2))
       WRITE(NDEBUG,903) NDHE2(NHE2),(ELHE2(K,NHE2),K=1,NDHE2(NHE2))
       WRITE(NDEBUG,904) SCHE2(NHE2)

       NELBUG=NDHE2(NHE2)/2
       NTBUG=NTHE2(NHE2)/2
         WRITE(NDEBUG,905) THE2(NTBUG,NHE2),ELHE2(NELBUG,NHE2),
     *                 (SHE2(K,NELBUG,NTBUG,NHE2),K=1,NWHE2(NHE2))
      ENDIF
      GOTO 30


!      End of Data

  100 NHE2=NHE2-1

      CLOSE(UNIT=NHEII)

      RETURN
 1000 FORMAT(/1X,3(A6,4X),I1,3F10.2)
 1001 FORMAT(2X,I4,2X,6(G12.4)/(8X,6(G12.4)))
 1002 FORMAT(6X,G12.4)
 1003 FORMAT(/10(1X,F7.3)/(10(1X,F7.3)))



!      Debug

  900 FORMAT('*** ATHEII ***',1X,3(A6,4X),I1,4X,2F10.2,2PE12.3)
  901 FORMAT('*** ATHEII ***',2H W,I4,2X,6(1PG12.4)/(8X,6(1PG12.4)))
  902 FORMAT('*** ATHEII ***',2H T,I4,2X,6(1PG12.4)/(8X,6(1PG12.4)))
  903 FORMAT('*** ATHEII ***',2H E,I4,2X,6(1PG12.4)/(8X,6(1PG12.4)))
  904 FORMAT('*** ATHEII ***',6H SCALE,1PG12.4,6H LOG 0)
  905 FORMAT('*** ATHEII ***',4X,'T=',F7.3,10X,'NE=',F7.3/
     *       (10(1X,F7.3)))

      END
