      SUBROUTINE DP_HGRID ( XMIN,XMAX, NLO, NUP )

!+    
!=    Sets up hydrogen line grid from XMIN and XMAX     
!-

!  Global variables
      USE SPC_GLOBAL
      USE SPC_VCSDATA      !! VCS tables

!     Double precision version
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)

      DOUBLE PRECISION :: XMIN  ! Wavelength range in which to set up wl grid
      DOUBLE PRECISION :: XMAX  !
      INTEGER :: NLO   ! Q.N of lower level in transition to include
      INTEGER :: NUP   ! Q.N of upper level in transition to include
!.

!     Announce program      
!     write (*,'(A,F8.2,2I3)') ' dp_hgrid: ',wh(nup-1,nlo), nlo, nup


!     If there is a hydrogen line in this wavelength range,
!     include its wavelength, gf-value, species no. and
!     ionization stage

      N = NLO
      I = NUP - 1
      IF(WH(I,N) >= XMIN .AND. WH(I,N) <= XMAX)THEN
        NELSY=NELSY+1
        WAVSY(NELSY)=WH(I,N)
        NSPSY(NELSY)=IH
        NIONSY(NELSY)=1
        GFSY(NELSY)=GH(N)*FH(I,N)
        EDAMSY(NELSY)=0.0
        RDAMSY(NELSY)=0.0
        EXCSY(NELSY)=0.0
      ELSE
        RETURN
      ENDIF


!     A possible 40 points on either side of line centre
!     With scale 0.01 and ratio 1.25 will cover +-300A
!     Sufficient for continuum definition     
      NPOINT=40
      WSCALE=0.01
      WRATIO=1.25

!     Set up negative wavelengths but NOT sorted in increasing
!     wavelength
      MCOUNT=1

      WORK(MCOUNT)=WAVSY(NELSY)
      WTEMP=WORK(MCOUNT)

      DO I=1,NPOINT
        WTEMP=WTEMP-WSCALE*(WRATIO**I)
        IF(WTEMP < XMIN) EXIT
        MCOUNT=MCOUNT+1
        WORK(MCOUNT)=WTEMP
      ENDDO

     
!     Set up positive wavelengths now sorted in increasing
!     wavelength     
      WTEMP=WAVSY(NELSY)  
      DO I=1,NPOINT
        WTEMP=WTEMP+WSCALE*(WRATIO**I)
        IF(WTEMP > XMAX) EXIT
        MCOUNT=MCOUNT+1
        WORK(MCOUNT)=WTEMP
      ENDDO


!     Define IWORK and MCOUNT
      IWORK(1)=MCOUNT
      
      IF(BUGAT) THEN
        WRITE(NDEBUG,900)IWORK(1),(WORK(I),I=1,IWORK(1))
      ENDIF


!     Format statements    
 900  FORMAT(' *** NO. POINTS IN HGRID = ',I5//
     1     ' *** GRID *** '//7(0PF10.3))

      END
