
      FUNCTION ELPE(PG,TEMP,Y,PEG)
      
!+
!=     Calculate electron pressure
!         from gas pressure - PG
!         electron temperature - TEMP
!         fractional number of helium atoms - Y
!            i.e. Y= n(He)/(n(H)+n(He))
!
!      PEG is estimated electron pressure
!
!-
!      Double precision version

      IMPLICIT REAL*8 (A-H,O-Z)


!      Atomic data for hydrogen and helium

      DIMENSION PO(2,2),PA(3,2),PX(3,2),AX(2),F(2,2)
      DATA PO(1,1),PO(2,1),PO(1,2),PO(2,2)/13.595,1000000.,24.58,54.4/
     1,PA(1,1),PA(2,1),PA(3,1),PA(1,2),PA(2,2),PA(3,2)/2.,1.,1.,1.,
     22.,1./
!.

!      Check for positive initial estimate of electron pressure

      IF(PEG.GE.0.0) THEN
        ELPE=PEG
      ELSE

!      Assume hydrogen fully ionized

        ELPE=0.5*PG
      ENDIF


!      Fractional number of hydrogen and helium atoms

      AX(1)=1.-Y
      AX(2)=Y

      DO I=1,2
        DO J=1,2
          J1=J+1

!      Saha's equation

          F(J,I)=.666*(TEMP**2.5)*PA(J1,I)/PA(J,I)*
     *           EXP(-11607.*PO(J,I)/TEMP)
        ENDDO
      ENDDO

      
!      Twenty iterations

      DO K=1,20


!       Fractional populations of H and He

        SUM=.0
        DO L=1,2
          PX(1,L)=1./(1.+(F(1,L)/ELPE)*(1.+F(2,L)/ELPE))
          PX(2,L)=PX(1,L)*F(1,L)/ELPE
          PX(3,L)=PX(2,L)*F(2,L)/ELPE


!     Number of electrons per nucleus

          SUM=SUM+(PX(2,L)+2.*PX(3,L))*AX(L)
        ENDDO


!      New estimate of the electron pressure

        PE=PG/(1.+1./SUM)


!      Check for convergence

        IF(ABS((PE-ELPE)/ELPE).LT..001)GOTO 10
        ELPE=((ELPE*PE*PE)**.3333333)
      ENDDO


!      Not converged after 20 iterations

      WRITE(6,200)ELPE,PE
   10 RETURN


!      Format statements

  200 FORMAT(' ***** ELPE NOT CONVERGED ELPE=',1PE12.4,'   PE=',1PE12.4)
      END
