      SUBROUTINE HE2SEARCH(XMIN,XMAX)

!+
!=     Subroutine to search for ionized He lines
!      Also sets up wavelength scale for any lines found
!-

!  Global variables
      USE SPC_GLOBAL

!  Double precision version
      IMPLICIT REAL*8 (A-H,O-Z)

!  Wavelength grid
      REAL*8 GRD(KW)

!.


!      Identify lines

      ICOUNT=0
      DO I=1,NHE2
          IF(WAVHE2(I).GE.XMIN.AND.WAVHE2(I).LE.XMAX) THEN
           NELSY=NELSY+1
           WAVSY(NELSY)=WAVHE2(I)
           NSPSY(NELSY)=IHE
           NIONSY(NELSY)=2
           GFSY(NELSY)=GFHE2(I)
           EXCSY(NELSY)=EXCHE2(I)
           EDAMSY(NELSY)=0.0
           RDAMSY(NELSY)=0.0
           ICOUNT=ICOUNT+1
          ENDIF
      ENDDO


!      Return if no diffuse helium line found

      IF(ICOUNT.EQ.0) THEN
        RETURN
      ENDIF


!      Calculates line grid (fixed, but eventually could be variable)
!      Contains 61 points which with a scale of 0.01 and a ratio of
!      1.25 give a wavelength coverage of approximately +-40A    

      IGRD=61
      WSCALE=0.01
      WRATIO=1.25

      IGRD2=IGRD/2


!      Zero wavelength

      GRD(1)=0.0


!      Negative/Positive wavelengths

      WTEMP=0
      DO I=1,IGRD2
        WTEMP=WTEMP+WSCALE*(WRATIO**I)
        GRD(I+1)=     -WTEMP
        GRD(IGRD2+I+1)=WTEMP
      ENDDO


!      Put grids shifted to correct wavelengths in WORK array

      IWVHED=0
      DO I=1,ICOUNT
        RLAMB=WAVSY(NELSY-ICOUNT+I)
        CALL HETYPE

!        write (*,'(A,F8.2,4I4)') 'he2search:', 
!    :         rlamb, idhe2 

        DO J=1,IGRD
          HETEMP=RLAMB+GRD(J)

          IF(HETEMP.GT.XMIN.AND.HETEMP.LT.XMAX) THEN
            IWVHED=IWVHED+1
            WORK(IWVHED)=HETEMP
          ENDIF

        ENDDO
      ENDDO

      IWORK(1)=IWVHED


!      Debug output

      IF(BUGAT) THEN
        WRITE(NDEBUG,900)IWORK(1),(WORK(I),I=1,IWORK(1))
      ENDIF

      RETURN


!      Format statements

900   FORMAT ( ' *** NO. POINTS IN HESEARCH= ',I5//
     1         ' *** GRID ***'//(0P,7F10.3))
      END 
