      SUBROUTINE HEI_EWID (IHES, TELOG, ELLOG, EWID, EDEL, MODE)

!+
!  HEI_EWID
!
!= Identify an appropriate electron damping width and shift
!  from Dimitrijevic & Sahal Brechot tables
!
!  Mode = 0 : use nearest point to T and Ne in table 
!  Mode = 1 : use linear interpolation in log T and log Ne
!  Mode = 2 : use linear interpolation in log T and log Ne
!
!
!  Author: CSJ
!  Date:   24 May 2001
!
!-

!  Global variables
      USE SPC_GLOBAL

!  Double precision version
      IMPLICIT REAL*8 (A-H,O-Z)

!  Subroutine arguments (given).
      INTEGER          IHES ! line identifier
      DOUBLE PRECISION TELOG ! log temperature
      DOUBLE PRECISION ELLOG ! log electron density
      INTEGER          MODE  ! 0 - no interpolation
                             ! 1 - linear interpolation in log Ne and log Te

!  Subroutine arguments (returned).
      DOUBLE PRECISION EWID  ! electron width (WE = fwhm / 2)
      DOUBLE PRECISION EDEL  ! line shift (A)


!  Local variables
      INTEGER          IEL   ! pointer for Ne
      INTEGER          ITT   ! pointer for T
      INTEGER          LID   ! last IHES
      REAL             SEL   ! log Ne
      REAL             STT   ! log T
      DOUBLE PRECISION LEL   ! last Ne
      DOUBLE PRECISION LTT   ! last T
      SAVE             LEL, LTT, LID
      SAVE             IEL, ITT
      REAL             TABEL(KEL)
      REAL             TABTE(KTE)
      REAL             SWID
      REAL             SDEL


      REAL        XX(2), YY(2) ! temporary variables for interpolation

      DATA LID / 0 /, LEL / 0 /, LTT / 0 /
!.

      SEL = ELLOG
      STT = TELOG

!  Evaluate widths at constant T,Ne
      IF ( MODE .EQ. 0 ) THEN
        SEL = 15.
        STT = 4.301
      
!  Prevent extrapolation
      ELSE
        SEL = MIN( MAX( SEL,ELHES(1,IHES) ), ELHES(NDHES(IHES),IHES) )
        STT = MIN( MAX( STT,TEHES(1,IHES) ), TEHES(NTHES(IHES),IHES) )
      ENDIF

!  Check T and Ne for interpolation
      IF ( ABS(STT-LTT)+ABS(SEL-LEL)+ABS(IHES-LID) .GT. 0.001 ) 
     :THEN
        CALL LOCATE (ELHES(1:KEL,IHES), NDHES(IHES), SEL*1.001, IEL)
        CALL LOCATE (TEHES(1:KTE,IHES), NTHES(IHES), STT*1.001, ITT)
        LEL = ELLOG
        LTT = TELOG
        LID = IHES
      ENDIF

 
!  Use default value without interpolation
      IF ( MODE .EQ. 0 ) THEN
        EWID = EWIDHES(ITT,IEL,IHES)
        EDEL = EDELHES(ITT,IEL,IHES)

!  Use linear interpolation
      ELSE


        XX(1:2) = ELHES(IEL:IEL+1,IHES)
        ITT = MIN(ITT,KTE-1)

        CALL LININT ( TEHES(ITT,IHES),TEHES(ITT+1,IHES),
     :              EWIDHES(ITT,IEL,IHES),EWIDHES(ITT+1,IEL,IHES), 
     :              STT, YY(1) )
        CALL LININT ( TEHES(ITT,IHES),TEHES(ITT+1,IHES),
     :              EWIDHES(ITT,IEL+1,IHES),EWIDHES(ITT+1,IEL+1,IHES), 
     :              STT, YY(2) )

        CALL LININT ( XX(1), XX(2), YY(1), YY(2), SEL, SWID )

        CALL LININT ( TEHES(ITT,IHES),TEHES(ITT+1,IHES),
     :              EDELHES(ITT,IEL,IHES),EDELHES(ITT+1,IEL,IHES), 
     :              STT, YY(1) )
        CALL LININT ( TEHES(ITT,IHES),TEHES(ITT+1,IHES),
     :              EDELHES(ITT,IEL+1,IHES),EDELHES(ITT+1,IEL+1,IHES), 
     :              STT, YY(2) )
        CALL LININT ( XX(1), XX(2), YY(1), YY(2), SEL, SDEL )

        EWID = SWID
        EDEL = SDEL

      ENDIF


      END



