SUBROUTINE INTEG_PLANCK

  !+
  !
  !=      Calculates the surface fluxes and the continuum optical depths
  !       where the line optical depth is approximately unity.
  !       Assumes Planck function for a source function
  !
  !       Modified by pld 17/06/01 to allow for variable continuum
  !       opacity in synthesis calculations using the formulation
  !       in integ_feaut but with the specific intensity calculations
  !       stripped out 
  !-

  !  Global variables
  USE SPC_GLOBAL

  !  Double precision version
  IMPLICIT REAL*8 (A-H,O-Z)

  !  Local arrays
  DOUBLE PRECISION WC, FC, FC2
  DIMENSION WC(KW),FC(KW),FC2(KW)

  DIMENSION OPC(KD),OPL(KD),TAUNEW(KD)

  !  Local temp variables for opacity interface (real)
  INTEGER  :: JD      ! Depth index
  INTEGER  :: IWL     ! OP Wavelenth index
  REAL     :: TTJ     ! Gas temperature
  REAL     :: PGJ     ! Gas pressure
  REAL     :: PEJ     ! Electron pressure
  REAL     :: WCJ     ! Wavelength
  REAL     :: CAPJ    ! bf+ff opacity
  REAL     :: SIGJ    ! e-s opacity

  !  Wavelength interval for continuum calculations
  DATA WCINT/10.0/

  !  Preset previous values
  DATA NDEPTP/0/,TEMPP/.0/,PGP/.0/,AHEP/10./,RLAMP/-1./

  !.     
  !  Single line integration
  IF (NMODE.NE.10.AND.NMODE.NE.11) THEN

        !  Recalculate continuous opacity, optical depth scale and flux
        WCJ=RLAMB

        !    Cycle over depth points
        DO  J=1,NDEPTH

           !     Calculate opacity
           TTJ=TEMP(J)
           PGJ=PG(J)
           PEJ=PE(J)
           OPC(J)=OPAC(TTJ,PGJ,PEJ,WCJ,CAPJ,SIGJ,J,NOPTYP,1)

           !     Calculate optical depth
           IF ( J == 1 ) TAUNEW(1)=TAU(1)
           IF ( J >  1 ) TAUNEW(J)=TAUNEW(J-1)+0.5*(TAU(J)-TAU(J-1))* &
                (OPC(J-1)/OP(J-1)+OPC(J)/OP(J))

        ENDDO


        !     Calculate continuum flux
        CONFL=SFLUX(TAUNEW,TEMP,RLAMB,NDEPTH)

     !  Check for continuum only calculation
     IF (NW == 0) RETURN


     !  Line optical depth scale calculated assuming 
     !  constant continuous opacity

     !   Cycle over wavelength
     DO I=1,NW
        TAUNEW(1)=TAU(1)
        DO J=2,NDEPTH


           !      Calculate line plus continuum optical depth
           TAUNEW(J)=TAUNEW(J-1)+0.5*(TAU(J)-TAU(J-1))* &
                ((RLMU(I,J)+OPC(J))/OP(J)+ &
                         (RLMU(I,J-1)+OPC(J-1))/OP(J-1))


           !      Calculate continuum optical depth where line optical depth is unity
           IF(TAUNEW(J) > 1.0.AND.TAUNEW(J-1) < 1.0) THEN

              TAUL(I)=TAU(J-1)+(TAU(J)-TAU(J-1))* &
                   (1.-TAUNEW(J-1))/(TAUNEW(J)-TAUNEW(J-1))
           ENDIF
!!!         write (*,'(2i3,1p5e10.2)') 
!!!     :           i,j,rlamb,rlmu(i,j),opc(j),op(j),taunew(j)
        ENDDO


        !  Calculates line fluxes
        FLUX(I)=SFLUX(TAUNEW,TEMP,RLAMB,NDEPTH)
     ENDDO


     !  Synthetic spectrum      
  ELSE

     !    CONTINUUM FLUXES

     !    Set up 
     NWC   = (W(NW)-W(1)) / WCINT + 1
     DWC   = (W(NW)-W(1)) / FLOAT(NWC - 1)

     !    Cycle over wavelengths
     DO IC = 1,NWC

        WC(IC) = W(1) + (IC-1) * DWC
        WCJ=WC(IC)

        !    Cycle over depth points
        DO  J=1,NDEPTH

           !     Calculate opacity
           TTJ=TEMP(J)
           PGJ=PG(J)
           PEJ=PE(J)
           OPC(J)=OPAC(TTJ,PGJ,PEJ,WCJ,CAPJ,SIGJ,J,NOPTYP,IC)

           !     Calculate optical depth
           IF ( J == 1 ) TAUNEW(1)=TAU(1)
           IF ( J >  1 ) TAUNEW(J)=TAUNEW(J-1)+0.5*(TAU(J)-TAU(J-1))* &
                (OPC(J-1)/OP(J-1)+OPC(J)/OP(J))

        ENDDO

        !     Calculate continuum flux
        CONFL=SFLUX(TAUNEW,TEMP,WC(IC),NDEPTH)

        !       Store continuum fluxes (and intensities)
        FC(IC) = CONFL

     ENDDO

     CALL NR_D_SPLINE (WC,FC,NWC,2.d30,2.d30,FC2)
     DO I = 1,NW
        CALL NR_D_SPLINT (WC,FC,FC2,NWC,W(I),FLUXC(I))
     ENDDO

     !     LINE FLUXES

     !   Cycle over wavelength
     DO I=1,NW
        WCJ=W(I)

        DO J=1,NDEPTH

           TTJ=TEMP(J)
           PGJ=PG(J)
           PEJ=PE(J)
           OPC(J)=OPAC(TTJ,PGJ,PEJ,WCJ,CAPJ,SIGJ,J,NOPTYP,IC)
           OPL(J) = RLMU(I,J)

           !      Calculate line plus continuum optical depth
           IF ( J == 1 ) TAUNEW(1)=TAU(1)
           IF ( J >  1 ) TAUNEW(J)=TAUNEW(J-1)+0.5*(TAU(J)-TAU(J-1))* &
                ((OPL(J)+OPC(J))/OP(J)+ &
                (OPL(J-1)+OPC(J-1))/OP(J-1))


           !      Calculate continuum optical depth where line optical depth is unity
           IF (TAUNEW(J) > 1.0.AND.TAUNEW(J-1) < 1.0) THEN
              TAUL(I)=TAU(J-1)+(TAU(J)-TAU(J-1))* &
                   (1.-TAUNEW(J-1))/(TAUNEW(J)-TAUNEW(J-1))
           ENDIF

        ENDDO

        !  Calculates line fluxes
        FLUX(I)=SFLUX(TAUNEW,TEMP,W(I),NDEPTH)
     ENDDO

  ENDIF

END SUBROUTINE INTEG_PLANCK
