SUBROUTINE LHI

  !+
  !
  !=      Calculates hydrogen line opacity
  !
  !       Bugs:
  !       Code allows for convolution with microturbulent velocity 
  !       but does not appear to be working correctly. OK for vturb = 0.0
  !-

!    Public constants
      USE SPC_CONSTANTS

!  Global variables
      USE SPC_GLOBAL
      USE SPC_VCSDATA      !! VCS tables

  !  Double precision version
  IMPLICIT REAL*8 (A-H,O-Z)

  !  Arrays and variables for Gauss-Hermite integration
  INTEGER, PARAMETER :: NGH=16
  DOUBLE PRECISION, DIMENSION(NGH), SAVE ::  GHX, GHW
  LOGICAL, SAVE   :: NOBBF = .TRUE.

  !  Arrays and worskspace for cubic spline interpolation
  !  NHM is the maximum number of wavelength points in the
  !  (symmetric) hydrogen line profile (see WAVEG).
  PARAMETER        (NHM=100)
  DOUBLE PRECISION  SWAV,       SABS,       SKNOTS
  DIMENSION         SWAV(NHM),  SABS(NHM),  SKNOTS(NHM)
  DOUBLE PRECISION  BOUND
  PARAMETER        (BOUND=2D+30)

  !  Other local variables.
  DOUBLE PRECISION   RL, PHIRL

  !  Other data
  DOUBLE PRECISION, PARAMETER ::  RTPI = 1.772453850905516D0

  DOUBLE PRECISION :: CLAM2 ! c. lambda^2 in appropriate units
  DOUBLE PRECISION :: XABUND ! scaled abundance (alpha/mu)

  !.

  !  Load quadrature weights for convolution integral
  IF (NOBBF) THEN
     NG = NGH
     CALL NR_D_GAUHER (GHX,GHW,NG)        
     NOBBF = .FALSE.
  ENDIF

  !  Calculates constant in line opacity 
  CLAM2 = CLOPAC*RLAMB*RLAMB
  XABUND = ABUND/AMU

  !  Identify hydrogen line
  CALL LHI_ID (RLAMB,NLOW,NUP)

  !  Cycle over depth
  DO I=1,NDEPTH

     !      Extract abundances
     IF (QUB__QSTRAT(NSP)) XABUND = QUB__ABSTRAT(NSP,I)/QUB__AMU(I)

     !  Doppler width due to microturbulence (depth-dependent)
     DOPP = RLAMB * QUB__VTRB(I) * SQRT(CDOPPV)

     !    Boltzmann equation
     U_K = TAP_PARFN ( 1,0,TEMP(I),PE(I)/10. )
     FEX=GH(NLOW)*FH(NUP-NLOW,NLOW)/U_K*EXP(-CEVTOT*EH(NLOW)/TEMP(I))

     !    Ionization equilibria
     U_J = TAP_PARFN ( 1,1,TEMP(I),PE(I)/10. )
     BT = CSAHAE*(TEMP(I)**2.5)/PE(I)
     EQUIL = BT*U_J/U_K*EXP(-CEVTOT*CHYDEV/TEMP(I))

     !    FION is the CONST*(fractional population of the lower level)
     !                        *(stimulated emission correction)
     FION=CLAM2*XABUND*FEX*(1.0-EXP(-CSTIME/(TEMP(I)*RLAMB)))/(1.0+EQUIL)

     !    Call subroutine to calculate normalised hydrogen opacity
     CALL HSTARK(TEMP(I),PE(I),NLOW,NUP)


     IF(BUGLN) THEN
        WRITE (NDEBUG,902) I,FION,WORK(1:NW:3)
        WRITE (NDEBUG,*) 'clam2,xabund,fex,equil: ',clam2,xabund,fex,equil
        WRITE (NDEBUG,*) 'bt,u_j,u_k,dopp,abund,amu: ',bt,u_j,u_k,dopp,abund,amu
        IF (QUB__QSTRAT(NSP)) WRITE (NDEBUG,*) 'qub__abstrat, qub__amu: ', QUB__ABSTRAT(NSP,I), QUB__AMU(I)
     ENDIF


     !    Calculate opacity   
     !    . no microturbulence*
     IF (VT.LT.0.1) THEN
        RLMU(1:NW,I)=FION*WORK(1:NW)


        !    . including microturbulence 
     ELSE

        !    .extend the wavelength range
        !     so that the spline interpolation works properly
        SWAV(1) = -W(NW) - 10.
        SWAV(2) = -W(NW) - 5.
        SWAV(3) = -W(NW) - 1.
        DO J = 1,NW
           SWAV(NW+4-J) = -W(J)
           SWAV(NW+2+J) =  W(J)
        ENDDO
        SWAV(2*NW+3) = W(NW) + 1.
        SWAV(2*NW+4) = W(NW) + 5.
        SWAV(2*NW+5) = W(NW) + 10.

        SABS(1) = WORK(NW) 
        SABS(2) = WORK(NW) 
        SABS(3) = WORK(NW) 
        DO J = 1,NW
           SABS(NW+4-J) =  WORK(J)
           SABS(NW+2+J) =  WORK(J)
        ENDDO
        SABS(2*NW+3) = WORK(NW)
        SABS(2*NW+4) = WORK(NW)
        SABS(2*NW+5) = WORK(NW)

        MW = 2*NW+5

        !      .setup coefficients for cubic spline interpolation
        CALL NR_D_SPLINE (SWAV, SABS, MW, BOUND, BOUND, SKNOTS)

        DO J=1,NW
           PHI=0.0
           !       .the following loop is executed NDEPTH * NW * NGH times per profile
           !        typically, this may be 40 * 35 * 16 = 22,400 !!!!
           DO N=1,NGH

              !         .interpolate in profile using cubic spline
              RL = W(J) + DOPP*GHX(N)
              CALL NR_D_SPLINT (SWAV, SABS, SKNOTS, MW, RL, PHIRL) 

              !         .increment Gauss-Hermite quadrature
              PHI=PHI + GHW(N)*PHIRL

              IF(BUGLN) THEN
                 WRITE (6,900) GHX(N),RL,PHIRL,GHW(N),PHI
              ENDIF

           ENDDO

           !       .ensure integral is positive 
           !       ( the above spline intrpolation fails at very low densities 
           !         when the line profile is almost a delta function )
           !       .multiply by ionisation fraction and normalise
           !       .normalisation with respect to root pi

           PHI = MAX ( 0.D0, PHI )
           RLMU(J,I)=FION*PHI/RTPI

        ENDDO


     ENDIF

     !     Debug output
     IF(BUGLN) THEN
        WRITE (NDEBUG,901) (RLMU(J,I),J=1,NW,3)
     ENDIF

  ENDDO

  RLAMBP=RLAMB



  !  Format statements
900 FORMAT (' ***** LHI ***** X, RL, PHIL, W, PHI', 1P,5E10.3)
901 FORMAT (' ***** LHI ***** RLMU',/1P,10E8.1/10E8.1)
902 FORMAT (' ***** LHI ***** I,FION,WORK',I3,1P,E10.3/10E8.1/10E8.1)
END SUBROUTINE LHI
