      SUBROUTINE LHI_ID (RLAMB, NLOW, NUP)
!+
!
!  Purpose.
!=     Identifies hydrogen line
!
!  Description.
!      Identifies upper and lower quantum numbers for H 
!      line of a given wavelength, providing the atomic
!      data for this line are given in the VCS broadening
!      tables used by SPECTRUM.
!
!
!  Arguments.
!    Input.
!      RLAMB        wavelength of hydrogen line
!
!    Returned.
!      NLOW         quantum number of lower level
!      NUP          quantum number of upper level
!-

!  Global variables
      USE SPC_VCSDATA      !! VCS tables

!  Double precision version
      IMPLICIT REAL*8 (A-H,O-Z)

!.


!  Identify series
      NLOW = 0
      DO I=3,1,-1
         IF (RLAMB.LE.WH(1,I)*1.1) NLOW = I
      ENDDO

!  Series not found ?
      IF (NLOW.EQ.0) THEN
         WRITE(6,200) RLAMB, (WH(1,I),I=1,3)
         RETURN
      ENDIF

!  Identify line
      NUP = NLOW 
      W2 = WH(1,NLOW)+(WH(1,NLOW)-WH(2,NLOW))/2
      DO I=1,NH(NLOW)
        W1 = W2 
        W2 = WH(I,NLOW)-(WH(I,NLOW)-WH(I+1,NLOW))/2 
        IF (W1.GT.RLAMB .AND. RLAMB.GT.W2) NUP = NLOW+I
      ENDDO

!  Line not found ?
      IF (NUP.EQ.NLOW) THEN
         WRITE(6,200) RLAMB, 0.,0.,0.
!  Check line wavelength given is accurate
      ELSEIF (ABS(RLAMB-WH(NUP-NLOW,NLOW)).GT.1.0) THEN
         WRITE(6,200) RLAMB, WH(NUP-NLOW,NLOW),0.,0.

      ENDIF


!  Format statements
  200 FORMAT (' ***** WRONG VALUE OF RLAMB IN LHI',E14.4/
     :          3F10.2/
     :        ' ***** ATTEMPTING TO CONTINUE *****')

      END
