      SUBROUTINE OPAQUB (TEMP,PG,PE,RLAMB,OPAC,CAP,SIG,JD)

!+
!     =      Main function to calculate opacity
!     
!     
!     Double precision version
!-

!     Public constants
      USE SPC_CONSTANTS

!     Global variables
      USE SPC_GLOBAL, ONLY : NMODE
      USE SPC_GLOBAL, ONLY : ALPHA, AMU
      USE SPC_GLOBAL, ONLY : RION
      USE OP_GLOBAL, ONLY : OP_XUU

!     Implicity typing     
      IMPLICIT REAL*8 (A-H,O-Z)

!  Input Arguments:
      REAL, INTENT(IN) :: TEMP  ! Temperature (K)
      REAL, INTENT(IN) :: PG    ! Gas pressure (cgs)
      REAL, INTENT(IN) :: PE    ! Electron pressure (cgs)
      REAL, INTENT(IN) :: RLAMB ! Wavelength (A)
      INTEGER, INTENT(IN) :: JD ! Depth index

!  Subroutine Arguments (Returned).
      REAL, INTENT(OUT) :: OPAC
      REAL, INTENT(OUT) :: CAP
      REAL, INTENT(OUT) :: SIG

!   Local composition
      REAL :: AH, AHE, AMG, ASI

!   Local variables passed to AVMET
      REAL :: THETA
      REAL :: FREQ
      REAL :: FSI
      REAL :: FMG

!     Initialize previous values of temperature and pressure
      DOUBLE PRECISION, SAVE :: TEMPP = 0.
      DOUBLE PRECISION, SAVE :: PGP = 0.

!     Partition functions for H and He
      DOUBLE PRECISION, DIMENSION(2) :: ZH  = (/ 2., 1. /)
      DOUBLE PRECISION, DIMENSION(3) :: ZHE = (/ 1., 2., 1. /)
      DOUBLE PRECISION, DIMENSION(4) :: RAT

!.


!     Re-initialize opacity
      CAP=.0
      SIG=.0

!     Composition
      AH  = ALPHA( 1)
      AHE = ALPHA( 2)
      AMG = ALPHA(12)
      ASI = ALPHA(16)


!     Thomson scattering by electrons
      SIG = CELSCT*(CNUMBM/AMU)*(PE/(PG-PE))


!     Number of hydrogen and helium atoms per unit mass
      RH= CNUMBM*AH /AMU
      RHE=CNUMBM*AHE/AMU


!     Stimulated emission factor
      ST=(1.-EXP(-CSTIME/(RLAMB*TEMP)))


!     Check for same temperature and pressure
      IF(TEMP.NE.TEMPP.OR.PG.NE.PGP) THEN
         

!     Recalculate Ionization equilibria
         A=CSAHAE*(TEMP**2.5)*(ZH(2)/ZH(1))  *EXP(-157800./TEMP)/PE
         B=CSAHAE*(TEMP**2.5)*(ZHE(2)/ZHE(1))*EXP(-285300./TEMP)/PE
         C=CSAHAE*(TEMP**2.5)*(ZHE(3)/ZHE(2))*EXP(-631411./TEMP)/PE
         
         FHI=  1.0/(1.0+A)
         FHEI= 1.0/(1.0+B+B*C)
         FHEII=B  /(1.0+B+B*C)


!     FMG, FSI fractional abundances of neutral magnesium and silicon
!     relative to hydrogen
         CONST=CSAHAE*(TEMP**2.5)/PE
         DO J=1,3
            RAT(J)=CONST*EXP(-CEVTOT*RION(J,12)/TEMP)*
     *           OP_XUU(J+1,12,JD)/OP_XUU(J,12,JD)
         ENDDO
         FMG=AMG/(1.+RAT(1)*(1.+RAT(2)*(1.+RAT(3))))

         DO J=1,3
            RAT(J)=CONST*EXP(-CEVTOT*RION(J,14)/TEMP)*
     *           OP_XUU(J+1,14,JD)/OP_XUU(J,14,JD)
         ENDDO
         FSI=ASI/(1.+RAT(1)*(1.+RAT(2)*(1.+RAT(3))))
      ENDIF


!     Calculate absorption coefficient

!     Include stimulated emission if necessary


!     Only include hydrogen and helium wing opacities
!     for isolated lines
      IF(NMODE.EQ.10.OR.NMODE.EQ.11) THEN
         CAP=RHE*FHEI*(OPHEM(TEMP,PE,RLAMB)
     *        +OPHEI(TEMP,PE,RLAMB)*ST)
     *        +RH *FHI *(OPHM(TEMP,PE,RLAMB)
     *        +OPHI(TEMP,PE,RLAMB)*ST)
     *        +RHE*FHEII*OPHEII(TEMP,PE,RLAMB)*ST
      ELSE
         CAP=RHE*FHEI*(OPHEM(TEMP,PE,RLAMB)
     *        +OPHEI(TEMP,PE,RLAMB)*ST
     *        +OPHEL(TEMP,PE,RLAMB)*ST)
     *        +RH *FHI *(OPHM(TEMP,PE,RLAMB)
     *        +OPHI(TEMP,PE,RLAMB)*ST
     *        +OPHL(TEMP,PE,RLAMB)*ST)
     *        +RHE*FHEII*OPHEII(TEMP,PE,RLAMB)*ST
      ENDIF

!     Magnesium and silicon opacities
      THETA=5040./TEMP
      FREQ=3.E18/RLAMB
      CAP=CAP+6.E-3/(1.+4.*AHE)*AVMET(THETA,FREQ,FSI,FMG)

!     Re-initialize temperature and pressure
      TEMPP=TEMP
      PGP=PG

!     Set function value
      OPAC = CAP + SIG

!     AKHEM = RHE*FHEI*OPHEM(TEMP,PE,RLAMB)
!     AKHEI = RHE*FHEI*OPHEI(TEMP,PE,RLAMB)*ST
!     AKHEL = RHE*FHEI*OPHEL(TEMP,PE,RLAMB)*ST
!     AKHM  = RH*FHI*OPHM(TEMP,PE,RLAMB)
!     AKHI  = RH*FHI*OPHI(TEMP,PE,RLAMB)*ST
!     AKHL  = RH*FHI*OPHL(TEMP,PE,RLAMB)*ST
!     AKHEII = RHE*FHEII*OPHEII(TEMP,PE,RLAMB)*ST
!     AKAVM = 6.E-3/(1.+4.*AHE)*AVMET(THETA,FREQ,FSI,FMG)
!     
!     write (*,'(1p5e10.2)') temp,pg,cap,sig,opac
!     write (*,'(1p8e10.2)') 
!     :  fhi,rh*fhi,akhi+akhm,OPHI(TEMP,PE,RLAMB)
!     *  akhem,akhei,akhel,akhm,akhi,akhl,akheii,akavm

      END
