      SUBROUTINE OUTDIP

!+
!
!   outdip
!
!
!=  write output to DIPSO file (spectrum format 2)
!
!
!-

!  Global variables
      USE SPC_GLOBAL

!  Double precision version
      IMPLICIT REAL*8 (A-H,O-Z)

!  DIPSO single precision and character variables
      REAL WDIP(KW),FDIP(KW)

!  Abundances (maximum) for DIPSO Header
      REAL ABUSYL(KL)
      CHARACTER*79 HEADER(2)
      CHARACTER*18 dips_ext

!.


!  Check for DIPSO output
      IF(NMODE.GE.20) THEN
        RETURN
      ENDIF

!  Convert to single precision for DIPSO outtput
      IF(SYMM)THEN

!      Symmetric profile
        NDIP=2*NW-1

!      Negative and zero wavelengths
        DO I=1,NW
         IDIP=NW-I+1
         WDIP(I)=-W(IDIP)
         FDIP(I)=FLUXN(IDIP)
        ENDDO

!      Positive wavelengths
        DO I=NW+1,NDIP
         IDIP=I-NW+1
         WDIP(I)= W(IDIP)
         FDIP(I)=FLUXN(IDIP)
        ENDDO
      ELSE

!      Asymmetric profile
        NDIP=NW
        DO I=1,NW
         WDIP(I)= W(I)
         FDIP(I)=FLUXN(I)
        ENDDO
      ENDIF


!  Prepare header
      GRAVL=LOG10(GRAV)
      TEFFK=TEFF/1000.0
      IF(NMODE.EQ.0) THEN

!     Logarithmic abundance
        ABUNDL=LOG10(ABUND)+ANORM

        IF(NSP.EQ.0) THEN
          WRITE(HEADER(1),803)TEFFK,GRAVL,AHE,VT,RLAMB,EW
          WRITE(HEADER(2),801)

        ELSE
          WRITE(HEADER(1),800)TEFFK,GRAVL,AHE,ABUNDL,VT,RLAMB,EW
          WRITE(HEADER(2),801)

        ENDIF

      ELSEIF(NMODE.EQ.10.OR.NMODE.EQ.11) THEN

!     Logarithmic abundances
        DO I=1,NELSY
          IF(ABUSY(I).GT.0.0) THEN
            ABUSYL(I)=LOG10(ABUSY(I))+ANORM
          ENDIF
        ENDDO

!     Overwrite previous data
         WRITE(HEADER(1),803)TEFFK,GRAVL,AHE,VT,RLAMB,EW

!     Only first ten abundances output
        IF(NABSY.GT.10) THEN
          WRITE(HEADER(2),804)(ABUSYL(I),I=1,10)
        ELSE
          WRITE(HEADER(2),804)(ABUSYL(I),I=1,NABSY)
        ENDIF

      ENDIF

!  Debug output
      IF(BUGOT) THEN
       WRITE(NDEBUG,900)HEADER,NDIP,(WDIP(I),FDIP(I),I=1,NDIP)
      ENDIF

!  Write out profiles to stream NDIPSO
      OPEN(UNIT=NDIPSO,FILE=dips_ext(),FORM='FORMATTED',
     :     STATUS='UNKNOWN')
      CALL OUTSPC(WDIP,FDIP,NDIP,HEADER,1,NDIPSO)
      CLOSE(UNIT=NDIPSO)



!  Format statements

  800 FORMAT('T=',F4.1,1X,'G=',F4.2,1X,'HE=',F5.3,1X,
     *'AB=',F5.2,1X,'VT=',F4.1,1X,'WA=',F6.0,1X,'EW=',F6.3)
  801 FORMAT(80X)
  802 FORMAT(A79)
  803 FORMAT('T=',F4.1,1X,'G=',F4.2,1X,'HE=',F5.3,1X,
     *                'VT=',F4.1,1X,'WA=',F6.0,1X,'EW=',F6.3)
  804 FORMAT(' AB=',10F7.2)

!  Debug

  900 FORMAT(' ** OUTDIP **',5X,A79/18X,A79/18X,'NDIP=',I5/
     *18X,'WAVELENGTH AND FLUXES'/100(10F10.5/))

      END
