subroutine flxodf(newtemp_it,KEY_OPBF)

  !+
  !
  !      Calculates monochromatic and integrated flux and some 
  !      integrals for temperature correction
  !      includes opacity distribution functions
  !
  !-

  use lte_precisions
  use lte_wlgrid
  use lte_model

  use stn_parameters
  use stn_constants
  use stn_intgra
  use stn_fluxes
  use stn_odfdata

  implicit none

  integer, intent(in) :: newtemp_it

  character(len=12), intent(in) :: KEY_OPBF 

  integer :: i, k, j

  !  Local variables.

  real :: EN(ND)      ! Electron densities     ne(tau)
  real :: CAP(ND)
  real :: SIGM(ND)                                                 
  real :: OPA
  real :: FREQ

  !! debugging check:
  real(kind=qq), allocatable, dimension (:) :: tau_nu   ! local optical depth


  integer :: N, NSTEPS

  real(kind=qq) :: W 
  real :: STEPWT, SUMWT

  !!  External function declaration
  real, external :: FREWGT

  !! Allocate radiative arrays:

  allocate(BNU(ND))   
  allocate(SNU(ND))   
  allocate(JNU(ND))   
  allocate(FNU(ND))   

  allocate(FNUC(ND))  
  allocate(JNUC(ND))  
  allocate(FNUL(ND))  
  allocate(JNUL(ND))  

  allocate(CAC(ND))
  allocate(tau_nu(ND))

  !! Allocate interpolation coefficients (for LINOP)

  allocate(CO1(ND))
  allocate(CO2(ND))
  allocate(CO3(ND))
  allocate(CO4(ND))
  allocate(INEJ(ND))
  allocate(ITJ(ND))

  NU_REFWL = C / REFWL *  1.e+8 

  !  Calculate frequencies.      
  do i = LA,LL
     nu(i) = C / wl(i) * 1.e+8
  end do

  !  Initialize all variables and integrals      
  do k = 1,ND
     SIGM(k) = sig(k)
     B(k)    = 0.0
     FLX(k)  = 0.0
     TNS(k)  = 0.0
     KAPP(k) = 0.0
     KAPJ(k) = 0.0
     KAPF(k) = 0.0
     GRAD(k) = 0.0
  end do

  !  Boltzmann factors and electron densities.
  !  Thomson scattering.
  do k=1,ND         
     EN(k)    = P_e(k) / (BK * temp(k))
  end do

  !********************************
  !  Loop over frequencies
  do i = LA,LL
     W = FREWGT(i,nu,la,ll)
     FREQ = nu(i)

     !     Planck function.
     CALL BNUE(temp,FREQ,BNU,ND)
     !!*     to be tested....
     !!*       CALL RTF_BNU (temp,ND, nu(i),1, BNU,ND)

     !     Continuous opacities.
     DO k=1,ND
        kappa_nu(k)=0.0
        sig(k)   =0.0
        CAC(k) = 0.0
        OPA = 0.0
        CALL STN_OPAC (KEY_OPBF,k,i,temp(k),P_total(k),P_e(k),wl(i),OPA,CAC(k),sig(k))
     ENDDO

     !    Continuum source function (Feautrier)
     CALL FLX_FEAUT (nu(i),tau_nu,kappa_nu,JNUC)

     DO k=1,ND-1
        IF (tau_nu(k) .LT. 5.) THEN
           CALL RTF_PHI (tau_nu,k,FNUC(k))  
        ENDIF

        IF (tau_nu(k) .GE. 5. .OR. FNUC(k) .LT. 0.) THEN
           IF (k .GT. 1) THEN  
              FNUC(k) = 0.5*((BNU(k)-BNU(k-1))/(tau_nu(k)-tau_nu(k-1)) &
                   &  +(BNU(k+1)-BNU(k))/(tau_nu(k+1)-tau_nu(k)))*(4./3.)
           ELSE
              FNUC(1) = 0.5*(BNU(k)/tau_nu(k) &
                   & +(BNU(k+1)-BNU(k))/(tau_nu(k+1)-tau_nu(k)))*(4./3.)
           ENDIF
        ENDIF
     ENDDO
     FNUC(ND) = (BNU(ND)-BNU(ND-1))/(tau_nu(ND)-tau_nu(ND-1))*4./3.

     !     Include line opacities from odfs (ordered from low-to-high opacity).
     DO k=1,ND
        FNU(k)  = 0.
        JNU(k)  = 0.
     ENDDO

     SUMWT  = 0.
     NSTEPS = 10

     DO N=1,NSTEPS
        CALL LINOP(EN,FREQ,N,STEPWT,newtemp_it)
        DO k=1,ND
           kappa_nu(k)=MIN(kappa_nu(k),1.D9)
        ENDDO

        !           Line source function (Feautrier)
        CALL FLX_FEAUT (nu(i),tau_nu,kappa_nu,JNUL)

        DO k=1,ND-1
           IF (tau_nu(k) .LT. 5.) THEN
              CALL RTF_PHI (tau_nu, k, FNUL(k))
           ENDIF
           IF (tau_nu(k) .GE. 5. .OR. FNUL(k) .LT. 0.) THEN
              IF (k.GT.1) THEN
                 FNUL(k) = 0.5*((BNU(k)-BNU(k-1))/(tau_nu(k)-tau_nu(k-1)) &
                      & +(BNU(k+1)-BNU(k))/(tau_nu(k+1)-tau_nu(k)))*(4./3.)
              ELSE
                 FNUL(1) = 0.5*(BNU(1)/tau_nu(1) &
                      &  +(BNU(2)-BNU(1))/(tau_nu(2)-tau_nu(1)))*(4./3.)
              ENDIF
           ENDIF
        ENDDO
        FNUL(ND) = (BNU(ND)-BNU(ND-1))/(tau_nu(ND)-tau_nu(ND-1))*4./3.

        !         Frequency integration
        DO k=1,ND
           FNU(k)  = FNU(k) +                  FNUL(k) *STEPWT
           JNU(k)  = JNU(k) +                  JNUL(k) *STEPWT
           B(k)    = B(k)   + W*                BNU(k) *STEPWT
           FLX(k)  = FLX(k) + W*               FNUL(k) *STEPWT
           TNS(k)  = TNS(k) + W*               JNUL(k) *STEPWT
           CAP(k)  =             CAC(k)+kappa_nu(k)
           KAPP(k) = KAPP(k)+ W* CAP(k)        *BNU(k) *STEPWT
           KAPJ(k) = KAPJ(k)+ W* CAP(k)        *JNUL(k)*STEPWT
           KAPF(k) = KAPF(k)+ W*(CAP(k)+sig(k))*FNUL(k)*STEPWT
        ENDDO

        SUMWT = SUMWT + STEPWT
     ENDDO

     blk(i) = 1-(FNU(1)/FNUC(1))

     fnue(i) = FNU(1)


  end do


  !  end of frequency loop
  !***********************************

  DO k = 1,ND                                           
     GRAD(k)= PI/C/kappa(k)*KAPF(k)                                   
     sig(k) = SIGM(k)                                               
  ENDDO

  !! deallocate arrays:

  deallocate(BNU)   
  deallocate(SNU)   
  deallocate(JNU)   
  deallocate(FNU)   
  deallocate(FNUC)  
  deallocate(JNUC)  
  deallocate(FNUL)  
  deallocate(JNUL)  
  deallocate(CO1)
  deallocate(CO2)
  deallocate(CO3)
  deallocate(CO4)
  deallocate(INEJ)
  deallocate(ITJ)

  deallocate(CAC)
  deallocate(tau_nu)

contains

  subroutine flx_feaut (flx_nu,flx_tau,flx_kap,jnu)


    ! This subroutine provides an interface to the standard rtf_feaut 
    ! subroutine. It is required because this version of flxos uses a
    ! "real(kind=qq)" to define the variable precision, whilst "rtf" 
    ! assumes double precision throughout. 

    !  sb arguments
    REAL(KIND=QQ)               :: flx_nu
    REAL(KIND=QQ), DIMENSION(*) :: flx_tau,flx_kap,jnu

    !  local copies for interface to rtf

    !      INTEGER    nd                              ! declare atmosphere structure
    REAL*8                 :: nuzero
    REAL*8, DIMENSION(100) :: tauz, tt, pe, opz

    REAL*8                 :: fnu               ! declare opacities at freq
    REAL*8, DIMENSION(100) :: opc, ops, opl     ! for which solution reqd.

    REAL*8, DIMENSION(100) :: rnu, a, phi       ! function frequency structure

    REAL*8, DIMENSION(100) :: ss, jj, taunu                    ! output structures

    real*8, dimension(10)  :: XNU = 0.
    real*8, dimension(10)  :: XA = (/1.0,(0.0, i=2,10)/)
    real*8, dimension(10)  :: XPHI = (/1.0,(0.0,i=2,10)/)
    real*8, dimension(16)  :: XMU = 0.
    real*8, dimension(16)  :: XB = 0.

    integer :: NM = 4

    !   copy into local arrays for passing to rtf

    nuzero      = nu_refwl
    tauz(1:nd)  = tau(1:nd)
    tt(1:nd)    = temp(1:nd)
    pe(1:nd)    = p_e(1:nd)
    opz(1:nd)   = kappa(1:nd)
    fnu         = flx_nu
    opc(1:nd)   = cac(1:nd)
    ops(1:nd)   = sig(1:nd)
    opl(1:nd)   = kappa_nu(1:nd)


    CALL RTF_FEAUT ( nuzero, tauz, tt, pe, opz, nd, &
         fnu, opc, ops, opl, 1, &
         XNU, XA, XPHI, 1, &
         XMU, XB, NM, &
         taunu, ss, jj )

    !   copy back local arrays for passing to rtf


    tau_nu(1:nd) = taunu(1:nd)
    snu(1:nd) = ss(1:nd)
    jnu(1:nd) = jj(1:nd)

  end subroutine flx_feaut



  subroutine flx_phi  ( tau_nu, k, fnu )

! This subroutine provides an interface to the standard rtf_phi
! subroutine. It is required because this version of flxos uses a
! "real(kind=qq)" to define the variable precision, whilst "rtf" 
! assumes double precision throughout. 

    !  sb arguments
    REAL(KIND=QQ), DIMENSION(*) :: tau_nu
    INTEGER        :: k
    REAL(KIND=QQ)  :: fnu

    !  local definitions

    !    Import
    DOUBLE PRECISION t(100)                 ! t
    DOUBLE PRECISION f(100)                 ! f(t)
    INTEGER n                             ! dimension of f(t)
    DOUBLE PRECISION tau                  ! PHI evaluation 
    !    Export
    DOUBLE PRECISION phi                  ! PHI integral

    ! Convert variable types

    t(1:nd) = tau_nu(1:nd)
    f(1:nd) = snu(1:nd)
    tau     = tau_nu(k)

    CALL RTF_PHI ( t, f, nd, tau, phi  )

    fnu = phi

  end subroutine flx_phi


end subroutine flxodf
