  SUBROUTINE LINOP(EN,FREQ,N,STEPWT,newtemp_it)

!+
!
! Read odf on unit 10 (modified from Kurucz routine)
!
!-

      use lte_precisions
      use lte_wlgrid
      use lte_model
      use stn_parameters
      use stn_odfdata

      implicit none

! constants
      real(kind=rr), parameter :: TENLOG=2.30258509299405E0     
      real(kind=qq), parameter :: CLIGHT=2.99792458E17
      
! subroutine arguments
      real, intent(in) :: EN(ND)
      real, intent(in) :: FREQ
      real :: STEPWT
      integer, intent(in) :: N, newtemp_it

      integer :: J, IT, INE
      integer :: odf=10
      real :: XNELOG, TL, X, Y, WAVE 

! odf
      REAL  WLBEG, WLEND
      REAL  STEPS(9,29,10)
      DATA  WLBEG/1.E20/, WLEND/0.0/
      SAVE  WLBEG, WLEND

! grid data
      real :: TABT(29),TABNE(9)

! distribution function weights
      real :: WT(10)

! housekeeping
      integer :: ITEMP1 = 0

 !! allocate distribution function weights

      WT = (/ 1.66666666666666D-2, 3.333333333333333D-2, &
             &  5.0D-2, 1.D-1, 1.D-1, 1.D-1, 1.D-1, &
             &  1.66666666666666D-1, 1.66666666666666D-1, & 
             &  1.66666666666666D-1 /)
     
 !! allocate grid data

      TABT = (/3.48,3.52,3.56,3.60,3.64,3.68,3.72,3.76,3.80,3.84,3.88, &
       & 3.92,3.96,4.0,4.05,4.10,4.15,4.20,4.25,4.30,4.35,4.40,4.45,4.5, &
       & 4.6,4.7,4.8,4.9,5.0/)

      TABNE = (/17.,16.,15.,14.,13.,12.,11.,10.,9./)      
      
!.
!      open (unit=odf,file='osdata/odf6/dfbp00',status='old',form='unformatted')
!      open (unit=odf,file=ODF,status='old',form='unformatted')

! write(*,*) newtemp_it, ITEMP1

!   new iteration ?
      IF (newtemp_it .NE. ITEMP1) THEN
        ITEMP1=newtemp_it

!     for each depth point
        DO J=1,ND

!       locate position in grid
          TL=LOG10(temp(J))
          DO IT=2,29
           IF(TL .LT. TABT(IT))GO TO 11
          ENDDO
          IT=29
   11     XNELOG=LOG10(EN(J))
          DO INE=2,9
            IF(XNELOG .GT. TABNE(INE))GO TO 13
          ENDDO
          INE=9
   13     INEJ(J)=INE
          ITJ(J)=IT

!       find interpolation coefficients
          X=(TL-TABT(IT-1))/(TABT(IT)-TABT(IT-1))
          Y=(XNELOG-TABNE(INE-1))/(TABNE(INE)-TABNE(INE-1))
          CO1(J)=(1.-X)*(1.-Y)*TENLOG
          CO2(J)=(1.-X)*  Y   *TENLOG
          CO3(J)=  X   *(1.-Y)*TENLOG
          CO4(J)=  X   *  Y   *TENLOG
        ENDDO

!     start odf search at beginning of file
        REWIND odf
        WLEND=0.

      ENDIF

!   search odf file for wavelength (in nanometers)      
      WAVE=CLIGHT/FREQ
   21 IF (WAVE .LT. WLEND) GO TO 22
        READ(odf,END=999) WLBEG,WLEND,STEPS
        GO TO 21

!   compute line opacity
   22 STEPWT=WT(N)
      DO J=1,ND
        IT=ITJ(J)
        INE=INEJ(J)
        kappa_nu(J)=EXP(  CO1(J)*STEPS(INE-1,IT-1,N) &
                    & + CO2(J)*STEPS(INE,IT-1,N) &
                    & + CO3(J)*STEPS(INE-1,IT,N) &
                    & + CO4(J)*STEPS(INE,IT,N)     )
      ENDDO

! experimental test with capodf = 2*capodf to see effect of
! increasing line opacity artificially
!     DO J=1,ND
!       kappa_nu(J) = 2.0 * kappa_nu(J)
!     ENDDO


! normal exit      
!      close(odf)
      RETURN

! unexpected end of odf file      
999   STOP 'END of ODF FILE'

  END SUBROUTINE LINOP
