SUBROUTINE STN_OPAC (KEY_OPBF,JD,IW,TL,PGL,PEL,WLS,OP,KAP,SIG)

  !+
  !
  !  Name:
  !     STN_OPAC
  !
  !  Purpose:
  !     To front-end and select the required b-f opacity library
  !
  !  Language:
  !     Fortran 90
  !
  !  Input arguments:
  !     JD        Depth zone indicator
  !     IW        wavelength index (set to maxnw+1 or 0 for refwl)
  !     TL        Temperature (K)
  !     PGL       Gas pressure (dyn / cm^2)
  !     PEL       Electron pressure (dyn / cm^2)
  !     WLS       Wavelength (A)
  !
  !  Output arguments:
  !     OP        Total monochromatic opacity...
  !     KAP       ...continuous (bf & ff).
  !     SIG       ...electron scattering.
  !
  !  Authors:
  !     CSJ: C.S.Jeffery (Armagh)
  !
  !  History:
  !     18-May-1999 (CSJ): Original version 
  !     20-Jul-2007 (CSJ): Moved to F90
  !
  !-

  USE LTE_PRECISIONS

  !  Global typing.
  IMPLICIT NONE

  CHARACTER(LEN=12), INTENT(IN) :: KEY_OPBF 

  !  Macroscopic.
  INTEGER :: JD                   ! Depth zone indicator
  INTEGER :: IW                   ! Wavelength index
  REAL :: TL          ! Temperature
  REAL :: PGL         ! Gas pressure
  REAL :: PEL         ! Electron pressure
  REAL :: WLS         ! Wavelength (A)

  ! Opacities.
  REAL :: OP                      ! Total cont. + scat. opacity
  REAL :: KAP                     ! Total continuous opacity (bf & ff)
  REAL :: SIG                     ! Total scattering opacity


  !.

  IF (KEY_OPBF(1:2) == 'KI') THEN
     CALL OP_KIEL_FFBF (TL,PGL,PEL,WLS,OP,KAP,SIG,JD)
  ELSEIF (KEY_OPBF(1:2) == 'OP') THEN
     CALL OP_OP_FFBF (JD,IW,TL,PGL,PEL,WLS,OP,KAP,SIG)
  ENDIF

END SUBROUTINE STN_OPAC
