  SUBROUTINE STN_TEMKOR (T_NEW, DT_0, DELT, DELF, ERR, RMS) 

!+
!
!  Temperature correction after Unsoeld and Lucy
!
!  Untested..
!  a) KK (second moment flux) is not defined
!  b) eqns are couched in tau - frequency averagedoptical depth, not tau_4000
!     which is what is given.
!
!-

      USE LTE_MODEL
      USE OP_GLOBAL
      USE stn_parameters
      USE stn_switches
      USE stn_intgra
      USE stn_convergence
      USE TAPM_PAR, ONLY: TAPM__PI
      USE TAPP_PAR, ONLY: TAPP__S

!  Global typing.
      IMPLICIT NONE

!  Subroutine arguments.

!   input and output:
      REAL, INTENT(inout) :: DELT(ND)      ! Last temperature correction 
      REAL, INTENT(inout) :: DT_0(ND)

!   output:
      REAL, INTENT(out) :: t_new(ND)      ! new temperature
      REAL, INTENT(out) :: DELF(ND)      ! Eddington flux error (fractional)
      REAL, INTENT(out) :: ERR           ! Maximum error in flux
      REAL, INTENT(out) :: RMS           ! rms temperature correction

!  Local variables.

      INTEGER, PARAMETER :: NDMAX = 201

!    Loop counters
      INTEGER :: j,i             ! Depth in atmosphere

!    Fluxes and flux intrgrals
      REAL :: HTOT           ! Total Eddington Flux
      REAL :: HARG(NDMAX)    ! Integrand for integral of DELF

!    Temperature correction
      REAL :: DAMP           ! Damping coefficient
      REAL :: FKJ            ! Eddington approximation (??)

      REAL :: DF(NDMAX)         ! Flux error
      REAL :: DT(NDMAX)         ! New temperature correction

      REAL :: DAM_RE=0.25  ! Damping term for radiative equilibrium : eg 0.1
      REAL :: DAM_BC=0.25  ! Damping term for boundary condition : eg 0.1
      REAL :: DAM_FC=0.25  ! Damping term for flux constancy : eg 0.1
      REAL :: TAU_REF=1.   ! Reference point for applying exponential 
                           ! damping weights; decrease to shift the
                           ! action of the radiative term outwards.

!  Convergence characteristics
      REAL :: AMAXDT
      REAL :: AMAXDF
      INTEGER          ICONV         ! Inherited convergence 
!.

!   total flux
      HTOT   = TEFF**4 * TAPP__S*1.E3/TAPM__PI

!   starting values
      HARG(1) = 0.25 * KAPF(1)/kappa(1)* (FLX(1)-HTOT)/FLX(1)
      DELF(1) = 0.

!   ensure tau damping parameter is nonzero
      TAU_REF = MAX ( TAU_REF, 1.E-8 )

!   Loop through atmosphere
      DO j = 1,ND

!     compute opt. depth integral
         IF (j.LT.ND) THEN
           HARG(j+1) = 0.25 * KAPF(j+1)/kappa(j+1)*(FLX(j+1)-HTOT)/FLX(j+1)
           DELF(j+1) = DELF(j)+0.5*(HARG(j+1)+HARG(j))*(tau(j+1)-tau(j))
         ENDIF

!      compute correction
         DAMP  = MAX (0., MIN (EXP(-tau(j)/TAU_REF), 1. ) )  ! Dreizler correction factor
         FKJ   = 1./3. + 0.0768*EXP(-SQRT(tau(j)))   ! Eddington approx.

         DT(j) = ( DAMP * DAM_RE * ( KAPJ(j)/KAPP(j) - 1. ) &
                  & - (1. - DAMP) * KAPJ(j)/KAPP(j)/TNS(j) * &
                    &  ( DAM_BC * (FLX(1)-HTOT)/(FLX(1)/TNS(1)) + & 
                      &  DAM_FC * DELF(j)/FKJ ) )  

!      constrain correction
!      .. review this - see stn version 1
         IF (DELT(j) /= 0.) THEN 
            IF (DT(j)/DELT(j) < -0.5) DT(j) = (DT(j)+DELT(j))/2.
         ENDIF
         IF (DT(j).GE.0.025) DT(j) = 0.8*DT(j)
         IF (ABS(DT(j)) >= 0.05 .AND. LM > 1) THEN
!         IF (ABS(DT(j)).GE.0.05) THEN
            DT(j) = 0.2*ABS(DT(j))/DT(j)
!            DT(j) = 0.05*ABS(DT(j))/DT(j)
         ENDIF
         DT(J) = MAX(MIN(DT(J),0.1),-0.1)

!     apply correction
         t_new(j) = temp(j)*(1.+DT(j))

      ENDDO

!  Check flux constancy and convergence

        ERR = 0.0
        RMS = 0.0
        DO j = 1,ND       
           DELF(j) = (FLX(j)-HTOT)/FLX(j)      
           DELT(j) = t_new(j) - temp(j)         

           IF ( DT_0(j).NE.0.0 .AND. DELT(j)/DT_0(j).GT.0.& 
                & .AND. ABS(DELT(j)).GT..5*ABS(DT_0(j)) ) THEN
              DELT(j) = (DELT(j)+DT_0(j))/2.0         
              t_new(j) = temp(j) + DELT(j)     
           ENDIF

           IF(j.GT.2) ERR = MAX( ABS(DELF(j)), ERR ) ! neglect outer 2 layers for convergence
           DELT(j) = (t_new(j)-temp(j))/temp(j)
           DT_0(j) = DELT(j)
           IF(j.GT.2) RMS = RMS + DELT(j)*DELT(j)    ! 
        ENDDO       

        RMS = SQRT ( RMS / FLOAT(ND-1) ) 
        NIT = NIT+1
        CORREC(NIT) = RMS
        DELREC(NIT) = ERR


!  Convergence tests.
      ICONV = 0
      DF(1:ND) = ABS ( DELF )
      AMAXDF = MAXVAL ( DF(1:ND-2) ) 
      DT(1:ND) = ABS ( DELT )
      AMAXDT = MAXVAL ( DT(6:ND) * TEMP(6:ND) )


      ! maximum flux error < 1%
      IF     ( ERR   <= 0.001  .AND. AMAXDT <= 1. ) THEN
        ICONV = 4
      ! maximum flux error above last two layers < 1%
      ELSEIF ( AMAXDF <= 0.005  .AND. AMAXDT <= 1. ) THEN
        ICONV = 3
      ! rms temperature correction < .01%
      ELSEIF ( RMS    <= 0.00005 ) THEN
        ICONV = 2
      ! max temperature correction < 1K
      ELSEIF ( AMAXDT <= 1.     ) THEN
         ICONV = 1
      ENDIF
      WRITE (*,'(A,I3,3(A,2F9.5))') &
       ' TEMKOR', ICONV, ' |dF|, |dF_|  ',ERR*100., AMAXDF*100., &
                         ' <dT^2>, |dT| ',RMS, AMAXDT, &
                         ' dam_f, tau_r ',DAM_FC, LOG10(TAU_REF)


  END SUBROUTINE STN_TEMKOR                                                              
