SUBROUTINE TAP_ERMES ( TEXT, TEXLEN, STATUS )

!+
!  Name:
!     TAP_ERMES

!  Purpose:
!=    return an error message associated with a TAP status value.

!  Language:
!     Fortran 90

!  Invocation:
!     CALL TAP_ERMES( TEXT, TEXLEN, STATUS )

!  Description:
!     The TAP error codes provided in TAP_ERR are searched for the 
!     given status value. If successful, the error message text is 
!     returned. If unsuccessful, the standard SAE values in SAE_PAR 
!     are searched. If successful, an appropriate error message is 
!     returned. If unsuccessful, an error message to this effect is 
!     constructed, including the given status value, and returned.

!  Arguments:
!     TEXT = CHARACTER *  ( * ) (Returned)
!        The returned error message text.
!     TEXLEN = INTEGER (Returned)
!        The length of the returned error message text.
!     STATUS = INTEGER (Given)
!        The global status.

!  Authors:
!     PCTR: Paul Rees (STARLINK)
!     {enter_new_authors_here}

!  History:
!     11-JAN-1993 (PCTR):
!        Original version.
!     {enter_changes_here}

!  Bugs:
!     {note_any_bugs_here}

!-

!  Global Constants:
      USE  SAE_PAR               ! Standard SAE error codes
      USE  TAP_ERR               ! TAP error codes

!  Type Definitions:
      IMPLICIT NONE              ! No implicit typing

!  Arguments Returned:
      CHARACTER * ( * ) :: TEXT

      INTEGER :: TEXLEN

!  Status:
      INTEGER :: STATUS             ! Global status

!  Local Variables:
      INTEGER :: ISTAT              ! Local status
      INTEGER :: NCHAR              ! String length

      CHARACTER * ( 10 ) :: CSTAT   ! CHARACTER string for status

!.

!  Check through the known TAP error status values and deliver the
!  associated error message.
   IF ( STATUS .EQ. SAI__OK ) THEN
     TEXT = 'SAI__OK: OK status value given in call to TAP_ERMES.'
   ELSE IF ( STATUS .EQ. SAI__WARN ) THEN
     TEXT = 'SAI__WARN: Undefined warning status given in call to TAP_ERMES.'
   ELSE IF ( STATUS .EQ. SAI__ERROR ) THEN
     TEXT = 'SAI__ERROR: Undefined error status given in call to TAP_ERMES.'
   ELSE
     CALL CHR_ITOC( STATUS, CSTAT, NCHAR )
     TEXT = 'TAP_BADSTAT: Unknown status value: ' // CSTAT( : NCHAR ) // '.'
   END IF

   TEXLEN = LEN_TRIM( TEXT )

   END
