INTEGER FUNCTION TAP_ZELEM ( NAME )

!+
!  Name:
!     TAP_ZELEM

!  Purpose:
!=    Return the atomic number of an element.

!  Language:
!     Fortran 90

!  Invocation:
!     RESULT = TAP_ZELEM( NAME )

!  Description:
!     The atomic number ot element associated with the given name is
!     returned. Either the element name or its symbol may be given via
!     the NAME argument. If no element can be associated with the given
!     name or symbol, a value TAP__INULL is returned.

!  Arguments:
!     NAME = CHARACTER * ( * ) (Given)
!        The name or symbol of the element fo rwhich Z is required.

!  Returned Value:
!     TAP_ZELEM = INTEGER
!        The atomic number, Z, of the given element.

!  Authors:
!     PCTR: Paul Rees (STARLINK)
!     {enter_new_authors_here}

!  History:
!     14-JAN-1993 (PCTR):
!        Original version.
!     8-JAN-2002 (CSJ):
!        Converted to F90.
!     {enter_changes_here}

!  Bugs:
!     {note_any_bugs_here}

!-
      
!  Global Constants:
      USE SAE_PAR                ! Standard SAE constants
      USE TAP_PAR                ! TAP public constants

!  Global Variables:
      USE TAPC_CMN, ONLY : TACNAM, TACSYM     ! TAP chemical global data

!        TACNAM( TAP__NELEM ) = CHARACTER ( 12 ) (Given)
!           Table of element names.
!        TACSYM( TAP__NELEM ) = CHARACTER * ( 2 ) (Given)
!           Table of element symbols.

!  Type Definitions:
      IMPLICIT NONE              ! No implicit typing

!  Arguments Given:
      CHARACTER * ( * ) :: NAME

!  External References:
      LOGICAL :: CHR_SIMLR          ! Caseless string equality

!  Local Variables:
      INTEGER :: LENGTH             ! Length of NAME string
      INTEGER :: IZ                 ! Atomic number loop index

!.

!  Get the length of the given string.
      LENGTH = LEN_TRIM( NAME )

!  If the length of the name string is less than three characters,
!  assume it is an element symbol. Otherwise, assume it is an element
!  name.
      IF ( LENGTH .LT. 3 ) THEN

!     Loop to search through the element symbol table for a match.
         DO IZ = 1, TAP__NELEM
            IF ( CHR_SIMLR( NAME( : 2 ), TACSYM( IZ ) ) ) THEN

!           A symbol match has been found, so assign the returned value
!           and exit the loop.
               TAP_ZELEM = IZ
               GO TO 20
            END IF
         END DO

!     No symbol match has been found, so return a value of TAP__INULL.
         TAP_ZELEM = TAP__INULL
 20      CONTINUE
      ELSE

!     Loop to search through the element symbol table for a match.
         DO IZ = 1, TAP__NELEM
            IF ( CHR_SIMLR( NAME( : LENGTH ), TACNAM( IZ ) ) ) THEN

!           A name match has been found, so assign the returned value
!           and exit the loop.
               TAP_ZELEM = IZ
               GO TO 40
            END IF
          END DO

!     No name match has been found, so return a value of TAP__INULL.
         TAP_ZELEM = TAP__INULL
 40      CONTINUE
      END IF
      
      END FUNCTION TAP_ZELEM
