      SUBROUTINE ISRED (WAV,EBV,RED,A, R,LAW)  

!+
!
!  Program:
!     isred
!
!  Purpose:
!=    Compute reddening A_lambda given E(B-V) and R.
!
!  Language:
!     Fortran 90
! 
!  Reference:
!     Seaton M.J. 1979. MNRAS 187, 73P
!     Howarth I.D. 1983. MNRAS 
!
!  Authors:
!     C.S.Jeffery (CSJ) (Armagh Observatory)
!
!  History:
!     27-May-1999: CSJ
!        original version
!
!-

 
!  Subroutine arguments:
      REAL      :: WAV                       ! Wavelength (Angstroms) (given)
      REAL      :: EBV                       ! Extinction coefficient  E(B-V) (given)
      REAL      :: RED                       ! Total extinction (fraction) (returned)
      REAL      :: A                         ! Total extinction (mag) (returned)       
      REAL      :: R                         ! Total/Selective extinction Av/E(B-V)
      INTEGER   :: LAW                       ! law: >= 0 galactic; < 0 LMC)

!  Local variables:
      REAL      :: INVW                      ! Inverse wavelength (microns^-1)


!.


!  Inverse wavelength
      INVW = 1.0/(WAV*1.E-4)


!  UV/optical
      WL: IF (INVW>=1.83) THEN

!     LMC law
        LMC: IF (LAW<0) THEN

!       UV (H83) 2.75<X<10.0
           IF (INVW>=2.75) THEN
             BIGX = (INVW-4.557)**2 + 0.293
             BIGX = (0.105*INVW+0.462)*INVW+0.454/BIGX
             BIGX = R - 0.236 + BIGX

!       Optical (H83) 1.83<=X<=2.75
           ELSE
             BIGX = INVW - 1.83
             BIGX = R + (0.094*BIGX+2.04)*BIGX
           END IF

!     Galactic law
        ELSE

!       UV (S79) 7.14<=X<=10.0
           IF (INVW>7.14) THEN
             BIGX = ((0.2975*INVW-3.2)*INVW) + 16.17
             BIGX = BIGX + R - 3.2

!       UV (S79) 3.65<=X<=7.14
            ELSEIF (INVW>3.65) THEN
              BIGX = (INVW-4.60)**2 + 0.28
              BIGX = 2.29 + 0.848*INVW + 1.01/BIGX
              BIGX = BIGX + R - 3.2

!       UV (S79) 2.75<=X<=3.65
            ELSEIF (INVW>2.75) THEN
              BIGX = (INVW-4.60)**2 + 0.28
              BIGX = 1.56 + 1.048*INVW + 1.01/BIGX
              BIGX = BIGX + R - 3.2

!       Optical (H83) 1.83<=X<=2.75
            ELSE
               BIGX = INVW - 1.83
               BIGX = R + (2.56-0.993*BIGX)*BIGX
            END IF

        END IF LMC


!  Infrared (H83) 0.0<=X<=1.83
      ELSE
        IF (INVW>=0.0) THEN
           BIGX = ((1.86-0.48*INVW)*INVW-0.1)*INVW
           BIGX = BIGX*R/3.1
        ELSE
           WRITE (*,*) ' ISRED - illegal wavelength '
        ENDIF
      END IF WL 


!   Reddening coefficients
      A    = BIGX*EBV
      RED  = 10.0**(-0.4*BIGX*EBV)


      END SUBROUTINE ISRED
