      SUBROUTINE QD_TRAP_R  (X,Y,S,N1,N2, SUM,SUMS)

!+
!
!  Subroutine:
!     qd_trap
!         Real version
!
!  Purpose:
!     Compute quadrature over points n1:n2 in function y(x)
!     each having a standard error s(x).
!
!  Language:
!     Fortran 90
! 
!  Authors:
!     C.S.Jeffery (CSJ) (Armagh Observatory)
!
!  History:
!     01-Jun-1999: CSJ
!        original version
!
!-


!  Global typing.

      IMPLICIT NONE


!  Subroutine Arguments.

      REAL, DIMENSION(*)  ::  X     ! x values                   (given)
      REAL, DIMENSION(*)  ::  Y     ! y(x)                       (given)
      REAL, DIMENSION(*)  ::  S     ! s(x) standard deviations   (given)
      INTEGER             ::  N1    ! index of first and last  
      INTEGER             ::  N2    ! valid points in quadrature (given)

      REAL                ::  SUM   ! Quadrature sum             (returned)
      REAL                ::  SUMS  ! Error in quadrature sum    (returned)


!  Local variables.

      INTEGER             ::  N     ! Quadrature loop index
      REAL                ::  DX    ! Quadrature interval
      

!.

!  Initialize local sums
      SUM  = 0.
      SUMS = 0.

      QUAD: DO  N = N1,N2-1
         DX   = (X(N+1)-X(N))
         SUM  = SUM  + 0.5 * (Y(N)+Y(N+1)) * DX
         IF (Y(N)>0.)   SUMS = SUMS + 0.5*S(N)*S(N)*DX
         IF (Y(N+1)>0.) SUMS = SUMS + 0.5*S(N+1)*S(N+1)*DX
!        SUMS = SUMS + 0.5 * (S(N)*S(N) + S(N+1)*S(N+1)) * DX
      END DO QUAD

      SUMS = SQRT ( SUMS )

      END SUBROUTINE QD_TRAP_R



      SUBROUTINE QD_TRAP_D  (X,Y,S,N1,N2, SUM,SUMS)

!+
!
!  Subroutine:
!     qd_trap
!         Double precision version
!
!  Purpose:
!     Compute quadrature over points n1:n2 in function y(x)
!     each having a standard error s(x).
!
!  Language:
!     Fortran 90
! 
!  Authors:
!     C.S.Jeffery (CSJ) (Armagh Observatory)
!
!  History:
!     01-Jun-1999: CSJ
!        original version
!
!-

!  Global typing.

      IMPLICIT NONE


!  Subroutine Arguments.

      DOUBLE PRECISION, DIMENSION(*)  ::  X     ! x values                   (given)
      DOUBLE PRECISION, DIMENSION(*)  ::  Y     ! y(x)                       (given)
      DOUBLE PRECISION, DIMENSION(*)  ::  S     ! s(x) standard deviations   (given)
      INTEGER                         ::  N1    ! index of first and last  
      INTEGER                         ::  N2    ! valid points in quadrature (given)

      DOUBLE PRECISION                ::  SUM   ! Quadrature sum             (returned)
      DOUBLE PRECISION                ::  SUMS  ! Error in quadrature sum    (returned)


!  Local variables.

      INTEGER                         ::  N     ! Quadrature loop index
      DOUBLE PRECISION                ::  DX    ! Quadrature interval
      

!.

!  Initialize local sums
      SUM  = 0.
      SUMS = 0.

      QUAD: DO  N = N1,N2-1
         DX   = (X(N+1)-X(N))
         SUM  = SUM  + 0.5 * (Y(N)+Y(N+1)) * DX
         SUMS = SUMS + 0.5 * (S(N)*S(N) + S(N+1)*S(N+1)) * DX
      END DO QUAD

      SUMS = SQRT ( SUMS )

      END SUBROUTINE QD_TRAP_D
