MODULE SFIT_OBSDATA

!+
!
!  Module:
!     sfit_obsdata
!
!  Purpose:
!=    Holders for global variables containing the observed spectrum
!     to be fitted by programme SFIT
!
!  Language:
!     Fortran 90
! 
!  Authors:
!     C.S.Jeffery (CSJ) (Armagh Observatory)
!
!  History:
!     07-FEB-2000: CSJ
!        original version
!
!  Prerequisites:
!     Module XFIT_DIMS
!
!-


  USE XFIT_DIMS


!  Observed fluxes
  CHARACTER :: OBSFOLDER*256     ! folder containing observed spectra
  CHARACTER :: OBSFILE*256       ! filename for observed spectrum
  CHARACTER :: OBSTITLE*128      ! title for observed spectrum
  INTEGER   :: NWOBS             ! number of wavelengths in observation
  REAL      :: WOBS(NOMAX)       ! observed wavelengths
  REAL      :: FOBS(NOMAX)       ! observed fluxes
  REAL      :: SOBS(NOMAX)       ! weights or errors on fluxes
  
  REAL      :: SINST=0.0         ! Instrumental broadening (FWHM)
  REAL      :: DVSYSKM=0.0       ! Systemic velocity broadening (km/s)
  REAL      :: DVSYS=0.0         ! Systemic velocity broadening (A)
  REAL      :: CRTHRSH=1.E30     ! Cosmic ray threshold

  LOGICAL   :: FOBS_NORM=.TRUE.  ! Flag indicating status of data: 
                                 ! true if normalized 
                                 ! false if fluxed

  CHARACTER(LEN=20) :: WOBS_UNITS='Angstroms'  ! Units for wavelengths 
  CHARACTER(LEN=20) :: FOBS_UNITS='normalized' ! Units for fluxes
  REAL              :: FOBS_SCALE=1.0          ! Scaling factor for fluxes

!  Fitted spectrum
  REAL      :: FFIT(NOMAX)       ! fitted fluxes binned onto model grid
  REAL      :: FSIG(NOMAX)       ! weights or errors on fitted fluxes
  REAL      :: DFIT(NOMAX)       ! fit - obs differences
  REAL      :: CFIT(NOMAX)       ! fit to continuum

  REAL      :: FIT1(NOMAX)       ! fitted fluxes component 1
  REAL      :: FIT2(NOMAX)       ! fitted fluxes component 2
!.

END MODULE SFIT_OBSDATA
