SUBROUTINE SFIT_RDBIN  ( GRDFILE, &
     NWMAX,NTMAX,NGMAX,NHMAX, &
     NWMOD,NTMOD,NGMOD,NHMOD, &
     WMOD, TMOD, GMOD, HMOD, &
     FMOD, CMOD )

  !+
  !  Program:
  !     sfit_rdbin
  !
  !  Purpose:
  !=    Read a grid of model spectra from a binary file
  !
  !  Language:
  !     Fortran 90
  ! 
  !  Reference:
  !
  !  Authors:
  !     C.S.Jeffery (CSJ) (Armagh Observatory)
  !
  !  History:
  !     26-Oct-2001: CSJ
  !     23-Feb-2005: CSJ:  Removed AMOD
  !
  !-

  ! Implicit declaration
  IMPLICIT NONE


  ! Subroutine Arguments.
  CHARACTER :: GRDFILE*(*)        ! filename for model grid

  INTEGER   :: NWMAX             ! maximum number of wavelengths
  INTEGER   :: NTMAX             ! maximum number of temperatures
  INTEGER   :: NGMAX             ! maximum number of gravities
  INTEGER   :: NHMAX             ! maximum number of helium abundances 

  INTEGER   :: NWMOD             ! number of wavelengths
  INTEGER   :: NTMOD             ! number of temperatures 
  INTEGER   :: NGMOD             ! number of gravities
  INTEGER   :: NHMOD             ! number of helium abundances

  REAL      :: TMOD(NTMAX)       ! temperatures in grid
  REAL      :: GMOD(NGMAX)       ! gravities in grid
  REAL      :: HMOD(NHMAX)       ! helium abundances in grid
  REAL      :: WMOD(NWMAX)       ! wavelengths in model

  REAL      :: FMOD(NWMAX,NTMAX,NGMAX,NHMAX)  ! emergent fluxes
  REAL      :: CMOD(NWMAX,NTMAX,NGMAX,NHMAX)  ! continuum fluxes

  ! Temporary local arrays to aoid segmentation faults
  REAL, ALLOCATABLE :: FLOC(:)
  REAL, ALLOCATABLE :: CLOC(:)

  !  Loop counters
  INTEGER   :: NW                ! loop counter for wavelength
  INTEGER   :: NT                ! loop counter for temperature
  INTEGER   :: NG                ! loop counter for gravity
  INTEGER   :: NH                ! loop counter for helium abundance
  !. 


  !  Open binary file
  OPEN  (1,FILE=GRDFILE,STATUS='OLD',FORM='UNFORMATTED')

  !  Read grid dimensions
  READ  (1) NTMOD, NGMOD, NHMOD, NWMOD

  ! Check grid within limits
  IF (NTMOD>NTMAX .OR. NGMOD>NGMAX .OR. NHMOD>NHMAX .OR. NWMOD>NWMAX) THEN
    WRITE (*,'(A,I6,3I3)') &
         ' model grid exceeded : maximum dimensions:',NWMAX,NTMAX,NGMAX,NHMAX
    WRITE (*,'(A,I6,3I3)') &
         '                     : given dimensions:  ',NWMOD,NTMOD,NGMOD,NHMOD
    STOP
  ENDIF

  !  Read grid axes
  READ  (1) TMOD(1:NTMOD)
  READ  (1) GMOD(1:NGMOD)
  READ  (1) HMOD(1:NHMOD)
  READ  (1) WMOD(1:NWMOD)

  ALLOCATE ( FLOC(NWMOD), CLOC(NWMOD) )

  !  Reda grid data
  DO NH = 1,NHMOD 
    DO NG = 1,NGMOD
      DO NT = 1,NTMOD

        READ  (1) FLOC
        READ  (1) CLOC
        FMOD(1:NWMOD,NT,NG,NH) = FLOC
        CMOD(1:NWMOD,NT,NG,NH) = CLOC

      END DO
    END DO
  END DO

  DEALLOCATE ( FLOC, CLOC )

  !  Close binay file
  CLOSE (1)


  !  Report grid

  WRITE (*,'(/'' Model grid (from binary file):'')')
  WRITE (*,'(4x,''NMOD '',I5)') NTMOD*NGMOD*NHMOD
  WRITE (*,'(4x,''WMOD '',I5,'' ('',I5,'')'',10F10.2)') NWMOD,NWMAX,WMOD(1),WMOD(NWMOD)
  WRITE (*,'(4x,''TMOD '',I5,'' ('',I5,'')'',10F10.2,3(/10F10.2))') NTMOD,NTMAX,TMOD(1:NTMOD)
  WRITE (*,'(4x,''GMOD '',I5,'' ('',I5,'')'',10F10.2)') NGMOD,NGMAX,GMOD(1:NGMOD)
  WRITE (*,'(4x,''AMOD '',I5,'' ('',I5,'')'',2X,10F10.4)') NHMOD,NHMAX,HMOD(1:NHMOD)
  WRITE (*,*)

  WRITE (11,'(/'' Model grid (from binary file):'')')
  WRITE (11,'(4x,''NMOD '',I5)') NTMOD*NGMOD*NHMOD
  WRITE (11,'(4x,''WMOD '',I5,'' ('',I5,'')'',10F10.2)') NWMOD,NWMAX,WMOD(1),WMOD(NWMOD)
  WRITE (11,'(4x,''TMOD '',I5,'' ('',I5,'')'',10F10.2,3(/10F10.2))') NTMOD,NTMAX,TMOD(1:NTMOD)
  WRITE (11,'(4x,''GMOD '',I5,'' ('',I5,'')'',10F10.2)') NGMOD,NGMAX,GMOD(1:NGMOD)
  WRITE (11,'(4x,''AMOD '',I5,'' ('',I5,'')'',2X,10F10.4)') NHMOD,NHMAX,HMOD(1:NHMOD)
  WRITE (11,*)

END SUBROUTINE SFIT_RDBIN








