#include <stdlib.h>
#include "tetgen.h"

extern "C" void tetgen(double** points, int *npoints,
                       int** tetra, int *ntetra, int** neighbours) {
	tetgenio in, out;
	int i;

	/*
	 *Set up the tetgen input structure
     */
	in.numberofpoints = *npoints;
	in.pointlist      = *points;

	/*
	 *Perform the tetrahedralisation. Switch 'n'
	 * generates the neighbours list.
	 */
	tetrahedralize("n", &in, &out);

	/*
	 * Set up the return values by grabbing them
	 * from the tetgen output structure
	 */
	*ntetra     = out.numberoftetrahedra;
	*tetra      = (int *)malloc(*ntetra * 4 * sizeof(int));
	*neighbours = (int *)malloc(*ntetra * 4 * sizeof(int));

	/* 
	 * Manually copy over the tetrahedron corners and
	 * neighbours lists. The magic number 4 denotes that
	 * there are 4 corners (and 4 neighbours) per tetrahedron.
	 */
	for (i = 0; i < (4 * out.numberoftetrahedra); i++) {
		(*tetra)[i]      = out.tetrahedronlist[i];
		(*neighbours)[i] = out.neighborlist[i];
	}
}


extern "C" void tetgen_c_free(void** a) {
	free(*a);
}
