*
*       Checks a model by calculating the electron pressure
*       and opacity and comparing with tabulated values
*
      PROGRAM MOD_CHECK

*
*       Double precision version
*
      IMPLICIT REAL*8 (A-H,O-Z)

*
*       Common blocks
*
      INCLUDE 'LT_SOURCE:COMMON_ALL'

*
*       Input/output streams
*
      NWRITE=6
      NDISC=7
      NATOM=11
      NMODEL=20

*
*       Read in atomic data
*
      CALL ATDATA

*
*       Define number of model (large number) and number of depth points
*
      NMOD=999
      NDEPTH=25

*
*       Cycle over model atmospheres
*
      DO I=1,NMOD

*
*       Read in model atmosphere
*

        CALL MODEL_ATM

*
*       Check wavelength for continuous monochromatic absorption coefficient
*
        RLAMB = 5000.
        IF (NOPTYP.EQ.1) RLAMB = 4000.

*
*       Output atmospheric parameters
*
        WRITE(NWRITE,200)TEFF,GRAV,AHE
        WRITE(NDISC,200)TEFF,GRAV,AHE

        DO J=1,NDEPTH
          JDEPTH=J

*
*       Calculates electron pressure and opacity
*
          PENEW=ELPE(PG(J),TEMP(J),AHE,0.5*PG(J))
          OPNEW=OPAC(TEMP(J),PG(J),PE(J),RLAMB,CAP,SIG)

*
*       Calculates logarithmic differences
*
          PEDIFF=LOG10(PENEW/PE(J))
          OPDIFF=LOG10(OPNEW/OP(J))

*
*       Output comparison
*
          WRITE(NWRITE,201)TAU(J),TEMP(J),PG(J),PE(J),OP(J),
     *                     PEDIFF,OPDIFF
          WRITE(NDISC,201)TAU(J),TEMP(J),PG(J),PE(J),OP(J),
     *                    PEDIFF,OPDIFF

        ENDDO

*
*       New page on disc file
*
      WRITE(NDISC,203)

      ENDDO

      STOP

*
*       No more models
*
   10 WRITE(6,202)

      STOP

*
*       Format statements
*
  200 FORMAT(//6X,'TEFF=',F9.0,10X,'GRAV=',E10.3,10X,'N(HE)=',F8.3
     *//8X,' TAU',8X,'TEMP',10X,'PG',10X,'PE',10X,'OP',3X,'DEL PE',3X,
     *'DEL OP')
  201 FORMAT(1P5E12.4,0P2F9.3)
  202 FORMAT(///' ***** NO MORE MODELS *****')
  203 FORMAT('1')
      END

